//! More than 2500 icons, ready for use in your app!
//!
//! # Sources
//!
//! Icons are from
//!
//! + [icon-development-kit](https://gitlab.gnome.org/Teams/Design/icon-development-kit) ([CC0 license](https://gitlab.gnome.org/Teams/Design/icon-development-kit/-/blob/main/COPYING.md))
//! + [fluentui-system-icons](https://github.com/microsoft/fluentui-system-icons) ([MIT license](https://github.com/microsoft/fluentui-system-icons/blob/main/LICENSE))

#![doc(html_logo_url = "https://relm4.org/icons/relm4_logo.svg")]
#![doc(html_favicon_url = "https://relm4.org/icons/relm4_org.svg")]
#![warn(
    missing_debug_implementations,
    missing_docs,
    rust_2018_idioms,
    unreachable_pub,
    unused_qualifications,
    clippy::cargo,
    clippy::must_use_candidate
)]
#![allow(clippy::negative_feature_names)]
#![cfg_attr(docsrs, feature(doc_cfg))]

use gtk::{gdk, gio};

/// Initialized the icons and registers them globally for your application.
pub fn initialize_icons() {
    gio::resources_register_include!("resources.gresource").unwrap();

    let display = gdk::Display::default().unwrap();
    let theme = gtk::IconTheme::for_display(&display);
    theme.add_resource_path("/relm4/icons/");
}

#[cfg(all(test, feature = "arrow-circle-right-filled", feature = "work-week"))]
mod test {
    use super::*;

    #[test]
    fn test() {
        gtk::init().unwrap();

        initialize_icons();

        let display = gdk::Display::default().unwrap();
        let theme = gtk::IconTheme::for_display(&display);
        assert!(theme.has_icon("arrow-circle-right-filled-symbolic"));
        assert!(theme.has_icon("work-week-symbolic"));
    }
}

/// Module containing constants for icons names.
pub mod icon_name {
    // AUTOGENERATED - DO NOT EDIT

    #[cfg_attr(docsrs, doc(cfg(any(feature = "C", feature = "icon-development-kit"))))]
    #[cfg(any(feature = "C", feature = "icon-development-kit"))]
    /// Icon name constant for the `C` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/C-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const C: &str = "C";
    #[doc(alias = "about")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "about", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "about", feature = "icon-development-kit"))]
    /// Icon name constant for the `about` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/about-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ABOUT: &str = "about";
    #[doc(alias = "accessibility-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "accessibility-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "accessibility-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `accessibility-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/accessibility-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ACCESSIBILITY_FILLED: &str = "accessibility-filled";
    #[doc(alias = "accessibility-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "accessibility-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "accessibility-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `accessibility-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/accessibility-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ACCESSIBILITY_REGULAR: &str = "accessibility-regular";
    #[doc(alias = "add-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "add-circle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "add-circle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `add-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/add-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADD_CIRCLE_FILLED: &str = "add-circle-filled";
    #[doc(alias = "add-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "add-circle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "add-circle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `add-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/add-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADD_CIRCLE_REGULAR: &str = "add-circle-regular";
    #[doc(alias = "add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADD_FILLED: &str = "add-filled";
    #[doc(alias = "add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADD_REGULAR: &str = "add-regular";
    #[doc(alias = "add-square-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "add-square-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "add-square-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `add-square-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/add-square-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADD_SQUARE_FILLED: &str = "add-square-filled";
    #[doc(alias = "add-square-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "add-square-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "add-square-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `add-square-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/add-square-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADD_SQUARE_MULTIPLE_FILLED: &str = "add-square-multiple-filled";
    #[doc(alias = "add-square-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "add-square-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "add-square-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `add-square-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/add-square-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADD_SQUARE_MULTIPLE_REGULAR: &str = "add-square-multiple-regular";
    #[doc(alias = "add-square-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "add-square-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "add-square-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `add-square-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/add-square-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADD_SQUARE_REGULAR: &str = "add-square-regular";
    #[doc(alias = "add-subtract-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "add-subtract-circle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "add-subtract-circle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `add-subtract-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/add-subtract-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADD_SUBTRACT_CIRCLE_FILLED: &str = "add-subtract-circle-filled";
    #[doc(alias = "add-subtract-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "add-subtract-circle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "add-subtract-circle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `add-subtract-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/add-subtract-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADD_SUBTRACT_CIRCLE_REGULAR: &str = "add-subtract-circle-regular";
    #[doc(alias = "address-book")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "address-book", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "address-book", feature = "icon-development-kit"))]
    /// Icon name constant for the `address-book` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/address-book-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADDRESS_BOOK: &str = "address-book";
    #[doc(alias = "address-book-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "address-book-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "address-book-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `address-book-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/address-book-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ADDRESS_BOOK_ALT: &str = "address-book-alt";
    #[doc(alias = "airbrush-tool")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "airbrush-tool", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "airbrush-tool", feature = "icon-development-kit"))]
    /// Icon name constant for the `airbrush-tool` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/airbrush-tool-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AIRBRUSH_TOOL: &str = "airbrush-tool";
    #[doc(alias = "airplane-landing-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "airplane-landing-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "airplane-landing-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `airplane-landing-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/airplane-landing-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AIRPLANE_LANDING_FILLED: &str = "airplane-landing-filled";
    #[doc(alias = "airplane-landing-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "airplane-landing-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "airplane-landing-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `airplane-landing-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/airplane-landing-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AIRPLANE_LANDING_REGULAR: &str = "airplane-landing-regular";
    #[doc(alias = "airplane-take-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "airplane-take-off-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "airplane-take-off-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `airplane-take-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/airplane-take-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AIRPLANE_TAKE_OFF_FILLED: &str = "airplane-take-off-filled";
    #[doc(alias = "airplane-take-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "airplane-take-off-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "airplane-take-off-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `airplane-take-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/airplane-take-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AIRPLANE_TAKE_OFF_REGULAR: &str = "airplane-take-off-regular";
    #[doc(alias = "alarm")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "alarm", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "alarm", feature = "icon-development-kit"))]
    /// Icon name constant for the `alarm` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/alarm-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALARM: &str = "alarm";
    #[doc(alias = "alert-badge-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "alert-badge-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "alert-badge-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `alert-badge-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/alert-badge-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALERT_BADGE_FILLED: &str = "alert-badge-filled";
    #[doc(alias = "alert-badge-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "alert-badge-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "alert-badge-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `alert-badge-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/alert-badge-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALERT_BADGE_REGULAR: &str = "alert-badge-regular";
    #[doc(alias = "alert-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "alert-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "alert-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `alert-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/alert-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALERT_FILLED: &str = "alert-filled";
    #[doc(alias = "alert-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "alert-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "alert-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `alert-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/alert-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALERT_OFF_FILLED: &str = "alert-off-filled";
    #[doc(alias = "alert-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "alert-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "alert-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `alert-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/alert-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALERT_OFF_REGULAR: &str = "alert-off-regular";
    #[doc(alias = "alert-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "alert-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "alert-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `alert-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/alert-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALERT_REGULAR: &str = "alert-regular";
    #[doc(alias = "alert-snooze-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "alert-snooze-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "alert-snooze-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `alert-snooze-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/alert-snooze-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALERT_SNOOZE_FILLED: &str = "alert-snooze-filled";
    #[doc(alias = "alert-snooze-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "alert-snooze-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "alert-snooze-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `alert-snooze-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/alert-snooze-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALERT_SNOOZE_REGULAR: &str = "alert-snooze-regular";
    #[doc(alias = "alert-urgent-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "alert-urgent-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "alert-urgent-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `alert-urgent-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/alert-urgent-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALERT_URGENT_FILLED: &str = "alert-urgent-filled";
    #[doc(alias = "alert-urgent-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "alert-urgent-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "alert-urgent-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `alert-urgent-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/alert-urgent-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALERT_URGENT_REGULAR: &str = "alert-urgent-regular";
    #[doc(alias = "align-bottom-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "align-bottom-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "align-bottom-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `align-bottom-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-bottom-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_BOTTOM_FILLED: &str = "align-bottom-filled";
    #[doc(alias = "align-bottom-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "align-bottom-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "align-bottom-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `align-bottom-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-bottom-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_BOTTOM_REGULAR: &str = "align-bottom-regular";
    #[doc(alias = "align-center-horizontal-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-center-horizontal-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-center-horizontal-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-center-horizontal-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-center-horizontal-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_CENTER_HORIZONTAL_FILLED: &str = "align-center-horizontal-filled";
    #[doc(alias = "align-center-horizontal-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-center-horizontal-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-center-horizontal-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-center-horizontal-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-center-horizontal-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_CENTER_HORIZONTAL_REGULAR: &str = "align-center-horizontal-regular";
    #[doc(alias = "align-center-vertical-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-center-vertical-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-center-vertical-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-center-vertical-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-center-vertical-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_CENTER_VERTICAL_FILLED: &str = "align-center-vertical-filled";
    #[doc(alias = "align-center-vertical-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-center-vertical-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-center-vertical-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-center-vertical-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-center-vertical-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_CENTER_VERTICAL_REGULAR: &str = "align-center-vertical-regular";
    #[doc(alias = "align-distribute-bottom-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-distribute-bottom-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-distribute-bottom-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-distribute-bottom-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-distribute-bottom-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_DISTRIBUTE_BOTTOM_FILLED: &str = "align-distribute-bottom-filled";
    #[doc(alias = "align-distribute-bottom-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-distribute-bottom-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-distribute-bottom-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-distribute-bottom-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-distribute-bottom-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_DISTRIBUTE_BOTTOM_REGULAR: &str = "align-distribute-bottom-regular";
    #[doc(alias = "align-distribute-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-distribute-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-distribute-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-distribute-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-distribute-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_DISTRIBUTE_LEFT_FILLED: &str = "align-distribute-left-filled";
    #[doc(alias = "align-distribute-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-distribute-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-distribute-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-distribute-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-distribute-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_DISTRIBUTE_LEFT_REGULAR: &str = "align-distribute-left-regular";
    #[doc(alias = "align-distribute-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-distribute-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-distribute-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-distribute-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-distribute-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_DISTRIBUTE_RIGHT_FILLED: &str = "align-distribute-right-filled";
    #[doc(alias = "align-distribute-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-distribute-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-distribute-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-distribute-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-distribute-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_DISTRIBUTE_RIGHT_REGULAR: &str = "align-distribute-right-regular";
    #[doc(alias = "align-distribute-top-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-distribute-top-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-distribute-top-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-distribute-top-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-distribute-top-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_DISTRIBUTE_TOP_FILLED: &str = "align-distribute-top-filled";
    #[doc(alias = "align-distribute-top-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-distribute-top-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-distribute-top-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-distribute-top-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-distribute-top-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_DISTRIBUTE_TOP_REGULAR: &str = "align-distribute-top-regular";
    #[doc(alias = "align-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "align-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "align-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `align-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_LEFT_FILLED: &str = "align-left-filled";
    #[doc(alias = "align-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "align-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "align-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `align-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_LEFT_REGULAR: &str = "align-left-regular";
    #[doc(alias = "align-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "align-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "align-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `align-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_RIGHT_FILLED: &str = "align-right-filled";
    #[doc(alias = "align-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "align-right-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "align-right-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `align-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_RIGHT_REGULAR: &str = "align-right-regular";
    #[doc(alias = "align-stretch-horizontal-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-stretch-horizontal-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-stretch-horizontal-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-stretch-horizontal-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-stretch-horizontal-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_STRETCH_HORIZONTAL_FILLED: &str = "align-stretch-horizontal-filled";
    #[doc(alias = "align-stretch-horizontal-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-stretch-horizontal-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-stretch-horizontal-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-stretch-horizontal-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-stretch-horizontal-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_STRETCH_HORIZONTAL_REGULAR: &str = "align-stretch-horizontal-regular";
    #[doc(alias = "align-stretch-vertical-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-stretch-vertical-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-stretch-vertical-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-stretch-vertical-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-stretch-vertical-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_STRETCH_VERTICAL_FILLED: &str = "align-stretch-vertical-filled";
    #[doc(alias = "align-stretch-vertical-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "align-stretch-vertical-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "align-stretch-vertical-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `align-stretch-vertical-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-stretch-vertical-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_STRETCH_VERTICAL_REGULAR: &str = "align-stretch-vertical-regular";
    #[doc(alias = "align-tool")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "align-tool", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "align-tool", feature = "icon-development-kit"))]
    /// Icon name constant for the `align-tool` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/align-tool-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_TOOL: &str = "align-tool";
    #[doc(alias = "align-top-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "align-top-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "align-top-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `align-top-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-top-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_TOP_FILLED: &str = "align-top-filled";
    #[doc(alias = "align-top-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "align-top-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "align-top-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `align-top-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/align-top-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ALIGN_TOP_REGULAR: &str = "align-top-regular";
    #[doc(alias = "ambulance")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ambulance", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "ambulance", feature = "icon-development-kit"))]
    /// Icon name constant for the `ambulance` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/ambulance-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AMBULANCE: &str = "ambulance";
    #[doc(alias = "animal-cat-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "animal-cat-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "animal-cat-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `animal-cat-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/animal-cat-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ANIMAL_CAT_FILLED: &str = "animal-cat-filled";
    #[doc(alias = "animal-cat-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "animal-cat-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "animal-cat-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `animal-cat-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/animal-cat-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ANIMAL_CAT_REGULAR: &str = "animal-cat-regular";
    #[doc(alias = "animal-dog-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "animal-dog-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "animal-dog-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `animal-dog-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/animal-dog-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ANIMAL_DOG_FILLED: &str = "animal-dog-filled";
    #[doc(alias = "animal-dog-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "animal-dog-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "animal-dog-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `animal-dog-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/animal-dog-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ANIMAL_DOG_REGULAR: &str = "animal-dog-regular";
    #[doc(alias = "animal-rabbit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "animal-rabbit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "animal-rabbit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `animal-rabbit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/animal-rabbit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ANIMAL_RABBIT_FILLED: &str = "animal-rabbit-filled";
    #[doc(alias = "animal-rabbit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "animal-rabbit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "animal-rabbit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `animal-rabbit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/animal-rabbit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ANIMAL_RABBIT_REGULAR: &str = "animal-rabbit-regular";
    #[doc(alias = "animal-turtle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "animal-turtle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "animal-turtle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `animal-turtle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/animal-turtle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ANIMAL_TURTLE_FILLED: &str = "animal-turtle-filled";
    #[doc(alias = "animal-turtle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "animal-turtle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "animal-turtle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `animal-turtle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/animal-turtle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ANIMAL_TURTLE_REGULAR: &str = "animal-turtle-regular";
    #[doc(alias = "anniversary")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "anniversary", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "anniversary", feature = "icon-development-kit"))]
    /// Icon name constant for the `anniversary` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/anniversary-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ANNIVERSARY: &str = "anniversary";
    #[doc(alias = "annotation-sidebar")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "annotation-sidebar", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "annotation-sidebar", feature = "icon-development-kit"))]
    /// Icon name constant for the `annotation-sidebar` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/annotation-sidebar-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ANNOTATION_SIDEBAR: &str = "annotation-sidebar";
    #[doc(alias = "app-folder-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "app-folder-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "app-folder-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `app-folder-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/app-folder-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const APP_FOLDER_FILLED: &str = "app-folder-filled";
    #[doc(alias = "app-folder-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "app-folder-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "app-folder-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `app-folder-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/app-folder-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const APP_FOLDER_REGULAR: &str = "app-folder-regular";
    #[doc(alias = "app-icon-design")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "app-icon-design", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "app-icon-design", feature = "icon-development-kit"))]
    /// Icon name constant for the `app-icon-design` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/app-icon-design-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const APP_ICON_DESIGN: &str = "app-icon-design";
    #[doc(alias = "applause")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "applause", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "applause", feature = "icon-development-kit"))]
    /// Icon name constant for the `applause` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/applause-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const APPLAUSE: &str = "applause";
    #[doc(alias = "application-x-firmware")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "application-x-firmware", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "application-x-firmware", feature = "icon-development-kit"))]
    /// Icon name constant for the `application-x-firmware` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/application-x-firmware-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const APPLICATION_X_FIRMWARE: &str = "application-x-firmware";
    #[doc(alias = "approvals-app-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "approvals-app-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "approvals-app-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `approvals-app-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/approvals-app-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const APPROVALS_APP_FILLED: &str = "approvals-app-filled";
    #[doc(alias = "approvals-app-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "approvals-app-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "approvals-app-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `approvals-app-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/approvals-app-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const APPROVALS_APP_REGULAR: &str = "approvals-app-regular";
    #[doc(alias = "apps-add-in-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "apps-add-in-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "apps-add-in-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `apps-add-in-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/apps-add-in-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const APPS_ADD_IN_FILLED: &str = "apps-add-in-filled";
    #[doc(alias = "apps-add-in-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "apps-add-in-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "apps-add-in-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `apps-add-in-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/apps-add-in-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const APPS_ADD_IN_REGULAR: &str = "apps-add-in-regular";
    #[doc(alias = "apps-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "apps-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "apps-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `apps-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/apps-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const APPS_FILLED: &str = "apps-filled";
    #[doc(alias = "apps-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "apps-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "apps-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `apps-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/apps-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const APPS_REGULAR: &str = "apps-regular";
    #[doc(alias = "archive")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "archive", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "archive", feature = "icon-development-kit"))]
    /// Icon name constant for the `archive` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/archive-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARCHIVE: &str = "archive";
    #[doc(alias = "archive-arrow-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "archive-arrow-back-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "archive-arrow-back-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `archive-arrow-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/archive-arrow-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARCHIVE_ARROW_BACK_FILLED: &str = "archive-arrow-back-filled";
    #[doc(alias = "archive-arrow-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "archive-arrow-back-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "archive-arrow-back-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `archive-arrow-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/archive-arrow-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARCHIVE_ARROW_BACK_REGULAR: &str = "archive-arrow-back-regular";
    #[doc(alias = "archive-extract")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "archive-extract", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "archive-extract", feature = "icon-development-kit"))]
    /// Icon name constant for the `archive-extract` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/archive-extract-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARCHIVE_EXTRACT: &str = "archive-extract";
    #[doc(alias = "archive-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "archive-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "archive-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `archive-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/archive-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARCHIVE_FILLED: &str = "archive-filled";
    #[doc(alias = "archive-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "archive-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "archive-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `archive-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/archive-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARCHIVE_MULTIPLE_FILLED: &str = "archive-multiple-filled";
    #[doc(alias = "archive-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "archive-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "archive-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `archive-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/archive-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARCHIVE_MULTIPLE_REGULAR: &str = "archive-multiple-regular";
    #[doc(alias = "archive-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "archive-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "archive-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `archive-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/archive-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARCHIVE_REGULAR: &str = "archive-regular";
    #[doc(alias = "archive-settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "archive-settings-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "archive-settings-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `archive-settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/archive-settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARCHIVE_SETTINGS_FILLED: &str = "archive-settings-filled";
    #[doc(alias = "archive-settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "archive-settings-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "archive-settings-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `archive-settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/archive-settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARCHIVE_SETTINGS_REGULAR: &str = "archive-settings-regular";
    #[doc(alias = "arrow-bidirectional-left-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-bidirectional-left-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-bidirectional-left-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-bidirectional-left-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-bidirectional-left-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_BIDIRECTIONAL_LEFT_RIGHT_FILLED: &str = "arrow-bidirectional-left-right-filled";
    #[doc(alias = "arrow-bidirectional-left-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-bidirectional-left-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-bidirectional-left-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-bidirectional-left-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-bidirectional-left-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_BIDIRECTIONAL_LEFT_RIGHT_REGULAR: &str =
        "arrow-bidirectional-left-right-regular";
    #[doc(alias = "arrow-bidirectional-up-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-bidirectional-up-down-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-bidirectional-up-down-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-bidirectional-up-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-bidirectional-up-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_BIDIRECTIONAL_UP_DOWN_FILLED: &str = "arrow-bidirectional-up-down-filled";
    #[doc(alias = "arrow-bidirectional-up-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-bidirectional-up-down-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-bidirectional-up-down-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-bidirectional-up-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-bidirectional-up-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_BIDIRECTIONAL_UP_DOWN_REGULAR: &str = "arrow-bidirectional-up-down-regular";
    #[doc(alias = "arrow-bounce-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-bounce-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-bounce-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-bounce-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-bounce-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_BOUNCE_FILLED: &str = "arrow-bounce-filled";
    #[doc(alias = "arrow-bounce-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-bounce-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-bounce-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-bounce-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-bounce-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_BOUNCE_REGULAR: &str = "arrow-bounce-regular";
    #[doc(alias = "arrow-circle-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-circle-down-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-circle-down-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-circle-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-circle-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CIRCLE_DOWN_FILLED: &str = "arrow-circle-down-filled";
    #[doc(alias = "arrow-circle-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-circle-down-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-circle-down-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-circle-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-circle-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CIRCLE_DOWN_REGULAR: &str = "arrow-circle-down-regular";
    #[doc(alias = "arrow-circle-down-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-circle-down-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-circle-down-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-circle-down-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-circle-down-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CIRCLE_DOWN_RIGHT_FILLED: &str = "arrow-circle-down-right-filled";
    #[doc(alias = "arrow-circle-down-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-circle-down-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-circle-down-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-circle-down-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-circle-down-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CIRCLE_DOWN_RIGHT_REGULAR: &str = "arrow-circle-down-right-regular";
    #[doc(alias = "arrow-circle-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-circle-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-circle-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-circle-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-circle-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CIRCLE_LEFT_FILLED: &str = "arrow-circle-left-filled";
    #[doc(alias = "arrow-circle-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-circle-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-circle-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-circle-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-circle-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CIRCLE_LEFT_REGULAR: &str = "arrow-circle-left-regular";
    #[doc(alias = "arrow-circle-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-circle-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-circle-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-circle-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-circle-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CIRCLE_RIGHT_FILLED: &str = "arrow-circle-right-filled";
    #[doc(alias = "arrow-circle-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-circle-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-circle-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-circle-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-circle-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CIRCLE_RIGHT_REGULAR: &str = "arrow-circle-right-regular";
    #[doc(alias = "arrow-circle-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-circle-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-circle-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-circle-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-circle-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CIRCLE_UP_FILLED: &str = "arrow-circle-up-filled";
    #[doc(alias = "arrow-circle-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-circle-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-circle-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-circle-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-circle-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CIRCLE_UP_REGULAR: &str = "arrow-circle-up-regular";
    #[doc(alias = "arrow-clockwise-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-clockwise-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-clockwise-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-clockwise-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-clockwise-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CLOCKWISE_FILLED: &str = "arrow-clockwise-filled";
    #[doc(alias = "arrow-clockwise-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-clockwise-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-clockwise-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-clockwise-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-clockwise-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CLOCKWISE_REGULAR: &str = "arrow-clockwise-regular";
    #[doc(alias = "arrow-counterclockwise-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-counterclockwise-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-counterclockwise-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-counterclockwise-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-counterclockwise-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_COUNTERCLOCKWISE_FILLED: &str = "arrow-counterclockwise-filled";
    #[doc(alias = "arrow-counterclockwise-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-counterclockwise-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-counterclockwise-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-counterclockwise-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-counterclockwise-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_COUNTERCLOCKWISE_REGULAR: &str = "arrow-counterclockwise-regular";
    #[doc(alias = "arrow-curve-down-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-curve-down-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-curve-down-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-curve-down-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-curve-down-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CURVE_DOWN_LEFT_FILLED: &str = "arrow-curve-down-left-filled";
    #[doc(alias = "arrow-curve-down-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-curve-down-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-curve-down-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-curve-down-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-curve-down-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_CURVE_DOWN_LEFT_REGULAR: &str = "arrow-curve-down-left-regular";
    #[doc(alias = "arrow-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-down-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-down-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_DOWN_FILLED: &str = "arrow-down-filled";
    #[doc(alias = "arrow-down-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-down-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-down-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-down-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-down-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_DOWN_LEFT_FILLED: &str = "arrow-down-left-filled";
    #[doc(alias = "arrow-down-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-down-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-down-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-down-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-down-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_DOWN_LEFT_REGULAR: &str = "arrow-down-left-regular";
    #[doc(alias = "arrow-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-down-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-down-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_DOWN_REGULAR: &str = "arrow-down-regular";
    #[doc(alias = "arrow-download-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-download-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-download-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-download-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-download-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_DOWNLOAD_FILLED: &str = "arrow-download-filled";
    #[doc(alias = "arrow-download-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-download-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-download-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-download-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-download-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_DOWNLOAD_REGULAR: &str = "arrow-download-regular";
    #[doc(alias = "arrow-enter-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-enter-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-enter-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-enter-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-enter-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_ENTER_FILLED: &str = "arrow-enter-filled";
    #[doc(alias = "arrow-enter-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-enter-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-enter-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-enter-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-enter-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_ENTER_REGULAR: &str = "arrow-enter-regular";
    #[doc(alias = "arrow-export-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-export-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-export-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-export-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-export-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_EXPORT_FILLED: &str = "arrow-export-filled";
    #[doc(alias = "arrow-export-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-export-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-export-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-export-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-export-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_EXPORT_REGULAR: &str = "arrow-export-regular";
    #[doc(alias = "arrow-fit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-fit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-fit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-fit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-fit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_FIT_FILLED: &str = "arrow-fit-filled";
    #[doc(alias = "arrow-fit-in-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-fit-in-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-fit-in-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-fit-in-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-fit-in-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_FIT_IN_FILLED: &str = "arrow-fit-in-filled";
    #[doc(alias = "arrow-fit-in-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-fit-in-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-fit-in-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-fit-in-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-fit-in-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_FIT_IN_REGULAR: &str = "arrow-fit-in-regular";
    #[doc(alias = "arrow-fit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-fit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-fit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-fit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-fit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_FIT_REGULAR: &str = "arrow-fit-regular";
    #[doc(alias = "arrow-flow-diagonal-up-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-flow-diagonal-up-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-flow-diagonal-up-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-flow-diagonal-up-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-flow-diagonal-up-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_FLOW_DIAGONAL_UP_RIGHT_FILLED: &str = "arrow-flow-diagonal-up-right-filled";
    #[doc(alias = "arrow-flow-diagonal-up-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-flow-diagonal-up-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-flow-diagonal-up-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-flow-diagonal-up-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-flow-diagonal-up-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_FLOW_DIAGONAL_UP_RIGHT_REGULAR: &str = "arrow-flow-diagonal-up-right-regular";
    #[doc(alias = "arrow-flow-up-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-flow-up-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-flow-up-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-flow-up-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-flow-up-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_FLOW_UP_RIGHT_FILLED: &str = "arrow-flow-up-right-filled";
    #[doc(alias = "arrow-flow-up-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-flow-up-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-flow-up-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-flow-up-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-flow-up-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_FLOW_UP_RIGHT_REGULAR: &str = "arrow-flow-up-right-regular";
    #[doc(alias = "arrow-forward-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-forward-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-forward-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-forward-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-forward-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_FORWARD_FILLED: &str = "arrow-forward-filled";
    #[doc(alias = "arrow-forward-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-forward-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-forward-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-forward-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-forward-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_FORWARD_REGULAR: &str = "arrow-forward-regular";
    #[doc(alias = "arrow-hook-down-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-hook-down-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-hook-down-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-hook-down-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-hook-down-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_HOOK_DOWN_LEFT_FILLED: &str = "arrow-hook-down-left-filled";
    #[doc(alias = "arrow-hook-down-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-hook-down-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-hook-down-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-hook-down-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-hook-down-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_HOOK_DOWN_LEFT_REGULAR: &str = "arrow-hook-down-left-regular";
    #[doc(alias = "arrow-hook-down-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-hook-down-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-hook-down-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-hook-down-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-hook-down-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_HOOK_DOWN_RIGHT_FILLED: &str = "arrow-hook-down-right-filled";
    #[doc(alias = "arrow-hook-down-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-hook-down-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-hook-down-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-hook-down-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-hook-down-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_HOOK_DOWN_RIGHT_REGULAR: &str = "arrow-hook-down-right-regular";
    #[doc(alias = "arrow-hook-up-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-hook-up-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-hook-up-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-hook-up-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-hook-up-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_HOOK_UP_LEFT_FILLED: &str = "arrow-hook-up-left-filled";
    #[doc(alias = "arrow-hook-up-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-hook-up-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-hook-up-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-hook-up-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-hook-up-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_HOOK_UP_LEFT_REGULAR: &str = "arrow-hook-up-left-regular";
    #[doc(alias = "arrow-hook-up-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-hook-up-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-hook-up-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-hook-up-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-hook-up-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_HOOK_UP_RIGHT_FILLED: &str = "arrow-hook-up-right-filled";
    #[doc(alias = "arrow-hook-up-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-hook-up-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-hook-up-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-hook-up-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-hook-up-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_HOOK_UP_RIGHT_REGULAR: &str = "arrow-hook-up-right-regular";
    #[doc(alias = "arrow-into-box")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-into-box", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow-into-box", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow-into-box` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow-into-box-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_INTO_BOX: &str = "arrow-into-box";
    #[doc(alias = "arrow-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_LEFT_FILLED: &str = "arrow-left-filled";
    #[doc(alias = "arrow-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_LEFT_REGULAR: &str = "arrow-left-regular";
    #[doc(alias = "arrow-maximize-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-maximize-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-maximize-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-maximize-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-maximize-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_MAXIMIZE_FILLED: &str = "arrow-maximize-filled";
    #[doc(alias = "arrow-maximize-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-maximize-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-maximize-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-maximize-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-maximize-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_MAXIMIZE_REGULAR: &str = "arrow-maximize-regular";
    #[doc(alias = "arrow-minimize-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-minimize-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-minimize-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-minimize-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-minimize-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_MINIMIZE_FILLED: &str = "arrow-minimize-filled";
    #[doc(alias = "arrow-minimize-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-minimize-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-minimize-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-minimize-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-minimize-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_MINIMIZE_REGULAR: &str = "arrow-minimize-regular";
    #[doc(alias = "arrow-next-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-next-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-next-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-next-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-next-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_NEXT_FILLED: &str = "arrow-next-filled";
    #[doc(alias = "arrow-next-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-next-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-next-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-next-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-next-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_NEXT_REGULAR: &str = "arrow-next-regular";
    #[doc(alias = "arrow-outline-down-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-outline-down-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-outline-down-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-outline-down-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-outline-down-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_OUTLINE_DOWN_LEFT_FILLED: &str = "arrow-outline-down-left-filled";
    #[doc(alias = "arrow-outline-down-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-outline-down-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-outline-down-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-outline-down-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-outline-down-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_OUTLINE_DOWN_LEFT_REGULAR: &str = "arrow-outline-down-left-regular";
    #[doc(alias = "arrow-paragraph-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-paragraph-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-paragraph-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-paragraph-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-paragraph-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_PARAGRAPH_FILLED: &str = "arrow-paragraph-filled";
    #[doc(alias = "arrow-paragraph-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-paragraph-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-paragraph-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-paragraph-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-paragraph-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_PARAGRAPH_REGULAR: &str = "arrow-paragraph-regular";
    #[doc(alias = "arrow-previous-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-previous-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-previous-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-previous-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-previous-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_PREVIOUS_FILLED: &str = "arrow-previous-filled";
    #[doc(alias = "arrow-previous-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-previous-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-previous-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-previous-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-previous-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_PREVIOUS_REGULAR: &str = "arrow-previous-regular";
    #[doc(alias = "arrow-redo-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-redo-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-redo-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-redo-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-redo-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REDO_FILLED: &str = "arrow-redo-filled";
    #[doc(alias = "arrow-redo-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-redo-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-redo-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-redo-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-redo-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REDO_REGULAR: &str = "arrow-redo-regular";
    #[doc(alias = "arrow-repeat-1-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-repeat-1-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-repeat-1-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-repeat-1-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-repeat-1-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPEAT_1_FILLED: &str = "arrow-repeat-1-filled";
    #[doc(alias = "arrow-repeat-1-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-repeat-1-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-repeat-1-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-repeat-1-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-repeat-1-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPEAT_1_REGULAR: &str = "arrow-repeat-1-regular";
    #[doc(alias = "arrow-repeat-all-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-repeat-all-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-repeat-all-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-repeat-all-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-repeat-all-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPEAT_ALL_FILLED: &str = "arrow-repeat-all-filled";
    #[doc(alias = "arrow-repeat-all-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-repeat-all-off-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-repeat-all-off-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-repeat-all-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-repeat-all-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPEAT_ALL_OFF_FILLED: &str = "arrow-repeat-all-off-filled";
    #[doc(alias = "arrow-repeat-all-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-repeat-all-off-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-repeat-all-off-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-repeat-all-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-repeat-all-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPEAT_ALL_OFF_REGULAR: &str = "arrow-repeat-all-off-regular";
    #[doc(alias = "arrow-repeat-all-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-repeat-all-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-repeat-all-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-repeat-all-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-repeat-all-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPEAT_ALL_REGULAR: &str = "arrow-repeat-all-regular";
    #[doc(alias = "arrow-reply-all-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-reply-all-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-reply-all-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-reply-all-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-reply-all-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPLY_ALL_FILLED: &str = "arrow-reply-all-filled";
    #[doc(alias = "arrow-reply-all-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-reply-all-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-reply-all-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-reply-all-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-reply-all-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPLY_ALL_REGULAR: &str = "arrow-reply-all-regular";
    #[doc(alias = "arrow-reply-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-reply-down-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-reply-down-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-reply-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-reply-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPLY_DOWN_FILLED: &str = "arrow-reply-down-filled";
    #[doc(alias = "arrow-reply-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-reply-down-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-reply-down-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-reply-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-reply-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPLY_DOWN_REGULAR: &str = "arrow-reply-down-regular";
    #[doc(alias = "arrow-reply-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-reply-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-reply-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-reply-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-reply-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPLY_FILLED: &str = "arrow-reply-filled";
    #[doc(alias = "arrow-reply-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-reply-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-reply-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-reply-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-reply-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_REPLY_REGULAR: &str = "arrow-reply-regular";
    #[doc(alias = "arrow-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_RIGHT_FILLED: &str = "arrow-right-filled";
    #[doc(alias = "arrow-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-right-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-right-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_RIGHT_REGULAR: &str = "arrow-right-regular";
    #[doc(alias = "arrow-rotate-clockwise-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-rotate-clockwise-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-rotate-clockwise-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-rotate-clockwise-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-rotate-clockwise-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_ROTATE_CLOCKWISE_FILLED: &str = "arrow-rotate-clockwise-filled";
    #[doc(alias = "arrow-rotate-clockwise-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-rotate-clockwise-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-rotate-clockwise-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-rotate-clockwise-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-rotate-clockwise-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_ROTATE_CLOCKWISE_REGULAR: &str = "arrow-rotate-clockwise-regular";
    #[doc(alias = "arrow-shuffle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-shuffle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-shuffle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-shuffle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-shuffle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SHUFFLE_FILLED: &str = "arrow-shuffle-filled";
    #[doc(alias = "arrow-shuffle-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-shuffle-off-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-shuffle-off-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-shuffle-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-shuffle-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SHUFFLE_OFF_FILLED: &str = "arrow-shuffle-off-filled";
    #[doc(alias = "arrow-shuffle-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-shuffle-off-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-shuffle-off-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-shuffle-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-shuffle-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SHUFFLE_OFF_REGULAR: &str = "arrow-shuffle-off-regular";
    #[doc(alias = "arrow-shuffle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-shuffle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-shuffle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-shuffle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-shuffle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SHUFFLE_REGULAR: &str = "arrow-shuffle-regular";
    #[doc(alias = "arrow-sort-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sort-down-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sort-down-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sort-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sort-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SORT_DOWN_FILLED: &str = "arrow-sort-down-filled";
    #[doc(alias = "arrow-sort-down-lines-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-sort-down-lines-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-sort-down-lines-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-sort-down-lines-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sort-down-lines-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SORT_DOWN_LINES_FILLED: &str = "arrow-sort-down-lines-filled";
    #[doc(alias = "arrow-sort-down-lines-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-sort-down-lines-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-sort-down-lines-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-sort-down-lines-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sort-down-lines-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SORT_DOWN_LINES_REGULAR: &str = "arrow-sort-down-lines-regular";
    #[doc(alias = "arrow-sort-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sort-down-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sort-down-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sort-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sort-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SORT_DOWN_REGULAR: &str = "arrow-sort-down-regular";
    #[doc(alias = "arrow-sort-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sort-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sort-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sort-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sort-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SORT_FILLED: &str = "arrow-sort-filled";
    #[doc(alias = "arrow-sort-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sort-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sort-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sort-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sort-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SORT_REGULAR: &str = "arrow-sort-regular";
    #[doc(alias = "arrow-sort-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sort-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sort-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sort-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sort-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SORT_UP_FILLED: &str = "arrow-sort-up-filled";
    #[doc(alias = "arrow-sort-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sort-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sort-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sort-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sort-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SORT_UP_REGULAR: &str = "arrow-sort-up-regular";
    #[doc(alias = "arrow-split-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-split-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-split-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-split-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-split-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SPLIT_FILLED: &str = "arrow-split-filled";
    #[doc(alias = "arrow-split-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-split-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-split-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-split-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-split-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SPLIT_REGULAR: &str = "arrow-split-regular";
    #[doc(alias = "arrow-sprint-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sprint-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sprint-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sprint-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sprint-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SPRINT_FILLED: &str = "arrow-sprint-filled";
    #[doc(alias = "arrow-sprint-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sprint-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sprint-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sprint-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sprint-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SPRINT_REGULAR: &str = "arrow-sprint-regular";
    #[doc(alias = "arrow-step-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-step-back-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-step-back-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-step-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_BACK_FILLED: &str = "arrow-step-back-filled";
    #[doc(alias = "arrow-step-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-step-back-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-step-back-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-step-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_BACK_REGULAR: &str = "arrow-step-back-regular";
    #[doc(alias = "arrow-step-in-diagonal-down-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-step-in-diagonal-down-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-step-in-diagonal-down-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-step-in-diagonal-down-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-in-diagonal-down-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_IN_DIAGONAL_DOWN_LEFT_FILLED: &str =
        "arrow-step-in-diagonal-down-left-filled";
    #[doc(alias = "arrow-step-in-diagonal-down-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-step-in-diagonal-down-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-step-in-diagonal-down-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-step-in-diagonal-down-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-in-diagonal-down-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_IN_DIAGONAL_DOWN_LEFT_REGULAR: &str =
        "arrow-step-in-diagonal-down-left-regular";
    #[doc(alias = "arrow-step-in-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-step-in-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-step-in-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-step-in-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-in-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_IN_FILLED: &str = "arrow-step-in-filled";
    #[doc(alias = "arrow-step-in-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-step-in-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-step-in-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-step-in-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-in-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_IN_LEFT_FILLED: &str = "arrow-step-in-left-filled";
    #[doc(alias = "arrow-step-in-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-step-in-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-step-in-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-step-in-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-in-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_IN_LEFT_REGULAR: &str = "arrow-step-in-left-regular";
    #[doc(alias = "arrow-step-in-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-step-in-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-step-in-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-step-in-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-in-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_IN_REGULAR: &str = "arrow-step-in-regular";
    #[doc(alias = "arrow-step-in-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-step-in-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-step-in-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-step-in-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-in-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_IN_RIGHT_FILLED: &str = "arrow-step-in-right-filled";
    #[doc(alias = "arrow-step-in-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-step-in-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-step-in-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-step-in-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-in-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_IN_RIGHT_REGULAR: &str = "arrow-step-in-right-regular";
    #[doc(alias = "arrow-step-out-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-step-out-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-step-out-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-step-out-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-out-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_OUT_FILLED: &str = "arrow-step-out-filled";
    #[doc(alias = "arrow-step-out-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-step-out-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-step-out-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-step-out-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-out-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_OUT_REGULAR: &str = "arrow-step-out-regular";
    #[doc(alias = "arrow-step-over-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-step-over-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-step-over-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-step-over-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-over-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_OVER_FILLED: &str = "arrow-step-over-filled";
    #[doc(alias = "arrow-step-over-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-step-over-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-step-over-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-step-over-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-step-over-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_STEP_OVER_REGULAR: &str = "arrow-step-over-regular";
    #[doc(alias = "arrow-swap-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-swap-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-swap-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-swap-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-swap-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SWAP_FILLED: &str = "arrow-swap-filled";
    #[doc(alias = "arrow-swap-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-swap-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-swap-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-swap-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-swap-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SWAP_REGULAR: &str = "arrow-swap-regular";
    #[doc(alias = "arrow-sync-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-sync-circle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-sync-circle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-sync-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sync-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SYNC_CIRCLE_FILLED: &str = "arrow-sync-circle-filled";
    #[doc(alias = "arrow-sync-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-sync-circle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-sync-circle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-sync-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sync-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SYNC_CIRCLE_REGULAR: &str = "arrow-sync-circle-regular";
    #[doc(alias = "arrow-sync-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sync-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sync-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sync-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sync-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SYNC_FILLED: &str = "arrow-sync-filled";
    #[doc(alias = "arrow-sync-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sync-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sync-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sync-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sync-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SYNC_OFF_FILLED: &str = "arrow-sync-off-filled";
    #[doc(alias = "arrow-sync-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sync-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sync-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sync-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sync-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SYNC_OFF_REGULAR: &str = "arrow-sync-off-regular";
    #[doc(alias = "arrow-sync-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-sync-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-sync-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-sync-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-sync-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_SYNC_REGULAR: &str = "arrow-sync-regular";
    #[doc(alias = "arrow-trending-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-trending-down-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-trending-down-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-trending-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-trending-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_TRENDING_DOWN_FILLED: &str = "arrow-trending-down-filled";
    #[doc(alias = "arrow-trending-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "arrow-trending-down-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "arrow-trending-down-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `arrow-trending-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-trending-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_TRENDING_DOWN_REGULAR: &str = "arrow-trending-down-regular";
    #[doc(alias = "arrow-trending-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-trending-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-trending-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-trending-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-trending-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_TRENDING_FILLED: &str = "arrow-trending-filled";
    #[doc(alias = "arrow-trending-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-trending-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-trending-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-trending-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-trending-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_TRENDING_REGULAR: &str = "arrow-trending-regular";
    #[doc(alias = "arrow-undo-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-undo-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-undo-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-undo-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-undo-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_UNDO_FILLED: &str = "arrow-undo-filled";
    #[doc(alias = "arrow-undo-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-undo-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-undo-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-undo-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-undo-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_UNDO_REGULAR: &str = "arrow-undo-regular";
    #[doc(alias = "arrow-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_UP_FILLED: &str = "arrow-up-filled";
    #[doc(alias = "arrow-up-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-up-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-up-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-up-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-up-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_UP_LEFT_FILLED: &str = "arrow-up-left-filled";
    #[doc(alias = "arrow-up-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-up-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-up-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-up-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-up-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_UP_LEFT_REGULAR: &str = "arrow-up-left-regular";
    #[doc(alias = "arrow-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_UP_REGULAR: &str = "arrow-up-regular";
    #[doc(alias = "arrow-up-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-up-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-up-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-up-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-up-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_UP_RIGHT_FILLED: &str = "arrow-up-right-filled";
    #[doc(alias = "arrow-up-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-up-right-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-up-right-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-up-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-up-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_UP_RIGHT_REGULAR: &str = "arrow-up-right-regular";
    #[doc(alias = "arrow-upload-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-upload-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-upload-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-upload-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-upload-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_UPLOAD_FILLED: &str = "arrow-upload-filled";
    #[doc(alias = "arrow-upload-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow-upload-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "arrow-upload-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `arrow-upload-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/arrow-upload-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW_UPLOAD_REGULAR: &str = "arrow-upload-regular";
    #[doc(alias = "arrow1-down")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow1-down", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow1-down", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow1-down` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow1-down-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW1_DOWN: &str = "arrow1-down";
    #[doc(alias = "arrow1-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow1-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow1-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow1-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow1-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW1_LEFT: &str = "arrow1-left";
    #[doc(alias = "arrow1-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow1-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow1-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow1-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow1-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW1_RIGHT: &str = "arrow1-right";
    #[doc(alias = "arrow1-up")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow1-up", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow1-up", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow1-up` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow1-up-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW1_UP: &str = "arrow1-up";
    #[doc(alias = "arrow2-bottom-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow2-bottom-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow2-bottom-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow2-bottom-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow2-bottom-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW2_BOTTOM_LEFT: &str = "arrow2-bottom-left";
    #[doc(alias = "arrow2-bottom-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow2-bottom-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow2-bottom-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow2-bottom-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow2-bottom-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW2_BOTTOM_RIGHT: &str = "arrow2-bottom-right";
    #[doc(alias = "arrow2-down")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow2-down", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow2-down", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow2-down` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow2-down-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW2_DOWN: &str = "arrow2-down";
    #[doc(alias = "arrow2-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow2-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow2-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow2-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow2-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW2_LEFT: &str = "arrow2-left";
    #[doc(alias = "arrow2-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow2-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow2-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow2-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow2-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW2_RIGHT: &str = "arrow2-right";
    #[doc(alias = "arrow2-top-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow2-top-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow2-top-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow2-top-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow2-top-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW2_TOP_LEFT: &str = "arrow2-top-left";
    #[doc(alias = "arrow2-top-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow2-top-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow2-top-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow2-top-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow2-top-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW2_TOP_RIGHT: &str = "arrow2-top-right";
    #[doc(alias = "arrow2-up")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow2-up", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow2-up", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow2-up` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow2-up-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW2_UP: &str = "arrow2-up";
    #[doc(alias = "arrow3-down")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow3-down", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow3-down", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow3-down` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow3-down-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW3_DOWN: &str = "arrow3-down";
    #[doc(alias = "arrow3-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow3-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow3-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow3-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow3-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW3_LEFT: &str = "arrow3-left";
    #[doc(alias = "arrow3-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow3-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow3-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow3-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow3-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW3_RIGHT: &str = "arrow3-right";
    #[doc(alias = "arrow3-up")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrow3-up", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrow3-up", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrow3-up` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrow3-up-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROW3_UP: &str = "arrow3-up";
    #[doc(alias = "arrows-questionmark")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "arrows-questionmark", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "arrows-questionmark", feature = "icon-development-kit"))]
    /// Icon name constant for the `arrows-questionmark` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/arrows-questionmark-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ARROWS_QUESTIONMARK: &str = "arrows-questionmark";
    #[doc(alias = "assistive-listening")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "assistive-listening", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "assistive-listening", feature = "icon-development-kit"))]
    /// Icon name constant for the `assistive-listening` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/assistive-listening-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ASSISTIVE_LISTENING: &str = "assistive-listening";
    #[doc(alias = "attach-audio")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "attach-audio", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "attach-audio", feature = "icon-development-kit"))]
    /// Icon name constant for the `attach-audio` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/attach-audio-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ATTACH_AUDIO: &str = "attach-audio";
    #[doc(alias = "attach-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "attach-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "attach-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `attach-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/attach-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ATTACH_FILLED: &str = "attach-filled";
    #[doc(alias = "attach-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "attach-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "attach-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `attach-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/attach-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ATTACH_REGULAR: &str = "attach-regular";
    #[doc(alias = "audio-only")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "audio-only", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "audio-only", feature = "icon-development-kit"))]
    /// Icon name constant for the `audio-only` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/audio-only-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AUDIO_ONLY: &str = "audio-only";
    #[doc(alias = "audio-x-generic")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "audio-x-generic", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "audio-x-generic", feature = "icon-development-kit"))]
    /// Icon name constant for the `audio-x-generic` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/audio-x-generic-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AUDIO_X_GENERIC: &str = "audio-x-generic";
    #[doc(alias = "auth-otp")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "auth-otp", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "auth-otp", feature = "icon-development-kit"))]
    /// Icon name constant for the `auth-otp` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/auth-otp-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AUTH_OTP: &str = "auth-otp";
    #[doc(alias = "autosum-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "autosum-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "autosum-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `autosum-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/autosum-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AUTOSUM_FILLED: &str = "autosum-filled";
    #[doc(alias = "autosum-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "autosum-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "autosum-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `autosum-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/autosum-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AUTOSUM_REGULAR: &str = "autosum-regular";
    #[doc(alias = "axes-four-quadrants")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "axes-four-quadrants", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "axes-four-quadrants", feature = "icon-development-kit"))]
    /// Icon name constant for the `axes-four-quadrants` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/axes-four-quadrants-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AXES_FOUR_QUADRANTS: &str = "axes-four-quadrants";
    #[doc(alias = "axes-one-quadrant")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "axes-one-quadrant", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "axes-one-quadrant", feature = "icon-development-kit"))]
    /// Icon name constant for the `axes-one-quadrant` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/axes-one-quadrant-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AXES_ONE_QUADRANT: &str = "axes-one-quadrant";
    #[doc(alias = "axis-log-horizontal")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "axis-log-horizontal", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "axis-log-horizontal", feature = "icon-development-kit"))]
    /// Icon name constant for the `axis-log-horizontal` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/axis-log-horizontal-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AXIS_LOG_HORIZONTAL: &str = "axis-log-horizontal";
    #[doc(alias = "axis-log-vertical")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "axis-log-vertical", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "axis-log-vertical", feature = "icon-development-kit"))]
    /// Icon name constant for the `axis-log-vertical` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/axis-log-vertical-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const AXIS_LOG_VERTICAL: &str = "axis-log-vertical";
    #[doc(alias = "background-app")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "background-app", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "background-app", feature = "icon-development-kit"))]
    /// Icon name constant for the `background-app` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/background-app-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BACKGROUND_APP: &str = "background-app";
    #[doc(alias = "background-app-ghost")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "background-app-ghost", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "background-app-ghost", feature = "icon-development-kit"))]
    /// Icon name constant for the `background-app-ghost` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/background-app-ghost-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BACKGROUND_APP_GHOST: &str = "background-app-ghost";
    #[doc(alias = "background-app-rectangular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "background-app-rectangular",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "background-app-rectangular",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `background-app-rectangular` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/background-app-rectangular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BACKGROUND_APP_RECTANGULAR: &str = "background-app-rectangular";
    #[doc(alias = "background-app-sleepyface")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "background-app-sleepyface",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "background-app-sleepyface",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `background-app-sleepyface` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/background-app-sleepyface-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BACKGROUND_APP_SLEEPYFACE: &str = "background-app-sleepyface";
    #[doc(alias = "backpack-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "backpack-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "backpack-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `backpack-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/backpack-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BACKPACK_FILLED: &str = "backpack-filled";
    #[doc(alias = "backpack-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "backpack-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "backpack-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `backpack-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/backpack-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BACKPACK_REGULAR: &str = "backpack-regular";
    #[doc(alias = "backspace-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "backspace-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "backspace-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `backspace-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/backspace-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BACKSPACE_FILLED: &str = "backspace-filled";
    #[doc(alias = "backspace-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "backspace-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "backspace-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `backspace-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/backspace-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BACKSPACE_REGULAR: &str = "backspace-regular";
    #[doc(alias = "balloon-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "balloon-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "balloon-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `balloon-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/balloon-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BALLOON_FILLED: &str = "balloon-filled";
    #[doc(alias = "balloon-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "balloon-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "balloon-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `balloon-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/balloon-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BALLOON_REGULAR: &str = "balloon-regular";
    #[doc(alias = "bank")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bank", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bank", feature = "icon-development-kit"))]
    /// Icon name constant for the `bank` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bank-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BANK: &str = "bank";
    #[doc(alias = "banner")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "banner", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "banner", feature = "icon-development-kit"))]
    /// Icon name constant for the `banner` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/banner-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BANNER: &str = "banner";
    #[doc(alias = "barbecue")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "barbecue", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "barbecue", feature = "icon-development-kit"))]
    /// Icon name constant for the `barbecue` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/barbecue-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BARBECUE: &str = "barbecue";
    #[doc(alias = "baseball")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "baseball", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "baseball", feature = "icon-development-kit"))]
    /// Icon name constant for the `baseball` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/baseball-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BASEBALL: &str = "baseball";
    #[doc(alias = "battery")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "battery", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "battery", feature = "icon-development-kit"))]
    /// Icon name constant for the `battery` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/battery-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BATTERY: &str = "battery";
    #[doc(alias = "beach-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "beach-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "beach-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `beach-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/beach-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BEACH_FILLED: &str = "beach-filled";
    #[doc(alias = "beach-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "beach-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "beach-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `beach-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/beach-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BEACH_REGULAR: &str = "beach-regular";
    #[doc(alias = "beaker-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "beaker-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "beaker-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `beaker-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/beaker-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BEAKER_FILLED: &str = "beaker-filled";
    #[doc(alias = "beaker-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "beaker-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "beaker-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `beaker-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/beaker-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BEAKER_REGULAR: &str = "beaker-regular";
    #[doc(alias = "beaker-settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "beaker-settings-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "beaker-settings-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `beaker-settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/beaker-settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BEAKER_SETTINGS_FILLED: &str = "beaker-settings-filled";
    #[doc(alias = "beaker-settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "beaker-settings-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "beaker-settings-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `beaker-settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/beaker-settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BEAKER_SETTINGS_REGULAR: &str = "beaker-settings-regular";
    #[doc(alias = "bear")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bear", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bear", feature = "icon-development-kit"))]
    /// Icon name constant for the `bear` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bear-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BEAR: &str = "bear";
    #[doc(alias = "bed")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bed", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bed", feature = "icon-development-kit"))]
    /// Icon name constant for the `bed` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bed-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BED: &str = "bed";
    #[doc(alias = "bed-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bed-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "bed-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `bed-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bed-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BED_FILLED: &str = "bed-filled";
    #[doc(alias = "bed-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bed-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "bed-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `bed-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bed-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BED_REGULAR: &str = "bed-regular";
    #[doc(alias = "bell")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bell", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bell", feature = "icon-development-kit"))]
    /// Icon name constant for the `bell` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bell-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BELL: &str = "bell";
    #[doc(alias = "bell-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bell-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bell-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `bell-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bell-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BELL_LARGE: &str = "bell-large";
    #[doc(alias = "bell-large-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bell-large-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bell-large-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `bell-large-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bell-large-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BELL_LARGE_NONE: &str = "bell-large-none";
    #[doc(alias = "bell-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bell-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bell-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `bell-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bell-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BELL_NONE: &str = "bell-none";
    #[doc(alias = "bell-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bell-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bell-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `bell-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bell-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BELL_OUTLINE: &str = "bell-outline";
    #[doc(alias = "bell-outline-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bell-outline-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bell-outline-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `bell-outline-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bell-outline-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BELL_OUTLINE_NONE: &str = "bell-outline-none";
    #[doc(alias = "bench")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bench", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bench", feature = "icon-development-kit"))]
    /// Icon name constant for the `bench` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bench-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BENCH: &str = "bench";
    #[doc(alias = "big-dot")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "big-dot", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "big-dot", feature = "icon-development-kit"))]
    /// Icon name constant for the `big-dot` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/big-dot-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BIG_DOT: &str = "big-dot";
    #[doc(alias = "big-x")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "big-x", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "big-x", feature = "icon-development-kit"))]
    /// Icon name constant for the `big-x` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/big-x-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BIG_X: &str = "big-x";
    #[doc(alias = "binder-triangle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "binder-triangle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "binder-triangle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `binder-triangle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/binder-triangle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BINDER_TRIANGLE_FILLED: &str = "binder-triangle-filled";
    #[doc(alias = "binder-triangle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "binder-triangle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "binder-triangle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `binder-triangle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/binder-triangle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BINDER_TRIANGLE_REGULAR: &str = "binder-triangle-regular";
    #[doc(alias = "birthday")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "birthday", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "birthday", feature = "icon-development-kit"))]
    /// Icon name constant for the `birthday` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/birthday-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BIRTHDAY: &str = "birthday";
    #[doc(alias = "blend-tool")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "blend-tool", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "blend-tool", feature = "icon-development-kit"))]
    /// Icon name constant for the `blend-tool` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/blend-tool-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BLEND_TOOL: &str = "blend-tool";
    #[doc(alias = "blind")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "blind", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "blind", feature = "icon-development-kit"))]
    /// Icon name constant for the `blind` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/blind-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BLIND: &str = "blind";
    #[doc(alias = "bluetooth")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bluetooth", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bluetooth", feature = "icon-development-kit"))]
    /// Icon name constant for the `bluetooth` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bluetooth-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BLUETOOTH: &str = "bluetooth";
    #[doc(alias = "bluetooth-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bluetooth-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "bluetooth-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `bluetooth-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bluetooth-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BLUETOOTH_FILLED: &str = "bluetooth-filled";
    #[doc(alias = "bluetooth-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bluetooth-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bluetooth-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `bluetooth-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bluetooth-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BLUETOOTH_NONE: &str = "bluetooth-none";
    #[doc(alias = "bluetooth-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bluetooth-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "bluetooth-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `bluetooth-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bluetooth-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BLUETOOTH_REGULAR: &str = "bluetooth-regular";
    #[doc(alias = "blur")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "blur", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "blur", feature = "icon-development-kit"))]
    /// Icon name constant for the `blur` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/blur-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BLUR: &str = "blur";
    #[doc(alias = "blur-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "blur-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "blur-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `blur-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/blur-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BLUR_ALT: &str = "blur-alt";
    #[doc(alias = "blur-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "blur-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "blur-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `blur-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/blur-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BLUR_FILLED: &str = "blur-filled";
    #[doc(alias = "blur-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "blur-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "blur-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `blur-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/blur-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BLUR_REGULAR: &str = "blur-regular";
    #[doc(alias = "board-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "board-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "board-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `board-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/board-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOARD_FILLED: &str = "board-filled";
    #[doc(alias = "board-heart-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "board-heart-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "board-heart-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `board-heart-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/board-heart-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOARD_HEART_FILLED: &str = "board-heart-filled";
    #[doc(alias = "board-heart-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "board-heart-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "board-heart-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `board-heart-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/board-heart-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOARD_HEART_REGULAR: &str = "board-heart-regular";
    #[doc(alias = "board-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "board-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "board-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `board-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/board-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOARD_REGULAR: &str = "board-regular";
    #[doc(alias = "board-split-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "board-split-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "board-split-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `board-split-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/board-split-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOARD_SPLIT_FILLED: &str = "board-split-filled";
    #[doc(alias = "board-split-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "board-split-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "board-split-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `board-split-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/board-split-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOARD_SPLIT_REGULAR: &str = "board-split-regular";
    #[doc(alias = "body")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "body", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "body", feature = "icon-development-kit"))]
    /// Icon name constant for the `body` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/body-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BODY: &str = "body";
    #[doc(alias = "book-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "book-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "book-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `book-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/book-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOOK_DISMISS_FILLED: &str = "book-dismiss-filled";
    #[doc(alias = "book-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "book-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "book-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `book-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/book-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOOK_DISMISS_REGULAR: &str = "book-dismiss-regular";
    #[doc(alias = "book-number-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "book-number-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "book-number-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `book-number-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/book-number-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOOK_NUMBER_FILLED: &str = "book-number-filled";
    #[doc(alias = "book-number-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "book-number-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "book-number-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `book-number-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/book-number-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOOK_NUMBER_REGULAR: &str = "book-number-regular";
    #[doc(alias = "book-open-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "book-open-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "book-open-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `book-open-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/book-open-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOOK_OPEN_FILLED: &str = "book-open-filled";
    #[doc(alias = "book-open-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "book-open-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "book-open-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `book-open-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/book-open-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOOK_OPEN_REGULAR: &str = "book-open-regular";
    #[doc(alias = "bookmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bookmark-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "bookmark-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `bookmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bookmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOOKMARK_FILLED: &str = "bookmark-filled";
    #[doc(alias = "bookmark-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "bookmark-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "bookmark-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `bookmark-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bookmark-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOOKMARK_MULTIPLE_FILLED: &str = "bookmark-multiple-filled";
    #[doc(alias = "bookmark-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "bookmark-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "bookmark-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `bookmark-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bookmark-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOOKMARK_MULTIPLE_REGULAR: &str = "bookmark-multiple-regular";
    #[doc(alias = "bookmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bookmark-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "bookmark-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `bookmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bookmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOOKMARK_REGULAR: &str = "bookmark-regular";
    #[doc(alias = "border-all-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "border-all-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "border-all-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `border-all-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/border-all-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BORDER_ALL_FILLED: &str = "border-all-filled";
    #[doc(alias = "border-all-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "border-all-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "border-all-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `border-all-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/border-all-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BORDER_ALL_REGULAR: &str = "border-all-regular";
    #[doc(alias = "bottom")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bottom", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bottom", feature = "icon-development-kit"))]
    /// Icon name constant for the `bottom` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bottom-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOTTOM: &str = "bottom";
    #[doc(alias = "bottom-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bottom-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bottom-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `bottom-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bottom-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOTTOM_LARGE: &str = "bottom-large";
    #[doc(alias = "bowl-chopsticks-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bowl-chopsticks-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "bowl-chopsticks-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `bowl-chopsticks-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bowl-chopsticks-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOWL_CHOPSTICKS_FILLED: &str = "bowl-chopsticks-filled";
    #[doc(alias = "bowl-chopsticks-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bowl-chopsticks-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "bowl-chopsticks-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `bowl-chopsticks-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bowl-chopsticks-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOWL_CHOPSTICKS_REGULAR: &str = "bowl-chopsticks-regular";
    #[doc(alias = "box-down")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "box-down", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "box-down", feature = "icon-development-kit"))]
    /// Icon name constant for the `box-down` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/box-down-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOX_DOWN: &str = "box-down";
    #[doc(alias = "box-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "box-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "box-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `box-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/box-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOX_FILLED: &str = "box-filled";
    #[doc(alias = "box-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "box-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "box-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `box-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/box-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOX_LEFT: &str = "box-left";
    #[doc(alias = "box-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "box-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "box-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `box-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/box-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOX_REGULAR: &str = "box-regular";
    #[doc(alias = "box-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "box-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "box-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `box-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/box-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOX_RIGHT: &str = "box-right";
    #[doc(alias = "box-search-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "box-search-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "box-search-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `box-search-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/box-search-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOX_SEARCH_FILLED: &str = "box-search-filled";
    #[doc(alias = "box-search-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "box-search-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "box-search-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `box-search-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/box-search-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOX_SEARCH_REGULAR: &str = "box-search-regular";
    #[doc(alias = "box-up")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "box-up", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "box-up", feature = "icon-development-kit"))]
    /// Icon name constant for the `box-up` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/box-up-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BOX_UP: &str = "box-up";
    #[doc(alias = "braces-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "braces-checkmark-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "braces-checkmark-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `braces-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/braces-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRACES_CHECKMARK_FILLED: &str = "braces-checkmark-filled";
    #[doc(alias = "braces-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "braces-checkmark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "braces-checkmark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `braces-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/braces-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRACES_CHECKMARK_REGULAR: &str = "braces-checkmark-regular";
    #[doc(alias = "braces-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "braces-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "braces-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `braces-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/braces-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRACES_DISMISS_FILLED: &str = "braces-dismiss-filled";
    #[doc(alias = "braces-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "braces-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "braces-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `braces-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/braces-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRACES_DISMISS_REGULAR: &str = "braces-dismiss-regular";
    #[doc(alias = "braces-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "braces-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "braces-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `braces-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/braces-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRACES_FILLED: &str = "braces-filled";
    #[doc(alias = "braces-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "braces-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "braces-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `braces-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/braces-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRACES_REGULAR: &str = "braces-regular";
    #[doc(alias = "brain")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "brain", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "brain", feature = "icon-development-kit"))]
    /// Icon name constant for the `brain` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/brain-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRAIN: &str = "brain";
    #[doc(alias = "brain-augemnted")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "brain-augemnted", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "brain-augemnted", feature = "icon-development-kit"))]
    /// Icon name constant for the `brain-augemnted` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/brain-augemnted-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRAIN_AUGEMNTED: &str = "brain-augemnted";
    #[doc(alias = "branch")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "branch", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "branch", feature = "icon-development-kit"))]
    /// Icon name constant for the `branch` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/branch-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRANCH: &str = "branch";
    #[doc(alias = "branch-compare-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "branch-compare-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "branch-compare-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `branch-compare-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/branch-compare-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRANCH_COMPARE_FILLED: &str = "branch-compare-filled";
    #[doc(alias = "branch-compare-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "branch-compare-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "branch-compare-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `branch-compare-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/branch-compare-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRANCH_COMPARE_REGULAR: &str = "branch-compare-regular";
    #[doc(alias = "branch-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "branch-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "branch-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `branch-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/branch-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRANCH_FILLED: &str = "branch-filled";
    #[doc(alias = "branch-fork-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "branch-fork-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "branch-fork-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `branch-fork-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/branch-fork-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRANCH_FORK_FILLED: &str = "branch-fork-filled";
    #[doc(alias = "branch-fork-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "branch-fork-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "branch-fork-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `branch-fork-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/branch-fork-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRANCH_FORK_REGULAR: &str = "branch-fork-regular";
    #[doc(alias = "branch-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "branch-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "branch-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `branch-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/branch-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRANCH_REGULAR: &str = "branch-regular";
    #[doc(alias = "bread")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bread", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bread", feature = "icon-development-kit"))]
    /// Icon name constant for the `bread` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bread-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BREAD: &str = "bread";
    #[doc(alias = "break-point")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "break-point", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "break-point", feature = "icon-development-kit"))]
    /// Icon name constant for the `break-point` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/break-point-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BREAK_POINT: &str = "break-point";
    #[doc(alias = "briefcase")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "briefcase", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "briefcase", feature = "icon-development-kit"))]
    /// Icon name constant for the `briefcase` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/briefcase-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRIEFCASE: &str = "briefcase";
    #[doc(alias = "briefcase-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "briefcase-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "briefcase-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `briefcase-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/briefcase-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRIEFCASE_FILLED: &str = "briefcase-filled";
    #[doc(alias = "briefcase-medical-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "briefcase-medical-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "briefcase-medical-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `briefcase-medical-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/briefcase-medical-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRIEFCASE_MEDICAL_FILLED: &str = "briefcase-medical-filled";
    #[doc(alias = "briefcase-medical-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "briefcase-medical-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "briefcase-medical-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `briefcase-medical-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/briefcase-medical-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRIEFCASE_MEDICAL_REGULAR: &str = "briefcase-medical-regular";
    #[doc(alias = "briefcase-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "briefcase-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "briefcase-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `briefcase-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/briefcase-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRIEFCASE_OFF_FILLED: &str = "briefcase-off-filled";
    #[doc(alias = "briefcase-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "briefcase-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "briefcase-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `briefcase-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/briefcase-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRIEFCASE_OFF_REGULAR: &str = "briefcase-off-regular";
    #[doc(alias = "briefcase-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "briefcase-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "briefcase-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `briefcase-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/briefcase-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRIEFCASE_REGULAR: &str = "briefcase-regular";
    #[doc(alias = "brightness-high-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "brightness-high-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "brightness-high-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `brightness-high-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/brightness-high-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRIGHTNESS_HIGH_FILLED: &str = "brightness-high-filled";
    #[doc(alias = "brightness-high-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "brightness-high-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "brightness-high-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `brightness-high-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/brightness-high-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRIGHTNESS_HIGH_REGULAR: &str = "brightness-high-regular";
    #[doc(alias = "brightness-low-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "brightness-low-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "brightness-low-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `brightness-low-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/brightness-low-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRIGHTNESS_LOW_FILLED: &str = "brightness-low-filled";
    #[doc(alias = "brightness-low-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "brightness-low-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "brightness-low-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `brightness-low-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/brightness-low-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRIGHTNESS_LOW_REGULAR: &str = "brightness-low-regular";
    #[doc(alias = "broad-activity-feed-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "broad-activity-feed-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "broad-activity-feed-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `broad-activity-feed-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/broad-activity-feed-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BROAD_ACTIVITY_FEED_FILLED: &str = "broad-activity-feed-filled";
    #[doc(alias = "broad-activity-feed-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "broad-activity-feed-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "broad-activity-feed-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `broad-activity-feed-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/broad-activity-feed-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BROAD_ACTIVITY_FEED_REGULAR: &str = "broad-activity-feed-regular";
    #[doc(alias = "broken-camera-inverse")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "broken-camera-inverse", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "broken-camera-inverse", feature = "icon-development-kit"))]
    /// Icon name constant for the `broken-camera-inverse` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/broken-camera-inverse-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BROKEN_CAMERA_INVERSE: &str = "broken-camera-inverse";
    #[doc(alias = "broken-playback")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "broken-playback", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "broken-playback", feature = "icon-development-kit"))]
    /// Icon name constant for the `broken-playback` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/broken-playback-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BROKEN_PLAYBACK: &str = "broken-playback";
    #[doc(alias = "broken-video")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "broken-video", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "broken-video", feature = "icon-development-kit"))]
    /// Icon name constant for the `broken-video` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/broken-video-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BROKEN_VIDEO: &str = "broken-video";
    #[doc(alias = "broom-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "broom-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "broom-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `broom-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/broom-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BROOM_FILLED: &str = "broom-filled";
    #[doc(alias = "broom-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "broom-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "broom-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `broom-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/broom-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BROOM_REGULAR: &str = "broom-regular";
    #[doc(alias = "brush")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "brush", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "brush", feature = "icon-development-kit"))]
    /// Icon name constant for the `brush` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/brush-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRUSH: &str = "brush";
    #[doc(alias = "brush-monitor")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "brush-monitor", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "brush-monitor", feature = "icon-development-kit"))]
    /// Icon name constant for the `brush-monitor` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/brush-monitor-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BRUSH_MONITOR: &str = "brush-monitor";
    #[doc(alias = "bug")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bug", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bug", feature = "icon-development-kit"))]
    /// Icon name constant for the `bug` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bug-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUG: &str = "bug";
    #[doc(alias = "bug-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bug-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bug-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `bug-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bug-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUG_ALT: &str = "bug-alt";
    #[doc(alias = "bug-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bug-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "bug-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `bug-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bug-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUG_FILLED: &str = "bug-filled";
    #[doc(alias = "bug-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bug-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "bug-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `bug-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/bug-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUG_REGULAR: &str = "bug-regular";
    #[doc(alias = "build")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "build", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "build", feature = "icon-development-kit"))]
    /// Icon name constant for the `build` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/build-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILD: &str = "build";
    #[doc(alias = "build-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "build-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "build-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `build-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/build-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILD_ALT: &str = "build-alt";
    #[doc(alias = "build-configure")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "build-configure", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "build-configure", feature = "icon-development-kit"))]
    /// Icon name constant for the `build-configure` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/build-configure-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILD_CONFIGURE: &str = "build-configure";
    #[doc(alias = "building")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "building", feature = "icon-development-kit"))]
    /// Icon name constant for the `building` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/building-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING: &str = "building";
    #[doc(alias = "building-bank-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-bank-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-bank-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-bank-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-bank-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_BANK_FILLED: &str = "building-bank-filled";
    #[doc(alias = "building-bank-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "building-bank-link-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "building-bank-link-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `building-bank-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-bank-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_BANK_LINK_FILLED: &str = "building-bank-link-filled";
    #[doc(alias = "building-bank-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "building-bank-link-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "building-bank-link-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `building-bank-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-bank-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_BANK_LINK_REGULAR: &str = "building-bank-link-regular";
    #[doc(alias = "building-bank-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-bank-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-bank-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-bank-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-bank-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_BANK_REGULAR: &str = "building-bank-regular";
    #[doc(alias = "building-desktop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-desktop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-desktop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-desktop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-desktop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_DESKTOP_FILLED: &str = "building-desktop-filled";
    #[doc(alias = "building-desktop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "building-desktop-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "building-desktop-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `building-desktop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-desktop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_DESKTOP_REGULAR: &str = "building-desktop-regular";
    #[doc(alias = "building-factory-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-factory-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-factory-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-factory-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-factory-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_FACTORY_FILLED: &str = "building-factory-filled";
    #[doc(alias = "building-factory-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "building-factory-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "building-factory-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `building-factory-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-factory-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_FACTORY_REGULAR: &str = "building-factory-regular";
    #[doc(alias = "building-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_FILLED: &str = "building-filled";
    #[doc(alias = "building-home-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-home-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-home-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-home-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-home-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_HOME_FILLED: &str = "building-home-filled";
    #[doc(alias = "building-home-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-home-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-home-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-home-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-home-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_HOME_REGULAR: &str = "building-home-regular";
    #[doc(alias = "building-mosque-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-mosque-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-mosque-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-mosque-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-mosque-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_MOSQUE_FILLED: &str = "building-mosque-filled";
    #[doc(alias = "building-mosque-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-mosque-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-mosque-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-mosque-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-mosque-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_MOSQUE_REGULAR: &str = "building-mosque-regular";
    #[doc(alias = "building-people-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-people-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-people-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-people-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-people-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_PEOPLE_FILLED: &str = "building-people-filled";
    #[doc(alias = "building-people-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-people-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-people-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-people-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-people-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_PEOPLE_REGULAR: &str = "building-people-regular";
    #[doc(alias = "building-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_REGULAR: &str = "building-regular";
    #[doc(alias = "building-shop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-shop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-shop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-shop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-shop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_SHOP_FILLED: &str = "building-shop-filled";
    #[doc(alias = "building-shop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "building-shop-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "building-shop-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `building-shop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-shop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_SHOP_REGULAR: &str = "building-shop-regular";
    #[doc(alias = "building-skyscraper-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "building-skyscraper-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "building-skyscraper-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `building-skyscraper-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-skyscraper-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_SKYSCRAPER_FILLED: &str = "building-skyscraper-filled";
    #[doc(alias = "building-skyscraper-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "building-skyscraper-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "building-skyscraper-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `building-skyscraper-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/building-skyscraper-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUILDING_SKYSCRAPER_REGULAR: &str = "building-skyscraper-regular";
    #[doc(alias = "bus")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "bus", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "bus", feature = "icon-development-kit"))]
    /// Icon name constant for the `bus` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/bus-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUS: &str = "bus";
    #[doc(alias = "button-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "button-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "button-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `button-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/button-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUTTON_FILLED: &str = "button-filled";
    #[doc(alias = "button-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "button-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "button-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `button-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/button-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const BUTTON_REGULAR: &str = "button-regular";
    #[doc(alias = "cablecar")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cablecar", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cablecar", feature = "icon-development-kit"))]
    /// Icon name constant for the `cablecar` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cablecar-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CABLECAR: &str = "cablecar";
    #[doc(alias = "cafe")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cafe", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cafe", feature = "icon-development-kit"))]
    /// Icon name constant for the `cafe` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cafe-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAFE: &str = "cafe";
    #[doc(alias = "cage")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cage", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cage", feature = "icon-development-kit"))]
    /// Icon name constant for the `cage` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cage-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAGE: &str = "cage";
    #[doc(alias = "calculator-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calculator-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calculator-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calculator-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calculator-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALCULATOR_FILLED: &str = "calculator-filled";
    #[doc(alias = "calculator-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calculator-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calculator-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calculator-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calculator-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALCULATOR_MULTIPLE_FILLED: &str = "calculator-multiple-filled";
    #[doc(alias = "calculator-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calculator-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calculator-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calculator-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calculator-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALCULATOR_MULTIPLE_REGULAR: &str = "calculator-multiple-regular";
    #[doc(alias = "calculator-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calculator-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calculator-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calculator-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calculator-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALCULATOR_REGULAR: &str = "calculator-regular";
    #[doc(alias = "calendar-3-day-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-3-day-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-3-day-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-3-day-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-3-day-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_3_DAY_FILLED: &str = "calendar-3-day-filled";
    #[doc(alias = "calendar-3-day-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-3-day-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-3-day-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-3-day-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-3-day-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_3_DAY_REGULAR: &str = "calendar-3-day-regular";
    #[doc(alias = "calendar-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_ADD_FILLED: &str = "calendar-add-filled";
    #[doc(alias = "calendar-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_ADD_REGULAR: &str = "calendar-add-regular";
    #[doc(alias = "calendar-arrow-counterclockwise-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-arrow-counterclockwise-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-arrow-counterclockwise-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-arrow-counterclockwise-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-arrow-counterclockwise-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_ARROW_COUNTERCLOCKWISE_FILLED: &str =
        "calendar-arrow-counterclockwise-filled";
    #[doc(alias = "calendar-arrow-counterclockwise-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-arrow-counterclockwise-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-arrow-counterclockwise-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-arrow-counterclockwise-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-arrow-counterclockwise-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_ARROW_COUNTERCLOCKWISE_REGULAR: &str =
        "calendar-arrow-counterclockwise-regular";
    #[doc(alias = "calendar-arrow-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-arrow-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-arrow-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-arrow-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-arrow-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_ARROW_RIGHT_FILLED: &str = "calendar-arrow-right-filled";
    #[doc(alias = "calendar-arrow-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-arrow-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-arrow-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-arrow-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-arrow-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_ARROW_RIGHT_REGULAR: &str = "calendar-arrow-right-regular";
    #[doc(alias = "calendar-assistant-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-assistant-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-assistant-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-assistant-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-assistant-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_ASSISTANT_FILLED: &str = "calendar-assistant-filled";
    #[doc(alias = "calendar-assistant-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-assistant-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-assistant-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-assistant-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-assistant-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_ASSISTANT_REGULAR: &str = "calendar-assistant-regular";
    #[doc(alias = "calendar-cancel-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-cancel-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-cancel-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-cancel-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-cancel-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_CANCEL_FILLED: &str = "calendar-cancel-filled";
    #[doc(alias = "calendar-cancel-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-cancel-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-cancel-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-cancel-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-cancel-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_CANCEL_REGULAR: &str = "calendar-cancel-regular";
    #[doc(alias = "calendar-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-checkmark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-checkmark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_CHECKMARK_FILLED: &str = "calendar-checkmark-filled";
    #[doc(alias = "calendar-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-checkmark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-checkmark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_CHECKMARK_REGULAR: &str = "calendar-checkmark-regular";
    #[doc(alias = "calendar-clock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-clock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-clock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-clock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-clock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_CLOCK_FILLED: &str = "calendar-clock-filled";
    #[doc(alias = "calendar-clock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-clock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-clock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-clock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-clock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_CLOCK_REGULAR: &str = "calendar-clock-regular";
    #[doc(alias = "calendar-data-bar-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-data-bar-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-data-bar-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-data-bar-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-data-bar-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_DATA_BAR_FILLED: &str = "calendar-data-bar-filled";
    #[doc(alias = "calendar-data-bar-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-data-bar-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-data-bar-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-data-bar-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-data-bar-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_DATA_BAR_REGULAR: &str = "calendar-data-bar-regular";
    #[doc(alias = "calendar-day-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-day-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-day-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-day-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-day-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_DAY_FILLED: &str = "calendar-day-filled";
    #[doc(alias = "calendar-day-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-day-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-day-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-day-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-day-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_DAY_REGULAR: &str = "calendar-day-regular";
    #[doc(alias = "calendar-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_EDIT_FILLED: &str = "calendar-edit-filled";
    #[doc(alias = "calendar-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_EDIT_REGULAR: &str = "calendar-edit-regular";
    #[doc(alias = "calendar-empty-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-empty-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-empty-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-empty-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-empty-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_EMPTY_FILLED: &str = "calendar-empty-filled";
    #[doc(alias = "calendar-empty-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-empty-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-empty-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-empty-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-empty-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_EMPTY_REGULAR: &str = "calendar-empty-regular";
    #[doc(alias = "calendar-error-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-error-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-error-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-error-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-error-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_ERROR_FILLED: &str = "calendar-error-filled";
    #[doc(alias = "calendar-error-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-error-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-error-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-error-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-error-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_ERROR_REGULAR: &str = "calendar-error-regular";
    #[doc(alias = "calendar-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_FILLED: &str = "calendar-filled";
    #[doc(alias = "calendar-info-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-info-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-info-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-info-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-info-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_INFO_FILLED: &str = "calendar-info-filled";
    #[doc(alias = "calendar-info-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-info-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-info-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-info-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-info-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_INFO_REGULAR: &str = "calendar-info-regular";
    #[doc(alias = "calendar-lock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-lock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-lock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-lock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-lock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_LOCK_FILLED: &str = "calendar-lock-filled";
    #[doc(alias = "calendar-lock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-lock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-lock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-lock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-lock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_LOCK_REGULAR: &str = "calendar-lock-regular";
    #[doc(alias = "calendar-mail-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-mail-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-mail-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-mail-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-mail-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_MAIL_FILLED: &str = "calendar-mail-filled";
    #[doc(alias = "calendar-mail-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-mail-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-mail-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-mail-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-mail-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_MAIL_REGULAR: &str = "calendar-mail-regular";
    #[doc(alias = "calendar-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_MULTIPLE_FILLED: &str = "calendar-multiple-filled";
    #[doc(alias = "calendar-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_MULTIPLE_REGULAR: &str = "calendar-multiple-regular";
    #[doc(alias = "calendar-pattern-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-pattern-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-pattern-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-pattern-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-pattern-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_PATTERN_FILLED: &str = "calendar-pattern-filled";
    #[doc(alias = "calendar-pattern-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-pattern-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-pattern-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-pattern-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-pattern-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_PATTERN_REGULAR: &str = "calendar-pattern-regular";
    #[doc(alias = "calendar-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-person-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-person-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_PERSON_FILLED: &str = "calendar-person-filled";
    #[doc(alias = "calendar-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-person-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-person-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_PERSON_REGULAR: &str = "calendar-person-regular";
    #[doc(alias = "calendar-phone-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-phone-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-phone-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-phone-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-phone-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_PHONE_FILLED: &str = "calendar-phone-filled";
    #[doc(alias = "calendar-phone-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-phone-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-phone-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-phone-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-phone-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_PHONE_REGULAR: &str = "calendar-phone-regular";
    #[doc(alias = "calendar-play-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-play-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-play-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-play-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-play-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_PLAY_FILLED: &str = "calendar-play-filled";
    #[doc(alias = "calendar-play-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-play-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-play-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-play-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-play-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_PLAY_REGULAR: &str = "calendar-play-regular";
    #[doc(alias = "calendar-question-mark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-question-mark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-question-mark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-question-mark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-question-mark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_QUESTION_MARK_FILLED: &str = "calendar-question-mark-filled";
    #[doc(alias = "calendar-question-mark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-question-mark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-question-mark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-question-mark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-question-mark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_QUESTION_MARK_REGULAR: &str = "calendar-question-mark-regular";
    #[doc(alias = "calendar-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_REGULAR: &str = "calendar-regular";
    #[doc(alias = "calendar-reply-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-reply-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-reply-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-reply-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-reply-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_REPLY_FILLED: &str = "calendar-reply-filled";
    #[doc(alias = "calendar-reply-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-reply-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-reply-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-reply-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-reply-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_REPLY_REGULAR: &str = "calendar-reply-regular";
    #[doc(alias = "calendar-search-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-search-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-search-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-search-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-search-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_SEARCH_FILLED: &str = "calendar-search-filled";
    #[doc(alias = "calendar-search-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-search-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-search-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-search-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-search-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_SEARCH_REGULAR: &str = "calendar-search-regular";
    #[doc(alias = "calendar-settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-settings-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-settings-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_SETTINGS_FILLED: &str = "calendar-settings-filled";
    #[doc(alias = "calendar-settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-settings-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-settings-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_SETTINGS_REGULAR: &str = "calendar-settings-regular";
    #[doc(alias = "calendar-shield-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-shield-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-shield-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-shield-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-shield-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_SHIELD_FILLED: &str = "calendar-shield-filled";
    #[doc(alias = "calendar-shield-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-shield-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-shield-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-shield-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-shield-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_SHIELD_REGULAR: &str = "calendar-shield-regular";
    #[doc(alias = "calendar-star-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-star-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-star-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-star-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-star-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_STAR_FILLED: &str = "calendar-star-filled";
    #[doc(alias = "calendar-star-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-star-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-star-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-star-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-star-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_STAR_REGULAR: &str = "calendar-star-regular";
    #[doc(alias = "calendar-sync-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-sync-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-sync-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-sync-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-sync-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_SYNC_FILLED: &str = "calendar-sync-filled";
    #[doc(alias = "calendar-sync-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-sync-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-sync-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-sync-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-sync-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_SYNC_REGULAR: &str = "calendar-sync-regular";
    #[doc(alias = "calendar-today-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-today-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-today-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-today-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-today-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_TODAY_FILLED: &str = "calendar-today-filled";
    #[doc(alias = "calendar-today-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "calendar-today-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "calendar-today-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `calendar-today-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-today-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_TODAY_REGULAR: &str = "calendar-today-regular";
    #[doc(alias = "calendar-work-week-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-work-week-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-work-week-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-work-week-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-work-week-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_WORK_WEEK_FILLED: &str = "calendar-work-week-filled";
    #[doc(alias = "calendar-work-week-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "calendar-work-week-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "calendar-work-week-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `calendar-work-week-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/calendar-work-week-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALENDAR_WORK_WEEK_REGULAR: &str = "calendar-work-week-regular";
    #[doc(alias = "call-add")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-add", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-add", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-add` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-add-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_ADD: &str = "call-add";
    #[doc(alias = "call-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_ADD_FILLED: &str = "call-add-filled";
    #[doc(alias = "call-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_ADD_REGULAR: &str = "call-add-regular";
    #[doc(alias = "call-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_DISMISS_FILLED: &str = "call-dismiss-filled";
    #[doc(alias = "call-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_DISMISS_REGULAR: &str = "call-dismiss-regular";
    #[doc(alias = "call-emergency")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-emergency", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-emergency", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-emergency` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-emergency-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_EMERGENCY: &str = "call-emergency";
    #[doc(alias = "call-end-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-end-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-end-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-end-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-end-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_END_FILLED: &str = "call-end-filled";
    #[doc(alias = "call-end-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-end-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-end-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-end-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-end-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_END_REGULAR: &str = "call-end-regular";
    #[doc(alias = "call-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_FILLED: &str = "call-filled";
    #[doc(alias = "call-forward-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-forward-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-forward-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-forward-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-forward-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_FORWARD_FILLED: &str = "call-forward-filled";
    #[doc(alias = "call-forward-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-forward-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-forward-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-forward-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-forward-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_FORWARD_REGULAR: &str = "call-forward-regular";
    #[doc(alias = "call-inbound-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-inbound-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-inbound-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-inbound-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-inbound-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_INBOUND_FILLED: &str = "call-inbound-filled";
    #[doc(alias = "call-inbound-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-inbound-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-inbound-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-inbound-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-inbound-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_INBOUND_REGULAR: &str = "call-inbound-regular";
    #[doc(alias = "call-incoming")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-incoming", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-incoming", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-incoming` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-incoming-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_INCOMING: &str = "call-incoming";
    #[doc(alias = "call-made")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-made", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-made", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-made` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-made-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_MADE: &str = "call-made";
    #[doc(alias = "call-merge")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-merge", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-merge", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-merge` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-merge-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_MERGE: &str = "call-merge";
    #[doc(alias = "call-missed")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-missed", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-missed", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-missed` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-missed-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_MISSED: &str = "call-missed";
    #[doc(alias = "call-missed-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-missed-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-missed-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-missed-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-missed-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_MISSED_FILLED: &str = "call-missed-filled";
    #[doc(alias = "call-missed-incoming")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-missed-incoming", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-missed-incoming", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-missed-incoming` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-missed-incoming-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_MISSED_INCOMING: &str = "call-missed-incoming";
    #[doc(alias = "call-missed-outgoing")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-missed-outgoing", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-missed-outgoing", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-missed-outgoing` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-missed-outgoing-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_MISSED_OUTGOING: &str = "call-missed-outgoing";
    #[doc(alias = "call-missed-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-missed-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-missed-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-missed-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-missed-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_MISSED_REGULAR: &str = "call-missed-regular";
    #[doc(alias = "call-outbound-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-outbound-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-outbound-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-outbound-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-outbound-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_OUTBOUND_FILLED: &str = "call-outbound-filled";
    #[doc(alias = "call-outbound-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-outbound-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-outbound-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-outbound-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-outbound-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_OUTBOUND_REGULAR: &str = "call-outbound-regular";
    #[doc(alias = "call-outgoing")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-outgoing", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-outgoing", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-outgoing` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-outgoing-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_OUTGOING: &str = "call-outgoing";
    #[doc(alias = "call-outgoing-unsuccessful")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "call-outgoing-unsuccessful",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "call-outgoing-unsuccessful",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `call-outgoing-unsuccessful` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-outgoing-unsuccessful-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_OUTGOING_UNSUCCESSFUL: &str = "call-outgoing-unsuccessful";
    #[doc(alias = "call-park-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-park-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-park-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-park-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-park-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_PARK_FILLED: &str = "call-park-filled";
    #[doc(alias = "call-park-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-park-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-park-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-park-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-park-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_PARK_REGULAR: &str = "call-park-regular";
    #[doc(alias = "call-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-prohibited-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-prohibited-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_PROHIBITED_FILLED: &str = "call-prohibited-filled";
    #[doc(alias = "call-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-prohibited-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-prohibited-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_PROHIBITED_REGULAR: &str = "call-prohibited-regular";
    #[doc(alias = "call-received")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-received", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-received", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-received` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-received-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_RECEIVED: &str = "call-received";
    #[doc(alias = "call-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_REGULAR: &str = "call-regular";
    #[doc(alias = "call-ring")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-ring", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-ring", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-ring` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-ring-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_RING: &str = "call-ring";
    #[doc(alias = "call-ringer-silenced")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-ringer-silenced", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-ringer-silenced", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-ringer-silenced` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-ringer-silenced-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_RINGER_SILENCED: &str = "call-ringer-silenced";
    #[doc(alias = "call-split")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-split", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "call-split", feature = "icon-development-kit"))]
    /// Icon name constant for the `call-split` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/call-split-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_SPLIT: &str = "call-split";
    #[doc(alias = "call-transfer-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-transfer-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-transfer-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-transfer-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-transfer-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_TRANSFER_FILLED: &str = "call-transfer-filled";
    #[doc(alias = "call-transfer-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-transfer-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-transfer-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-transfer-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-transfer-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_TRANSFER_REGULAR: &str = "call-transfer-regular";
    #[doc(alias = "call-warning-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-warning-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-warning-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-warning-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-warning-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_WARNING_FILLED: &str = "call-warning-filled";
    #[doc(alias = "call-warning-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "call-warning-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "call-warning-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `call-warning-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/call-warning-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CALL_WARNING_REGULAR: &str = "call-warning-regular";
    #[doc(alias = "camera")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA: &str = "camera";
    #[doc(alias = "camera-broken")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-broken", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-broken", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-broken` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-broken-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_BROKEN: &str = "camera-broken";
    #[doc(alias = "camera-dead")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-dead", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-dead", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-dead` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-dead-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_DEAD: &str = "camera-dead";
    #[doc(alias = "camera-dome-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-dome-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "camera-dome-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `camera-dome-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/camera-dome-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_DOME_FILLED: &str = "camera-dome-filled";
    #[doc(alias = "camera-dome-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-dome-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "camera-dome-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `camera-dome-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/camera-dome-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_DOME_REGULAR: &str = "camera-dome-regular";
    #[doc(alias = "camera-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "camera-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `camera-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/camera-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_FILLED: &str = "camera-filled";
    #[doc(alias = "camera-flash")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-flash", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-flash", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-flash` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-flash-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_FLASH: &str = "camera-flash";
    #[doc(alias = "camera-flash-auto")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-flash-auto", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-flash-auto", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-flash-auto` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-flash-auto-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_FLASH_AUTO: &str = "camera-flash-auto";
    #[doc(alias = "camera-flash-disabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-flash-disabled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-flash-disabled", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-flash-disabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-flash-disabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_FLASH_DISABLED: &str = "camera-flash-disabled";
    #[doc(alias = "camera-focus")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-focus", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-focus", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-focus` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-focus-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_FOCUS: &str = "camera-focus";
    #[doc(alias = "camera-grid")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-grid", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-grid", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-grid` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-grid-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_GRID: &str = "camera-grid";
    #[doc(alias = "camera-iso")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-iso", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-iso", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-iso` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-iso-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_ISO: &str = "camera-iso";
    #[doc(alias = "camera-iso-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-iso-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-iso-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-iso-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-iso-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_ISO_ALT: &str = "camera-iso-alt";
    #[doc(alias = "camera-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_LARGE: &str = "camera-large";
    #[doc(alias = "camera-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "camera-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `camera-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/camera-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_OFF_FILLED: &str = "camera-off-filled";
    #[doc(alias = "camera-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "camera-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `camera-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/camera-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_OFF_REGULAR: &str = "camera-off-regular";
    #[doc(alias = "camera-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "camera-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `camera-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/camera-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_REGULAR: &str = "camera-regular";
    #[doc(alias = "camera-shutter")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-shutter", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-shutter", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-shutter` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-shutter-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_SHUTTER: &str = "camera-shutter";
    #[doc(alias = "camera-sparkles-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-sparkles-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "camera-sparkles-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `camera-sparkles-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/camera-sparkles-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_SPARKLES_FILLED: &str = "camera-sparkles-filled";
    #[doc(alias = "camera-sparkles-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-sparkles-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "camera-sparkles-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `camera-sparkles-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/camera-sparkles-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_SPARKLES_REGULAR: &str = "camera-sparkles-regular";
    #[doc(alias = "camera-static")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-static", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-static", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-static` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-static-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_STATIC: &str = "camera-static";
    #[doc(alias = "camera-static-inverse")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-static-inverse", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-static-inverse", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-static-inverse` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-static-inverse-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_STATIC_INVERSE: &str = "camera-static-inverse";
    #[doc(alias = "camera-timer")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-timer", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-timer", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-timer` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-timer-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_TIMER: &str = "camera-timer";
    #[doc(alias = "camera-toggle")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "camera-toggle", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "camera-toggle", feature = "icon-development-kit"))]
    /// Icon name constant for the `camera-toggle` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/camera-toggle-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERA_TOGGLE: &str = "camera-toggle";
    #[doc(alias = "cameras")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cameras", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cameras", feature = "icon-development-kit"))]
    /// Icon name constant for the `cameras` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cameras-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAMERAS: &str = "cameras";
    #[doc(alias = "caret-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "caret-down-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "caret-down-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `caret-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/caret-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CARET_DOWN_FILLED: &str = "caret-down-filled";
    #[doc(alias = "caret-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "caret-down-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "caret-down-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `caret-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/caret-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CARET_DOWN_REGULAR: &str = "caret-down-regular";
    #[doc(alias = "caret-down-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "caret-down-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "caret-down-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `caret-down-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/caret-down-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CARET_DOWN_RIGHT_FILLED: &str = "caret-down-right-filled";
    #[doc(alias = "caret-down-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "caret-down-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "caret-down-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `caret-down-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/caret-down-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CARET_DOWN_RIGHT_REGULAR: &str = "caret-down-right-regular";
    #[doc(alias = "caret-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "caret-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "caret-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `caret-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/caret-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CARET_LEFT_FILLED: &str = "caret-left-filled";
    #[doc(alias = "caret-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "caret-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "caret-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `caret-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/caret-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CARET_LEFT_REGULAR: &str = "caret-left-regular";
    #[doc(alias = "caret-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "caret-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "caret-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `caret-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/caret-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CARET_RIGHT_FILLED: &str = "caret-right-filled";
    #[doc(alias = "caret-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "caret-right-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "caret-right-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `caret-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/caret-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CARET_RIGHT_REGULAR: &str = "caret-right-regular";
    #[doc(alias = "caret-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "caret-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "caret-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `caret-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/caret-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CARET_UP_FILLED: &str = "caret-up-filled";
    #[doc(alias = "caret-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "caret-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "caret-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `caret-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/caret-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CARET_UP_REGULAR: &str = "caret-up-regular";
    #[doc(alias = "carousel")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "carousel", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "carousel", feature = "icon-development-kit"))]
    /// Icon name constant for the `carousel` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/carousel-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAROUSEL: &str = "carousel";
    #[doc(alias = "cart-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cart-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cart-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cart-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cart-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CART_FILLED: &str = "cart-filled";
    #[doc(alias = "cart-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cart-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cart-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cart-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cart-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CART_REGULAR: &str = "cart-regular";
    #[doc(alias = "cat")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cat", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cat", feature = "icon-development-kit"))]
    /// Icon name constant for the `cat` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cat-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAT: &str = "cat";
    #[doc(alias = "cat-sleeping")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cat-sleeping", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cat-sleeping", feature = "icon-development-kit"))]
    /// Icon name constant for the `cat-sleeping` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cat-sleeping-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CAT_SLEEPING: &str = "cat-sleeping";
    #[doc(alias = "catch-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "catch-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "catch-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `catch-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/catch-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CATCH_UP_FILLED: &str = "catch-up-filled";
    #[doc(alias = "catch-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "catch-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "catch-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `catch-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/catch-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CATCH_UP_REGULAR: &str = "catch-up-regular";
    #[doc(alias = "cd")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cd", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cd", feature = "icon-development-kit"))]
    /// Icon name constant for the `cd` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cd-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CD: &str = "cd";
    #[doc(alias = "cd-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cd-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cd-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cd-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cd-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CD_FILLED: &str = "cd-filled";
    #[doc(alias = "cd-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cd-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cd-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cd-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cd-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CD_REGULAR: &str = "cd-regular";
    #[doc(alias = "center")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "center", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "center", feature = "icon-development-kit"))]
    /// Icon name constant for the `center` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/center-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CENTER: &str = "center";
    #[doc(alias = "center-on-page-horizontal")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "center-on-page-horizontal",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "center-on-page-horizontal",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `center-on-page-horizontal` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/center-on-page-horizontal-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CENTER_ON_PAGE_HORIZONTAL: &str = "center-on-page-horizontal";
    #[doc(alias = "center-on-page-vertical")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "center-on-page-vertical", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "center-on-page-vertical", feature = "icon-development-kit"))]
    /// Icon name constant for the `center-on-page-vertical` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/center-on-page-vertical-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CENTER_ON_PAGE_VERTICAL: &str = "center-on-page-vertical";
    #[doc(alias = "certificate-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "certificate-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "certificate-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `certificate-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/certificate-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CERTIFICATE_FILLED: &str = "certificate-filled";
    #[doc(alias = "certificate-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "certificate-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "certificate-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `certificate-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/certificate-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CERTIFICATE_REGULAR: &str = "certificate-regular";
    #[doc(alias = "chain-link")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chain-link", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "chain-link", feature = "icon-development-kit"))]
    /// Icon name constant for the `chain-link` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/chain-link-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAIN_LINK: &str = "chain-link";
    #[doc(alias = "chain-link-loose")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chain-link-loose", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "chain-link-loose", feature = "icon-development-kit"))]
    /// Icon name constant for the `chain-link-loose` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/chain-link-loose-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAIN_LINK_LOOSE: &str = "chain-link-loose";
    #[doc(alias = "channel-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "channel-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "channel-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `channel-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_ADD_FILLED: &str = "channel-add-filled";
    #[doc(alias = "channel-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "channel-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "channel-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `channel-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_ADD_REGULAR: &str = "channel-add-regular";
    #[doc(alias = "channel-alert-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "channel-alert-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "channel-alert-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `channel-alert-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-alert-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_ALERT_FILLED: &str = "channel-alert-filled";
    #[doc(alias = "channel-alert-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "channel-alert-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "channel-alert-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `channel-alert-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-alert-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_ALERT_REGULAR: &str = "channel-alert-regular";
    #[doc(alias = "channel-arrow-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "channel-arrow-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "channel-arrow-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `channel-arrow-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-arrow-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_ARROW_LEFT_FILLED: &str = "channel-arrow-left-filled";
    #[doc(alias = "channel-arrow-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "channel-arrow-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "channel-arrow-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `channel-arrow-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-arrow-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_ARROW_LEFT_REGULAR: &str = "channel-arrow-left-regular";
    #[doc(alias = "channel-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "channel-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "channel-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `channel-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_DISMISS_FILLED: &str = "channel-dismiss-filled";
    #[doc(alias = "channel-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "channel-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "channel-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `channel-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_DISMISS_REGULAR: &str = "channel-dismiss-regular";
    #[doc(alias = "channel-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "channel-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "channel-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `channel-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_FILLED: &str = "channel-filled";
    #[doc(alias = "channel-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "channel-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "channel-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `channel-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_REGULAR: &str = "channel-regular";
    #[doc(alias = "channel-share-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "channel-share-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "channel-share-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `channel-share-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-share-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_SHARE_FILLED: &str = "channel-share-filled";
    #[doc(alias = "channel-share-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "channel-share-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "channel-share-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `channel-share-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-share-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_SHARE_REGULAR: &str = "channel-share-regular";
    #[doc(alias = "channel-subtract-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "channel-subtract-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "channel-subtract-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `channel-subtract-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-subtract-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_SUBTRACT_FILLED: &str = "channel-subtract-filled";
    #[doc(alias = "channel-subtract-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "channel-subtract-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "channel-subtract-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `channel-subtract-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/channel-subtract-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHANNEL_SUBTRACT_REGULAR: &str = "channel-subtract-regular";
    #[doc(alias = "charge")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "charge", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "charge", feature = "icon-development-kit"))]
    /// Icon name constant for the `charge` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/charge-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHARGE: &str = "charge";
    #[doc(alias = "chat")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "chat", feature = "icon-development-kit"))]
    /// Icon name constant for the `chat` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/chat-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT: &str = "chat";
    #[doc(alias = "chat-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_ADD_FILLED: &str = "chat-add-filled";
    #[doc(alias = "chat-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_ADD_REGULAR: &str = "chat-add-regular";
    #[doc(alias = "chat-arrow-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-arrow-back-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-arrow-back-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-arrow-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-arrow-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_ARROW_BACK_FILLED: &str = "chat-arrow-back-filled";
    #[doc(alias = "chat-arrow-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-arrow-back-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-arrow-back-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-arrow-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-arrow-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_ARROW_BACK_REGULAR: &str = "chat-arrow-back-regular";
    #[doc(alias = "chat-arrow-double-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chat-arrow-double-back-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chat-arrow-double-back-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chat-arrow-double-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-arrow-double-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_ARROW_DOUBLE_BACK_FILLED: &str = "chat-arrow-double-back-filled";
    #[doc(alias = "chat-arrow-double-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chat-arrow-double-back-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chat-arrow-double-back-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chat-arrow-double-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-arrow-double-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_ARROW_DOUBLE_BACK_REGULAR: &str = "chat-arrow-double-back-regular";
    #[doc(alias = "chat-bubble-emtpy")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-bubble-emtpy", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "chat-bubble-emtpy", feature = "icon-development-kit"))]
    /// Icon name constant for the `chat-bubble-emtpy` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/chat-bubble-emtpy-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_BUBBLE_EMTPY: &str = "chat-bubble-emtpy";
    #[doc(alias = "chat-bubble-text")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-bubble-text", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "chat-bubble-text", feature = "icon-development-kit"))]
    /// Icon name constant for the `chat-bubble-text` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/chat-bubble-text-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_BUBBLE_TEXT: &str = "chat-bubble-text";
    #[doc(alias = "chat-bubble-text-inverted")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chat-bubble-text-inverted",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "chat-bubble-text-inverted",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `chat-bubble-text-inverted` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/chat-bubble-text-inverted-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_BUBBLE_TEXT_INVERTED: &str = "chat-bubble-text-inverted";
    #[doc(alias = "chat-bubbles-empty-inverted")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chat-bubbles-empty-inverted",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "chat-bubbles-empty-inverted",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `chat-bubbles-empty-inverted` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/chat-bubbles-empty-inverted-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_BUBBLES_EMPTY_INVERTED: &str = "chat-bubbles-empty-inverted";
    #[doc(alias = "chat-bubbles-emtpy")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-bubbles-emtpy", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "chat-bubbles-emtpy", feature = "icon-development-kit"))]
    /// Icon name constant for the `chat-bubbles-emtpy` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/chat-bubbles-emtpy-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_BUBBLES_EMTPY: &str = "chat-bubbles-emtpy";
    #[doc(alias = "chat-bubbles-question-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chat-bubbles-question-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chat-bubbles-question-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chat-bubbles-question-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-bubbles-question-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_BUBBLES_QUESTION_FILLED: &str = "chat-bubbles-question-filled";
    #[doc(alias = "chat-bubbles-question-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chat-bubbles-question-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chat-bubbles-question-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chat-bubbles-question-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-bubbles-question-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_BUBBLES_QUESTION_REGULAR: &str = "chat-bubbles-question-regular";
    #[doc(alias = "chat-bubbles-text")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-bubbles-text", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "chat-bubbles-text", feature = "icon-development-kit"))]
    /// Icon name constant for the `chat-bubbles-text` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/chat-bubbles-text-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_BUBBLES_TEXT: &str = "chat-bubbles-text";
    #[doc(alias = "chat-bubbles-text-inverted")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chat-bubbles-text-inverted",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "chat-bubbles-text-inverted",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `chat-bubbles-text-inverted` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/chat-bubbles-text-inverted-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_BUBBLES_TEXT_INVERTED: &str = "chat-bubbles-text-inverted";
    #[doc(alias = "chat-cursor-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-cursor-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-cursor-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-cursor-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-cursor-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_CURSOR_FILLED: &str = "chat-cursor-filled";
    #[doc(alias = "chat-cursor-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-cursor-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-cursor-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-cursor-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-cursor-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_CURSOR_REGULAR: &str = "chat-cursor-regular";
    #[doc(alias = "chat-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_DISMISS_FILLED: &str = "chat-dismiss-filled";
    #[doc(alias = "chat-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_DISMISS_REGULAR: &str = "chat-dismiss-regular";
    #[doc(alias = "chat-empty-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-empty-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-empty-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-empty-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-empty-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_EMPTY_FILLED: &str = "chat-empty-filled";
    #[doc(alias = "chat-empty-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-empty-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-empty-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-empty-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-empty-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_EMPTY_REGULAR: &str = "chat-empty-regular";
    #[doc(alias = "chat-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_FILLED: &str = "chat-filled";
    #[doc(alias = "chat-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_MULTIPLE_FILLED: &str = "chat-multiple-filled";
    #[doc(alias = "chat-multiple-heart-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chat-multiple-heart-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chat-multiple-heart-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chat-multiple-heart-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-multiple-heart-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_MULTIPLE_HEART_FILLED: &str = "chat-multiple-heart-filled";
    #[doc(alias = "chat-multiple-heart-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chat-multiple-heart-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chat-multiple-heart-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chat-multiple-heart-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-multiple-heart-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_MULTIPLE_HEART_REGULAR: &str = "chat-multiple-heart-regular";
    #[doc(alias = "chat-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_MULTIPLE_REGULAR: &str = "chat-multiple-regular";
    #[doc(alias = "chat-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "chat-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `chat-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/chat-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_NONE: &str = "chat-none";
    #[doc(alias = "chat-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_REGULAR: &str = "chat-regular";
    #[doc(alias = "chat-sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-sparkle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-sparkle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_SPARKLE_FILLED: &str = "chat-sparkle-filled";
    #[doc(alias = "chat-sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-sparkle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-sparkle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_SPARKLE_REGULAR: &str = "chat-sparkle-regular";
    #[doc(alias = "chat-warning-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-warning-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-warning-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-warning-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-warning-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_WARNING_FILLED: &str = "chat-warning-filled";
    #[doc(alias = "chat-warning-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chat-warning-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chat-warning-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chat-warning-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chat-warning-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHAT_WARNING_REGULAR: &str = "chat-warning-regular";
    #[doc(alias = "check-plain")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "check-plain", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "check-plain", feature = "icon-development-kit"))]
    /// Icon name constant for the `check-plain` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/check-plain-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECK_PLAIN: &str = "check-plain";
    #[doc(alias = "check-round-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "check-round-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "check-round-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `check-round-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/check-round-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECK_ROUND_OUTLINE: &str = "check-round-outline";
    #[doc(alias = "check-round-outline-whole")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "check-round-outline-whole",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "check-round-outline-whole",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `check-round-outline-whole` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/check-round-outline-whole-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECK_ROUND_OUTLINE_WHOLE: &str = "check-round-outline-whole";
    #[doc(alias = "check-round-outline2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "check-round-outline2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "check-round-outline2", feature = "icon-development-kit"))]
    /// Icon name constant for the `check-round-outline2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/check-round-outline2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECK_ROUND_OUTLINE2: &str = "check-round-outline2";
    #[doc(alias = "checkbox-checked-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkbox-checked-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "checkbox-checked-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `checkbox-checked-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkbox-checked-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKBOX_CHECKED_FILLED: &str = "checkbox-checked-filled";
    #[doc(alias = "checkbox-checked-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkbox-checked-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkbox-checked-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkbox-checked-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkbox-checked-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKBOX_CHECKED_REGULAR: &str = "checkbox-checked-regular";
    #[doc(alias = "checkbox-checked-sync-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkbox-checked-sync-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkbox-checked-sync-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkbox-checked-sync-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkbox-checked-sync-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKBOX_CHECKED_SYNC_FILLED: &str = "checkbox-checked-sync-filled";
    #[doc(alias = "checkbox-checked-sync-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkbox-checked-sync-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkbox-checked-sync-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkbox-checked-sync-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkbox-checked-sync-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKBOX_CHECKED_SYNC_REGULAR: &str = "checkbox-checked-sync-regular";
    #[doc(alias = "checkbox-indeterminate-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkbox-indeterminate-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkbox-indeterminate-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkbox-indeterminate-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkbox-indeterminate-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKBOX_INDETERMINATE_FILLED: &str = "checkbox-indeterminate-filled";
    #[doc(alias = "checkbox-indeterminate-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkbox-indeterminate-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkbox-indeterminate-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkbox-indeterminate-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkbox-indeterminate-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKBOX_INDETERMINATE_REGULAR: &str = "checkbox-indeterminate-regular";
    #[doc(alias = "checkbox-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkbox-person-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "checkbox-person-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `checkbox-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkbox-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKBOX_PERSON_FILLED: &str = "checkbox-person-filled";
    #[doc(alias = "checkbox-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkbox-person-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "checkbox-person-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `checkbox-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkbox-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKBOX_PERSON_REGULAR: &str = "checkbox-person-regular";
    #[doc(alias = "checkbox-unchecked-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkbox-unchecked-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkbox-unchecked-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkbox-unchecked-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkbox-unchecked-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKBOX_UNCHECKED_FILLED: &str = "checkbox-unchecked-filled";
    #[doc(alias = "checkbox-unchecked-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkbox-unchecked-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkbox-unchecked-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkbox-unchecked-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkbox-unchecked-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKBOX_UNCHECKED_REGULAR: &str = "checkbox-unchecked-regular";
    #[doc(alias = "checkerboard")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkerboard", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "checkerboard", feature = "icon-development-kit"))]
    /// Icon name constant for the `checkerboard` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/checkerboard-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKERBOARD: &str = "checkerboard";
    #[doc(alias = "checkerboard-big")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkerboard-big", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "checkerboard-big", feature = "icon-development-kit"))]
    /// Icon name constant for the `checkerboard-big` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/checkerboard-big-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKERBOARD_BIG: &str = "checkerboard-big";
    #[doc(alias = "checkmark")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkmark", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "checkmark", feature = "icon-development-kit"))]
    /// Icon name constant for the `checkmark` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/checkmark-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK: &str = "checkmark";
    #[doc(alias = "checkmark-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkmark-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "checkmark-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `checkmark-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/checkmark-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_ALT: &str = "checkmark-alt";
    #[doc(alias = "checkmark-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkmark-circle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "checkmark-circle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `checkmark-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_CIRCLE_FILLED: &str = "checkmark-circle-filled";
    #[doc(alias = "checkmark-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkmark-circle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkmark-circle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkmark-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_CIRCLE_REGULAR: &str = "checkmark-circle-regular";
    #[doc(alias = "checkmark-circle-square-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkmark-circle-square-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkmark-circle-square-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkmark-circle-square-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-circle-square-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_CIRCLE_SQUARE_FILLED: &str = "checkmark-circle-square-filled";
    #[doc(alias = "checkmark-circle-square-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkmark-circle-square-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkmark-circle-square-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkmark-circle-square-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-circle-square-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_CIRCLE_SQUARE_REGULAR: &str = "checkmark-circle-square-regular";
    #[doc(alias = "checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkmark-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "checkmark-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_FILLED: &str = "checkmark-filled";
    #[doc(alias = "checkmark-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkmark-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "checkmark-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `checkmark-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/checkmark-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_LARGE: &str = "checkmark-large";
    #[doc(alias = "checkmark-lock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkmark-lock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "checkmark-lock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `checkmark-lock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-lock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_LOCK_FILLED: &str = "checkmark-lock-filled";
    #[doc(alias = "checkmark-lock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkmark-lock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "checkmark-lock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `checkmark-lock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-lock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_LOCK_REGULAR: &str = "checkmark-lock-regular";
    #[doc(alias = "checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkmark-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "checkmark-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_REGULAR: &str = "checkmark-regular";
    #[doc(alias = "checkmark-small")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "checkmark-small", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "checkmark-small", feature = "icon-development-kit"))]
    /// Icon name constant for the `checkmark-small` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/checkmark-small-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_SMALL: &str = "checkmark-small";
    #[doc(alias = "checkmark-starburst-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkmark-starburst-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkmark-starburst-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkmark-starburst-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-starburst-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_STARBURST_FILLED: &str = "checkmark-starburst-filled";
    #[doc(alias = "checkmark-starburst-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkmark-starburst-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkmark-starburst-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkmark-starburst-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-starburst-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_STARBURST_REGULAR: &str = "checkmark-starburst-regular";
    #[doc(alias = "checkmark-underline-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkmark-underline-circle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkmark-underline-circle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkmark-underline-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-underline-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_UNDERLINE_CIRCLE_FILLED: &str = "checkmark-underline-circle-filled";
    #[doc(alias = "checkmark-underline-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "checkmark-underline-circle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "checkmark-underline-circle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `checkmark-underline-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/checkmark-underline-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHECKMARK_UNDERLINE_CIRCLE_REGULAR: &str = "checkmark-underline-circle-regular";
    #[doc(alias = "chevron-circle-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-circle-down-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-circle-down-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-circle-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-circle-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_CIRCLE_DOWN_FILLED: &str = "chevron-circle-down-filled";
    #[doc(alias = "chevron-circle-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-circle-down-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-circle-down-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-circle-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-circle-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_CIRCLE_DOWN_REGULAR: &str = "chevron-circle-down-regular";
    #[doc(alias = "chevron-circle-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-circle-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-circle-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-circle-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-circle-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_CIRCLE_LEFT_FILLED: &str = "chevron-circle-left-filled";
    #[doc(alias = "chevron-circle-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-circle-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-circle-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-circle-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-circle-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_CIRCLE_LEFT_REGULAR: &str = "chevron-circle-left-regular";
    #[doc(alias = "chevron-circle-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-circle-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-circle-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-circle-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-circle-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_CIRCLE_RIGHT_FILLED: &str = "chevron-circle-right-filled";
    #[doc(alias = "chevron-circle-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-circle-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-circle-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-circle-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-circle-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_CIRCLE_RIGHT_REGULAR: &str = "chevron-circle-right-regular";
    #[doc(alias = "chevron-circle-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-circle-up-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-circle-up-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-circle-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-circle-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_CIRCLE_UP_FILLED: &str = "chevron-circle-up-filled";
    #[doc(alias = "chevron-circle-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-circle-up-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-circle-up-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-circle-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-circle-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_CIRCLE_UP_REGULAR: &str = "chevron-circle-up-regular";
    #[doc(alias = "chevron-double-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-double-down-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-double-down-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-double-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-double-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOUBLE_DOWN_FILLED: &str = "chevron-double-down-filled";
    #[doc(alias = "chevron-double-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-double-down-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-double-down-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-double-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-double-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOUBLE_DOWN_REGULAR: &str = "chevron-double-down-regular";
    #[doc(alias = "chevron-double-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-double-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-double-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-double-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-double-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOUBLE_LEFT_FILLED: &str = "chevron-double-left-filled";
    #[doc(alias = "chevron-double-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-double-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-double-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-double-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-double-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOUBLE_LEFT_REGULAR: &str = "chevron-double-left-regular";
    #[doc(alias = "chevron-double-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-double-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-double-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-double-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-double-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOUBLE_RIGHT_FILLED: &str = "chevron-double-right-filled";
    #[doc(alias = "chevron-double-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-double-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-double-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-double-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-double-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOUBLE_RIGHT_REGULAR: &str = "chevron-double-right-regular";
    #[doc(alias = "chevron-double-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-double-up-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-double-up-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-double-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-double-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOUBLE_UP_FILLED: &str = "chevron-double-up-filled";
    #[doc(alias = "chevron-double-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "chevron-double-up-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "chevron-double-up-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `chevron-double-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-double-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOUBLE_UP_REGULAR: &str = "chevron-double-up-regular";
    #[doc(alias = "chevron-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-down-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-down-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOWN_FILLED: &str = "chevron-down-filled";
    #[doc(alias = "chevron-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-down-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-down-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOWN_REGULAR: &str = "chevron-down-regular";
    #[doc(alias = "chevron-down-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-down-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-down-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-down-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-down-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOWN_UP_FILLED: &str = "chevron-down-up-filled";
    #[doc(alias = "chevron-down-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-down-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-down-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-down-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-down-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_DOWN_UP_REGULAR: &str = "chevron-down-up-regular";
    #[doc(alias = "chevron-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_LEFT_FILLED: &str = "chevron-left-filled";
    #[doc(alias = "chevron-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_LEFT_REGULAR: &str = "chevron-left-regular";
    #[doc(alias = "chevron-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_RIGHT_FILLED: &str = "chevron-right-filled";
    #[doc(alias = "chevron-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-right-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-right-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_RIGHT_REGULAR: &str = "chevron-right-regular";
    #[doc(alias = "chevron-up-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-up-down-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-up-down-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-up-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-up-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_UP_DOWN_FILLED: &str = "chevron-up-down-filled";
    #[doc(alias = "chevron-up-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-up-down-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-up-down-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-up-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-up-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_UP_DOWN_REGULAR: &str = "chevron-up-down-regular";
    #[doc(alias = "chevron-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_UP_FILLED: &str = "chevron-up-filled";
    #[doc(alias = "chevron-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "chevron-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "chevron-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `chevron-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/chevron-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHEVRON_UP_REGULAR: &str = "chevron-up-regular";
    #[doc(alias = "christmas")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "christmas", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "christmas", feature = "icon-development-kit"))]
    /// Icon name constant for the `christmas` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/christmas-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CHRISTMAS: &str = "christmas";
    #[doc(alias = "cigarette")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cigarette", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cigarette", feature = "icon-development-kit"))]
    /// Icon name constant for the `cigarette` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cigarette-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIGARETTE: &str = "cigarette";
    #[doc(alias = "cigarette-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cigarette-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cigarette-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `cigarette-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cigarette-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIGARETTE_NONE: &str = "cigarette-none";
    #[doc(alias = "circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "circle-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `circle-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_FILLED: &str = "circle-filled";
    #[doc(alias = "circle-filled-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-filled-alt", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "circle-filled-alt", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `circle-filled-alt` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_FILLED_ALT: &str = "circle-filled-alt";
    #[doc(alias = "circle-half-fill-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-half-fill-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "circle-half-fill-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `circle-half-fill-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-half-fill-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_HALF_FILL_FILLED: &str = "circle-half-fill-filled";
    #[doc(alias = "circle-half-fill-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "circle-half-fill-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "circle-half-fill-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `circle-half-fill-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-half-fill-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_HALF_FILL_REGULAR: &str = "circle-half-fill-regular";
    #[doc(alias = "circle-hint-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-hint-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "circle-hint-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `circle-hint-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-hint-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_HINT_FILLED: &str = "circle-hint-filled";
    #[doc(alias = "circle-hint-half-vertical-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "circle-hint-half-vertical-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "circle-hint-half-vertical-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `circle-hint-half-vertical-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-hint-half-vertical-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_HINT_HALF_VERTICAL_FILLED: &str = "circle-hint-half-vertical-filled";
    #[doc(alias = "circle-hint-half-vertical-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "circle-hint-half-vertical-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "circle-hint-half-vertical-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `circle-hint-half-vertical-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-hint-half-vertical-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_HINT_HALF_VERTICAL_REGULAR: &str = "circle-hint-half-vertical-regular";
    #[doc(alias = "circle-hint-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-hint-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "circle-hint-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `circle-hint-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-hint-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_HINT_REGULAR: &str = "circle-hint-regular";
    #[doc(alias = "circle-image-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-image-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "circle-image-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `circle-image-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-image-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_IMAGE_FILLED: &str = "circle-image-filled";
    #[doc(alias = "circle-image-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-image-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "circle-image-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `circle-image-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-image-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_IMAGE_REGULAR: &str = "circle-image-regular";
    #[doc(alias = "circle-line-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-line-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "circle-line-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `circle-line-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-line-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_LINE_FILLED: &str = "circle-line-filled";
    #[doc(alias = "circle-line-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-line-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "circle-line-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `circle-line-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-line-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_LINE_REGULAR: &str = "circle-line-regular";
    #[doc(alias = "circle-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "circle-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `circle-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_OFF_FILLED: &str = "circle-off-filled";
    #[doc(alias = "circle-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "circle-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `circle-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_OFF_REGULAR: &str = "circle-off-regular";
    #[doc(alias = "circle-outline-thick")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-outline-thick", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "circle-outline-thick", feature = "icon-development-kit"))]
    /// Icon name constant for the `circle-outline-thick` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/circle-outline-thick-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_OUTLINE_THICK: &str = "circle-outline-thick";
    #[doc(alias = "circle-outline-thin")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-outline-thin", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "circle-outline-thin", feature = "icon-development-kit"))]
    /// Icon name constant for the `circle-outline-thin` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/circle-outline-thin-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_OUTLINE_THIN: &str = "circle-outline-thin";
    #[doc(alias = "circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "circle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "circle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CIRCLE_REGULAR: &str = "circle-regular";
    #[doc(alias = "city")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "city", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "city", feature = "icon-development-kit"))]
    /// Icon name constant for the `city` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/city-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CITY: &str = "city";
    #[doc(alias = "city-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "city-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "city-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `city-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/city-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CITY_FILLED: &str = "city-filled";
    #[doc(alias = "city-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "city-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "city-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `city-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/city-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CITY_REGULAR: &str = "city-regular";
    #[doc(alias = "classification-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "classification-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "classification-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `classification-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/classification-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLASSIFICATION_FILLED: &str = "classification-filled";
    #[doc(alias = "classification-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "classification-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "classification-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `classification-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/classification-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLASSIFICATION_REGULAR: &str = "classification-regular";
    #[doc(alias = "clear-formatting-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clear-formatting-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clear-formatting-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clear-formatting-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clear-formatting-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLEAR_FORMATTING_FILLED: &str = "clear-formatting-filled";
    #[doc(alias = "clear-formatting-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "clear-formatting-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "clear-formatting-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `clear-formatting-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clear-formatting-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLEAR_FORMATTING_REGULAR: &str = "clear-formatting-regular";
    #[doc(alias = "clipboard")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "clipboard", feature = "icon-development-kit"))]
    /// Icon name constant for the `clipboard` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/clipboard-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD: &str = "clipboard";
    #[doc(alias = "clipboard-3-day-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-3-day-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-3-day-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-3-day-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-3-day-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_3_DAY_FILLED: &str = "clipboard-3-day-filled";
    #[doc(alias = "clipboard-3-day-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-3-day-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-3-day-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-3-day-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-3-day-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_3_DAY_REGULAR: &str = "clipboard-3-day-regular";
    #[doc(alias = "clipboard-arrow-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "clipboard-arrow-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "clipboard-arrow-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `clipboard-arrow-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-arrow-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_ARROW_RIGHT_FILLED: &str = "clipboard-arrow-right-filled";
    #[doc(alias = "clipboard-arrow-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "clipboard-arrow-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "clipboard-arrow-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `clipboard-arrow-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-arrow-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_ARROW_RIGHT_REGULAR: &str = "clipboard-arrow-right-regular";
    #[doc(alias = "clipboard-bullet-list-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "clipboard-bullet-list-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "clipboard-bullet-list-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `clipboard-bullet-list-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-bullet-list-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_BULLET_LIST_FILLED: &str = "clipboard-bullet-list-filled";
    #[doc(alias = "clipboard-bullet-list-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "clipboard-bullet-list-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "clipboard-bullet-list-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `clipboard-bullet-list-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-bullet-list-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_BULLET_LIST_REGULAR: &str = "clipboard-bullet-list-regular";
    #[doc(alias = "clipboard-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "clipboard-checkmark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "clipboard-checkmark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `clipboard-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_CHECKMARK_FILLED: &str = "clipboard-checkmark-filled";
    #[doc(alias = "clipboard-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "clipboard-checkmark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "clipboard-checkmark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `clipboard-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_CHECKMARK_REGULAR: &str = "clipboard-checkmark-regular";
    #[doc(alias = "clipboard-code-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-code-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-code-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-code-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-code-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_CODE_FILLED: &str = "clipboard-code-filled";
    #[doc(alias = "clipboard-code-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-code-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-code-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-code-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-code-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_CODE_REGULAR: &str = "clipboard-code-regular";
    #[doc(alias = "clipboard-day-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-day-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-day-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-day-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-day-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_DAY_FILLED: &str = "clipboard-day-filled";
    #[doc(alias = "clipboard-day-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-day-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-day-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-day-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-day-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_DAY_REGULAR: &str = "clipboard-day-regular";
    #[doc(alias = "clipboard-error-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-error-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-error-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-error-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-error-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_ERROR_FILLED: &str = "clipboard-error-filled";
    #[doc(alias = "clipboard-error-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-error-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-error-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-error-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-error-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_ERROR_REGULAR: &str = "clipboard-error-regular";
    #[doc(alias = "clipboard-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_FILLED: &str = "clipboard-filled";
    #[doc(alias = "clipboard-letter-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-letter-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-letter-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-letter-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-letter-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_LETTER_FILLED: &str = "clipboard-letter-filled";
    #[doc(alias = "clipboard-letter-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "clipboard-letter-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "clipboard-letter-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `clipboard-letter-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-letter-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_LETTER_REGULAR: &str = "clipboard-letter-regular";
    #[doc(alias = "clipboard-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-link-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-link-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_LINK_FILLED: &str = "clipboard-link-filled";
    #[doc(alias = "clipboard-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-link-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-link-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_LINK_REGULAR: &str = "clipboard-link-regular";
    #[doc(alias = "clipboard-month-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-month-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-month-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-month-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-month-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_MONTH_FILLED: &str = "clipboard-month-filled";
    #[doc(alias = "clipboard-month-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-month-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-month-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-month-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-month-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_MONTH_REGULAR: &str = "clipboard-month-regular";
    #[doc(alias = "clipboard-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "clipboard-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "clipboard-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `clipboard-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_MULTIPLE_FILLED: &str = "clipboard-multiple-filled";
    #[doc(alias = "clipboard-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "clipboard-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "clipboard-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `clipboard-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_MULTIPLE_REGULAR: &str = "clipboard-multiple-regular";
    #[doc(alias = "clipboard-note-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-note-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-note-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-note-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-note-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_NOTE_FILLED: &str = "clipboard-note-filled";
    #[doc(alias = "clipboard-note-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-note-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-note-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-note-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-note-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_NOTE_REGULAR: &str = "clipboard-note-regular";
    #[doc(alias = "clipboard-paste-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-paste-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-paste-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-paste-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-paste-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_PASTE_FILLED: &str = "clipboard-paste-filled";
    #[doc(alias = "clipboard-paste-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-paste-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-paste-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-paste-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-paste-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_PASTE_REGULAR: &str = "clipboard-paste-regular";
    #[doc(alias = "clipboard-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_REGULAR: &str = "clipboard-regular";
    #[doc(alias = "clipboard-task-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-task-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-task-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-task-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-task-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_TASK_FILLED: &str = "clipboard-task-filled";
    #[doc(alias = "clipboard-task-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clipboard-task-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clipboard-task-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clipboard-task-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clipboard-task-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLIPBOARD_TASK_REGULAR: &str = "clipboard-task-regular";
    #[doc(alias = "clock")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clock", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "clock", feature = "icon-development-kit"))]
    /// Icon name constant for the `clock` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/clock-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOCK: &str = "clock";
    #[doc(alias = "clock-alarm-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clock-alarm-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clock-alarm-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clock-alarm-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clock-alarm-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOCK_ALARM_FILLED: &str = "clock-alarm-filled";
    #[doc(alias = "clock-alarm-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clock-alarm-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clock-alarm-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clock-alarm-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clock-alarm-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOCK_ALARM_REGULAR: &str = "clock-alarm-regular";
    #[doc(alias = "clock-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clock-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "clock-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `clock-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/clock-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOCK_ALT: &str = "clock-alt";
    #[doc(alias = "clock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOCK_FILLED: &str = "clock-filled";
    #[doc(alias = "clock-lock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clock-lock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clock-lock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clock-lock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clock-lock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOCK_LOCK_FILLED: &str = "clock-lock-filled";
    #[doc(alias = "clock-lock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clock-lock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clock-lock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clock-lock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clock-lock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOCK_LOCK_REGULAR: &str = "clock-lock-regular";
    #[doc(alias = "clock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOCK_REGULAR: &str = "clock-regular";
    #[doc(alias = "closed-caption-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "closed-caption-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "closed-caption-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `closed-caption-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/closed-caption-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOSED_CAPTION_FILLED: &str = "closed-caption-filled";
    #[doc(alias = "closed-caption-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "closed-caption-off-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "closed-caption-off-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `closed-caption-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/closed-caption-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOSED_CAPTION_OFF_FILLED: &str = "closed-caption-off-filled";
    #[doc(alias = "closed-caption-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "closed-caption-off-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "closed-caption-off-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `closed-caption-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/closed-caption-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOSED_CAPTION_OFF_REGULAR: &str = "closed-caption-off-regular";
    #[doc(alias = "closed-caption-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "closed-caption-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "closed-caption-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `closed-caption-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/closed-caption-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOSED_CAPTION_REGULAR: &str = "closed-caption-regular";
    #[doc(alias = "closed-captioning")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "closed-captioning", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "closed-captioning", feature = "icon-development-kit"))]
    /// Icon name constant for the `closed-captioning` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/closed-captioning-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOSED_CAPTIONING: &str = "closed-captioning";
    #[doc(alias = "cloud-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_ADD_FILLED: &str = "cloud-add-filled";
    #[doc(alias = "cloud-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_ADD_REGULAR: &str = "cloud-add-regular";
    #[doc(alias = "cloud-archive-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-archive-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-archive-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-archive-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-archive-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_ARCHIVE_FILLED: &str = "cloud-archive-filled";
    #[doc(alias = "cloud-archive-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-archive-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-archive-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-archive-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-archive-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_ARCHIVE_REGULAR: &str = "cloud-archive-regular";
    #[doc(alias = "cloud-arrow-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-arrow-down-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-arrow-down-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-arrow-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-arrow-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_ARROW_DOWN_FILLED: &str = "cloud-arrow-down-filled";
    #[doc(alias = "cloud-arrow-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "cloud-arrow-down-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "cloud-arrow-down-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `cloud-arrow-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-arrow-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_ARROW_DOWN_REGULAR: &str = "cloud-arrow-down-regular";
    #[doc(alias = "cloud-arrow-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-arrow-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-arrow-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-arrow-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-arrow-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_ARROW_UP_FILLED: &str = "cloud-arrow-up-filled";
    #[doc(alias = "cloud-arrow-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-arrow-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-arrow-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-arrow-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-arrow-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_ARROW_UP_REGULAR: &str = "cloud-arrow-up-regular";
    #[doc(alias = "cloud-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-checkmark-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-checkmark-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_CHECKMARK_FILLED: &str = "cloud-checkmark-filled";
    #[doc(alias = "cloud-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-checkmark-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-checkmark-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_CHECKMARK_REGULAR: &str = "cloud-checkmark-regular";
    #[doc(alias = "cloud-disabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-disabled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cloud-disabled", feature = "icon-development-kit"))]
    /// Icon name constant for the `cloud-disabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cloud-disabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_DISABLED: &str = "cloud-disabled";
    #[doc(alias = "cloud-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_DISMISS_FILLED: &str = "cloud-dismiss-filled";
    #[doc(alias = "cloud-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_DISMISS_REGULAR: &str = "cloud-dismiss-regular";
    #[doc(alias = "cloud-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_EDIT_FILLED: &str = "cloud-edit-filled";
    #[doc(alias = "cloud-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_EDIT_REGULAR: &str = "cloud-edit-regular";
    #[doc(alias = "cloud-error-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-error-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-error-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-error-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-error-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_ERROR_FILLED: &str = "cloud-error-filled";
    #[doc(alias = "cloud-error-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-error-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-error-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-error-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-error-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_ERROR_REGULAR: &str = "cloud-error-regular";
    #[doc(alias = "cloud-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cloud-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `cloud-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cloud-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_FILLED: &str = "cloud-filled";
    #[doc(alias = "cloud-filled-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-filled-alt", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-filled-alt", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-filled-alt` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_FILLED_ALT: &str = "cloud-filled-alt";
    #[doc(alias = "cloud-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-link-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-link-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_LINK_FILLED: &str = "cloud-link-filled";
    #[doc(alias = "cloud-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-link-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-link-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_LINK_REGULAR: &str = "cloud-link-regular";
    #[doc(alias = "cloud-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_OFF_FILLED: &str = "cloud-off-filled";
    #[doc(alias = "cloud-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_OFF_REGULAR: &str = "cloud-off-regular";
    #[doc(alias = "cloud-outline-thick")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-outline-thick", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cloud-outline-thick", feature = "icon-development-kit"))]
    /// Icon name constant for the `cloud-outline-thick` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cloud-outline-thick-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_OUTLINE_THICK: &str = "cloud-outline-thick";
    #[doc(alias = "cloud-outline-thin")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-outline-thin", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cloud-outline-thin", feature = "icon-development-kit"))]
    /// Icon name constant for the `cloud-outline-thin` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cloud-outline-thin-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_OUTLINE_THIN: &str = "cloud-outline-thin";
    #[doc(alias = "cloud-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_REGULAR: &str = "cloud-regular";
    #[doc(alias = "cloud-sync-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-sync-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-sync-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-sync-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-sync-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_SYNC_FILLED: &str = "cloud-sync-filled";
    #[doc(alias = "cloud-sync-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-sync-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-sync-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-sync-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-sync-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_SYNC_REGULAR: &str = "cloud-sync-regular";
    #[doc(alias = "cloud-words-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-words-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-words-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-words-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-words-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_WORDS_FILLED: &str = "cloud-words-filled";
    #[doc(alias = "cloud-words-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cloud-words-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cloud-words-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cloud-words-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cloud-words-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUD_WORDS_REGULAR: &str = "cloud-words-regular";
    #[doc(alias = "clouds")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clouds", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "clouds", feature = "icon-development-kit"))]
    /// Icon name constant for the `clouds` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/clouds-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUDS: &str = "clouds";
    #[doc(alias = "clouds-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clouds-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "clouds-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `clouds-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/clouds-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOUDS_OUTLINE: &str = "clouds-outline";
    #[doc(alias = "clover-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clover-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clover-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clover-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clover-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOVER_FILLED: &str = "clover-filled";
    #[doc(alias = "clover-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "clover-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "clover-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `clover-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/clover-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CLOVER_REGULAR: &str = "clover-regular";
    #[doc(alias = "cocktail")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cocktail", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cocktail", feature = "icon-development-kit"))]
    /// Icon name constant for the `cocktail` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cocktail-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COCKTAIL: &str = "cocktail";
    #[doc(alias = "code")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "code", feature = "icon-development-kit"))]
    /// Icon name constant for the `code` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/code-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE: &str = "code";
    #[doc(alias = "code-block-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-block-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-block-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-block-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-block-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_BLOCK_FILLED: &str = "code-block-filled";
    #[doc(alias = "code-block-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-block-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-block-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-block-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-block-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_BLOCK_REGULAR: &str = "code-block-regular";
    #[doc(alias = "code-cs-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-cs-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-cs-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-cs-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-cs-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_CS_FILLED: &str = "code-cs-filled";
    #[doc(alias = "code-cs-rectangle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-cs-rectangle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-cs-rectangle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-cs-rectangle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-cs-rectangle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_CS_RECTANGLE_FILLED: &str = "code-cs-rectangle-filled";
    #[doc(alias = "code-cs-rectangle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-cs-rectangle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-cs-rectangle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-cs-rectangle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-cs-rectangle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_CS_RECTANGLE_REGULAR: &str = "code-cs-rectangle-regular";
    #[doc(alias = "code-cs-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-cs-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-cs-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-cs-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-cs-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_CS_REGULAR: &str = "code-cs-regular";
    #[doc(alias = "code-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_FILLED: &str = "code-filled";
    #[doc(alias = "code-fs-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-fs-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-fs-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-fs-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-fs-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_FS_FILLED: &str = "code-fs-filled";
    #[doc(alias = "code-fs-rectangle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-fs-rectangle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-fs-rectangle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-fs-rectangle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-fs-rectangle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_FS_RECTANGLE_FILLED: &str = "code-fs-rectangle-filled";
    #[doc(alias = "code-fs-rectangle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-fs-rectangle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-fs-rectangle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-fs-rectangle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-fs-rectangle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_FS_RECTANGLE_REGULAR: &str = "code-fs-rectangle-regular";
    #[doc(alias = "code-fs-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-fs-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-fs-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-fs-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-fs-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_FS_REGULAR: &str = "code-fs-regular";
    #[doc(alias = "code-js-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-js-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-js-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-js-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-js-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_JS_FILLED: &str = "code-js-filled";
    #[doc(alias = "code-js-rectangle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-js-rectangle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-js-rectangle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-js-rectangle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-js-rectangle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_JS_RECTANGLE_FILLED: &str = "code-js-rectangle-filled";
    #[doc(alias = "code-js-rectangle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-js-rectangle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-js-rectangle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-js-rectangle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-js-rectangle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_JS_RECTANGLE_REGULAR: &str = "code-js-rectangle-regular";
    #[doc(alias = "code-js-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-js-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-js-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-js-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-js-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_JS_REGULAR: &str = "code-js-regular";
    #[doc(alias = "code-py-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-py-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-py-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-py-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-py-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_PY_FILLED: &str = "code-py-filled";
    #[doc(alias = "code-py-rectangle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-py-rectangle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-py-rectangle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-py-rectangle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-py-rectangle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_PY_RECTANGLE_FILLED: &str = "code-py-rectangle-filled";
    #[doc(alias = "code-py-rectangle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-py-rectangle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-py-rectangle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-py-rectangle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-py-rectangle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_PY_RECTANGLE_REGULAR: &str = "code-py-rectangle-regular";
    #[doc(alias = "code-py-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-py-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-py-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-py-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-py-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_PY_REGULAR: &str = "code-py-regular";
    #[doc(alias = "code-rb-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-rb-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-rb-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-rb-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-rb-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_RB_FILLED: &str = "code-rb-filled";
    #[doc(alias = "code-rb-rectangle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-rb-rectangle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-rb-rectangle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-rb-rectangle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-rb-rectangle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_RB_RECTANGLE_FILLED: &str = "code-rb-rectangle-filled";
    #[doc(alias = "code-rb-rectangle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-rb-rectangle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-rb-rectangle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-rb-rectangle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-rb-rectangle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_RB_RECTANGLE_REGULAR: &str = "code-rb-rectangle-regular";
    #[doc(alias = "code-rb-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-rb-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-rb-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-rb-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-rb-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_RB_REGULAR: &str = "code-rb-regular";
    #[doc(alias = "code-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_REGULAR: &str = "code-regular";
    #[doc(alias = "code-text-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-text-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-text-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-text-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-text-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_TEXT_FILLED: &str = "code-text-filled";
    #[doc(alias = "code-text-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-text-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-text-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-text-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-text-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_TEXT_OFF_FILLED: &str = "code-text-off-filled";
    #[doc(alias = "code-text-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-text-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-text-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-text-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-text-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_TEXT_OFF_REGULAR: &str = "code-text-off-regular";
    #[doc(alias = "code-text-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-text-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-text-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-text-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-text-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_TEXT_REGULAR: &str = "code-text-regular";
    #[doc(alias = "code-ts-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-ts-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-ts-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-ts-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-ts-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_TS_FILLED: &str = "code-ts-filled";
    #[doc(alias = "code-ts-rectangle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-ts-rectangle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-ts-rectangle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-ts-rectangle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-ts-rectangle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_TS_RECTANGLE_FILLED: &str = "code-ts-rectangle-filled";
    #[doc(alias = "code-ts-rectangle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-ts-rectangle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-ts-rectangle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-ts-rectangle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-ts-rectangle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_TS_RECTANGLE_REGULAR: &str = "code-ts-rectangle-regular";
    #[doc(alias = "code-ts-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-ts-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-ts-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-ts-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-ts-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_TS_REGULAR: &str = "code-ts-regular";
    #[doc(alias = "code-vb-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-vb-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-vb-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-vb-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-vb-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_VB_FILLED: &str = "code-vb-filled";
    #[doc(alias = "code-vb-rectangle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-vb-rectangle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-vb-rectangle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-vb-rectangle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-vb-rectangle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_VB_RECTANGLE_FILLED: &str = "code-vb-rectangle-filled";
    #[doc(alias = "code-vb-rectangle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "code-vb-rectangle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "code-vb-rectangle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `code-vb-rectangle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-vb-rectangle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_VB_RECTANGLE_REGULAR: &str = "code-vb-rectangle-regular";
    #[doc(alias = "code-vb-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "code-vb-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "code-vb-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `code-vb-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/code-vb-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CODE_VB_REGULAR: &str = "code-vb-regular";
    #[doc(alias = "coin")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "coin", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "coin", feature = "icon-development-kit"))]
    /// Icon name constant for the `coin` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/coin-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COIN: &str = "coin";
    #[doc(alias = "color")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "color", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "color", feature = "icon-development-kit"))]
    /// Icon name constant for the `color` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/color-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLOR: &str = "color";
    #[doc(alias = "color-fill-accent-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "color-fill-accent-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "color-fill-accent-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `color-fill-accent-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/color-fill-accent-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLOR_FILL_ACCENT_REGULAR: &str = "color-fill-accent-regular";
    #[doc(alias = "color-fill-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "color-fill-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "color-fill-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `color-fill-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/color-fill-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLOR_FILL_FILLED: &str = "color-fill-filled";
    #[doc(alias = "color-fill-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "color-fill-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "color-fill-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `color-fill-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/color-fill-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLOR_FILL_REGULAR: &str = "color-fill-regular";
    #[doc(alias = "color-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "color-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "color-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `color-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/color-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLOR_FILLED: &str = "color-filled";
    #[doc(alias = "color-line-accent-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "color-line-accent-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "color-line-accent-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `color-line-accent-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/color-line-accent-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLOR_LINE_ACCENT_REGULAR: &str = "color-line-accent-regular";
    #[doc(alias = "color-line-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "color-line-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "color-line-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `color-line-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/color-line-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLOR_LINE_FILLED: &str = "color-line-filled";
    #[doc(alias = "color-line-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "color-line-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "color-line-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `color-line-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/color-line-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLOR_LINE_REGULAR: &str = "color-line-regular";
    #[doc(alias = "color-picker")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "color-picker", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "color-picker", feature = "icon-development-kit"))]
    /// Icon name constant for the `color-picker` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/color-picker-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLOR_PICKER: &str = "color-picker";
    #[doc(alias = "color-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "color-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "color-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `color-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/color-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLOR_REGULAR: &str = "color-regular";
    #[doc(alias = "colorimeter-colorhug")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "colorimeter-colorhug", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "colorimeter-colorhug", feature = "icon-development-kit"))]
    /// Icon name constant for the `colorimeter-colorhug` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/colorimeter-colorhug-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLORIMETER_COLORHUG: &str = "colorimeter-colorhug";
    #[doc(alias = "column-single-compare-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "column-single-compare-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "column-single-compare-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `column-single-compare-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/column-single-compare-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLUMN_SINGLE_COMPARE_FILLED: &str = "column-single-compare-filled";
    #[doc(alias = "column-single-compare-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "column-single-compare-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "column-single-compare-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `column-single-compare-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/column-single-compare-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLUMN_SINGLE_COMPARE_REGULAR: &str = "column-single-compare-regular";
    #[doc(alias = "column-single-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "column-single-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "column-single-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `column-single-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/column-single-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLUMN_SINGLE_FILLED: &str = "column-single-filled";
    #[doc(alias = "column-single-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "column-single-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "column-single-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `column-single-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/column-single-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLUMN_SINGLE_REGULAR: &str = "column-single-regular";
    #[doc(alias = "columns")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "columns", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "columns", feature = "icon-development-kit"))]
    /// Icon name constant for the `columns` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/columns-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COLUMNS: &str = "columns";
    #[doc(alias = "comment-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_ADD_FILLED: &str = "comment-add-filled";
    #[doc(alias = "comment-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_ADD_REGULAR: &str = "comment-add-regular";
    #[doc(alias = "comment-arrow-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "comment-arrow-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "comment-arrow-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `comment-arrow-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-arrow-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_ARROW_LEFT_FILLED: &str = "comment-arrow-left-filled";
    #[doc(alias = "comment-arrow-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "comment-arrow-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "comment-arrow-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `comment-arrow-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-arrow-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_ARROW_LEFT_REGULAR: &str = "comment-arrow-left-regular";
    #[doc(alias = "comment-arrow-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "comment-arrow-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "comment-arrow-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `comment-arrow-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-arrow-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_ARROW_RIGHT_FILLED: &str = "comment-arrow-right-filled";
    #[doc(alias = "comment-arrow-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "comment-arrow-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "comment-arrow-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `comment-arrow-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-arrow-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_ARROW_RIGHT_REGULAR: &str = "comment-arrow-right-regular";
    #[doc(alias = "comment-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "comment-checkmark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "comment-checkmark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `comment-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_CHECKMARK_FILLED: &str = "comment-checkmark-filled";
    #[doc(alias = "comment-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "comment-checkmark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "comment-checkmark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `comment-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_CHECKMARK_REGULAR: &str = "comment-checkmark-regular";
    #[doc(alias = "comment-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_EDIT_FILLED: &str = "comment-edit-filled";
    #[doc(alias = "comment-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_EDIT_REGULAR: &str = "comment-edit-regular";
    #[doc(alias = "comment-error-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-error-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-error-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-error-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-error-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_ERROR_FILLED: &str = "comment-error-filled";
    #[doc(alias = "comment-error-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-error-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-error-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-error-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-error-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_ERROR_REGULAR: &str = "comment-error-regular";
    #[doc(alias = "comment-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_FILLED: &str = "comment-filled";
    #[doc(alias = "comment-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-link-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-link-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_LINK_FILLED: &str = "comment-link-filled";
    #[doc(alias = "comment-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-link-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-link-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_LINK_REGULAR: &str = "comment-link-regular";
    #[doc(alias = "comment-mention-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-mention-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-mention-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-mention-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-mention-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_MENTION_FILLED: &str = "comment-mention-filled";
    #[doc(alias = "comment-mention-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-mention-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-mention-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-mention-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-mention-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_MENTION_REGULAR: &str = "comment-mention-regular";
    #[doc(alias = "comment-multiple-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "comment-multiple-checkmark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "comment-multiple-checkmark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `comment-multiple-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-multiple-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_MULTIPLE_CHECKMARK_FILLED: &str = "comment-multiple-checkmark-filled";
    #[doc(alias = "comment-multiple-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "comment-multiple-checkmark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "comment-multiple-checkmark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `comment-multiple-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-multiple-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_MULTIPLE_CHECKMARK_REGULAR: &str = "comment-multiple-checkmark-regular";
    #[doc(alias = "comment-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_MULTIPLE_FILLED: &str = "comment-multiple-filled";
    #[doc(alias = "comment-multiple-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "comment-multiple-link-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "comment-multiple-link-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `comment-multiple-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-multiple-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_MULTIPLE_LINK_FILLED: &str = "comment-multiple-link-filled";
    #[doc(alias = "comment-multiple-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "comment-multiple-link-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "comment-multiple-link-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `comment-multiple-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-multiple-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_MULTIPLE_LINK_REGULAR: &str = "comment-multiple-link-regular";
    #[doc(alias = "comment-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "comment-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "comment-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `comment-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_MULTIPLE_REGULAR: &str = "comment-multiple-regular";
    #[doc(alias = "comment-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_OFF_FILLED: &str = "comment-off-filled";
    #[doc(alias = "comment-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_OFF_REGULAR: &str = "comment-off-regular";
    #[doc(alias = "comment-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "comment-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "comment-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `comment-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/comment-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMENT_REGULAR: &str = "comment-regular";
    #[doc(alias = "communication-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "communication-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "communication-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `communication-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/communication-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMUNICATION_FILLED: &str = "communication-filled";
    #[doc(alias = "communication-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "communication-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "communication-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `communication-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/communication-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMMUNICATION_REGULAR: &str = "communication-regular";
    #[doc(alias = "compass")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "compass", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "compass", feature = "icon-development-kit"))]
    /// Icon name constant for the `compass` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/compass-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMPASS: &str = "compass";
    #[doc(alias = "compass-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "compass-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "compass-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `compass-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/compass-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMPASS_ALT: &str = "compass-alt";
    #[doc(alias = "compass-northwest-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "compass-northwest-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "compass-northwest-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `compass-northwest-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/compass-northwest-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMPASS_NORTHWEST_FILLED: &str = "compass-northwest-filled";
    #[doc(alias = "compass-northwest-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "compass-northwest-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "compass-northwest-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `compass-northwest-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/compass-northwest-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMPASS_NORTHWEST_REGULAR: &str = "compass-northwest-regular";
    #[doc(alias = "compass-wind")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "compass-wind", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "compass-wind", feature = "icon-development-kit"))]
    /// Icon name constant for the `compass-wind` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/compass-wind-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMPASS_WIND: &str = "compass-wind";
    #[doc(alias = "compass2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "compass2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "compass2", feature = "icon-development-kit"))]
    /// Icon name constant for the `compass2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/compass2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMPASS2: &str = "compass2";
    #[doc(alias = "compose-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "compose-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "compose-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `compose-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/compose-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMPOSE_FILLED: &str = "compose-filled";
    #[doc(alias = "compose-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "compose-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "compose-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `compose-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/compose-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMPOSE_REGULAR: &str = "compose-regular";
    #[doc(alias = "computer")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "computer", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "computer", feature = "icon-development-kit"))]
    /// Icon name constant for the `computer` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/computer-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMPUTER: &str = "computer";
    #[doc(alias = "computer-chip")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "computer-chip", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "computer-chip", feature = "icon-development-kit"))]
    /// Icon name constant for the `computer-chip` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/computer-chip-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COMPUTER_CHIP: &str = "computer-chip";
    #[doc(alias = "cone-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cone-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cone-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cone-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cone-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONE_FILLED: &str = "cone-filled";
    #[doc(alias = "cone-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cone-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cone-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cone-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cone-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONE_REGULAR: &str = "cone-regular";
    #[doc(alias = "conference-room-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "conference-room-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "conference-room-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `conference-room-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/conference-room-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONFERENCE_ROOM_FILLED: &str = "conference-room-filled";
    #[doc(alias = "conference-room-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "conference-room-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "conference-room-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `conference-room-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/conference-room-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONFERENCE_ROOM_REGULAR: &str = "conference-room-regular";
    #[doc(alias = "configure")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "configure", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "configure", feature = "icon-development-kit"))]
    /// Icon name constant for the `configure` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/configure-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONFIGURE: &str = "configure";
    #[doc(alias = "connected-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "connected-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "connected-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `connected-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/connected-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONNECTED_FILLED: &str = "connected-filled";
    #[doc(alias = "connected-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "connected-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "connected-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `connected-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/connected-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONNECTED_REGULAR: &str = "connected-regular";
    #[doc(alias = "connector-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "connector-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "connector-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `connector-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/connector-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONNECTOR_FILLED: &str = "connector-filled";
    #[doc(alias = "connector-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "connector-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "connector-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `connector-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/connector-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONNECTOR_REGULAR: &str = "connector-regular";
    #[doc(alias = "contact-card-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "contact-card-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "contact-card-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `contact-card-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/contact-card-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTACT_CARD_FILLED: &str = "contact-card-filled";
    #[doc(alias = "contact-card-group-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "contact-card-group-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "contact-card-group-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `contact-card-group-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/contact-card-group-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTACT_CARD_GROUP_FILLED: &str = "contact-card-group-filled";
    #[doc(alias = "contact-card-group-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "contact-card-group-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "contact-card-group-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `contact-card-group-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/contact-card-group-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTACT_CARD_GROUP_REGULAR: &str = "contact-card-group-regular";
    #[doc(alias = "contact-card-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "contact-card-link-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "contact-card-link-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `contact-card-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/contact-card-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTACT_CARD_LINK_FILLED: &str = "contact-card-link-filled";
    #[doc(alias = "contact-card-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "contact-card-link-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "contact-card-link-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `contact-card-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/contact-card-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTACT_CARD_LINK_REGULAR: &str = "contact-card-link-regular";
    #[doc(alias = "contact-card-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "contact-card-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "contact-card-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `contact-card-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/contact-card-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTACT_CARD_REGULAR: &str = "contact-card-regular";
    #[doc(alias = "contact-card-ribbon-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "contact-card-ribbon-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "contact-card-ribbon-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `contact-card-ribbon-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/contact-card-ribbon-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTACT_CARD_RIBBON_FILLED: &str = "contact-card-ribbon-filled";
    #[doc(alias = "contact-card-ribbon-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "contact-card-ribbon-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "contact-card-ribbon-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `contact-card-ribbon-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/contact-card-ribbon-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTACT_CARD_RIBBON_REGULAR: &str = "contact-card-ribbon-regular";
    #[doc(alias = "container-terminal")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "container-terminal", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "container-terminal", feature = "icon-development-kit"))]
    /// Icon name constant for the `container-terminal` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/container-terminal-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTAINER_TERMINAL: &str = "container-terminal";
    #[doc(alias = "content-settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "content-settings-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "content-settings-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `content-settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/content-settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTENT_SETTINGS_FILLED: &str = "content-settings-filled";
    #[doc(alias = "content-settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "content-settings-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "content-settings-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `content-settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/content-settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTENT_SETTINGS_REGULAR: &str = "content-settings-regular";
    #[doc(alias = "content-view-gallery-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "content-view-gallery-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "content-view-gallery-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `content-view-gallery-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/content-view-gallery-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTENT_VIEW_GALLERY_FILLED: &str = "content-view-gallery-filled";
    #[doc(alias = "content-view-gallery-lightning-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "content-view-gallery-lightning-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "content-view-gallery-lightning-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `content-view-gallery-lightning-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/content-view-gallery-lightning-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTENT_VIEW_GALLERY_LIGHTNING_FILLED: &str = "content-view-gallery-lightning-filled";
    #[doc(alias = "content-view-gallery-lightning-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "content-view-gallery-lightning-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "content-view-gallery-lightning-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `content-view-gallery-lightning-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/content-view-gallery-lightning-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTENT_VIEW_GALLERY_LIGHTNING_REGULAR: &str =
        "content-view-gallery-lightning-regular";
    #[doc(alias = "content-view-gallery-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "content-view-gallery-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "content-view-gallery-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `content-view-gallery-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/content-view-gallery-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTENT_VIEW_GALLERY_REGULAR: &str = "content-view-gallery-regular";
    #[doc(alias = "contract-down-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "contract-down-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "contract-down-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `contract-down-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/contract-down-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTRACT_DOWN_LEFT_FILLED: &str = "contract-down-left-filled";
    #[doc(alias = "contract-down-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "contract-down-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "contract-down-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `contract-down-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/contract-down-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTRACT_DOWN_LEFT_REGULAR: &str = "contract-down-left-regular";
    #[doc(alias = "controls")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "controls", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "controls", feature = "icon-development-kit"))]
    /// Icon name constant for the `controls` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/controls-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTROLS: &str = "controls";
    #[doc(alias = "controls-big")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "controls-big", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "controls-big", feature = "icon-development-kit"))]
    /// Icon name constant for the `controls-big` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/controls-big-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CONTROLS_BIG: &str = "controls-big";
    #[doc(alias = "copy")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "copy", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "copy", feature = "icon-development-kit"))]
    /// Icon name constant for the `copy` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/copy-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COPY: &str = "copy";
    #[doc(alias = "copy-arrow-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "copy-arrow-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "copy-arrow-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `copy-arrow-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/copy-arrow-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COPY_ARROW_RIGHT_FILLED: &str = "copy-arrow-right-filled";
    #[doc(alias = "copy-arrow-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "copy-arrow-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "copy-arrow-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `copy-arrow-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/copy-arrow-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COPY_ARROW_RIGHT_REGULAR: &str = "copy-arrow-right-regular";
    #[doc(alias = "copy-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "copy-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "copy-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `copy-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/copy-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COPY_FILLED: &str = "copy-filled";
    #[doc(alias = "copy-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "copy-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "copy-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `copy-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/copy-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COPY_REGULAR: &str = "copy-regular";
    #[doc(alias = "cow")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cow", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cow", feature = "icon-development-kit"))]
    /// Icon name constant for the `cow` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cow-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const COW: &str = "cow";
    #[doc(alias = "credit-card")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "credit-card", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "credit-card", feature = "icon-development-kit"))]
    /// Icon name constant for the `credit-card` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/credit-card-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CREDIT_CARD: &str = "credit-card";
    #[doc(alias = "crop")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "crop", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "crop", feature = "icon-development-kit"))]
    /// Icon name constant for the `crop` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/crop-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CROP: &str = "crop";
    #[doc(alias = "crop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "crop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "crop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `crop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/crop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CROP_FILLED: &str = "crop-filled";
    #[doc(alias = "crop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "crop-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "crop-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `crop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/crop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CROP_REGULAR: &str = "crop-regular";
    #[doc(alias = "cross")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cross", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cross", feature = "icon-development-kit"))]
    /// Icon name constant for the `cross` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cross-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CROSS: &str = "cross";
    #[doc(alias = "cross-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cross-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cross-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `cross-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cross-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CROSS_FILLED: &str = "cross-filled";
    #[doc(alias = "cross-filled-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cross-filled-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cross-filled-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `cross-filled-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cross-filled-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CROSS_FILLED_LARGE: &str = "cross-filled-large";
    #[doc(alias = "cross-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cross-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cross-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `cross-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cross-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CROSS_LARGE: &str = "cross-large";
    #[doc(alias = "crossword-clue-across")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "crossword-clue-across", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "crossword-clue-across", feature = "icon-development-kit"))]
    /// Icon name constant for the `crossword-clue-across` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/crossword-clue-across-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CROSSWORD_CLUE_ACROSS: &str = "crossword-clue-across";
    #[doc(alias = "crossword-clue-down")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "crossword-clue-down", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "crossword-clue-down", feature = "icon-development-kit"))]
    /// Icon name constant for the `crossword-clue-down` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/crossword-clue-down-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CROSSWORD_CLUE_DOWN: &str = "crossword-clue-down";
    #[doc(alias = "crown-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "crown-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "crown-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `crown-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/crown-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CROWN_FILLED: &str = "crown-filled";
    #[doc(alias = "crown-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "crown-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "crown-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `crown-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/crown-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CROWN_REGULAR: &str = "crown-regular";
    #[doc(alias = "cube-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cube-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cube-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cube-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cube-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CUBE_FILLED: &str = "cube-filled";
    #[doc(alias = "cube-quick-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cube-quick-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cube-quick-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cube-quick-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cube-quick-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CUBE_QUICK_FILLED: &str = "cube-quick-filled";
    #[doc(alias = "cube-quick-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cube-quick-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cube-quick-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cube-quick-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cube-quick-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CUBE_QUICK_REGULAR: &str = "cube-quick-regular";
    #[doc(alias = "cube-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cube-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cube-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cube-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cube-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CUBE_REGULAR: &str = "cube-regular";
    #[doc(alias = "currency-dollar-euro-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "currency-dollar-euro-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "currency-dollar-euro-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `currency-dollar-euro-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/currency-dollar-euro-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURRENCY_DOLLAR_EURO_FILLED: &str = "currency-dollar-euro-filled";
    #[doc(alias = "currency-dollar-euro-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "currency-dollar-euro-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "currency-dollar-euro-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `currency-dollar-euro-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/currency-dollar-euro-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURRENCY_DOLLAR_EURO_REGULAR: &str = "currency-dollar-euro-regular";
    #[doc(alias = "currency-dollar-rupee-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "currency-dollar-rupee-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "currency-dollar-rupee-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `currency-dollar-rupee-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/currency-dollar-rupee-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURRENCY_DOLLAR_RUPEE_FILLED: &str = "currency-dollar-rupee-filled";
    #[doc(alias = "currency-dollar-rupee-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "currency-dollar-rupee-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "currency-dollar-rupee-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `currency-dollar-rupee-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/currency-dollar-rupee-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURRENCY_DOLLAR_RUPEE_REGULAR: &str = "currency-dollar-rupee-regular";
    #[doc(alias = "cursor-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cursor-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cursor-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cursor-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cursor-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURSOR_FILLED: &str = "cursor-filled";
    #[doc(alias = "cursor-hover-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cursor-hover-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cursor-hover-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cursor-hover-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cursor-hover-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURSOR_HOVER_FILLED: &str = "cursor-hover-filled";
    #[doc(alias = "cursor-hover-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cursor-hover-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cursor-hover-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cursor-hover-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cursor-hover-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURSOR_HOVER_OFF_FILLED: &str = "cursor-hover-off-filled";
    #[doc(alias = "cursor-hover-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "cursor-hover-off-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "cursor-hover-off-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `cursor-hover-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cursor-hover-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURSOR_HOVER_OFF_REGULAR: &str = "cursor-hover-off-regular";
    #[doc(alias = "cursor-hover-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cursor-hover-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cursor-hover-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cursor-hover-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cursor-hover-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURSOR_HOVER_REGULAR: &str = "cursor-hover-regular";
    #[doc(alias = "cursor-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "cursor-prohibited-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "cursor-prohibited-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `cursor-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cursor-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURSOR_PROHIBITED_FILLED: &str = "cursor-prohibited-filled";
    #[doc(alias = "cursor-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "cursor-prohibited-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "cursor-prohibited-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `cursor-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cursor-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURSOR_PROHIBITED_REGULAR: &str = "cursor-prohibited-regular";
    #[doc(alias = "cursor-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cursor-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "cursor-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `cursor-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/cursor-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CURSOR_REGULAR: &str = "cursor-regular";
    #[doc(alias = "cut")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cut", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cut", feature = "icon-development-kit"))]
    /// Icon name constant for the `cut` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cut-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CUT: &str = "cut";
    #[doc(alias = "cycling")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "cycling", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "cycling", feature = "icon-development-kit"))]
    /// Icon name constant for the `cycling` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/cycling-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const CYCLING: &str = "cycling";
    #[doc(alias = "dark-mode")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dark-mode", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dark-mode", feature = "icon-development-kit"))]
    /// Icon name constant for the `dark-mode` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dark-mode-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DARK_MODE: &str = "dark-mode";
    #[doc(alias = "data-bar-horizontal-descending-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "data-bar-horizontal-descending-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "data-bar-horizontal-descending-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `data-bar-horizontal-descending-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-bar-horizontal-descending-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_BAR_HORIZONTAL_DESCENDING_FILLED: &str = "data-bar-horizontal-descending-filled";
    #[doc(alias = "data-bar-horizontal-descending-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "data-bar-horizontal-descending-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "data-bar-horizontal-descending-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `data-bar-horizontal-descending-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-bar-horizontal-descending-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_BAR_HORIZONTAL_DESCENDING_REGULAR: &str =
        "data-bar-horizontal-descending-regular";
    #[doc(alias = "data-bar-vertical-ascending-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "data-bar-vertical-ascending-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "data-bar-vertical-ascending-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `data-bar-vertical-ascending-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-bar-vertical-ascending-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_BAR_VERTICAL_ASCENDING_FILLED: &str = "data-bar-vertical-ascending-filled";
    #[doc(alias = "data-bar-vertical-ascending-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "data-bar-vertical-ascending-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "data-bar-vertical-ascending-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `data-bar-vertical-ascending-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-bar-vertical-ascending-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_BAR_VERTICAL_ASCENDING_REGULAR: &str = "data-bar-vertical-ascending-regular";
    #[doc(alias = "data-bar-vertical-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "data-bar-vertical-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "data-bar-vertical-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `data-bar-vertical-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-bar-vertical-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_BAR_VERTICAL_FILLED: &str = "data-bar-vertical-filled";
    #[doc(alias = "data-bar-vertical-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "data-bar-vertical-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "data-bar-vertical-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `data-bar-vertical-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-bar-vertical-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_BAR_VERTICAL_REGULAR: &str = "data-bar-vertical-regular";
    #[doc(alias = "data-bar-vertical-star-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "data-bar-vertical-star-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "data-bar-vertical-star-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `data-bar-vertical-star-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-bar-vertical-star-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_BAR_VERTICAL_STAR_FILLED: &str = "data-bar-vertical-star-filled";
    #[doc(alias = "data-bar-vertical-star-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "data-bar-vertical-star-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "data-bar-vertical-star-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `data-bar-vertical-star-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-bar-vertical-star-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_BAR_VERTICAL_STAR_REGULAR: &str = "data-bar-vertical-star-regular";
    #[doc(alias = "data-histogram-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "data-histogram-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "data-histogram-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `data-histogram-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-histogram-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_HISTOGRAM_FILLED: &str = "data-histogram-filled";
    #[doc(alias = "data-histogram-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "data-histogram-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "data-histogram-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `data-histogram-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-histogram-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_HISTOGRAM_REGULAR: &str = "data-histogram-regular";
    #[doc(alias = "data-trending-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "data-trending-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "data-trending-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `data-trending-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-trending-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_TRENDING_FILLED: &str = "data-trending-filled";
    #[doc(alias = "data-trending-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "data-trending-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "data-trending-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `data-trending-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/data-trending-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATA_TRENDING_REGULAR: &str = "data-trending-regular";
    #[doc(alias = "database-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "database-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "database-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `database-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/database-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATABASE_FILLED: &str = "database-filled";
    #[doc(alias = "database-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "database-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "database-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `database-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/database-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATABASE_REGULAR: &str = "database-regular";
    #[doc(alias = "database-stack-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "database-stack-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "database-stack-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `database-stack-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/database-stack-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATABASE_STACK_FILLED: &str = "database-stack-filled";
    #[doc(alias = "database-stack-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "database-stack-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "database-stack-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `database-stack-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/database-stack-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DATABASE_STACK_REGULAR: &str = "database-stack-regular";
    #[doc(alias = "daytime-sunrise")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "daytime-sunrise", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "daytime-sunrise", feature = "icon-development-kit"))]
    /// Icon name constant for the `daytime-sunrise` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/daytime-sunrise-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DAYTIME_SUNRISE: &str = "daytime-sunrise";
    #[doc(alias = "daytime-sunset")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "daytime-sunset", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "daytime-sunset", feature = "icon-development-kit"))]
    /// Icon name constant for the `daytime-sunset` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/daytime-sunset-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DAYTIME_SUNSET: &str = "daytime-sunset";
    #[doc(alias = "deaf")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "deaf", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "deaf", feature = "icon-development-kit"))]
    /// Icon name constant for the `deaf` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/deaf-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DEAF: &str = "deaf";
    #[doc(alias = "deck")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "deck", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "deck", feature = "icon-development-kit"))]
    /// Icon name constant for the `deck` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/deck-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DECK: &str = "deck";
    #[doc(alias = "decode")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "decode", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "decode", feature = "icon-development-kit"))]
    /// Icon name constant for the `decode` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/decode-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DECODE: &str = "decode";
    #[doc(alias = "delete-arrow-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "delete-arrow-back-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "delete-arrow-back-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `delete-arrow-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/delete-arrow-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DELETE_ARROW_BACK_FILLED: &str = "delete-arrow-back-filled";
    #[doc(alias = "delete-arrow-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "delete-arrow-back-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "delete-arrow-back-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `delete-arrow-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/delete-arrow-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DELETE_ARROW_BACK_REGULAR: &str = "delete-arrow-back-regular";
    #[doc(alias = "delete-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "delete-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "delete-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `delete-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/delete-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DELETE_FILLED: &str = "delete-filled";
    #[doc(alias = "delete-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "delete-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "delete-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `delete-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/delete-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DELETE_REGULAR: &str = "delete-regular";
    #[doc(alias = "dentist-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dentist-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "dentist-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `dentist-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/dentist-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DENTIST_FILLED: &str = "dentist-filled";
    #[doc(alias = "dentist-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dentist-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "dentist-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `dentist-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/dentist-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DENTIST_REGULAR: &str = "dentist-regular";
    #[doc(alias = "derivative")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "derivative", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "derivative", feature = "icon-development-kit"))]
    /// Icon name constant for the `derivative` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/derivative-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DERIVATIVE: &str = "derivative";
    #[doc(alias = "derivative2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "derivative2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "derivative2", feature = "icon-development-kit"))]
    /// Icon name constant for the `derivative2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/derivative2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DERIVATIVE2: &str = "derivative2";
    #[doc(alias = "design-ideas-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "design-ideas-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "design-ideas-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `design-ideas-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/design-ideas-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESIGN_IDEAS_FILLED: &str = "design-ideas-filled";
    #[doc(alias = "design-ideas-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "design-ideas-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "design-ideas-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `design-ideas-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/design-ideas-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESIGN_IDEAS_REGULAR: &str = "design-ideas-regular";
    #[doc(alias = "desk-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desk-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desk-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desk-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desk-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESK_FILLED: &str = "desk-filled";
    #[doc(alias = "desk-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desk-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desk-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desk-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desk-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESK_REGULAR: &str = "desk-regular";
    #[doc(alias = "desktop-arrow-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "desktop-arrow-down-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "desktop-arrow-down-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `desktop-arrow-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-arrow-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_ARROW_DOWN_FILLED: &str = "desktop-arrow-down-filled";
    #[doc(alias = "desktop-arrow-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "desktop-arrow-down-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "desktop-arrow-down-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `desktop-arrow-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-arrow-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_ARROW_DOWN_REGULAR: &str = "desktop-arrow-down-regular";
    #[doc(alias = "desktop-arrow-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "desktop-arrow-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "desktop-arrow-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `desktop-arrow-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-arrow-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_ARROW_RIGHT_FILLED: &str = "desktop-arrow-right-filled";
    #[doc(alias = "desktop-arrow-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "desktop-arrow-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "desktop-arrow-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `desktop-arrow-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-arrow-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_ARROW_RIGHT_REGULAR: &str = "desktop-arrow-right-regular";
    #[doc(alias = "desktop-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "desktop-checkmark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "desktop-checkmark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `desktop-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_CHECKMARK_FILLED: &str = "desktop-checkmark-filled";
    #[doc(alias = "desktop-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "desktop-checkmark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "desktop-checkmark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `desktop-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_CHECKMARK_REGULAR: &str = "desktop-checkmark-regular";
    #[doc(alias = "desktop-cursor-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-cursor-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-cursor-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-cursor-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-cursor-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_CURSOR_FILLED: &str = "desktop-cursor-filled";
    #[doc(alias = "desktop-cursor-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-cursor-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-cursor-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-cursor-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-cursor-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_CURSOR_REGULAR: &str = "desktop-cursor-regular";
    #[doc(alias = "desktop-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_EDIT_FILLED: &str = "desktop-edit-filled";
    #[doc(alias = "desktop-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_EDIT_REGULAR: &str = "desktop-edit-regular";
    #[doc(alias = "desktop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_FILLED: &str = "desktop-filled";
    #[doc(alias = "desktop-keyboard-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-keyboard-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-keyboard-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-keyboard-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-keyboard-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_KEYBOARD_FILLED: &str = "desktop-keyboard-filled";
    #[doc(alias = "desktop-keyboard-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "desktop-keyboard-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "desktop-keyboard-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `desktop-keyboard-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-keyboard-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_KEYBOARD_REGULAR: &str = "desktop-keyboard-regular";
    #[doc(alias = "desktop-mac-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-mac-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-mac-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-mac-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-mac-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_MAC_FILLED: &str = "desktop-mac-filled";
    #[doc(alias = "desktop-mac-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-mac-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-mac-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-mac-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-mac-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_MAC_REGULAR: &str = "desktop-mac-regular";
    #[doc(alias = "desktop-pulse-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-pulse-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-pulse-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-pulse-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-pulse-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_PULSE_FILLED: &str = "desktop-pulse-filled";
    #[doc(alias = "desktop-pulse-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-pulse-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-pulse-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-pulse-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-pulse-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_PULSE_REGULAR: &str = "desktop-pulse-regular";
    #[doc(alias = "desktop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_REGULAR: &str = "desktop-regular";
    #[doc(alias = "desktop-sync-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-sync-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-sync-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-sync-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-sync-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_SYNC_FILLED: &str = "desktop-sync-filled";
    #[doc(alias = "desktop-sync-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "desktop-sync-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "desktop-sync-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `desktop-sync-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/desktop-sync-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DESKTOP_SYNC_REGULAR: &str = "desktop-sync-regular";
    #[doc(alias = "detach-audio")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "detach-audio", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "detach-audio", feature = "icon-development-kit"))]
    /// Icon name constant for the `detach-audio` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/detach-audio-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DETACH_AUDIO: &str = "detach-audio";
    #[doc(alias = "developer-board-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "developer-board-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "developer-board-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `developer-board-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/developer-board-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DEVELOPER_BOARD_FILLED: &str = "developer-board-filled";
    #[doc(alias = "developer-board-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "developer-board-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "developer-board-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `developer-board-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/developer-board-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DEVELOPER_BOARD_REGULAR: &str = "developer-board-regular";
    #[doc(alias = "device-eq-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "device-eq-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "device-eq-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `device-eq-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/device-eq-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DEVICE_EQ_FILLED: &str = "device-eq-filled";
    #[doc(alias = "device-eq-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "device-eq-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "device-eq-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `device-eq-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/device-eq-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DEVICE_EQ_REGULAR: &str = "device-eq-regular";
    #[doc(alias = "device-meeting-room-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "device-meeting-room-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "device-meeting-room-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `device-meeting-room-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/device-meeting-room-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DEVICE_MEETING_ROOM_FILLED: &str = "device-meeting-room-filled";
    #[doc(alias = "device-meeting-room-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "device-meeting-room-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "device-meeting-room-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `device-meeting-room-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/device-meeting-room-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DEVICE_MEETING_ROOM_REGULAR: &str = "device-meeting-room-regular";
    #[doc(alias = "device-meeting-room-remote-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "device-meeting-room-remote-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "device-meeting-room-remote-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `device-meeting-room-remote-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/device-meeting-room-remote-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DEVICE_MEETING_ROOM_REMOTE_FILLED: &str = "device-meeting-room-remote-filled";
    #[doc(alias = "device-meeting-room-remote-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "device-meeting-room-remote-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "device-meeting-room-remote-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `device-meeting-room-remote-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/device-meeting-room-remote-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DEVICE_MEETING_ROOM_REMOTE_REGULAR: &str = "device-meeting-room-remote-regular";
    #[doc(alias = "diagnostics")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "diagnostics", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "diagnostics", feature = "icon-development-kit"))]
    /// Icon name constant for the `diagnostics` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/diagnostics-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIAGNOSTICS: &str = "diagnostics";
    #[doc(alias = "dialog")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dialog", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dialog", feature = "icon-development-kit"))]
    /// Icon name constant for the `dialog` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dialog-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIALOG: &str = "dialog";
    #[doc(alias = "dialpad")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dialpad", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dialpad", feature = "icon-development-kit"))]
    /// Icon name constant for the `dialpad` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dialpad-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIALPAD: &str = "dialpad";
    #[doc(alias = "diamond-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "diamond-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "diamond-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `diamond-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/diamond-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIAMOND_FILLED: &str = "diamond-filled";
    #[doc(alias = "diamond-filled-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "diamond-filled-alt", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "diamond-filled-alt", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `diamond-filled-alt` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/diamond-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIAMOND_FILLED_ALT: &str = "diamond-filled-alt";
    #[doc(alias = "diamond-outline-thick")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "diamond-outline-thick", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "diamond-outline-thick", feature = "icon-development-kit"))]
    /// Icon name constant for the `diamond-outline-thick` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/diamond-outline-thick-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIAMOND_OUTLINE_THICK: &str = "diamond-outline-thick";
    #[doc(alias = "diamond-outline-thin")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "diamond-outline-thin", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "diamond-outline-thin", feature = "icon-development-kit"))]
    /// Icon name constant for the `diamond-outline-thin` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/diamond-outline-thin-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIAMOND_OUTLINE_THIN: &str = "diamond-outline-thin";
    #[doc(alias = "diamond-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "diamond-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "diamond-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `diamond-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/diamond-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIAMOND_REGULAR: &str = "diamond-regular";
    #[doc(alias = "dice")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dice", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dice", feature = "icon-development-kit"))]
    /// Icon name constant for the `dice` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dice-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DICE: &str = "dice";
    #[doc(alias = "dice2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dice2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dice2", feature = "icon-development-kit"))]
    /// Icon name constant for the `dice2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dice2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DICE2: &str = "dice2";
    #[doc(alias = "dice3")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dice3", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dice3", feature = "icon-development-kit"))]
    /// Icon name constant for the `dice3` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dice3-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DICE3: &str = "dice3";
    #[doc(alias = "dictionary")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dictionary", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dictionary", feature = "icon-development-kit"))]
    /// Icon name constant for the `dictionary` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dictionary-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DICTIONARY: &str = "dictionary";
    #[doc(alias = "directions-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "directions-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "directions-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `directions-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/directions-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIRECTIONS_FILLED: &str = "directions-filled";
    #[doc(alias = "directions-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "directions-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "directions-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `directions-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/directions-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIRECTIONS_REGULAR: &str = "directions-regular";
    #[doc(alias = "discover")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "discover", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "discover", feature = "icon-development-kit"))]
    /// Icon name constant for the `discover` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/discover-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISCOVER: &str = "discover";
    #[doc(alias = "dismiss-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dismiss-circle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "dismiss-circle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `dismiss-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/dismiss-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISMISS_CIRCLE_FILLED: &str = "dismiss-circle-filled";
    #[doc(alias = "dismiss-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dismiss-circle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "dismiss-circle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `dismiss-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/dismiss-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISMISS_CIRCLE_REGULAR: &str = "dismiss-circle-regular";
    #[doc(alias = "dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISMISS_FILLED: &str = "dismiss-filled";
    #[doc(alias = "dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISMISS_REGULAR: &str = "dismiss-regular";
    #[doc(alias = "dismiss-square-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "dismiss-square-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "dismiss-square-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `dismiss-square-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/dismiss-square-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISMISS_SQUARE_MULTIPLE_FILLED: &str = "dismiss-square-multiple-filled";
    #[doc(alias = "dismiss-square-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "dismiss-square-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "dismiss-square-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `dismiss-square-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/dismiss-square-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISMISS_SQUARE_MULTIPLE_REGULAR: &str = "dismiss-square-multiple-regular";
    #[doc(alias = "display")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "display", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "display", feature = "icon-development-kit"))]
    /// Icon name constant for the `display` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/display-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISPLAY: &str = "display";
    #[doc(alias = "display-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "display-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "display-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `display-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/display-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISPLAY_ALT: &str = "display-alt";
    #[doc(alias = "display-brightness-high")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "display-brightness-high", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "display-brightness-high", feature = "icon-development-kit"))]
    /// Icon name constant for the `display-brightness-high` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/display-brightness-high-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISPLAY_BRIGHTNESS_HIGH: &str = "display-brightness-high";
    #[doc(alias = "display-brightness-low")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "display-brightness-low", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "display-brightness-low", feature = "icon-development-kit"))]
    /// Icon name constant for the `display-brightness-low` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/display-brightness-low-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISPLAY_BRIGHTNESS_LOW: &str = "display-brightness-low";
    #[doc(alias = "display-brightness-medium")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "display-brightness-medium",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "display-brightness-medium",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `display-brightness-medium` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/display-brightness-medium-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISPLAY_BRIGHTNESS_MEDIUM: &str = "display-brightness-medium";
    #[doc(alias = "display-projector")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "display-projector", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "display-projector", feature = "icon-development-kit"))]
    /// Icon name constant for the `display-projector` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/display-projector-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISPLAY_PROJECTOR: &str = "display-projector";
    #[doc(alias = "display-with-window")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "display-with-window", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "display-with-window", feature = "icon-development-kit"))]
    /// Icon name constant for the `display-with-window` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/display-with-window-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISPLAY_WITH_WINDOW: &str = "display-with-window";
    #[doc(alias = "distance")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "distance", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "distance", feature = "icon-development-kit"))]
    /// Icon name constant for the `distance` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/distance-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DISTANCE: &str = "distance";
    #[doc(alias = "divider-short-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "divider-short-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "divider-short-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `divider-short-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/divider-short-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIVIDER_SHORT_FILLED: &str = "divider-short-filled";
    #[doc(alias = "divider-short-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "divider-short-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "divider-short-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `divider-short-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/divider-short-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIVIDER_SHORT_REGULAR: &str = "divider-short-regular";
    #[doc(alias = "divider-tall-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "divider-tall-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "divider-tall-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `divider-tall-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/divider-tall-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIVIDER_TALL_FILLED: &str = "divider-tall-filled";
    #[doc(alias = "divider-tall-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "divider-tall-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "divider-tall-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `divider-tall-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/divider-tall-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DIVIDER_TALL_REGULAR: &str = "divider-tall-regular";
    #[doc(alias = "do-not-distrub")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "do-not-distrub", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "do-not-distrub", feature = "icon-development-kit"))]
    /// Icon name constant for the `do-not-distrub` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/do-not-distrub-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DO_NOT_DISTRUB: &str = "do-not-distrub";
    #[doc(alias = "dock")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dock", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dock", feature = "icon-development-kit"))]
    /// Icon name constant for the `dock` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dock-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCK: &str = "dock";
    #[doc(alias = "dock-bottom")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dock-bottom", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dock-bottom", feature = "icon-development-kit"))]
    /// Icon name constant for the `dock-bottom` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dock-bottom-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCK_BOTTOM: &str = "dock-bottom";
    #[doc(alias = "dock-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dock-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dock-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `dock-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dock-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCK_LEFT: &str = "dock-left";
    #[doc(alias = "dock-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dock-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dock-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `dock-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dock-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCK_RIGHT: &str = "dock-right";
    #[doc(alias = "dock-top")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dock-top", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dock-top", feature = "icon-development-kit"))]
    /// Icon name constant for the `dock-top` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dock-top-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCK_TOP: &str = "dock-top";
    #[doc(alias = "dock-usb")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dock-usb", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dock-usb", feature = "icon-development-kit"))]
    /// Icon name constant for the `dock-usb` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dock-usb-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCK_USB: &str = "dock-usb";
    #[doc(alias = "doctor-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "doctor-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "doctor-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `doctor-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/doctor-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCTOR_FILLED: &str = "doctor-filled";
    #[doc(alias = "doctor-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "doctor-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "doctor-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `doctor-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/doctor-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCTOR_REGULAR: &str = "doctor-regular";
    #[doc(alias = "document-100-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-100-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-100-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-100-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-100-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_100_FILLED: &str = "document-100-filled";
    #[doc(alias = "document-100-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-100-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-100-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-100-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-100-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_100_REGULAR: &str = "document-100-regular";
    #[doc(alias = "document-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ADD_FILLED: &str = "document-add-filled";
    #[doc(alias = "document-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ADD_REGULAR: &str = "document-add-regular";
    #[doc(alias = "document-arrow-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-arrow-down-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-arrow-down-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-arrow-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-arrow-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ARROW_DOWN_FILLED: &str = "document-arrow-down-filled";
    #[doc(alias = "document-arrow-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-arrow-down-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-arrow-down-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-arrow-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-arrow-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ARROW_DOWN_REGULAR: &str = "document-arrow-down-regular";
    #[doc(alias = "document-arrow-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-arrow-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-arrow-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-arrow-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-arrow-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ARROW_LEFT_FILLED: &str = "document-arrow-left-filled";
    #[doc(alias = "document-arrow-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-arrow-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-arrow-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-arrow-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-arrow-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ARROW_LEFT_REGULAR: &str = "document-arrow-left-regular";
    #[doc(alias = "document-arrow-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-arrow-up-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-arrow-up-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-arrow-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-arrow-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ARROW_UP_FILLED: &str = "document-arrow-up-filled";
    #[doc(alias = "document-arrow-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-arrow-up-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-arrow-up-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-arrow-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-arrow-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ARROW_UP_REGULAR: &str = "document-arrow-up-regular";
    #[doc(alias = "document-bullet-list-arrow-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-bullet-list-arrow-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-bullet-list-arrow-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-bullet-list-arrow-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-bullet-list-arrow-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_BULLET_LIST_ARROW_LEFT_FILLED: &str =
        "document-bullet-list-arrow-left-filled";
    #[doc(alias = "document-bullet-list-arrow-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-bullet-list-arrow-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-bullet-list-arrow-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-bullet-list-arrow-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-bullet-list-arrow-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_BULLET_LIST_ARROW_LEFT_REGULAR: &str =
        "document-bullet-list-arrow-left-regular";
    #[doc(alias = "document-bullet-list-cube-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-bullet-list-cube-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-bullet-list-cube-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-bullet-list-cube-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-bullet-list-cube-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_BULLET_LIST_CUBE_FILLED: &str = "document-bullet-list-cube-filled";
    #[doc(alias = "document-bullet-list-cube-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-bullet-list-cube-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-bullet-list-cube-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-bullet-list-cube-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-bullet-list-cube-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_BULLET_LIST_CUBE_REGULAR: &str = "document-bullet-list-cube-regular";
    #[doc(alias = "document-bullet-list-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-bullet-list-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-bullet-list-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-bullet-list-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-bullet-list-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_BULLET_LIST_FILLED: &str = "document-bullet-list-filled";
    #[doc(alias = "document-bullet-list-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-bullet-list-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-bullet-list-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-bullet-list-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-bullet-list-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_BULLET_LIST_REGULAR: &str = "document-bullet-list-regular";
    #[doc(alias = "document-catch-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-catch-up-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-catch-up-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-catch-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-catch-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_CATCH_UP_FILLED: &str = "document-catch-up-filled";
    #[doc(alias = "document-catch-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-catch-up-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-catch-up-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-catch-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-catch-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_CATCH_UP_REGULAR: &str = "document-catch-up-regular";
    #[doc(alias = "document-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-checkmark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-checkmark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_CHECKMARK_FILLED: &str = "document-checkmark-filled";
    #[doc(alias = "document-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-checkmark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-checkmark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_CHECKMARK_REGULAR: &str = "document-checkmark-regular";
    #[doc(alias = "document-contract-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-contract-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-contract-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-contract-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-contract-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_CONTRACT_FILLED: &str = "document-contract-filled";
    #[doc(alias = "document-contract-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-contract-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-contract-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-contract-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-contract-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_CONTRACT_REGULAR: &str = "document-contract-regular";
    #[doc(alias = "document-copy-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-copy-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-copy-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-copy-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-copy-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_COPY_FILLED: &str = "document-copy-filled";
    #[doc(alias = "document-copy-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-copy-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-copy-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-copy-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-copy-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_COPY_REGULAR: &str = "document-copy-regular";
    #[doc(alias = "document-cs-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-cs-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-cs-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-cs-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-cs-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_CS_FILLED: &str = "document-cs-filled";
    #[doc(alias = "document-cs-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-cs-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-cs-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-cs-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-cs-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_CS_REGULAR: &str = "document-cs-regular";
    #[doc(alias = "document-css-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-css-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-css-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-css-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-css-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_CSS_FILLED: &str = "document-css-filled";
    #[doc(alias = "document-css-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-css-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-css-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-css-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-css-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_CSS_REGULAR: &str = "document-css-regular";
    #[doc(alias = "document-data-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-data-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-data-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-data-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-data-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_DATA_FILLED: &str = "document-data-filled";
    #[doc(alias = "document-data-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-data-link-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-data-link-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-data-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-data-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_DATA_LINK_FILLED: &str = "document-data-link-filled";
    #[doc(alias = "document-data-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-data-link-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-data-link-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-data-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-data-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_DATA_LINK_REGULAR: &str = "document-data-link-regular";
    #[doc(alias = "document-data-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-data-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-data-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-data-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-data-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_DATA_REGULAR: &str = "document-data-regular";
    #[doc(alias = "document-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_DISMISS_FILLED: &str = "document-dismiss-filled";
    #[doc(alias = "document-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-dismiss-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-dismiss-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_DISMISS_REGULAR: &str = "document-dismiss-regular";
    #[doc(alias = "document-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_EDIT_FILLED: &str = "document-edit-filled";
    #[doc(alias = "document-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_EDIT_REGULAR: &str = "document-edit-regular";
    #[doc(alias = "document-error-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-error-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-error-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-error-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-error-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ERROR_FILLED: &str = "document-error-filled";
    #[doc(alias = "document-error-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-error-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-error-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-error-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-error-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ERROR_REGULAR: &str = "document-error-regular";
    #[doc(alias = "document-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_FILLED: &str = "document-filled";
    #[doc(alias = "document-fit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-fit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-fit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-fit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-fit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_FIT_FILLED: &str = "document-fit-filled";
    #[doc(alias = "document-fit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-fit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-fit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-fit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-fit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_FIT_REGULAR: &str = "document-fit-regular";
    #[doc(alias = "document-folder-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-folder-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-folder-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-folder-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-folder-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_FOLDER_FILLED: &str = "document-folder-filled";
    #[doc(alias = "document-folder-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-folder-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-folder-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-folder-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-folder-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_FOLDER_REGULAR: &str = "document-folder-regular";
    #[doc(alias = "document-footer-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-footer-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-footer-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-footer-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-footer-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_FOOTER_FILLED: &str = "document-footer-filled";
    #[doc(alias = "document-footer-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-footer-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-footer-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-footer-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-footer-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_FOOTER_REGULAR: &str = "document-footer-regular";
    #[doc(alias = "document-fs-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-fs-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-fs-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-fs-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-fs-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_FS_FILLED: &str = "document-fs-filled";
    #[doc(alias = "document-fs-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-fs-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-fs-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-fs-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-fs-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_FS_REGULAR: &str = "document-fs-regular";
    #[doc(alias = "document-header-arrow-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-header-arrow-down-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-header-arrow-down-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-header-arrow-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-header-arrow-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_HEADER_ARROW_DOWN_FILLED: &str = "document-header-arrow-down-filled";
    #[doc(alias = "document-header-arrow-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-header-arrow-down-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-header-arrow-down-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-header-arrow-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-header-arrow-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_HEADER_ARROW_DOWN_REGULAR: &str = "document-header-arrow-down-regular";
    #[doc(alias = "document-header-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-header-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-header-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-header-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-header-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_HEADER_FILLED: &str = "document-header-filled";
    #[doc(alias = "document-header-footer-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-header-footer-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-header-footer-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-header-footer-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-header-footer-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_HEADER_FOOTER_FILLED: &str = "document-header-footer-filled";
    #[doc(alias = "document-header-footer-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-header-footer-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-header-footer-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-header-footer-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-header-footer-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_HEADER_FOOTER_REGULAR: &str = "document-header-footer-regular";
    #[doc(alias = "document-header-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-header-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-header-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-header-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-header-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_HEADER_REGULAR: &str = "document-header-regular";
    #[doc(alias = "document-image-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-image-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-image-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-image-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-image-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_IMAGE_FILLED: &str = "document-image-filled";
    #[doc(alias = "document-image-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-image-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-image-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-image-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-image-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_IMAGE_REGULAR: &str = "document-image-regular";
    #[doc(alias = "document-java-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-java-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-java-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-java-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-java-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_JAVA_FILLED: &str = "document-java-filled";
    #[doc(alias = "document-java-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-java-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-java-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-java-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-java-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_JAVA_REGULAR: &str = "document-java-regular";
    #[doc(alias = "document-js-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-js-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-js-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-js-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-js-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_JS_FILLED: &str = "document-js-filled";
    #[doc(alias = "document-js-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-js-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-js-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-js-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-js-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_JS_REGULAR: &str = "document-js-regular";
    #[doc(alias = "document-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-link-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-link-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_LINK_FILLED: &str = "document-link-filled";
    #[doc(alias = "document-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-link-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-link-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_LINK_REGULAR: &str = "document-link-regular";
    #[doc(alias = "document-lock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-lock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-lock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-lock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-lock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_LOCK_FILLED: &str = "document-lock-filled";
    #[doc(alias = "document-lock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-lock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-lock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-lock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-lock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_LOCK_REGULAR: &str = "document-lock-regular";
    #[doc(alias = "document-mention-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-mention-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-mention-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-mention-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-mention-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_MENTION_FILLED: &str = "document-mention-filled";
    #[doc(alias = "document-mention-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-mention-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-mention-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-mention-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-mention-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_MENTION_REGULAR: &str = "document-mention-regular";
    #[doc(alias = "document-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_MULTIPLE_FILLED: &str = "document-multiple-filled";
    #[doc(alias = "document-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_MULTIPLE_REGULAR: &str = "document-multiple-regular";
    #[doc(alias = "document-number-1-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-number-1-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-number-1-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-number-1-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-number-1-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_NUMBER_1_FILLED: &str = "document-number-1-filled";
    #[doc(alias = "document-number-1-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-number-1-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-number-1-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-number-1-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-number-1-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_NUMBER_1_REGULAR: &str = "document-number-1-regular";
    #[doc(alias = "document-one-page-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-add-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-add-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_ADD_FILLED: &str = "document-one-page-add-filled";
    #[doc(alias = "document-one-page-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-add-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-add-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_ADD_REGULAR: &str = "document-one-page-add-regular";
    #[doc(alias = "document-one-page-beaker-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-beaker-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-beaker-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-beaker-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-beaker-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_BEAKER_FILLED: &str = "document-one-page-beaker-filled";
    #[doc(alias = "document-one-page-beaker-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-beaker-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-beaker-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-beaker-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-beaker-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_BEAKER_REGULAR: &str = "document-one-page-beaker-regular";
    #[doc(alias = "document-one-page-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_FILLED: &str = "document-one-page-filled";
    #[doc(alias = "document-one-page-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-link-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-link-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_LINK_FILLED: &str = "document-one-page-link-filled";
    #[doc(alias = "document-one-page-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-link-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-link-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_LINK_REGULAR: &str = "document-one-page-link-regular";
    #[doc(alias = "document-one-page-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_MULTIPLE_FILLED: &str = "document-one-page-multiple-filled";
    #[doc(alias = "document-one-page-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_MULTIPLE_REGULAR: &str = "document-one-page-multiple-regular";
    #[doc(alias = "document-one-page-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_REGULAR: &str = "document-one-page-regular";
    #[doc(alias = "document-one-page-sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-sparkle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-sparkle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_SPARKLE_FILLED: &str = "document-one-page-sparkle-filled";
    #[doc(alias = "document-one-page-sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-one-page-sparkle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-one-page-sparkle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-one-page-sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-one-page-sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_ONE_PAGE_SPARKLE_REGULAR: &str = "document-one-page-sparkle-regular";
    #[doc(alias = "document-pdf-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-pdf-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-pdf-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-pdf-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-pdf-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_PDF_FILLED: &str = "document-pdf-filled";
    #[doc(alias = "document-pdf-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-pdf-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-pdf-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-pdf-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-pdf-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_PDF_REGULAR: &str = "document-pdf-regular";
    #[doc(alias = "document-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-person-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-person-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_PERSON_FILLED: &str = "document-person-filled";
    #[doc(alias = "document-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-person-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-person-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_PERSON_REGULAR: &str = "document-person-regular";
    #[doc(alias = "document-py-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-py-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-py-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-py-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-py-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_PY_FILLED: &str = "document-py-filled";
    #[doc(alias = "document-py-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-py-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-py-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-py-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-py-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_PY_REGULAR: &str = "document-py-regular";
    #[doc(alias = "document-question-mark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-question-mark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-question-mark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-question-mark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-question-mark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_QUESTION_MARK_FILLED: &str = "document-question-mark-filled";
    #[doc(alias = "document-question-mark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-question-mark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-question-mark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-question-mark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-question-mark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_QUESTION_MARK_REGULAR: &str = "document-question-mark-regular";
    #[doc(alias = "document-rb-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-rb-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-rb-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-rb-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-rb-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_RB_FILLED: &str = "document-rb-filled";
    #[doc(alias = "document-rb-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-rb-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-rb-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-rb-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-rb-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_RB_REGULAR: &str = "document-rb-regular";
    #[doc(alias = "document-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_REGULAR: &str = "document-regular";
    #[doc(alias = "document-ribbon-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-ribbon-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-ribbon-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-ribbon-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-ribbon-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_RIBBON_FILLED: &str = "document-ribbon-filled";
    #[doc(alias = "document-ribbon-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-ribbon-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-ribbon-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-ribbon-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-ribbon-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_RIBBON_REGULAR: &str = "document-ribbon-regular";
    #[doc(alias = "document-sass-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-sass-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-sass-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-sass-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-sass-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SASS_FILLED: &str = "document-sass-filled";
    #[doc(alias = "document-sass-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-sass-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-sass-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-sass-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-sass-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SASS_REGULAR: &str = "document-sass-regular";
    #[doc(alias = "document-search-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-search-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-search-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-search-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-search-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SEARCH_FILLED: &str = "document-search-filled";
    #[doc(alias = "document-search-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-search-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-search-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-search-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-search-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SEARCH_REGULAR: &str = "document-search-regular";
    #[doc(alias = "document-settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-settings-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-settings-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SETTINGS_FILLED: &str = "document-settings-filled";
    #[doc(alias = "document-settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-settings-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-settings-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SETTINGS_REGULAR: &str = "document-settings-regular";
    #[doc(alias = "document-split-hint-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-split-hint-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-split-hint-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-split-hint-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-split-hint-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SPLIT_HINT_FILLED: &str = "document-split-hint-filled";
    #[doc(alias = "document-split-hint-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-split-hint-off-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-split-hint-off-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-split-hint-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-split-hint-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SPLIT_HINT_OFF_FILLED: &str = "document-split-hint-off-filled";
    #[doc(alias = "document-split-hint-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-split-hint-off-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-split-hint-off-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-split-hint-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-split-hint-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SPLIT_HINT_OFF_REGULAR: &str = "document-split-hint-off-regular";
    #[doc(alias = "document-split-hint-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "document-split-hint-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "document-split-hint-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `document-split-hint-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-split-hint-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SPLIT_HINT_REGULAR: &str = "document-split-hint-regular";
    #[doc(alias = "document-sync-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-sync-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-sync-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-sync-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-sync-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SYNC_FILLED: &str = "document-sync-filled";
    #[doc(alias = "document-sync-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-sync-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-sync-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-sync-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-sync-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_SYNC_REGULAR: &str = "document-sync-regular";
    #[doc(alias = "document-table-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-table-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-table-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-table-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-table-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_TABLE_FILLED: &str = "document-table-filled";
    #[doc(alias = "document-table-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-table-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-table-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-table-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-table-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_TABLE_REGULAR: &str = "document-table-regular";
    #[doc(alias = "document-target-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-target-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-target-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-target-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-target-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_TARGET_FILLED: &str = "document-target-filled";
    #[doc(alias = "document-target-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-target-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-target-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-target-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-target-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_TARGET_REGULAR: &str = "document-target-regular";
    #[doc(alias = "document-text-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-text-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-text-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-text-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-text-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_TEXT_FILLED: &str = "document-text-filled";
    #[doc(alias = "document-text-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-text-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-text-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-text-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-text-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_TEXT_REGULAR: &str = "document-text-regular";
    #[doc(alias = "document-ts-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-ts-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-ts-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-ts-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-ts-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_TS_FILLED: &str = "document-ts-filled";
    #[doc(alias = "document-ts-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-ts-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-ts-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-ts-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-ts-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_TS_REGULAR: &str = "document-ts-regular";
    #[doc(alias = "document-vb-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-vb-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-vb-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-vb-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-vb-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_VB_FILLED: &str = "document-vb-filled";
    #[doc(alias = "document-vb-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-vb-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-vb-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-vb-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-vb-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_VB_REGULAR: &str = "document-vb-regular";
    #[doc(alias = "document-yml-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-yml-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-yml-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-yml-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-yml-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_YML_FILLED: &str = "document-yml-filled";
    #[doc(alias = "document-yml-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "document-yml-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "document-yml-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `document-yml-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/document-yml-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOCUMENT_YML_REGULAR: &str = "document-yml-regular";
    #[doc(alias = "dog")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dog", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dog", feature = "icon-development-kit"))]
    /// Icon name constant for the `dog` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dog-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOG: &str = "dog";
    #[doc(alias = "door-arrow-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "door-arrow-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "door-arrow-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `door-arrow-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/door-arrow-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOOR_ARROW_LEFT_FILLED: &str = "door-arrow-left-filled";
    #[doc(alias = "door-arrow-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "door-arrow-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "door-arrow-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `door-arrow-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/door-arrow-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOOR_ARROW_LEFT_REGULAR: &str = "door-arrow-left-regular";
    #[doc(alias = "door-arrow-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "door-arrow-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "door-arrow-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `door-arrow-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/door-arrow-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOOR_ARROW_RIGHT_FILLED: &str = "door-arrow-right-filled";
    #[doc(alias = "door-arrow-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "door-arrow-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "door-arrow-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `door-arrow-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/door-arrow-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOOR_ARROW_RIGHT_REGULAR: &str = "door-arrow-right-regular";
    #[doc(alias = "door-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "door-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "door-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `door-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/door-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOOR_FILLED: &str = "door-filled";
    #[doc(alias = "door-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "door-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "door-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `door-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/door-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOOR_REGULAR: &str = "door-regular";
    #[doc(alias = "dot")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dot", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dot", feature = "icon-development-kit"))]
    /// Icon name constant for the `dot` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dot-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOT: &str = "dot";
    #[doc(alias = "dotted-box")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dotted-box", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "dotted-box", feature = "icon-development-kit"))]
    /// Icon name constant for the `dotted-box` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/dotted-box-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOTTED_BOX: &str = "dotted-box";
    #[doc(alias = "down")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "down", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "down", feature = "icon-development-kit"))]
    /// Icon name constant for the `down` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/down-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOWN: &str = "down";
    #[doc(alias = "down-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "down-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "down-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `down-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/down-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DOWN_LARGE: &str = "down-large";
    #[doc(alias = "drafts-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drafts-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drafts-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drafts-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drafts-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRAFTS_FILLED: &str = "drafts-filled";
    #[doc(alias = "drafts-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drafts-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drafts-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drafts-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drafts-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRAFTS_REGULAR: &str = "drafts-regular";
    #[doc(alias = "drag-n-drop")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drag-n-drop", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "drag-n-drop", feature = "icon-development-kit"))]
    /// Icon name constant for the `drag-n-drop` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/drag-n-drop-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRAG_N_DROP: &str = "drag-n-drop";
    #[doc(alias = "drawer")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drawer", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "drawer", feature = "icon-development-kit"))]
    /// Icon name constant for the `drawer` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/drawer-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRAWER: &str = "drawer";
    #[doc(alias = "drink-beer-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drink-beer-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drink-beer-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drink-beer-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drink-beer-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRINK_BEER_FILLED: &str = "drink-beer-filled";
    #[doc(alias = "drink-beer-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drink-beer-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drink-beer-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drink-beer-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drink-beer-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRINK_BEER_REGULAR: &str = "drink-beer-regular";
    #[doc(alias = "drink-coffee-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drink-coffee-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drink-coffee-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drink-coffee-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drink-coffee-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRINK_COFFEE_FILLED: &str = "drink-coffee-filled";
    #[doc(alias = "drink-coffee-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drink-coffee-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drink-coffee-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drink-coffee-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drink-coffee-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRINK_COFFEE_REGULAR: &str = "drink-coffee-regular";
    #[doc(alias = "drink-margarita-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drink-margarita-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drink-margarita-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drink-margarita-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drink-margarita-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRINK_MARGARITA_FILLED: &str = "drink-margarita-filled";
    #[doc(alias = "drink-margarita-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drink-margarita-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drink-margarita-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drink-margarita-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drink-margarita-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRINK_MARGARITA_REGULAR: &str = "drink-margarita-regular";
    #[doc(alias = "drink-wine-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drink-wine-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drink-wine-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drink-wine-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drink-wine-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRINK_WINE_FILLED: &str = "drink-wine-filled";
    #[doc(alias = "drink-wine-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drink-wine-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drink-wine-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drink-wine-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drink-wine-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRINK_WINE_REGULAR: &str = "drink-wine-regular";
    #[doc(alias = "drinks")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drinks", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "drinks", feature = "icon-development-kit"))]
    /// Icon name constant for the `drinks` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/drinks-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRINKS: &str = "drinks";
    #[doc(alias = "driving")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "driving", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "driving", feature = "icon-development-kit"))]
    /// Icon name constant for the `driving` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/driving-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRIVING: &str = "driving";
    #[doc(alias = "drone")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drone", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "drone", feature = "icon-development-kit"))]
    /// Icon name constant for the `drone` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/drone-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DRONE: &str = "drone";
    #[doc(alias = "drop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DROP_FILLED: &str = "drop-filled";
    #[doc(alias = "drop-hollow")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drop-hollow", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "drop-hollow", feature = "icon-development-kit"))]
    /// Icon name constant for the `drop-hollow` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/drop-hollow-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DROP_HOLLOW: &str = "drop-hollow";
    #[doc(alias = "drop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "drop-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "drop-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `drop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/drop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DROP_REGULAR: &str = "drop-regular";
    #[doc(alias = "dumbbell-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dumbbell-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "dumbbell-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `dumbbell-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/dumbbell-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DUMBBELL_FILLED: &str = "dumbbell-filled";
    #[doc(alias = "dumbbell-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "dumbbell-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "dumbbell-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `dumbbell-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/dumbbell-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const DUMBBELL_REGULAR: &str = "dumbbell-regular";
    #[doc(alias = "earth")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "earth", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "earth", feature = "icon-development-kit"))]
    /// Icon name constant for the `earth` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/earth-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EARTH: &str = "earth";
    #[doc(alias = "earth-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "earth-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "earth-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `earth-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/earth-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EARTH_FILLED: &str = "earth-filled";
    #[doc(alias = "earth-leaf-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "earth-leaf-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "earth-leaf-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `earth-leaf-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/earth-leaf-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EARTH_LEAF_FILLED: &str = "earth-leaf-filled";
    #[doc(alias = "earth-leaf-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "earth-leaf-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "earth-leaf-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `earth-leaf-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/earth-leaf-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EARTH_LEAF_REGULAR: &str = "earth-leaf-regular";
    #[doc(alias = "earth-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "earth-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "earth-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `earth-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/earth-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EARTH_REGULAR: &str = "earth-regular";
    #[doc(alias = "edit")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "edit", feature = "icon-development-kit"))]
    /// Icon name constant for the `edit` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/edit-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT: &str = "edit";
    #[doc(alias = "edit-arrow-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit-arrow-back-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "edit-arrow-back-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `edit-arrow-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/edit-arrow-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT_ARROW_BACK_FILLED: &str = "edit-arrow-back-filled";
    #[doc(alias = "edit-arrow-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit-arrow-back-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "edit-arrow-back-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `edit-arrow-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/edit-arrow-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT_ARROW_BACK_REGULAR: &str = "edit-arrow-back-regular";
    #[doc(alias = "edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT_FILLED: &str = "edit-filled";
    #[doc(alias = "edit-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "edit-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `edit-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/edit-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT_OFF_FILLED: &str = "edit-off-filled";
    #[doc(alias = "edit-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "edit-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `edit-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/edit-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT_OFF_REGULAR: &str = "edit-off-regular";
    #[doc(alias = "edit-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit-prohibited-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "edit-prohibited-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `edit-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/edit-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT_PROHIBITED_FILLED: &str = "edit-prohibited-filled";
    #[doc(alias = "edit-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit-prohibited-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "edit-prohibited-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `edit-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/edit-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT_PROHIBITED_REGULAR: &str = "edit-prohibited-regular";
    #[doc(alias = "edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT_REGULAR: &str = "edit-regular";
    #[doc(alias = "edit-select-all")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit-select-all", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "edit-select-all", feature = "icon-development-kit"))]
    /// Icon name constant for the `edit-select-all` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/edit-select-all-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT_SELECT_ALL: &str = "edit-select-all";
    #[doc(alias = "edit-select-all-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit-select-all-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "edit-select-all-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `edit-select-all-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/edit-select-all-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT_SELECT_ALL_ALT: &str = "edit-select-all-alt";
    #[doc(alias = "edit-select-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "edit-select-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "edit-select-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `edit-select-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/edit-select-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDIT_SELECT_NONE: &str = "edit-select-none";
    #[doc(alias = "editor")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "editor", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "editor", feature = "icon-development-kit"))]
    /// Icon name constant for the `editor` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/editor-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EDITOR: &str = "editor";
    #[doc(alias = "egg")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "egg", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "egg", feature = "icon-development-kit"))]
    /// Icon name constant for the `egg` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/egg-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EGG: &str = "egg";
    #[doc(alias = "eject")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eject", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eject", feature = "icon-development-kit"))]
    /// Icon name constant for the `eject` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eject-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EJECT: &str = "eject";
    #[doc(alias = "eject-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eject-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eject-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `eject-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eject-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EJECT_LARGE: &str = "eject-large";
    #[doc(alias = "electric-car")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "electric-car", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "electric-car", feature = "icon-development-kit"))]
    /// Icon name constant for the `electric-car` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/electric-car-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ELECTRIC_CAR: &str = "electric-car";
    #[doc(alias = "emergency-number")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emergency-number", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "emergency-number", feature = "icon-development-kit"))]
    /// Icon name constant for the `emergency-number` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/emergency-number-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMERGENCY_NUMBER: &str = "emergency-number";
    #[doc(alias = "emoji-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_ADD_FILLED: &str = "emoji-add-filled";
    #[doc(alias = "emoji-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_ADD_REGULAR: &str = "emoji-add-regular";
    #[doc(alias = "emoji-angry-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-angry-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-angry-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-angry-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-angry-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_ANGRY_FILLED: &str = "emoji-angry-filled";
    #[doc(alias = "emoji-angry-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-angry-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-angry-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-angry-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-angry-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_ANGRY_REGULAR: &str = "emoji-angry-regular";
    #[doc(alias = "emoji-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_EDIT_FILLED: &str = "emoji-edit-filled";
    #[doc(alias = "emoji-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_EDIT_REGULAR: &str = "emoji-edit-regular";
    #[doc(alias = "emoji-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_FILLED: &str = "emoji-filled";
    #[doc(alias = "emoji-hand-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-hand-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-hand-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-hand-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-hand-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_HAND_FILLED: &str = "emoji-hand-filled";
    #[doc(alias = "emoji-hand-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-hand-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-hand-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-hand-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-hand-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_HAND_REGULAR: &str = "emoji-hand-regular";
    #[doc(alias = "emoji-hint-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-hint-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-hint-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-hint-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-hint-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_HINT_FILLED: &str = "emoji-hint-filled";
    #[doc(alias = "emoji-hint-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-hint-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-hint-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-hint-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-hint-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_HINT_REGULAR: &str = "emoji-hint-regular";
    #[doc(alias = "emoji-laugh-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-laugh-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-laugh-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-laugh-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-laugh-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_LAUGH_FILLED: &str = "emoji-laugh-filled";
    #[doc(alias = "emoji-laugh-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-laugh-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-laugh-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-laugh-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-laugh-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_LAUGH_REGULAR: &str = "emoji-laugh-regular";
    #[doc(alias = "emoji-meh-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-meh-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-meh-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-meh-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-meh-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_MEH_FILLED: &str = "emoji-meh-filled";
    #[doc(alias = "emoji-meh-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-meh-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-meh-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-meh-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-meh-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_MEH_REGULAR: &str = "emoji-meh-regular";
    #[doc(alias = "emoji-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_REGULAR: &str = "emoji-regular";
    #[doc(alias = "emoji-sad-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-sad-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-sad-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-sad-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-sad-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_SAD_FILLED: &str = "emoji-sad-filled";
    #[doc(alias = "emoji-sad-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-sad-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-sad-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-sad-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-sad-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_SAD_REGULAR: &str = "emoji-sad-regular";
    #[doc(alias = "emoji-sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-sparkle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-sparkle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_SPARKLE_FILLED: &str = "emoji-sparkle-filled";
    #[doc(alias = "emoji-sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "emoji-sparkle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "emoji-sparkle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `emoji-sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/emoji-sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMOJI_SPARKLE_REGULAR: &str = "emoji-sparkle-regular";
    #[doc(alias = "empty-trash")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "empty-trash", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "empty-trash", feature = "icon-development-kit"))]
    /// Icon name constant for the `empty-trash` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/empty-trash-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMPTY_TRASH: &str = "empty-trash";
    #[doc(alias = "empty-trash-bin")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "empty-trash-bin", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "empty-trash-bin", feature = "icon-development-kit"))]
    /// Icon name constant for the `empty-trash-bin` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/empty-trash-bin-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EMPTY_TRASH_BIN: &str = "empty-trash-bin";
    #[doc(alias = "encode")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "encode", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "encode", feature = "icon-development-kit"))]
    /// Icon name constant for the `encode` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/encode-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ENCODE: &str = "encode";
    #[doc(alias = "encoder-knob")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "encoder-knob", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "encoder-knob", feature = "icon-development-kit"))]
    /// Icon name constant for the `encoder-knob` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/encoder-knob-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ENCODER_KNOB: &str = "encoder-knob";
    #[doc(alias = "entry-clear")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "entry-clear", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "entry-clear", feature = "icon-development-kit"))]
    /// Icon name constant for the `entry-clear` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/entry-clear-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ENTRY_CLEAR: &str = "entry-clear";
    #[doc(alias = "equal-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "equal-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "equal-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `equal-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/equal-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EQUAL_OFF_FILLED: &str = "equal-off-filled";
    #[doc(alias = "equal-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "equal-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "equal-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `equal-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/equal-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EQUAL_OFF_REGULAR: &str = "equal-off-regular";
    #[doc(alias = "eraser")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eraser", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eraser", feature = "icon-development-kit"))]
    /// Icon name constant for the `eraser` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eraser-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ERASER: &str = "eraser";
    #[doc(alias = "eraser2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eraser2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eraser2", feature = "icon-development-kit"))]
    /// Icon name constant for the `eraser2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eraser2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ERASER2: &str = "eraser2";
    #[doc(alias = "eraser3")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eraser3", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eraser3", feature = "icon-development-kit"))]
    /// Icon name constant for the `eraser3` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eraser3-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ERASER3: &str = "eraser3";
    #[doc(alias = "eraser4")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eraser4", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eraser4", feature = "icon-development-kit"))]
    /// Icon name constant for the `eraser4` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eraser4-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ERASER4: &str = "eraser4";
    #[doc(alias = "eraser5")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eraser5", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eraser5", feature = "icon-development-kit"))]
    /// Icon name constant for the `eraser5` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eraser5-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ERASER5: &str = "eraser5";
    #[doc(alias = "error")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "error", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "error", feature = "icon-development-kit"))]
    /// Icon name constant for the `error` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/error-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ERROR: &str = "error";
    #[doc(alias = "error-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "error-circle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "error-circle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `error-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/error-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ERROR_CIRCLE_FILLED: &str = "error-circle-filled";
    #[doc(alias = "error-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "error-circle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "error-circle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `error-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/error-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ERROR_CIRCLE_REGULAR: &str = "error-circle-regular";
    #[doc(alias = "error-circle-settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "error-circle-settings-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "error-circle-settings-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `error-circle-settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/error-circle-settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ERROR_CIRCLE_SETTINGS_FILLED: &str = "error-circle-settings-filled";
    #[doc(alias = "error-circle-settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "error-circle-settings-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "error-circle-settings-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `error-circle-settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/error-circle-settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ERROR_CIRCLE_SETTINGS_REGULAR: &str = "error-circle-settings-regular";
    #[doc(alias = "ev")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ev", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "ev", feature = "icon-development-kit"))]
    /// Icon name constant for the `ev` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/ev-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EV: &str = "ev";
    #[doc(alias = "execute-from")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "execute-from", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "execute-from", feature = "icon-development-kit"))]
    /// Icon name constant for the `execute-from` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/execute-from-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXECUTE_FROM: &str = "execute-from";
    #[doc(alias = "execute-to")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "execute-to", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "execute-to", feature = "icon-development-kit"))]
    /// Icon name constant for the `execute-to` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/execute-to-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXECUTE_TO: &str = "execute-to";
    #[doc(alias = "expand-up-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "expand-up-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "expand-up-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `expand-up-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/expand-up-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXPAND_UP_LEFT_FILLED: &str = "expand-up-left-filled";
    #[doc(alias = "expand-up-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "expand-up-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "expand-up-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `expand-up-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/expand-up-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXPAND_UP_LEFT_REGULAR: &str = "expand-up-left-regular";
    #[doc(alias = "expand-up-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "expand-up-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "expand-up-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `expand-up-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/expand-up-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXPAND_UP_RIGHT_FILLED: &str = "expand-up-right-filled";
    #[doc(alias = "expand-up-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "expand-up-right-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "expand-up-right-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `expand-up-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/expand-up-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXPAND_UP_RIGHT_REGULAR: &str = "expand-up-right-regular";
    #[doc(alias = "explore")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "explore", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "explore", feature = "icon-development-kit"))]
    /// Icon name constant for the `explore` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/explore-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXPLORE: &str = "explore";
    #[doc(alias = "explore2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "explore2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "explore2", feature = "icon-development-kit"))]
    /// Icon name constant for the `explore2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/explore2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXPLORE2: &str = "explore2";
    #[doc(alias = "explore2-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "explore2-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "explore2-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `explore2-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/explore2-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXPLORE2_LARGE: &str = "explore2-large";
    #[doc(alias = "external-devices")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "external-devices", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "external-devices", feature = "icon-development-kit"))]
    /// Icon name constant for the `external-devices` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/external-devices-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXTERNAL_DEVICES: &str = "external-devices";
    #[doc(alias = "external-display")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "external-display", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "external-display", feature = "icon-development-kit"))]
    /// Icon name constant for the `external-display` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/external-display-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXTERNAL_DISPLAY: &str = "external-display";
    #[doc(alias = "external-display2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "external-display2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "external-display2", feature = "icon-development-kit"))]
    /// Icon name constant for the `external-display2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/external-display2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXTERNAL_DISPLAY2: &str = "external-display2";
    #[doc(alias = "external-link")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "external-link", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "external-link", feature = "icon-development-kit"))]
    /// Icon name constant for the `external-link` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/external-link-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXTERNAL_LINK: &str = "external-link";
    #[doc(alias = "extract")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "extract", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "extract", feature = "icon-development-kit"))]
    /// Icon name constant for the `extract` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/extract-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EXTRACT: &str = "extract";
    #[doc(alias = "eye-closed")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-closed", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eye-closed", feature = "icon-development-kit"))]
    /// Icon name constant for the `eye-closed` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eye-closed-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_CLOSED: &str = "eye-closed";
    #[doc(alias = "eye-closed-negative")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-closed-negative", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eye-closed-negative", feature = "icon-development-kit"))]
    /// Icon name constant for the `eye-closed-negative` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eye-closed-negative-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_CLOSED_NEGATIVE: &str = "eye-closed-negative";
    #[doc(alias = "eye-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "eye-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `eye-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/eye-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_FILLED: &str = "eye-filled";
    #[doc(alias = "eye-not-looking")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-not-looking", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eye-not-looking", feature = "icon-development-kit"))]
    /// Icon name constant for the `eye-not-looking` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eye-not-looking-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_NOT_LOOKING: &str = "eye-not-looking";
    #[doc(alias = "eye-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "eye-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `eye-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/eye-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_OFF_FILLED: &str = "eye-off-filled";
    #[doc(alias = "eye-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "eye-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `eye-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/eye-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_OFF_REGULAR: &str = "eye-off-regular";
    #[doc(alias = "eye-open")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-open", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eye-open", feature = "icon-development-kit"))]
    /// Icon name constant for the `eye-open` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eye-open-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_OPEN: &str = "eye-open";
    #[doc(alias = "eye-open-negative")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-open-negative", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eye-open-negative", feature = "icon-development-kit"))]
    /// Icon name constant for the `eye-open-negative` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eye-open-negative-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_OPEN_NEGATIVE: &str = "eye-open-negative";
    #[doc(alias = "eye-open-negative-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-open-negative-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "eye-open-negative-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `eye-open-negative-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/eye-open-negative-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_OPEN_NEGATIVE_FILLED: &str = "eye-open-negative-filled";
    #[doc(alias = "eye-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "eye-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `eye-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/eye-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_REGULAR: &str = "eye-regular";
    #[doc(alias = "eye-tracking-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-tracking-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "eye-tracking-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `eye-tracking-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/eye-tracking-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_TRACKING_FILLED: &str = "eye-tracking-filled";
    #[doc(alias = "eye-tracking-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-tracking-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "eye-tracking-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `eye-tracking-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/eye-tracking-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_TRACKING_OFF_FILLED: &str = "eye-tracking-off-filled";
    #[doc(alias = "eye-tracking-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "eye-tracking-off-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "eye-tracking-off-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `eye-tracking-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/eye-tracking-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_TRACKING_OFF_REGULAR: &str = "eye-tracking-off-regular";
    #[doc(alias = "eye-tracking-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eye-tracking-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "eye-tracking-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `eye-tracking-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/eye-tracking-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYE_TRACKING_REGULAR: &str = "eye-tracking-regular";
    #[doc(alias = "eyedropper-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eyedropper-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "eyedropper-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `eyedropper-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/eyedropper-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYEDROPPER_FILLED: &str = "eyedropper-filled";
    #[doc(alias = "eyedropper-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "eyedropper-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "eyedropper-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `eyedropper-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/eyedropper-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const EYEDROPPER_REGULAR: &str = "eyedropper-regular";
    #[doc(alias = "f-stop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "f-stop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "f-stop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `f-stop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/f-stop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const F_STOP_FILLED: &str = "f-stop-filled";
    #[doc(alias = "f-stop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "f-stop-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "f-stop-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `f-stop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/f-stop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const F_STOP_REGULAR: &str = "f-stop-regular";
    #[doc(alias = "face-unlock")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "face-unlock", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "face-unlock", feature = "icon-development-kit"))]
    /// Icon name constant for the `face-unlock` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/face-unlock-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FACE_UNLOCK: &str = "face-unlock";
    #[doc(alias = "fast-food")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fast-food", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fast-food", feature = "icon-development-kit"))]
    /// Icon name constant for the `fast-food` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fast-food-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FAST_FOOD: &str = "fast-food";
    #[doc(alias = "fast-forward-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fast-forward-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fast-forward-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fast-forward-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fast-forward-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FAST_FORWARD_FILLED: &str = "fast-forward-filled";
    #[doc(alias = "fast-forward-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fast-forward-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fast-forward-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fast-forward-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fast-forward-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FAST_FORWARD_REGULAR: &str = "fast-forward-regular";
    #[doc(alias = "fast-fourier-transform")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fast-fourier-transform", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fast-fourier-transform", feature = "icon-development-kit"))]
    /// Icon name constant for the `fast-fourier-transform` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fast-fourier-transform-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FAST_FOURIER_TRANSFORM: &str = "fast-fourier-transform";
    #[doc(alias = "fax")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fax", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fax", feature = "icon-development-kit"))]
    /// Icon name constant for the `fax` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fax-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FAX: &str = "fax";
    #[doc(alias = "fax-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fax-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fax-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fax-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fax-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FAX_FILLED: &str = "fax-filled";
    #[doc(alias = "fax-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fax-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fax-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fax-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fax-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FAX_REGULAR: &str = "fax-regular";
    #[doc(alias = "feed-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "feed-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "feed-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `feed-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/feed-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FEED_FILLED: &str = "feed-filled";
    #[doc(alias = "feed-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "feed-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "feed-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `feed-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/feed-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FEED_REGULAR: &str = "feed-regular";
    #[doc(alias = "feet")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "feet", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "feet", feature = "icon-development-kit"))]
    /// Icon name constant for the `feet` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/feet-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FEET: &str = "feet";
    #[doc(alias = "ferry")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ferry", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "ferry", feature = "icon-development-kit"))]
    /// Icon name constant for the `ferry` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/ferry-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FERRY: &str = "ferry";
    #[doc(alias = "few-clouds")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "few-clouds", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "few-clouds", feature = "icon-development-kit"))]
    /// Icon name constant for the `few-clouds` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/few-clouds-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FEW_CLOUDS: &str = "few-clouds";
    #[doc(alias = "few-clouds-night")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "few-clouds-night", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "few-clouds-night", feature = "icon-development-kit"))]
    /// Icon name constant for the `few-clouds-night` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/few-clouds-night-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FEW_CLOUDS_NIGHT: &str = "few-clouds-night";
    #[doc(alias = "few-clouds-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "few-clouds-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "few-clouds-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `few-clouds-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/few-clouds-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FEW_CLOUDS_OUTLINE: &str = "few-clouds-outline";
    #[doc(alias = "file-cabinet")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "file-cabinet", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "file-cabinet", feature = "icon-development-kit"))]
    /// Icon name constant for the `file-cabinet` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/file-cabinet-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILE_CABINET: &str = "file-cabinet";
    #[doc(alias = "file-manager")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "file-manager", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "file-manager", feature = "icon-development-kit"))]
    /// Icon name constant for the `file-manager` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/file-manager-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILE_MANAGER: &str = "file-manager";
    #[doc(alias = "fill-tool")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fill-tool", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fill-tool", feature = "icon-development-kit"))]
    /// Icon name constant for the `fill-tool` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fill-tool-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILL_TOOL: &str = "fill-tool";
    #[doc(alias = "film-camera")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "film-camera", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "film-camera", feature = "icon-development-kit"))]
    /// Icon name constant for the `film-camera` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/film-camera-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILM_CAMERA: &str = "film-camera";
    #[doc(alias = "film-camera-disabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "film-camera-disabled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "film-camera-disabled", feature = "icon-development-kit"))]
    /// Icon name constant for the `film-camera-disabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/film-camera-disabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILM_CAMERA_DISABLED: &str = "film-camera-disabled";
    #[doc(alias = "filmstrip-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "filmstrip-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "filmstrip-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `filmstrip-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/filmstrip-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILMSTRIP_FILLED: &str = "filmstrip-filled";
    #[doc(alias = "filmstrip-play-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "filmstrip-play-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "filmstrip-play-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `filmstrip-play-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/filmstrip-play-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILMSTRIP_PLAY_FILLED: &str = "filmstrip-play-filled";
    #[doc(alias = "filmstrip-play-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "filmstrip-play-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "filmstrip-play-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `filmstrip-play-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/filmstrip-play-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILMSTRIP_PLAY_REGULAR: &str = "filmstrip-play-regular";
    #[doc(alias = "filmstrip-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "filmstrip-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "filmstrip-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `filmstrip-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/filmstrip-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILMSTRIP_REGULAR: &str = "filmstrip-regular";
    #[doc(alias = "filmstrip-split-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "filmstrip-split-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "filmstrip-split-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `filmstrip-split-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/filmstrip-split-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILMSTRIP_SPLIT_FILLED: &str = "filmstrip-split-filled";
    #[doc(alias = "filmstrip-split-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "filmstrip-split-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "filmstrip-split-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `filmstrip-split-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/filmstrip-split-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILMSTRIP_SPLIT_REGULAR: &str = "filmstrip-split-regular";
    #[doc(alias = "filter-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "filter-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "filter-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `filter-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/filter-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILTER_DISMISS_FILLED: &str = "filter-dismiss-filled";
    #[doc(alias = "filter-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "filter-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "filter-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `filter-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/filter-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILTER_DISMISS_REGULAR: &str = "filter-dismiss-regular";
    #[doc(alias = "filter-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "filter-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "filter-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `filter-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/filter-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILTER_FILLED: &str = "filter-filled";
    #[doc(alias = "filter-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "filter-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "filter-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `filter-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/filter-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FILTER_REGULAR: &str = "filter-regular";
    #[doc(alias = "fingerprint")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fingerprint", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fingerprint", feature = "icon-development-kit"))]
    /// Icon name constant for the `fingerprint` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fingerprint-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FINGERPRINT: &str = "fingerprint";
    #[doc(alias = "fingerprint-authentication")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "fingerprint-authentication",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "fingerprint-authentication",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `fingerprint-authentication` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fingerprint-authentication-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FINGERPRINT_AUTHENTICATION: &str = "fingerprint-authentication";
    #[doc(alias = "fingerprint2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fingerprint2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fingerprint2", feature = "icon-development-kit"))]
    /// Icon name constant for the `fingerprint2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fingerprint2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FINGERPRINT2: &str = "fingerprint2";
    #[doc(alias = "fire")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fire", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fire", feature = "icon-development-kit"))]
    /// Icon name constant for the `fire` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fire-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FIRE: &str = "fire";
    #[doc(alias = "fire-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fire-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fire-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fire-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fire-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FIRE_FILLED: &str = "fire-filled";
    #[doc(alias = "fire-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fire-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fire-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fire-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fire-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FIRE_REGULAR: &str = "fire-regular";
    #[doc(alias = "fire2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fire2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fire2", feature = "icon-development-kit"))]
    /// Icon name constant for the `fire2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fire2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FIRE2: &str = "fire2";
    #[doc(alias = "fire2-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fire2-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fire2-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `fire2-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fire2-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FIRE2_ALT: &str = "fire2-alt";
    #[doc(alias = "firefighter")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "firefighter", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "firefighter", feature = "icon-development-kit"))]
    /// Icon name constant for the `firefighter` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/firefighter-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FIREFIGHTER: &str = "firefighter";
    #[doc(alias = "firmware-update")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "firmware-update", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "firmware-update", feature = "icon-development-kit"))]
    /// Icon name constant for the `firmware-update` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/firmware-update-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FIRMWARE_UPDATE: &str = "firmware-update";
    #[doc(alias = "first")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "first", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "first", feature = "icon-development-kit"))]
    /// Icon name constant for the `first` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/first-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FIRST: &str = "first";
    #[doc(alias = "first-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "first-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "first-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `first-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/first-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FIRST_LARGE: &str = "first-large";
    #[doc(alias = "fish")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fish", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fish", feature = "icon-development-kit"))]
    /// Icon name constant for the `fish` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fish-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FISH: &str = "fish";
    #[doc(alias = "flag-clock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flag-clock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flag-clock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flag-clock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flag-clock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_CLOCK_FILLED: &str = "flag-clock-filled";
    #[doc(alias = "flag-clock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flag-clock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flag-clock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flag-clock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flag-clock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_CLOCK_REGULAR: &str = "flag-clock-regular";
    #[doc(alias = "flag-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flag-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "flag-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `flag-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/flag-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_FILLED: &str = "flag-filled";
    #[doc(alias = "flag-filled-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flag-filled-alt", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flag-filled-alt", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flag-filled-alt` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flag-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_FILLED_ALT: &str = "flag-filled-alt";
    #[doc(alias = "flag-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flag-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flag-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flag-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flag-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_OFF_FILLED: &str = "flag-off-filled";
    #[doc(alias = "flag-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flag-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flag-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flag-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flag-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_OFF_REGULAR: &str = "flag-off-regular";
    #[doc(alias = "flag-outline-thick")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flag-outline-thick", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "flag-outline-thick", feature = "icon-development-kit"))]
    /// Icon name constant for the `flag-outline-thick` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/flag-outline-thick-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_OUTLINE_THICK: &str = "flag-outline-thick";
    #[doc(alias = "flag-outline-thin")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flag-outline-thin", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "flag-outline-thin", feature = "icon-development-kit"))]
    /// Icon name constant for the `flag-outline-thin` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/flag-outline-thin-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_OUTLINE_THIN: &str = "flag-outline-thin";
    #[doc(alias = "flag-pride-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flag-pride-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flag-pride-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flag-pride-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flag-pride-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_PRIDE_FILLED: &str = "flag-pride-filled";
    #[doc(alias = "flag-pride-intersex-inclusive-progress-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "flag-pride-intersex-inclusive-progress-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "flag-pride-intersex-inclusive-progress-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `flag-pride-intersex-inclusive-progress-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flag-pride-intersex-inclusive-progress-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_PRIDE_INTERSEX_INCLUSIVE_PROGRESS_FILLED: &str =
        "flag-pride-intersex-inclusive-progress-filled";
    #[doc(alias = "flag-pride-philadelphia-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "flag-pride-philadelphia-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "flag-pride-philadelphia-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `flag-pride-philadelphia-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flag-pride-philadelphia-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_PRIDE_PHILADELPHIA_FILLED: &str = "flag-pride-philadelphia-filled";
    #[doc(alias = "flag-pride-progress-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "flag-pride-progress-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "flag-pride-progress-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `flag-pride-progress-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flag-pride-progress-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_PRIDE_PROGRESS_FILLED: &str = "flag-pride-progress-filled";
    #[doc(alias = "flag-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flag-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flag-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flag-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flag-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAG_REGULAR: &str = "flag-regular";
    #[doc(alias = "flap")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flap", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "flap", feature = "icon-development-kit"))]
    /// Icon name constant for the `flap` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/flap-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLAP: &str = "flap";
    #[doc(alias = "flash-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flash-checkmark-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flash-checkmark-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flash-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flash-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLASH_CHECKMARK_FILLED: &str = "flash-checkmark-filled";
    #[doc(alias = "flash-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flash-checkmark-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flash-checkmark-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flash-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flash-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLASH_CHECKMARK_REGULAR: &str = "flash-checkmark-regular";
    #[doc(alias = "flash-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flash-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flash-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flash-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flash-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLASH_FILLED: &str = "flash-filled";
    #[doc(alias = "flash-flow-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flash-flow-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flash-flow-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flash-flow-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flash-flow-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLASH_FLOW_FILLED: &str = "flash-flow-filled";
    #[doc(alias = "flash-flow-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flash-flow-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flash-flow-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flash-flow-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flash-flow-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLASH_FLOW_REGULAR: &str = "flash-flow-regular";
    #[doc(alias = "flash-memory")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flash-memory", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "flash-memory", feature = "icon-development-kit"))]
    /// Icon name constant for the `flash-memory` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/flash-memory-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLASH_MEMORY: &str = "flash-memory";
    #[doc(alias = "flash-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flash-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flash-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flash-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flash-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLASH_REGULAR: &str = "flash-regular";
    #[doc(alias = "flashlight")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flashlight", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "flashlight", feature = "icon-development-kit"))]
    /// Icon name constant for the `flashlight` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/flashlight-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLASHLIGHT: &str = "flashlight";
    #[doc(alias = "flashlight-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flashlight-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flashlight-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flashlight-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flashlight-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLASHLIGHT_FILLED: &str = "flashlight-filled";
    #[doc(alias = "flashlight-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flashlight-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "flashlight-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `flashlight-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/flashlight-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLASHLIGHT_NONE: &str = "flashlight-none";
    #[doc(alias = "flashlight-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flashlight-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flashlight-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flashlight-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flashlight-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLASHLIGHT_REGULAR: &str = "flashlight-regular";
    #[doc(alias = "flatpak")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flatpak", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "flatpak", feature = "icon-development-kit"))]
    /// Icon name constant for the `flatpak` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/flatpak-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLATPAK: &str = "flatpak";
    #[doc(alias = "flip-horizontal-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flip-horizontal-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flip-horizontal-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flip-horizontal-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flip-horizontal-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLIP_HORIZONTAL_FILLED: &str = "flip-horizontal-filled";
    #[doc(alias = "flip-horizontal-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flip-horizontal-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flip-horizontal-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flip-horizontal-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flip-horizontal-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLIP_HORIZONTAL_REGULAR: &str = "flip-horizontal-regular";
    #[doc(alias = "flip-vertical-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flip-vertical-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flip-vertical-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flip-vertical-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flip-vertical-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLIP_VERTICAL_FILLED: &str = "flip-vertical-filled";
    #[doc(alias = "flip-vertical-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flip-vertical-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flip-vertical-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flip-vertical-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flip-vertical-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLIP_VERTICAL_REGULAR: &str = "flip-vertical-regular";
    #[doc(alias = "floppy")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "floppy", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "floppy", feature = "icon-development-kit"))]
    /// Icon name constant for the `floppy` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/floppy-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLOPPY: &str = "floppy";
    #[doc(alias = "flow-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flow-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flow-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flow-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flow-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLOW_FILLED: &str = "flow-filled";
    #[doc(alias = "flow-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flow-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "flow-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `flow-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/flow-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLOW_REGULAR: &str = "flow-regular";
    #[doc(alias = "fluid-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fluid-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fluid-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fluid-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fluid-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLUID_FILLED: &str = "fluid-filled";
    #[doc(alias = "fluid-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fluid-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fluid-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fluid-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fluid-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLUID_REGULAR: &str = "fluid-regular";
    #[doc(alias = "flying")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flying", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "flying", feature = "icon-development-kit"))]
    /// Icon name constant for the `flying` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/flying-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLYING: &str = "flying";
    #[doc(alias = "flying2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "flying2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "flying2", feature = "icon-development-kit"))]
    /// Icon name constant for the `flying2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/flying2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FLYING2: &str = "flying2";
    #[doc(alias = "fog")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fog", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fog", feature = "icon-development-kit"))]
    /// Icon name constant for the `fog` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fog-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOG: &str = "fog";
    #[doc(alias = "folder-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_ADD_FILLED: &str = "folder-add-filled";
    #[doc(alias = "folder-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_ADD_REGULAR: &str = "folder-add-regular";
    #[doc(alias = "folder-arrow-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "folder-arrow-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "folder-arrow-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `folder-arrow-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-arrow-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_ARROW_LEFT_FILLED: &str = "folder-arrow-left-filled";
    #[doc(alias = "folder-arrow-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "folder-arrow-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "folder-arrow-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `folder-arrow-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-arrow-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_ARROW_LEFT_REGULAR: &str = "folder-arrow-left-regular";
    #[doc(alias = "folder-arrow-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "folder-arrow-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "folder-arrow-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `folder-arrow-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-arrow-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_ARROW_RIGHT_FILLED: &str = "folder-arrow-right-filled";
    #[doc(alias = "folder-arrow-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "folder-arrow-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "folder-arrow-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `folder-arrow-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-arrow-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_ARROW_RIGHT_REGULAR: &str = "folder-arrow-right-regular";
    #[doc(alias = "folder-arrow-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-arrow-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-arrow-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-arrow-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-arrow-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_ARROW_UP_FILLED: &str = "folder-arrow-up-filled";
    #[doc(alias = "folder-arrow-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-arrow-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-arrow-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-arrow-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-arrow-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_ARROW_UP_REGULAR: &str = "folder-arrow-up-regular";
    #[doc(alias = "folder-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_FILLED: &str = "folder-filled";
    #[doc(alias = "folder-globe-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-globe-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-globe-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-globe-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-globe-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_GLOBE_FILLED: &str = "folder-globe-filled";
    #[doc(alias = "folder-globe-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-globe-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-globe-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-globe-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-globe-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_GLOBE_REGULAR: &str = "folder-globe-regular";
    #[doc(alias = "folder-lightning-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-lightning-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-lightning-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-lightning-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-lightning-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_LIGHTNING_FILLED: &str = "folder-lightning-filled";
    #[doc(alias = "folder-lightning-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "folder-lightning-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "folder-lightning-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `folder-lightning-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-lightning-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_LIGHTNING_REGULAR: &str = "folder-lightning-regular";
    #[doc(alias = "folder-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-link-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-link-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_LINK_FILLED: &str = "folder-link-filled";
    #[doc(alias = "folder-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-link-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-link-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_LINK_REGULAR: &str = "folder-link-regular";
    #[doc(alias = "folder-list-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-list-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-list-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-list-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-list-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_LIST_FILLED: &str = "folder-list-filled";
    #[doc(alias = "folder-list-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-list-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-list-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-list-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-list-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_LIST_REGULAR: &str = "folder-list-regular";
    #[doc(alias = "folder-mail-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-mail-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-mail-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-mail-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-mail-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_MAIL_FILLED: &str = "folder-mail-filled";
    #[doc(alias = "folder-mail-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-mail-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-mail-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-mail-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-mail-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_MAIL_REGULAR: &str = "folder-mail-regular";
    #[doc(alias = "folder-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_MULTIPLE_FILLED: &str = "folder-multiple-filled";
    #[doc(alias = "folder-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_MULTIPLE_REGULAR: &str = "folder-multiple-regular";
    #[doc(alias = "folder-open-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-open-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-open-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-open-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-open-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_OPEN_FILLED: &str = "folder-open-filled";
    #[doc(alias = "folder-open-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-open-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-open-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-open-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-open-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_OPEN_REGULAR: &str = "folder-open-regular";
    #[doc(alias = "folder-open-vertical-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "folder-open-vertical-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "folder-open-vertical-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `folder-open-vertical-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-open-vertical-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_OPEN_VERTICAL_FILLED: &str = "folder-open-vertical-filled";
    #[doc(alias = "folder-open-vertical-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "folder-open-vertical-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "folder-open-vertical-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `folder-open-vertical-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-open-vertical-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_OPEN_VERTICAL_REGULAR: &str = "folder-open-vertical-regular";
    #[doc(alias = "folder-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-person-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-person-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_PERSON_FILLED: &str = "folder-person-filled";
    #[doc(alias = "folder-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-person-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-person-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_PERSON_REGULAR: &str = "folder-person-regular";
    #[doc(alias = "folder-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "folder-prohibited-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "folder-prohibited-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `folder-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_PROHIBITED_FILLED: &str = "folder-prohibited-filled";
    #[doc(alias = "folder-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "folder-prohibited-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "folder-prohibited-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `folder-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_PROHIBITED_REGULAR: &str = "folder-prohibited-regular";
    #[doc(alias = "folder-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_REGULAR: &str = "folder-regular";
    #[doc(alias = "folder-remote")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-remote", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "folder-remote", feature = "icon-development-kit"))]
    /// Icon name constant for the `folder-remote` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/folder-remote-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_REMOTE: &str = "folder-remote";
    #[doc(alias = "folder-swap-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-swap-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-swap-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-swap-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-swap-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_SWAP_FILLED: &str = "folder-swap-filled";
    #[doc(alias = "folder-swap-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-swap-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-swap-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-swap-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-swap-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_SWAP_REGULAR: &str = "folder-swap-regular";
    #[doc(alias = "folder-sync-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-sync-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-sync-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-sync-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-sync-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_SYNC_FILLED: &str = "folder-sync-filled";
    #[doc(alias = "folder-sync-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-sync-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-sync-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-sync-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-sync-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_SYNC_REGULAR: &str = "folder-sync-regular";
    #[doc(alias = "folder-zip-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-zip-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-zip-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-zip-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-zip-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_ZIP_FILLED: &str = "folder-zip-filled";
    #[doc(alias = "folder-zip-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "folder-zip-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "folder-zip-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `folder-zip-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/folder-zip-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOLDER_ZIP_REGULAR: &str = "folder-zip-regular";
    #[doc(alias = "font-space-tracking-in-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "font-space-tracking-in-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "font-space-tracking-in-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `font-space-tracking-in-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/font-space-tracking-in-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FONT_SPACE_TRACKING_IN_FILLED: &str = "font-space-tracking-in-filled";
    #[doc(alias = "font-space-tracking-in-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "font-space-tracking-in-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "font-space-tracking-in-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `font-space-tracking-in-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/font-space-tracking-in-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FONT_SPACE_TRACKING_IN_REGULAR: &str = "font-space-tracking-in-regular";
    #[doc(alias = "font-space-tracking-out-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "font-space-tracking-out-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "font-space-tracking-out-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `font-space-tracking-out-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/font-space-tracking-out-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FONT_SPACE_TRACKING_OUT_FILLED: &str = "font-space-tracking-out-filled";
    #[doc(alias = "font-space-tracking-out-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "font-space-tracking-out-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "font-space-tracking-out-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `font-space-tracking-out-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/font-space-tracking-out-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FONT_SPACE_TRACKING_OUT_REGULAR: &str = "font-space-tracking-out-regular";
    #[doc(alias = "font-x-generic")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "font-x-generic", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "font-x-generic", feature = "icon-development-kit"))]
    /// Icon name constant for the `font-x-generic` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/font-x-generic-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FONT_X_GENERIC: &str = "font-x-generic";
    #[doc(alias = "food-cake-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "food-cake-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "food-cake-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `food-cake-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/food-cake-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOOD_CAKE_FILLED: &str = "food-cake-filled";
    #[doc(alias = "food-cake-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "food-cake-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "food-cake-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `food-cake-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/food-cake-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOOD_CAKE_REGULAR: &str = "food-cake-regular";
    #[doc(alias = "food-chicken-leg-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "food-chicken-leg-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "food-chicken-leg-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `food-chicken-leg-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/food-chicken-leg-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOOD_CHICKEN_LEG_FILLED: &str = "food-chicken-leg-filled";
    #[doc(alias = "food-chicken-leg-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "food-chicken-leg-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "food-chicken-leg-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `food-chicken-leg-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/food-chicken-leg-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOOD_CHICKEN_LEG_REGULAR: &str = "food-chicken-leg-regular";
    #[doc(alias = "food-egg-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "food-egg-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "food-egg-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `food-egg-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/food-egg-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOOD_EGG_FILLED: &str = "food-egg-filled";
    #[doc(alias = "food-egg-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "food-egg-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "food-egg-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `food-egg-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/food-egg-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOOD_EGG_REGULAR: &str = "food-egg-regular";
    #[doc(alias = "food-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "food-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "food-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `food-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/food-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOOD_FILLED: &str = "food-filled";
    #[doc(alias = "food-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "food-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "food-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `food-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/food-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOOD_REGULAR: &str = "food-regular";
    #[doc(alias = "food-toast-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "food-toast-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "food-toast-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `food-toast-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/food-toast-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOOD_TOAST_FILLED: &str = "food-toast-filled";
    #[doc(alias = "food-toast-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "food-toast-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "food-toast-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `food-toast-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/food-toast-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOOD_TOAST_REGULAR: &str = "food-toast-regular";
    #[doc(alias = "football-american")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "football-american", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "football-american", feature = "icon-development-kit"))]
    /// Icon name constant for the `football-american` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/football-american-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FOOTBALL_AMERICAN: &str = "football-american";
    #[doc(alias = "fps-30-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fps-30-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fps-30-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fps-30-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fps-30-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FPS_30_FILLED: &str = "fps-30-filled";
    #[doc(alias = "fps-30-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fps-30-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fps-30-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fps-30-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fps-30-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FPS_30_REGULAR: &str = "fps-30-regular";
    #[doc(alias = "fps-60-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fps-60-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fps-60-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fps-60-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fps-60-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FPS_60_FILLED: &str = "fps-60-filled";
    #[doc(alias = "fps-60-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fps-60-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "fps-60-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `fps-60-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/fps-60-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FPS_60_REGULAR: &str = "fps-60-regular";
    #[doc(alias = "frame-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "frame-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "frame-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `frame-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/frame-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FRAME_FILLED: &str = "frame-filled";
    #[doc(alias = "frame-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "frame-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "frame-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `frame-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/frame-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FRAME_REGULAR: &str = "frame-regular";
    #[doc(alias = "fuel")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "fuel", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "fuel", feature = "icon-development-kit"))]
    /// Icon name constant for the `fuel` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/fuel-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FUEL: &str = "fuel";
    #[doc(alias = "full-screen-maximize-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "full-screen-maximize-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "full-screen-maximize-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `full-screen-maximize-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/full-screen-maximize-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FULL_SCREEN_MAXIMIZE_FILLED: &str = "full-screen-maximize-filled";
    #[doc(alias = "full-screen-maximize-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "full-screen-maximize-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "full-screen-maximize-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `full-screen-maximize-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/full-screen-maximize-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FULL_SCREEN_MAXIMIZE_REGULAR: &str = "full-screen-maximize-regular";
    #[doc(alias = "full-screen-minimize-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "full-screen-minimize-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "full-screen-minimize-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `full-screen-minimize-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/full-screen-minimize-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FULL_SCREEN_MINIMIZE_FILLED: &str = "full-screen-minimize-filled";
    #[doc(alias = "full-screen-minimize-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "full-screen-minimize-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "full-screen-minimize-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `full-screen-minimize-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/full-screen-minimize-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FULL_SCREEN_MINIMIZE_REGULAR: &str = "full-screen-minimize-regular";
    #[doc(alias = "function-exponential")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "function-exponential", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "function-exponential", feature = "icon-development-kit"))]
    /// Icon name constant for the `function-exponential` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/function-exponential-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FUNCTION_EXPONENTIAL: &str = "function-exponential";
    #[doc(alias = "function-linear")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "function-linear", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "function-linear", feature = "icon-development-kit"))]
    /// Icon name constant for the `function-linear` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/function-linear-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FUNCTION_LINEAR: &str = "function-linear";
    #[doc(alias = "function-parable")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "function-parable", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "function-parable", feature = "icon-development-kit"))]
    /// Icon name constant for the `function-parable` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/function-parable-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FUNCTION_PARABLE: &str = "function-parable";
    #[doc(alias = "function-parable-horizontal")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "function-parable-horizontal",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "function-parable-horizontal",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `function-parable-horizontal` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/function-parable-horizontal-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FUNCTION_PARABLE_HORIZONTAL: &str = "function-parable-horizontal";
    #[doc(alias = "function-third-order")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "function-third-order", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "function-third-order", feature = "icon-development-kit"))]
    /// Icon name constant for the `function-third-order` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/function-third-order-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FUNCTION_THIRD_ORDER: &str = "function-third-order";
    #[doc(alias = "function-third-order-horizontal")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "function-third-order-horizontal",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "function-third-order-horizontal",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `function-third-order-horizontal` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/function-third-order-horizontal-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FUNCTION_THIRD_ORDER_HORIZONTAL: &str = "function-third-order-horizontal";
    #[doc(alias = "funicular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "funicular", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "funicular", feature = "icon-development-kit"))]
    /// Icon name constant for the `funicular` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/funicular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FUNICULAR: &str = "funicular";
    #[doc(alias = "funnel")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "funnel", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "funnel", feature = "icon-development-kit"))]
    /// Icon name constant for the `funnel` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/funnel-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FUNNEL: &str = "funnel";
    #[doc(alias = "funnel-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "funnel-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "funnel-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `funnel-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/funnel-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const FUNNEL_OUTLINE: &str = "funnel-outline";
    #[doc(alias = "gamepad")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gamepad", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "gamepad", feature = "icon-development-kit"))]
    /// Icon name constant for the `gamepad` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/gamepad-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GAMEPAD: &str = "gamepad";
    #[doc(alias = "gamepad2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gamepad2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "gamepad2", feature = "icon-development-kit"))]
    /// Icon name constant for the `gamepad2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/gamepad2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GAMEPAD2: &str = "gamepad2";
    #[doc(alias = "games-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "games-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "games-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `games-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/games-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GAMES_FILLED: &str = "games-filled";
    #[doc(alias = "games-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "games-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "games-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `games-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/games-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GAMES_REGULAR: &str = "games-regular";
    #[doc(alias = "gantt-chart-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gantt-chart-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gantt-chart-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gantt-chart-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gantt-chart-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GANTT_CHART_FILLED: &str = "gantt-chart-filled";
    #[doc(alias = "gantt-chart-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gantt-chart-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gantt-chart-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gantt-chart-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gantt-chart-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GANTT_CHART_REGULAR: &str = "gantt-chart-regular";
    #[doc(alias = "garlic")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "garlic", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "garlic", feature = "icon-development-kit"))]
    /// Icon name constant for the `garlic` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/garlic-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GARLIC: &str = "garlic";
    #[doc(alias = "gavel-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gavel-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gavel-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gavel-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gavel-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GAVEL_FILLED: &str = "gavel-filled";
    #[doc(alias = "gavel-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gavel-prohibited-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gavel-prohibited-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gavel-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gavel-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GAVEL_PROHIBITED_FILLED: &str = "gavel-prohibited-filled";
    #[doc(alias = "gavel-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "gavel-prohibited-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "gavel-prohibited-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `gavel-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gavel-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GAVEL_PROHIBITED_REGULAR: &str = "gavel-prohibited-regular";
    #[doc(alias = "gavel-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gavel-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gavel-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gavel-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gavel-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GAVEL_REGULAR: &str = "gavel-regular";
    #[doc(alias = "gear")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gear", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "gear", feature = "icon-development-kit"))]
    /// Icon name constant for the `gear` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/gear-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GEAR: &str = "gear";
    #[doc(alias = "general-properties")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "general-properties", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "general-properties", feature = "icon-development-kit"))]
    /// Icon name constant for the `general-properties` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/general-properties-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GENERAL_PROPERTIES: &str = "general-properties";
    #[doc(alias = "gif-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gif-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gif-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gif-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gif-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GIF_FILLED: &str = "gif-filled";
    #[doc(alias = "gif-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gif-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gif-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gif-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gif-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GIF_REGULAR: &str = "gif-regular";
    #[doc(alias = "gift-card-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gift-card-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gift-card-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gift-card-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gift-card-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GIFT_CARD_FILLED: &str = "gift-card-filled";
    #[doc(alias = "gift-card-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gift-card-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gift-card-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gift-card-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gift-card-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GIFT_CARD_REGULAR: &str = "gift-card-regular";
    #[doc(alias = "gift-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gift-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gift-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gift-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gift-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GIFT_FILLED: &str = "gift-filled";
    #[doc(alias = "gift-open-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gift-open-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gift-open-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gift-open-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gift-open-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GIFT_OPEN_FILLED: &str = "gift-open-filled";
    #[doc(alias = "gift-open-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gift-open-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gift-open-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gift-open-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gift-open-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GIFT_OPEN_REGULAR: &str = "gift-open-regular";
    #[doc(alias = "gift-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "gift-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "gift-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `gift-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/gift-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GIFT_REGULAR: &str = "gift-regular";
    #[doc(alias = "git")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "git", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "git", feature = "icon-development-kit"))]
    /// Icon name constant for the `git` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/git-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GIT: &str = "git";
    #[doc(alias = "git-branch")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "git-branch", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "git-branch", feature = "icon-development-kit"))]
    /// Icon name constant for the `git-branch` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/git-branch-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GIT_BRANCH: &str = "git-branch";
    #[doc(alias = "git-merge")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "git-merge", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "git-merge", feature = "icon-development-kit"))]
    /// Icon name constant for the `git-merge` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/git-merge-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GIT_MERGE: &str = "git-merge";
    #[doc(alias = "glance-horizontal-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "glance-horizontal-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "glance-horizontal-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `glance-horizontal-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/glance-horizontal-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLANCE_HORIZONTAL_FILLED: &str = "glance-horizontal-filled";
    #[doc(alias = "glance-horizontal-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "glance-horizontal-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "glance-horizontal-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `glance-horizontal-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/glance-horizontal-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLANCE_HORIZONTAL_REGULAR: &str = "glance-horizontal-regular";
    #[doc(alias = "glance-horizontal-sparkles-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "glance-horizontal-sparkles-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "glance-horizontal-sparkles-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `glance-horizontal-sparkles-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/glance-horizontal-sparkles-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLANCE_HORIZONTAL_SPARKLES_FILLED: &str = "glance-horizontal-sparkles-filled";
    #[doc(alias = "glance-horizontal-sparkles-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "glance-horizontal-sparkles-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "glance-horizontal-sparkles-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `glance-horizontal-sparkles-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/glance-horizontal-sparkles-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLANCE_HORIZONTAL_SPARKLES_REGULAR: &str = "glance-horizontal-sparkles-regular";
    #[doc(alias = "glasses-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "glasses-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "glasses-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `glasses-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/glasses-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLASSES_FILLED: &str = "glasses-filled";
    #[doc(alias = "glasses-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "glasses-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "glasses-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `glasses-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/glasses-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLASSES_OFF_FILLED: &str = "glasses-off-filled";
    #[doc(alias = "glasses-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "glasses-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "glasses-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `glasses-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/glasses-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLASSES_OFF_REGULAR: &str = "glasses-off-regular";
    #[doc(alias = "glasses-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "glasses-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "glasses-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `glasses-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/glasses-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLASSES_REGULAR: &str = "glasses-regular";
    #[doc(alias = "globe")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "globe", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "globe", feature = "icon-development-kit"))]
    /// Icon name constant for the `globe` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/globe-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE: &str = "globe";
    #[doc(alias = "globe-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "globe-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "globe-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `globe-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/globe-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE_ALT: &str = "globe-alt";
    #[doc(alias = "globe-alt2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "globe-alt2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "globe-alt2", feature = "icon-development-kit"))]
    /// Icon name constant for the `globe-alt2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/globe-alt2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE_ALT2: &str = "globe-alt2";
    #[doc(alias = "globe-arrow-forward-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "globe-arrow-forward-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "globe-arrow-forward-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `globe-arrow-forward-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/globe-arrow-forward-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE_ARROW_FORWARD_FILLED: &str = "globe-arrow-forward-filled";
    #[doc(alias = "globe-arrow-forward-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "globe-arrow-forward-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "globe-arrow-forward-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `globe-arrow-forward-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/globe-arrow-forward-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE_ARROW_FORWARD_REGULAR: &str = "globe-arrow-forward-regular";
    #[doc(alias = "globe-clock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "globe-clock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "globe-clock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `globe-clock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/globe-clock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE_CLOCK_FILLED: &str = "globe-clock-filled";
    #[doc(alias = "globe-clock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "globe-clock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "globe-clock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `globe-clock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/globe-clock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE_CLOCK_REGULAR: &str = "globe-clock-regular";
    #[doc(alias = "globe-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "globe-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "globe-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `globe-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/globe-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE_FILLED: &str = "globe-filled";
    #[doc(alias = "globe-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "globe-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "globe-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `globe-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/globe-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE_REGULAR: &str = "globe-regular";
    #[doc(alias = "globe-small")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "globe-small", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "globe-small", feature = "icon-development-kit"))]
    /// Icon name constant for the `globe-small` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/globe-small-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE_SMALL: &str = "globe-small";
    #[doc(alias = "globe-star-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "globe-star-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "globe-star-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `globe-star-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/globe-star-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE_STAR_FILLED: &str = "globe-star-filled";
    #[doc(alias = "globe-star-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "globe-star-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "globe-star-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `globe-star-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/globe-star-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GLOBE_STAR_REGULAR: &str = "globe-star-regular";
    #[doc(alias = "goldola")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "goldola", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "goldola", feature = "icon-development-kit"))]
    /// Icon name constant for the `goldola` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/goldola-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GOLDOLA: &str = "goldola";
    #[doc(alias = "golf")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "golf", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "golf", feature = "icon-development-kit"))]
    /// Icon name constant for the `golf` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/golf-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GOLF: &str = "golf";
    #[doc(alias = "graph")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "graph", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "graph", feature = "icon-development-kit"))]
    /// Icon name constant for the `graph` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/graph-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GRAPH: &str = "graph";
    #[doc(alias = "graph2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "graph2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "graph2", feature = "icon-development-kit"))]
    /// Icon name constant for the `graph2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/graph2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GRAPH2: &str = "graph2";
    #[doc(alias = "graveyard")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "graveyard", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "graveyard", feature = "icon-development-kit"))]
    /// Icon name constant for the `graveyard` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/graveyard-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GRAVEYARD: &str = "graveyard";
    #[doc(alias = "grid")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "grid", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "grid", feature = "icon-development-kit"))]
    /// Icon name constant for the `grid` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/grid-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GRID: &str = "grid";
    #[doc(alias = "grid-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "grid-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "grid-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `grid-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/grid-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GRID_FILLED: &str = "grid-filled";
    #[doc(alias = "grid-filled-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "grid-filled-alt", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "grid-filled-alt", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `grid-filled-alt` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/grid-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GRID_FILLED_ALT: &str = "grid-filled-alt";
    #[doc(alias = "grid-kanban-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "grid-kanban-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "grid-kanban-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `grid-kanban-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/grid-kanban-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GRID_KANBAN_FILLED: &str = "grid-kanban-filled";
    #[doc(alias = "grid-kanban-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "grid-kanban-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "grid-kanban-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `grid-kanban-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/grid-kanban-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GRID_KANBAN_REGULAR: &str = "grid-kanban-regular";
    #[doc(alias = "grid-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "grid-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "grid-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `grid-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/grid-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GRID_LARGE: &str = "grid-large";
    #[doc(alias = "grid-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "grid-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "grid-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `grid-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/grid-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GRID_REGULAR: &str = "grid-regular";
    #[doc(alias = "group")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "group", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "group", feature = "icon-development-kit"))]
    /// Icon name constant for the `group` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/group-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GROUP: &str = "group";
    #[doc(alias = "guest-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "guest-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "guest-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `guest-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/guest-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GUEST_FILLED: &str = "guest-filled";
    #[doc(alias = "guest-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "guest-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "guest-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `guest-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/guest-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GUEST_REGULAR: &str = "guest-regular";
    #[doc(alias = "guitar-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "guitar-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "guitar-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `guitar-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/guitar-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GUITAR_FILLED: &str = "guitar-filled";
    #[doc(alias = "guitar-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "guitar-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "guitar-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `guitar-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/guitar-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const GUITAR_REGULAR: &str = "guitar-regular";
    #[doc(alias = "h")]
    #[cfg_attr(docsrs, doc(cfg(any(feature = "h", feature = "icon-development-kit"))))]
    #[cfg(any(feature = "h", feature = "icon-development-kit"))]
    /// Icon name constant for the `h` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/h-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const H: &str = "h";
    #[doc(alias = "hand-draw-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-draw-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-draw-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-draw-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-draw-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_DRAW_FILLED: &str = "hand-draw-filled";
    #[doc(alias = "hand-draw-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-draw-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-draw-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-draw-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-draw-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_DRAW_REGULAR: &str = "hand-draw-regular";
    #[doc(alias = "hand-fist")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-fist", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hand-fist", feature = "icon-development-kit"))]
    /// Icon name constant for the `hand-fist` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hand-fist-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_FIST: &str = "hand-fist";
    #[doc(alias = "hand-fist-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-fist-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hand-fist-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `hand-fist-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hand-fist-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_FIST_NONE: &str = "hand-fist-none";
    #[doc(alias = "hand-left-chat-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-left-chat-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-left-chat-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-left-chat-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-left-chat-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_LEFT_CHAT_FILLED: &str = "hand-left-chat-filled";
    #[doc(alias = "hand-left-chat-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-left-chat-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-left-chat-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-left-chat-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-left-chat-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_LEFT_CHAT_REGULAR: &str = "hand-left-chat-regular";
    #[doc(alias = "hand-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_LEFT_FILLED: &str = "hand-left-filled";
    #[doc(alias = "hand-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_LEFT_REGULAR: &str = "hand-left-regular";
    #[doc(alias = "hand-middle-finger")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-middle-finger", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hand-middle-finger", feature = "icon-development-kit"))]
    /// Icon name constant for the `hand-middle-finger` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hand-middle-finger-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_MIDDLE_FINGER: &str = "hand-middle-finger";
    #[doc(alias = "hand-open")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-open", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hand-open", feature = "icon-development-kit"))]
    /// Icon name constant for the `hand-open` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hand-open-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_OPEN: &str = "hand-open";
    #[doc(alias = "hand-openyay")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-openyay", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hand-openyay", feature = "icon-development-kit"))]
    /// Icon name constant for the `hand-openyay` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hand-openyay-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_OPENYAY: &str = "hand-openyay";
    #[doc(alias = "hand-point-horizontal")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-point-horizontal", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hand-point-horizontal", feature = "icon-development-kit"))]
    /// Icon name constant for the `hand-point-horizontal` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hand-point-horizontal-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_POINT_HORIZONTAL: &str = "hand-point-horizontal";
    #[doc(alias = "hand-point-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-point-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hand-point-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `hand-point-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hand-point-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_POINT_LEFT: &str = "hand-point-left";
    #[doc(alias = "hand-point-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-point-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hand-point-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `hand-point-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hand-point-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_POINT_RIGHT: &str = "hand-point-right";
    #[doc(alias = "hand-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_RIGHT_FILLED: &str = "hand-right-filled";
    #[doc(alias = "hand-right-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-right-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-right-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-right-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-right-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_RIGHT_OFF_FILLED: &str = "hand-right-off-filled";
    #[doc(alias = "hand-right-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-right-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-right-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-right-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-right-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_RIGHT_OFF_REGULAR: &str = "hand-right-off-regular";
    #[doc(alias = "hand-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-right-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-right-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_RIGHT_REGULAR: &str = "hand-right-regular";
    #[doc(alias = "hand-touch")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-touch", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hand-touch", feature = "icon-development-kit"))]
    /// Icon name constant for the `hand-touch` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hand-touch-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_TOUCH: &str = "hand-touch";
    #[doc(alias = "hand-wave-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-wave-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-wave-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-wave-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-wave-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_WAVE_FILLED: &str = "hand-wave-filled";
    #[doc(alias = "hand-wave-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hand-wave-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hand-wave-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hand-wave-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hand-wave-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAND_WAVE_REGULAR: &str = "hand-wave-regular";
    #[doc(alias = "handshake")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "handshake", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "handshake", feature = "icon-development-kit"))]
    /// Icon name constant for the `handshake` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/handshake-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HANDSHAKE: &str = "handshake";
    #[doc(alias = "handshake-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "handshake-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "handshake-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `handshake-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/handshake-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HANDSHAKE_FILLED: &str = "handshake-filled";
    #[doc(alias = "handshake-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "handshake-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "handshake-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `handshake-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/handshake-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HANDSHAKE_REGULAR: &str = "handshake-regular";
    #[doc(alias = "hard-drive-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hard-drive-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hard-drive-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hard-drive-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hard-drive-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HARD_DRIVE_FILLED: &str = "hard-drive-filled";
    #[doc(alias = "hard-drive-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hard-drive-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hard-drive-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hard-drive-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hard-drive-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HARD_DRIVE_REGULAR: &str = "hard-drive-regular";
    #[doc(alias = "harddisk")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "harddisk", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "harddisk", feature = "icon-development-kit"))]
    /// Icon name constant for the `harddisk` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/harddisk-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HARDDISK: &str = "harddisk";
    #[doc(alias = "harddisk-inverted")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "harddisk-inverted", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "harddisk-inverted", feature = "icon-development-kit"))]
    /// Icon name constant for the `harddisk-inverted` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/harddisk-inverted-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HARDDISK_INVERTED: &str = "harddisk-inverted";
    #[doc(alias = "hat-graduation-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hat-graduation-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hat-graduation-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hat-graduation-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hat-graduation-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAT_GRADUATION_FILLED: &str = "hat-graduation-filled";
    #[doc(alias = "hat-graduation-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hat-graduation-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hat-graduation-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hat-graduation-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hat-graduation-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAT_GRADUATION_REGULAR: &str = "hat-graduation-regular";
    #[doc(alias = "hat-graduation-sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "hat-graduation-sparkle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "hat-graduation-sparkle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `hat-graduation-sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hat-graduation-sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAT_GRADUATION_SPARKLE_FILLED: &str = "hat-graduation-sparkle-filled";
    #[doc(alias = "hat-graduation-sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "hat-graduation-sparkle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "hat-graduation-sparkle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `hat-graduation-sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hat-graduation-sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HAT_GRADUATION_SPARKLE_REGULAR: &str = "hat-graduation-sparkle-regular";
    #[doc(alias = "hd-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hd-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hd-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hd-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hd-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HD_FILLED: &str = "hd-filled";
    #[doc(alias = "hd-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hd-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hd-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hd-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hd-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HD_REGULAR: &str = "hd-regular";
    #[doc(alias = "headphones")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "headphones", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "headphones", feature = "icon-development-kit"))]
    /// Icon name constant for the `headphones` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/headphones-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEADPHONES: &str = "headphones";
    #[doc(alias = "headset")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "headset", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "headset", feature = "icon-development-kit"))]
    /// Icon name constant for the `headset` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/headset-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEADSET: &str = "headset";
    #[doc(alias = "headset-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "headset-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "headset-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `headset-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/headset-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEADSET_FILLED: &str = "headset-filled";
    #[doc(alias = "headset-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "headset-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "headset-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `headset-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/headset-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEADSET_REGULAR: &str = "headset-regular";
    #[doc(alias = "heal")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heal", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "heal", feature = "icon-development-kit"))]
    /// Icon name constant for the `heal` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/heal-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEAL: &str = "heal";
    #[doc(alias = "health-emergency")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "health-emergency", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "health-emergency", feature = "icon-development-kit"))]
    /// Icon name constant for the `health-emergency` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/health-emergency-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEALTH_EMERGENCY: &str = "health-emergency";
    #[doc(alias = "heart-broken")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-broken", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "heart-broken", feature = "icon-development-kit"))]
    /// Icon name constant for the `heart-broken` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/heart-broken-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_BROKEN: &str = "heart-broken";
    #[doc(alias = "heart-broken-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-broken-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "heart-broken-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `heart-broken-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/heart-broken-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_BROKEN_FILLED: &str = "heart-broken-filled";
    #[doc(alias = "heart-broken-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-broken-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "heart-broken-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `heart-broken-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/heart-broken-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_BROKEN_REGULAR: &str = "heart-broken-regular";
    #[doc(alias = "heart-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-circle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "heart-circle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `heart-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/heart-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_CIRCLE_FILLED: &str = "heart-circle-filled";
    #[doc(alias = "heart-circle-hint-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "heart-circle-hint-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "heart-circle-hint-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `heart-circle-hint-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/heart-circle-hint-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_CIRCLE_HINT_FILLED: &str = "heart-circle-hint-filled";
    #[doc(alias = "heart-circle-hint-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "heart-circle-hint-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "heart-circle-hint-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `heart-circle-hint-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/heart-circle-hint-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_CIRCLE_HINT_REGULAR: &str = "heart-circle-hint-regular";
    #[doc(alias = "heart-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-circle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "heart-circle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `heart-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/heart-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_CIRCLE_REGULAR: &str = "heart-circle-regular";
    #[doc(alias = "heart-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "heart-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `heart-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/heart-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_FILLED: &str = "heart-filled";
    #[doc(alias = "heart-filled-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-filled-alt", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "heart-filled-alt", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `heart-filled-alt` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/heart-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_FILLED_ALT: &str = "heart-filled-alt";
    #[doc(alias = "heart-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "heart-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `heart-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/heart-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_OFF_FILLED: &str = "heart-off-filled";
    #[doc(alias = "heart-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "heart-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `heart-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/heart-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_OFF_REGULAR: &str = "heart-off-regular";
    #[doc(alias = "heart-outline-thick")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-outline-thick", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "heart-outline-thick", feature = "icon-development-kit"))]
    /// Icon name constant for the `heart-outline-thick` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/heart-outline-thick-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_OUTLINE_THICK: &str = "heart-outline-thick";
    #[doc(alias = "heart-outline-thin")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-outline-thin", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "heart-outline-thin", feature = "icon-development-kit"))]
    /// Icon name constant for the `heart-outline-thin` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/heart-outline-thin-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_OUTLINE_THIN: &str = "heart-outline-thin";
    #[doc(alias = "heart-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "heart-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "heart-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `heart-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/heart-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEART_REGULAR: &str = "heart-regular";
    #[doc(alias = "hexagon-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hexagon-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hexagon-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hexagon-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hexagon-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEXAGON_FILLED: &str = "hexagon-filled";
    #[doc(alias = "hexagon-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hexagon-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hexagon-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hexagon-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hexagon-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEXAGON_REGULAR: &str = "hexagon-regular";
    #[doc(alias = "hexagon-three-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hexagon-three-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hexagon-three-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hexagon-three-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hexagon-three-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEXAGON_THREE_FILLED: &str = "hexagon-three-filled";
    #[doc(alias = "hexagon-three-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hexagon-three-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hexagon-three-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hexagon-three-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hexagon-three-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HEXAGON_THREE_REGULAR: &str = "hexagon-three-regular";
    #[doc(alias = "hig")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hig", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hig", feature = "icon-development-kit"))]
    /// Icon name constant for the `hig` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hig-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HIG: &str = "hig";
    #[doc(alias = "highlight-accent-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "highlight-accent-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "highlight-accent-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `highlight-accent-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/highlight-accent-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HIGHLIGHT_ACCENT_FILLED: &str = "highlight-accent-filled";
    #[doc(alias = "highlight-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "highlight-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "highlight-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `highlight-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/highlight-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HIGHLIGHT_FILLED: &str = "highlight-filled";
    #[doc(alias = "highlight-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "highlight-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "highlight-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `highlight-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/highlight-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HIGHLIGHT_REGULAR: &str = "highlight-regular";
    #[doc(alias = "history-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "history-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "history-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `history-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/history-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HISTORY_FILLED: &str = "history-filled";
    #[doc(alias = "history-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "history-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "history-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `history-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/history-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HISTORY_REGULAR: &str = "history-regular";
    #[doc(alias = "history-undo")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "history-undo", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "history-undo", feature = "icon-development-kit"))]
    /// Icon name constant for the `history-undo` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/history-undo-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HISTORY_UNDO: &str = "history-undo";
    #[doc(alias = "hockey")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hockey", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hockey", feature = "icon-development-kit"))]
    /// Icon name constant for the `hockey` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hockey-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOCKEY: &str = "hockey";
    #[doc(alias = "home-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "home-checkmark-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "home-checkmark-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `home-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/home-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOME_CHECKMARK_FILLED: &str = "home-checkmark-filled";
    #[doc(alias = "home-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "home-checkmark-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "home-checkmark-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `home-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/home-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOME_CHECKMARK_REGULAR: &str = "home-checkmark-regular";
    #[doc(alias = "home-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "home-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "home-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `home-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/home-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOME_FILLED: &str = "home-filled";
    #[doc(alias = "home-heart-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "home-heart-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "home-heart-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `home-heart-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/home-heart-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOME_HEART_FILLED: &str = "home-heart-filled";
    #[doc(alias = "home-heart-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "home-heart-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "home-heart-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `home-heart-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/home-heart-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOME_HEART_REGULAR: &str = "home-heart-regular";
    #[doc(alias = "home-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "home-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "home-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `home-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/home-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOME_REGULAR: &str = "home-regular";
    #[doc(alias = "horizontal-arrows")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "horizontal-arrows", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "horizontal-arrows", feature = "icon-development-kit"))]
    /// Icon name constant for the `horizontal-arrows` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/horizontal-arrows-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HORIZONTAL_ARROWS: &str = "horizontal-arrows";
    #[doc(alias = "horizontal-arrows-disabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "horizontal-arrows-disabled",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "horizontal-arrows-disabled",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `horizontal-arrows-disabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/horizontal-arrows-disabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HORIZONTAL_ARROWS_DISABLED: &str = "horizontal-arrows-disabled";
    #[doc(alias = "horizontal-arrows-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "horizontal-arrows-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "horizontal-arrows-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `horizontal-arrows-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/horizontal-arrows-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HORIZONTAL_ARROWS_LEFT: &str = "horizontal-arrows-left";
    #[doc(alias = "horizontal-arrows-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "horizontal-arrows-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "horizontal-arrows-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `horizontal-arrows-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/horizontal-arrows-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HORIZONTAL_ARROWS_NONE: &str = "horizontal-arrows-none";
    #[doc(alias = "horizontal-arrows-one-way")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "horizontal-arrows-one-way",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "horizontal-arrows-one-way",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `horizontal-arrows-one-way` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/horizontal-arrows-one-way-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HORIZONTAL_ARROWS_ONE_WAY: &str = "horizontal-arrows-one-way";
    #[doc(alias = "horizontal-arrows-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "horizontal-arrows-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "horizontal-arrows-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `horizontal-arrows-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/horizontal-arrows-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HORIZONTAL_ARROWS_RIGHT: &str = "horizontal-arrows-right";
    #[doc(alias = "hospital")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hospital", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hospital", feature = "icon-development-kit"))]
    /// Icon name constant for the `hospital` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hospital-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOSPITAL: &str = "hospital";
    #[doc(alias = "hospital-sign")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hospital-sign", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hospital-sign", feature = "icon-development-kit"))]
    /// Icon name constant for the `hospital-sign` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hospital-sign-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOSPITAL_SIGN: &str = "hospital-sign";
    #[doc(alias = "hotel-tag")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hotel-tag", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hotel-tag", feature = "icon-development-kit"))]
    /// Icon name constant for the `hotel-tag` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hotel-tag-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOTEL_TAG: &str = "hotel-tag";
    #[doc(alias = "hotel-tag-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hotel-tag-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hotel-tag-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `hotel-tag-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hotel-tag-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOTEL_TAG_OUTLINE: &str = "hotel-tag-outline";
    #[doc(alias = "hourglass")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hourglass", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "hourglass", feature = "icon-development-kit"))]
    /// Icon name constant for the `hourglass` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/hourglass-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOURGLASS: &str = "hourglass";
    #[doc(alias = "hourglass-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hourglass-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hourglass-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hourglass-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hourglass-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOURGLASS_FILLED: &str = "hourglass-filled";
    #[doc(alias = "hourglass-half-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hourglass-half-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hourglass-half-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hourglass-half-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hourglass-half-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOURGLASS_HALF_FILLED: &str = "hourglass-half-filled";
    #[doc(alias = "hourglass-half-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hourglass-half-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hourglass-half-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hourglass-half-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hourglass-half-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOURGLASS_HALF_REGULAR: &str = "hourglass-half-regular";
    #[doc(alias = "hourglass-one-quarter-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "hourglass-one-quarter-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "hourglass-one-quarter-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `hourglass-one-quarter-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hourglass-one-quarter-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOURGLASS_ONE_QUARTER_FILLED: &str = "hourglass-one-quarter-filled";
    #[doc(alias = "hourglass-one-quarter-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "hourglass-one-quarter-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "hourglass-one-quarter-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `hourglass-one-quarter-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hourglass-one-quarter-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOURGLASS_ONE_QUARTER_REGULAR: &str = "hourglass-one-quarter-regular";
    #[doc(alias = "hourglass-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "hourglass-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "hourglass-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `hourglass-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hourglass-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOURGLASS_REGULAR: &str = "hourglass-regular";
    #[doc(alias = "hourglass-three-quarter-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "hourglass-three-quarter-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "hourglass-three-quarter-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `hourglass-three-quarter-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hourglass-three-quarter-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOURGLASS_THREE_QUARTER_FILLED: &str = "hourglass-three-quarter-filled";
    #[doc(alias = "hourglass-three-quarter-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "hourglass-three-quarter-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "hourglass-three-quarter-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `hourglass-three-quarter-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/hourglass-three-quarter-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const HOURGLASS_THREE_QUARTER_REGULAR: &str = "hourglass-three-quarter-regular";
    #[doc(alias = "image")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "image", feature = "icon-development-kit"))]
    /// Icon name constant for the `image` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/image-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE: &str = "image";
    #[doc(alias = "image-adjust-brightness")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-adjust-brightness", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "image-adjust-brightness", feature = "icon-development-kit"))]
    /// Icon name constant for the `image-adjust-brightness` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/image-adjust-brightness-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_ADJUST_BRIGHTNESS: &str = "image-adjust-brightness";
    #[doc(alias = "image-adjust-contrast")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-adjust-contrast", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "image-adjust-contrast", feature = "icon-development-kit"))]
    /// Icon name constant for the `image-adjust-contrast` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/image-adjust-contrast-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_ADJUST_CONTRAST: &str = "image-adjust-contrast";
    #[doc(alias = "image-adjust-exposure")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-adjust-exposure", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "image-adjust-exposure", feature = "icon-development-kit"))]
    /// Icon name constant for the `image-adjust-exposure` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/image-adjust-exposure-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_ADJUST_EXPOSURE: &str = "image-adjust-exposure";
    #[doc(alias = "image-adjust-highlights")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-adjust-highlights", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "image-adjust-highlights", feature = "icon-development-kit"))]
    /// Icon name constant for the `image-adjust-highlights` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/image-adjust-highlights-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_ADJUST_HIGHLIGHTS: &str = "image-adjust-highlights";
    #[doc(alias = "image-adjust-shadows")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-adjust-shadows", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "image-adjust-shadows", feature = "icon-development-kit"))]
    /// Icon name constant for the `image-adjust-shadows` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/image-adjust-shadows-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_ADJUST_SHADOWS: &str = "image-adjust-shadows";
    #[doc(alias = "image-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "image-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `image-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/image-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_ALT: &str = "image-alt";
    #[doc(alias = "image-alt-text-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-alt-text-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-alt-text-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-alt-text-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-alt-text-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_ALT_TEXT_FILLED: &str = "image-alt-text-filled";
    #[doc(alias = "image-alt-text-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-alt-text-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-alt-text-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-alt-text-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-alt-text-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_ALT_TEXT_REGULAR: &str = "image-alt-text-regular";
    #[doc(alias = "image-border-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-border-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-border-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-border-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-border-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_BORDER_FILLED: &str = "image-border-filled";
    #[doc(alias = "image-border-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-border-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-border-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-border-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-border-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_BORDER_REGULAR: &str = "image-border-regular";
    #[doc(alias = "image-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-circle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-circle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_CIRCLE_FILLED: &str = "image-circle-filled";
    #[doc(alias = "image-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-circle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-circle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_CIRCLE_REGULAR: &str = "image-circle-regular";
    #[doc(alias = "image-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_EDIT_FILLED: &str = "image-edit-filled";
    #[doc(alias = "image-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_EDIT_REGULAR: &str = "image-edit-regular";
    #[doc(alias = "image-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_FILLED: &str = "image-filled";
    #[doc(alias = "image-missing")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-missing", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "image-missing", feature = "icon-development-kit"))]
    /// Icon name constant for the `image-missing` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/image-missing-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_MISSING: &str = "image-missing";
    #[doc(alias = "image-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_MULTIPLE_FILLED: &str = "image-multiple-filled";
    #[doc(alias = "image-multiple-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "image-multiple-off-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "image-multiple-off-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `image-multiple-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-multiple-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_MULTIPLE_OFF_FILLED: &str = "image-multiple-off-filled";
    #[doc(alias = "image-multiple-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "image-multiple-off-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "image-multiple-off-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `image-multiple-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-multiple-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_MULTIPLE_OFF_REGULAR: &str = "image-multiple-off-regular";
    #[doc(alias = "image-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_MULTIPLE_REGULAR: &str = "image-multiple-regular";
    #[doc(alias = "image-print")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-print", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "image-print", feature = "icon-development-kit"))]
    /// Icon name constant for the `image-print` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/image-print-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_PRINT: &str = "image-print";
    #[doc(alias = "image-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_REGULAR: &str = "image-regular";
    #[doc(alias = "image-round")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-round", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "image-round", feature = "icon-development-kit"))]
    /// Icon name constant for the `image-round` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/image-round-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_ROUND: &str = "image-round";
    #[doc(alias = "image-sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-sparkle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-sparkle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_SPARKLE_FILLED: &str = "image-sparkle-filled";
    #[doc(alias = "image-sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-sparkle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-sparkle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_SPARKLE_REGULAR: &str = "image-sparkle-regular";
    #[doc(alias = "image-stack-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-stack-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-stack-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-stack-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-stack-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_STACK_FILLED: &str = "image-stack-filled";
    #[doc(alias = "image-stack-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-stack-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-stack-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-stack-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-stack-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_STACK_REGULAR: &str = "image-stack-regular";
    #[doc(alias = "image-table-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-table-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-table-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-table-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-table-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_TABLE_FILLED: &str = "image-table-filled";
    #[doc(alias = "image-table-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "image-table-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "image-table-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `image-table-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/image-table-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMAGE_TABLE_REGULAR: &str = "image-table-regular";
    #[doc(alias = "immersive-reader-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "immersive-reader-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "immersive-reader-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `immersive-reader-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/immersive-reader-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMMERSIVE_READER_FILLED: &str = "immersive-reader-filled";
    #[doc(alias = "immersive-reader-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "immersive-reader-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "immersive-reader-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `immersive-reader-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/immersive-reader-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMMERSIVE_READER_REGULAR: &str = "immersive-reader-regular";
    #[doc(alias = "important-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "important-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "important-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `important-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/important-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMPORTANT_FILLED: &str = "important-filled";
    #[doc(alias = "important-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "important-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "important-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `important-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/important-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMPORTANT_REGULAR: &str = "important-regular";
    #[doc(alias = "important-small")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "important-small", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "important-small", feature = "icon-development-kit"))]
    /// Icon name constant for the `important-small` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/important-small-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IMPORTANT_SMALL: &str = "important-small";
    #[doc(alias = "inbox")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "inbox", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "inbox", feature = "icon-development-kit"))]
    /// Icon name constant for the `inbox` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/inbox-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INBOX: &str = "inbox";
    #[doc(alias = "info")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "info", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "info", feature = "icon-development-kit"))]
    /// Icon name constant for the `info` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/info-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INFO: &str = "info";
    #[doc(alias = "info-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "info-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "info-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `info-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/info-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INFO_FILLED: &str = "info-filled";
    #[doc(alias = "info-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "info-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "info-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `info-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/info-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INFO_REGULAR: &str = "info-regular";
    #[doc(alias = "ink-tool")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ink-tool", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "ink-tool", feature = "icon-development-kit"))]
    /// Icon name constant for the `ink-tool` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/ink-tool-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INK_TOOL: &str = "ink-tool";
    #[doc(alias = "inking-tool-accent-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "inking-tool-accent-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "inking-tool-accent-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `inking-tool-accent-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/inking-tool-accent-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INKING_TOOL_ACCENT_FILLED: &str = "inking-tool-accent-filled";
    #[doc(alias = "inking-tool-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "inking-tool-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "inking-tool-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `inking-tool-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/inking-tool-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INKING_TOOL_FILLED: &str = "inking-tool-filled";
    #[doc(alias = "inking-tool-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "inking-tool-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "inking-tool-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `inking-tool-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/inking-tool-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INKING_TOOL_REGULAR: &str = "inking-tool-regular";
    #[doc(alias = "inprivate-account-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "inprivate-account-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "inprivate-account-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `inprivate-account-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/inprivate-account-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INPRIVATE_ACCOUNT_FILLED: &str = "inprivate-account-filled";
    #[doc(alias = "inprivate-account-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "inprivate-account-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "inprivate-account-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `inprivate-account-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/inprivate-account-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INPRIVATE_ACCOUNT_REGULAR: &str = "inprivate-account-regular";
    #[doc(alias = "integral")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "integral", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "integral", feature = "icon-development-kit"))]
    /// Icon name constant for the `integral` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/integral-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INTEGRAL: &str = "integral";
    #[doc(alias = "integral2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "integral2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "integral2", feature = "icon-development-kit"))]
    /// Icon name constant for the `integral2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/integral2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INTEGRAL2: &str = "integral2";
    #[doc(alias = "integral3")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "integral3", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "integral3", feature = "icon-development-kit"))]
    /// Icon name constant for the `integral3` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/integral3-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INTEGRAL3: &str = "integral3";
    #[doc(alias = "inverse-fast-fourier-transform")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "inverse-fast-fourier-transform",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "inverse-fast-fourier-transform",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `inverse-fast-fourier-transform` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/inverse-fast-fourier-transform-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INVERSE_FAST_FOURIER_TRANSFORM: &str = "inverse-fast-fourier-transform";
    #[doc(alias = "invert-colors")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "invert-colors", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "invert-colors", feature = "icon-development-kit"))]
    /// Icon name constant for the `invert-colors` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/invert-colors-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const INVERT_COLORS: &str = "invert-colors";
    #[doc(alias = "iot-alert-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "iot-alert-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "iot-alert-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `iot-alert-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/iot-alert-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IOT_ALERT_FILLED: &str = "iot-alert-filled";
    #[doc(alias = "iot-alert-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "iot-alert-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "iot-alert-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `iot-alert-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/iot-alert-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IOT_ALERT_REGULAR: &str = "iot-alert-regular";
    #[doc(alias = "iot-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "iot-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "iot-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `iot-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/iot-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IOT_FILLED: &str = "iot-filled";
    #[doc(alias = "iot-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "iot-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "iot-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `iot-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/iot-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IOT_REGULAR: &str = "iot-regular";
    #[doc(alias = "iphone")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "iphone", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "iphone", feature = "icon-development-kit"))]
    /// Icon name constant for the `iphone` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/iphone-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IPHONE: &str = "iphone";
    #[doc(alias = "ipod")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ipod", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "ipod", feature = "icon-development-kit"))]
    /// Icon name constant for the `ipod` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/ipod-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const IPOD: &str = "ipod";
    #[doc(alias = "issue")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "issue", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "issue", feature = "icon-development-kit"))]
    /// Icon name constant for the `issue` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/issue-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ISSUE: &str = "issue";
    #[doc(alias = "item-missing")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "item-missing", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "item-missing", feature = "icon-development-kit"))]
    /// Icon name constant for the `item-missing` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/item-missing-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ITEM_MISSING: &str = "item-missing";
    #[doc(alias = "javascript-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "javascript-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "javascript-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `javascript-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/javascript-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const JAVASCRIPT_FILLED: &str = "javascript-filled";
    #[doc(alias = "javascript-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "javascript-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "javascript-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `javascript-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/javascript-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const JAVASCRIPT_REGULAR: &str = "javascript-regular";
    #[doc(alias = "joined-displays")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "joined-displays", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "joined-displays", feature = "icon-development-kit"))]
    /// Icon name constant for the `joined-displays` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/joined-displays-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const JOINED_DISPLAYS: &str = "joined-displays";
    #[doc(alias = "junk")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "junk", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "junk", feature = "icon-development-kit"))]
    /// Icon name constant for the `junk` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/junk-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const JUNK: &str = "junk";
    #[doc(alias = "junk-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "junk-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "junk-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `junk-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/junk-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const JUNK_ALT: &str = "junk-alt";
    #[doc(alias = "key")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "key", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "key", feature = "icon-development-kit"))]
    /// Icon name constant for the `key` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/key-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEY: &str = "key";
    #[doc(alias = "key-command-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "key-command-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "key-command-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `key-command-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/key-command-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEY_COMMAND_FILLED: &str = "key-command-filled";
    #[doc(alias = "key-command-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "key-command-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "key-command-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `key-command-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/key-command-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEY_COMMAND_REGULAR: &str = "key-command-regular";
    #[doc(alias = "key-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "key-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "key-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `key-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/key-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEY_FILLED: &str = "key-filled";
    #[doc(alias = "key-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "key-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "key-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `key-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/key-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEY_MULTIPLE_FILLED: &str = "key-multiple-filled";
    #[doc(alias = "key-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "key-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "key-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `key-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/key-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEY_MULTIPLE_REGULAR: &str = "key-multiple-regular";
    #[doc(alias = "key-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "key-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "key-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `key-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/key-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEY_REGULAR: &str = "key-regular";
    #[doc(alias = "key2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "key2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "key2", feature = "icon-development-kit"))]
    /// Icon name constant for the `key2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/key2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEY2: &str = "key2";
    #[doc(alias = "keyboard")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD: &str = "keyboard";
    #[doc(alias = "keyboard-brightness-high")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-brightness-high", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-brightness-high", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-brightness-high` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-brightness-high-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_BRIGHTNESS_HIGH: &str = "keyboard-brightness-high";
    #[doc(alias = "keyboard-brightness-medium")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "keyboard-brightness-medium",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "keyboard-brightness-medium",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `keyboard-brightness-medium` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-brightness-medium-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_BRIGHTNESS_MEDIUM: &str = "keyboard-brightness-medium";
    #[doc(alias = "keyboard-brightness-off")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-brightness-off", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-brightness-off", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-brightness-off` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-brightness-off-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_BRIGHTNESS_OFF: &str = "keyboard-brightness-off";
    #[doc(alias = "keyboard-caps-lock")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-caps-lock", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-caps-lock", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-caps-lock` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-caps-lock-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_CAPS_LOCK: &str = "keyboard-caps-lock";
    #[doc(alias = "keyboard-caps-lock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "keyboard-caps-lock-filled",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "keyboard-caps-lock-filled",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `keyboard-caps-lock-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-caps-lock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_CAPS_LOCK_FILLED: &str = "keyboard-caps-lock-filled";
    #[doc(alias = "keyboard-caps-lock-wide")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-caps-lock-wide", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-caps-lock-wide", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-caps-lock-wide` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-caps-lock-wide-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_CAPS_LOCK_WIDE: &str = "keyboard-caps-lock-wide";
    #[doc(alias = "keyboard-caps-lock-wide-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "keyboard-caps-lock-wide-filled",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "keyboard-caps-lock-wide-filled",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `keyboard-caps-lock-wide-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-caps-lock-wide-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_CAPS_LOCK_WIDE_FILLED: &str = "keyboard-caps-lock-wide-filled";
    #[doc(alias = "keyboard-enter")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-enter", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-enter", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-enter` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-enter-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_ENTER: &str = "keyboard-enter";
    #[doc(alias = "keyboard-extend")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-extend", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-extend", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-extend` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-extend-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_EXTEND: &str = "keyboard-extend";
    #[doc(alias = "keyboard-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "keyboard-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `keyboard-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/keyboard-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_FILLED: &str = "keyboard-filled";
    #[doc(alias = "keyboard-hide")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-hide", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-hide", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-hide` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-hide-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_HIDE: &str = "keyboard-hide";
    #[doc(alias = "keyboard-layout")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-layout", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-layout", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-layout` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-layout-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_LAYOUT: &str = "keyboard-layout";
    #[doc(alias = "keyboard-layout-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-layout-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-layout-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-layout-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-layout-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_LAYOUT_FILLED: &str = "keyboard-layout-filled";
    #[doc(alias = "keyboard-mouse-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-mouse-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "keyboard-mouse-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `keyboard-mouse-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/keyboard-mouse-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_MOUSE_FILLED: &str = "keyboard-mouse-filled";
    #[doc(alias = "keyboard-mouse-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-mouse-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "keyboard-mouse-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `keyboard-mouse-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/keyboard-mouse-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_MOUSE_REGULAR: &str = "keyboard-mouse-regular";
    #[doc(alias = "keyboard-option")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-option", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-option", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-option` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-option-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_OPTION: &str = "keyboard-option";
    #[doc(alias = "keyboard-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "keyboard-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `keyboard-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/keyboard-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_REGULAR: &str = "keyboard-regular";
    #[doc(alias = "keyboard-retract")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-retract", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-retract", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-retract` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-retract-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_RETRACT: &str = "keyboard-retract";
    #[doc(alias = "keyboard-shift")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-shift", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-shift", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-shift` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-shift-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_SHIFT: &str = "keyboard-shift";
    #[doc(alias = "keyboard-shift-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-shift-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-shift-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-shift-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-shift-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_SHIFT_FILLED: &str = "keyboard-shift-filled";
    #[doc(alias = "keyboard-shift-filled-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "keyboard-shift-filled-alt",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "keyboard-shift-filled-alt",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `keyboard-shift-filled-alt` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/keyboard-shift-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_SHIFT_FILLED_ALT: &str = "keyboard-shift-filled-alt";
    #[doc(alias = "keyboard-shift-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-shift-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "keyboard-shift-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `keyboard-shift-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/keyboard-shift-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_SHIFT_REGULAR: &str = "keyboard-shift-regular";
    #[doc(alias = "keyboard-shift-uppercase-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "keyboard-shift-uppercase-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "keyboard-shift-uppercase-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `keyboard-shift-uppercase-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/keyboard-shift-uppercase-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_SHIFT_UPPERCASE_FILLED: &str = "keyboard-shift-uppercase-filled";
    #[doc(alias = "keyboard-shift-uppercase-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "keyboard-shift-uppercase-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "keyboard-shift-uppercase-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `keyboard-shift-uppercase-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/keyboard-shift-uppercase-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_SHIFT_UPPERCASE_REGULAR: &str = "keyboard-shift-uppercase-regular";
    #[doc(alias = "keyboard-shortcuts")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard-shortcuts", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard-shortcuts", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard-shortcuts` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard-shortcuts-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD_SHORTCUTS: &str = "keyboard-shortcuts";
    #[doc(alias = "keyboard2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard2", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD2: &str = "keyboard2";
    #[doc(alias = "keyboard3")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "keyboard3", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "keyboard3", feature = "icon-development-kit"))]
    /// Icon name constant for the `keyboard3` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/keyboard3-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const KEYBOARD3: &str = "keyboard3";
    #[doc(alias = "lan")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lan", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "lan", feature = "icon-development-kit"))]
    /// Icon name constant for the `lan` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/lan-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LAN: &str = "lan";
    #[doc(alias = "language")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "language", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "language", feature = "icon-development-kit"))]
    /// Icon name constant for the `language` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/language-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LANGUAGE: &str = "language";
    #[doc(alias = "laptop-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "laptop-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "laptop-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `laptop-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/laptop-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LAPTOP_DISMISS_FILLED: &str = "laptop-dismiss-filled";
    #[doc(alias = "laptop-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "laptop-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "laptop-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `laptop-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/laptop-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LAPTOP_DISMISS_REGULAR: &str = "laptop-dismiss-regular";
    #[doc(alias = "laptop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "laptop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "laptop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `laptop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/laptop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LAPTOP_FILLED: &str = "laptop-filled";
    #[doc(alias = "laptop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "laptop-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "laptop-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `laptop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/laptop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LAPTOP_REGULAR: &str = "laptop-regular";
    #[doc(alias = "laptop-shield-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "laptop-shield-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "laptop-shield-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `laptop-shield-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/laptop-shield-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LAPTOP_SHIELD_FILLED: &str = "laptop-shield-filled";
    #[doc(alias = "laptop-shield-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "laptop-shield-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "laptop-shield-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `laptop-shield-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/laptop-shield-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LAPTOP_SHIELD_REGULAR: &str = "laptop-shield-regular";
    #[doc(alias = "large-brush")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "large-brush", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "large-brush", feature = "icon-development-kit"))]
    /// Icon name constant for the `large-brush` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/large-brush-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LARGE_BRUSH: &str = "large-brush";
    #[doc(alias = "larger-brush")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "larger-brush", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "larger-brush", feature = "icon-development-kit"))]
    /// Icon name constant for the `larger-brush` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/larger-brush-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LARGER_BRUSH: &str = "larger-brush";
    #[doc(alias = "last")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "last", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "last", feature = "icon-development-kit"))]
    /// Icon name constant for the `last` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/last-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LAST: &str = "last";
    #[doc(alias = "last-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "last-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "last-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `last-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/last-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LAST_LARGE: &str = "last-large";
    #[doc(alias = "leaf-one-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "leaf-one-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "leaf-one-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `leaf-one-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/leaf-one-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LEAF_ONE_FILLED: &str = "leaf-one-filled";
    #[doc(alias = "leaf-one-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "leaf-one-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "leaf-one-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `leaf-one-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/leaf-one-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LEAF_ONE_REGULAR: &str = "leaf-one-regular";
    #[doc(alias = "leaf-three-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "leaf-three-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "leaf-three-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `leaf-three-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/leaf-three-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LEAF_THREE_FILLED: &str = "leaf-three-filled";
    #[doc(alias = "leaf-three-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "leaf-three-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "leaf-three-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `leaf-three-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/leaf-three-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LEAF_THREE_REGULAR: &str = "leaf-three-regular";
    #[doc(alias = "leaf-two-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "leaf-two-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "leaf-two-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `leaf-two-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/leaf-two-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LEAF_TWO_FILLED: &str = "leaf-two-filled";
    #[doc(alias = "leaf-two-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "leaf-two-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "leaf-two-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `leaf-two-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/leaf-two-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LEAF_TWO_REGULAR: &str = "leaf-two-regular";
    #[doc(alias = "leaflet")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "leaflet", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "leaflet", feature = "icon-development-kit"))]
    /// Icon name constant for the `leaflet` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/leaflet-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LEAFLET: &str = "leaflet";
    #[doc(alias = "left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "left", feature = "icon-development-kit"))]
    /// Icon name constant for the `left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LEFT: &str = "left";
    #[doc(alias = "left-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "left-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "left-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `left-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/left-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LEFT_LARGE: &str = "left-large";
    #[doc(alias = "library")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "library", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "library", feature = "icon-development-kit"))]
    /// Icon name constant for the `library` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/library-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIBRARY: &str = "library";
    #[doc(alias = "library-artists")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "library-artists", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "library-artists", feature = "icon-development-kit"))]
    /// Icon name constant for the `library-artists` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/library-artists-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIBRARY_ARTISTS: &str = "library-artists";
    #[doc(alias = "library-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "library-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "library-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `library-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/library-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIBRARY_FILLED: &str = "library-filled";
    #[doc(alias = "library-music")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "library-music", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "library-music", feature = "icon-development-kit"))]
    /// Icon name constant for the `library-music` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/library-music-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIBRARY_MUSIC: &str = "library-music";
    #[doc(alias = "library-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "library-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "library-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `library-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/library-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIBRARY_REGULAR: &str = "library-regular";
    #[doc(alias = "lightbulb")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lightbulb", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "lightbulb", feature = "icon-development-kit"))]
    /// Icon name constant for the `lightbulb` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/lightbulb-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIGHTBULB: &str = "lightbulb";
    #[doc(alias = "lightbulb-filament-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "lightbulb-filament-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "lightbulb-filament-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `lightbulb-filament-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lightbulb-filament-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIGHTBULB_FILAMENT_FILLED: &str = "lightbulb-filament-filled";
    #[doc(alias = "lightbulb-filament-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "lightbulb-filament-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "lightbulb-filament-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `lightbulb-filament-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lightbulb-filament-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIGHTBULB_FILAMENT_REGULAR: &str = "lightbulb-filament-regular";
    #[doc(alias = "lightbulb-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lightbulb-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "lightbulb-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `lightbulb-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lightbulb-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIGHTBULB_FILLED: &str = "lightbulb-filled";
    #[doc(alias = "lightbulb-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lightbulb-person-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "lightbulb-person-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `lightbulb-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lightbulb-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIGHTBULB_PERSON_FILLED: &str = "lightbulb-person-filled";
    #[doc(alias = "lightbulb-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "lightbulb-person-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "lightbulb-person-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `lightbulb-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lightbulb-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIGHTBULB_PERSON_REGULAR: &str = "lightbulb-person-regular";
    #[doc(alias = "lightbulb-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lightbulb-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "lightbulb-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `lightbulb-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lightbulb-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIGHTBULB_REGULAR: &str = "lightbulb-regular";
    #[doc(alias = "likert-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "likert-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "likert-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `likert-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/likert-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIKERT_FILLED: &str = "likert-filled";
    #[doc(alias = "likert-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "likert-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "likert-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `likert-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/likert-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIKERT_REGULAR: &str = "likert-regular";
    #[doc(alias = "line-horizontal-1-dashes-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "line-horizontal-1-dashes-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "line-horizontal-1-dashes-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `line-horizontal-1-dashes-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/line-horizontal-1-dashes-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINE_HORIZONTAL_1_DASHES_FILLED: &str = "line-horizontal-1-dashes-filled";
    #[doc(alias = "line-horizontal-1-dashes-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "line-horizontal-1-dashes-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "line-horizontal-1-dashes-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `line-horizontal-1-dashes-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/line-horizontal-1-dashes-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINE_HORIZONTAL_1_DASHES_REGULAR: &str = "line-horizontal-1-dashes-regular";
    #[doc(alias = "line-horizontal-1-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "line-horizontal-1-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "line-horizontal-1-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `line-horizontal-1-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/line-horizontal-1-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINE_HORIZONTAL_1_FILLED: &str = "line-horizontal-1-filled";
    #[doc(alias = "line-horizontal-1-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "line-horizontal-1-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "line-horizontal-1-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `line-horizontal-1-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/line-horizontal-1-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINE_HORIZONTAL_1_REGULAR: &str = "line-horizontal-1-regular";
    #[doc(alias = "line-horizontal-2-dashes-solid-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "line-horizontal-2-dashes-solid-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "line-horizontal-2-dashes-solid-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `line-horizontal-2-dashes-solid-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/line-horizontal-2-dashes-solid-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINE_HORIZONTAL_2_DASHES_SOLID_FILLED: &str = "line-horizontal-2-dashes-solid-filled";
    #[doc(alias = "line-horizontal-2-dashes-solid-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "line-horizontal-2-dashes-solid-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "line-horizontal-2-dashes-solid-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `line-horizontal-2-dashes-solid-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/line-horizontal-2-dashes-solid-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINE_HORIZONTAL_2_DASHES_SOLID_REGULAR: &str =
        "line-horizontal-2-dashes-solid-regular";
    #[doc(alias = "line-horizontal-4-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "line-horizontal-4-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "line-horizontal-4-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `line-horizontal-4-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/line-horizontal-4-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINE_HORIZONTAL_4_FILLED: &str = "line-horizontal-4-filled";
    #[doc(alias = "line-horizontal-4-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "line-horizontal-4-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "line-horizontal-4-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `line-horizontal-4-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/line-horizontal-4-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINE_HORIZONTAL_4_REGULAR: &str = "line-horizontal-4-regular";
    #[doc(alias = "line-horizontal-4-search-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "line-horizontal-4-search-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "line-horizontal-4-search-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `line-horizontal-4-search-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/line-horizontal-4-search-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINE_HORIZONTAL_4_SEARCH_FILLED: &str = "line-horizontal-4-search-filled";
    #[doc(alias = "line-horizontal-4-search-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "line-horizontal-4-search-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "line-horizontal-4-search-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `line-horizontal-4-search-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/line-horizontal-4-search-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINE_HORIZONTAL_4_SEARCH_REGULAR: &str = "line-horizontal-4-search-regular";
    #[doc(alias = "link-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "link-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "link-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `link-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/link-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINK_DISMISS_FILLED: &str = "link-dismiss-filled";
    #[doc(alias = "link-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "link-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "link-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `link-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/link-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINK_DISMISS_REGULAR: &str = "link-dismiss-regular";
    #[doc(alias = "link-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "link-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "link-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `link-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/link-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINK_EDIT_FILLED: &str = "link-edit-filled";
    #[doc(alias = "link-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "link-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "link-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `link-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/link-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINK_EDIT_REGULAR: &str = "link-edit-regular";
    #[doc(alias = "link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "link-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "link-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINK_FILLED: &str = "link-filled";
    #[doc(alias = "link-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "link-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "link-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `link-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/link-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINK_MULTIPLE_FILLED: &str = "link-multiple-filled";
    #[doc(alias = "link-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "link-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "link-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `link-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/link-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINK_MULTIPLE_REGULAR: &str = "link-multiple-regular";
    #[doc(alias = "link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "link-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "link-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINK_REGULAR: &str = "link-regular";
    #[doc(alias = "link-square-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "link-square-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "link-square-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `link-square-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/link-square-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINK_SQUARE_FILLED: &str = "link-square-filled";
    #[doc(alias = "link-square-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "link-square-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "link-square-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `link-square-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/link-square-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LINK_SQUARE_REGULAR: &str = "link-square-regular";
    #[doc(alias = "list")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "list", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "list", feature = "icon-development-kit"))]
    /// Icon name constant for the `list` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/list-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST: &str = "list";
    #[doc(alias = "list-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "list-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "list-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `list-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/list-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST_ALT: &str = "list-alt";
    #[doc(alias = "list-bar-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "list-bar-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "list-bar-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `list-bar-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/list-bar-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST_BAR_FILLED: &str = "list-bar-filled";
    #[doc(alias = "list-bar-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "list-bar-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "list-bar-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `list-bar-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/list-bar-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST_BAR_REGULAR: &str = "list-bar-regular";
    #[doc(alias = "list-bar-tree-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "list-bar-tree-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "list-bar-tree-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `list-bar-tree-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/list-bar-tree-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST_BAR_TREE_FILLED: &str = "list-bar-tree-filled";
    #[doc(alias = "list-bar-tree-offset-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "list-bar-tree-offset-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "list-bar-tree-offset-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `list-bar-tree-offset-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/list-bar-tree-offset-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST_BAR_TREE_OFFSET_FILLED: &str = "list-bar-tree-offset-filled";
    #[doc(alias = "list-bar-tree-offset-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "list-bar-tree-offset-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "list-bar-tree-offset-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `list-bar-tree-offset-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/list-bar-tree-offset-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST_BAR_TREE_OFFSET_REGULAR: &str = "list-bar-tree-offset-regular";
    #[doc(alias = "list-bar-tree-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "list-bar-tree-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "list-bar-tree-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `list-bar-tree-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/list-bar-tree-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST_BAR_TREE_REGULAR: &str = "list-bar-tree-regular";
    #[doc(alias = "list-compact")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "list-compact", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "list-compact", feature = "icon-development-kit"))]
    /// Icon name constant for the `list-compact` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/list-compact-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST_COMPACT: &str = "list-compact";
    #[doc(alias = "list-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "list-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "list-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `list-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/list-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST_FILLED: &str = "list-filled";
    #[doc(alias = "list-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "list-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "list-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `list-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/list-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST_LARGE: &str = "list-large";
    #[doc(alias = "list-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "list-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "list-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `list-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/list-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LIST_REGULAR: &str = "list-regular";
    #[doc(alias = "listen")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "listen", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "listen", feature = "icon-development-kit"))]
    /// Icon name constant for the `listen` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/listen-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LISTEN: &str = "listen";
    #[doc(alias = "loaf")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "loaf", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "loaf", feature = "icon-development-kit"))]
    /// Icon name constant for the `loaf` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/loaf-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOAF: &str = "loaf";
    #[doc(alias = "local-language-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "local-language-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "local-language-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `local-language-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/local-language-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCAL_LANGUAGE_FILLED: &str = "local-language-filled";
    #[doc(alias = "local-language-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "local-language-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "local-language-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `local-language-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/local-language-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCAL_LANGUAGE_REGULAR: &str = "local-language-regular";
    #[doc(alias = "location-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "location-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "location-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `location-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_ADD_FILLED: &str = "location-add-filled";
    #[doc(alias = "location-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "location-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "location-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `location-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_ADD_REGULAR: &str = "location-add-regular";
    #[doc(alias = "location-arrow-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "location-arrow-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "location-arrow-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `location-arrow-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-arrow-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_ARROW_FILLED: &str = "location-arrow-filled";
    #[doc(alias = "location-arrow-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "location-arrow-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "location-arrow-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `location-arrow-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-arrow-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_ARROW_LEFT_FILLED: &str = "location-arrow-left-filled";
    #[doc(alias = "location-arrow-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "location-arrow-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "location-arrow-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `location-arrow-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-arrow-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_ARROW_LEFT_REGULAR: &str = "location-arrow-left-regular";
    #[doc(alias = "location-arrow-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "location-arrow-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "location-arrow-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `location-arrow-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-arrow-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_ARROW_REGULAR: &str = "location-arrow-regular";
    #[doc(alias = "location-arrow-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "location-arrow-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "location-arrow-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `location-arrow-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-arrow-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_ARROW_RIGHT_FILLED: &str = "location-arrow-right-filled";
    #[doc(alias = "location-arrow-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "location-arrow-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "location-arrow-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `location-arrow-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-arrow-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_ARROW_RIGHT_REGULAR: &str = "location-arrow-right-regular";
    #[doc(alias = "location-arrow-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "location-arrow-up-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "location-arrow-up-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `location-arrow-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-arrow-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_ARROW_UP_FILLED: &str = "location-arrow-up-filled";
    #[doc(alias = "location-arrow-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "location-arrow-up-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "location-arrow-up-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `location-arrow-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-arrow-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_ARROW_UP_REGULAR: &str = "location-arrow-up-regular";
    #[doc(alias = "location-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "location-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "location-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `location-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_FILLED: &str = "location-filled";
    #[doc(alias = "location-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "location-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "location-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `location-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_OFF_FILLED: &str = "location-off-filled";
    #[doc(alias = "location-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "location-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "location-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `location-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_OFF_REGULAR: &str = "location-off-regular";
    #[doc(alias = "location-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "location-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "location-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `location-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/location-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCATION_REGULAR: &str = "location-regular";
    #[doc(alias = "lock-closed-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lock-closed-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "lock-closed-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `lock-closed-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lock-closed-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCK_CLOSED_FILLED: &str = "lock-closed-filled";
    #[doc(alias = "lock-closed-key-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lock-closed-key-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "lock-closed-key-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `lock-closed-key-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lock-closed-key-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCK_CLOSED_KEY_FILLED: &str = "lock-closed-key-filled";
    #[doc(alias = "lock-closed-key-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lock-closed-key-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "lock-closed-key-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `lock-closed-key-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lock-closed-key-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCK_CLOSED_KEY_REGULAR: &str = "lock-closed-key-regular";
    #[doc(alias = "lock-closed-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lock-closed-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "lock-closed-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `lock-closed-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lock-closed-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCK_CLOSED_REGULAR: &str = "lock-closed-regular";
    #[doc(alias = "lock-open-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lock-open-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "lock-open-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `lock-open-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lock-open-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCK_OPEN_FILLED: &str = "lock-open-filled";
    #[doc(alias = "lock-open-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lock-open-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "lock-open-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `lock-open-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/lock-open-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCK_OPEN_REGULAR: &str = "lock-open-regular";
    #[doc(alias = "lock-small")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lock-small", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "lock-small", feature = "icon-development-kit"))]
    /// Icon name constant for the `lock-small` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/lock-small-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCK_SMALL: &str = "lock-small";
    #[doc(alias = "lock-small-open")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "lock-small-open", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "lock-small-open", feature = "icon-development-kit"))]
    /// Icon name constant for the `lock-small-open` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/lock-small-open-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOCK_SMALL_OPEN: &str = "lock-small-open";
    #[doc(alias = "loupe")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "loupe", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "loupe", feature = "icon-development-kit"))]
    /// Icon name constant for the `loupe` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/loupe-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOUPE: &str = "loupe";
    #[doc(alias = "loupe-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "loupe-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "loupe-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `loupe-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/loupe-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOUPE_LARGE: &str = "loupe-large";
    #[doc(alias = "loupe-plus")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "loupe-plus", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "loupe-plus", feature = "icon-development-kit"))]
    /// Icon name constant for the `loupe-plus` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/loupe-plus-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOUPE_PLUS: &str = "loupe-plus";
    #[doc(alias = "loupe-with-arrow")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "loupe-with-arrow", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "loupe-with-arrow", feature = "icon-development-kit"))]
    /// Icon name constant for the `loupe-with-arrow` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/loupe-with-arrow-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOUPE_WITH_ARROW: &str = "loupe-with-arrow";
    #[doc(alias = "loupe-with-heart")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "loupe-with-heart", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "loupe-with-heart", feature = "icon-development-kit"))]
    /// Icon name constant for the `loupe-with-heart` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/loupe-with-heart-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOUPE_WITH_HEART: &str = "loupe-with-heart";
    #[doc(alias = "low-vision")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "low-vision", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "low-vision", feature = "icon-development-kit"))]
    /// Icon name constant for the `low-vision` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/low-vision-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LOW_VISION: &str = "low-vision";
    #[doc(alias = "luggage-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "luggage-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "luggage-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `luggage-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/luggage-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LUGGAGE_FILLED: &str = "luggage-filled";
    #[doc(alias = "luggage-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "luggage-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "luggage-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `luggage-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/luggage-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const LUGGAGE_REGULAR: &str = "luggage-regular";
    #[doc(alias = "magic-wand")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "magic-wand", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "magic-wand", feature = "icon-development-kit"))]
    /// Icon name constant for the `magic-wand` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/magic-wand-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAGIC_WAND: &str = "magic-wand";
    #[doc(alias = "mail")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mail", feature = "icon-development-kit"))]
    /// Icon name constant for the `mail` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mail-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL: &str = "mail";
    #[doc(alias = "mail-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ADD_FILLED: &str = "mail-add-filled";
    #[doc(alias = "mail-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ADD_REGULAR: &str = "mail-add-regular";
    #[doc(alias = "mail-alert-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-alert-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-alert-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-alert-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-alert-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ALERT_FILLED: &str = "mail-alert-filled";
    #[doc(alias = "mail-alert-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-alert-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-alert-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-alert-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-alert-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ALERT_REGULAR: &str = "mail-alert-regular";
    #[doc(alias = "mail-all-read-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-all-read-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-all-read-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-all-read-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-all-read-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ALL_READ_FILLED: &str = "mail-all-read-filled";
    #[doc(alias = "mail-all-read-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-all-read-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-all-read-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-all-read-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-all-read-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ALL_READ_REGULAR: &str = "mail-all-read-regular";
    #[doc(alias = "mail-archive")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-archive", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mail-archive", feature = "icon-development-kit"))]
    /// Icon name constant for the `mail-archive` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mail-archive-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ARCHIVE: &str = "mail-archive";
    #[doc(alias = "mail-arrow-double-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-arrow-double-back-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-arrow-double-back-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-arrow-double-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-arrow-double-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ARROW_DOUBLE_BACK_FILLED: &str = "mail-arrow-double-back-filled";
    #[doc(alias = "mail-arrow-double-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-arrow-double-back-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-arrow-double-back-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-arrow-double-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-arrow-double-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ARROW_DOUBLE_BACK_REGULAR: &str = "mail-arrow-double-back-regular";
    #[doc(alias = "mail-arrow-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-arrow-down-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-arrow-down-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-arrow-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-arrow-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ARROW_DOWN_FILLED: &str = "mail-arrow-down-filled";
    #[doc(alias = "mail-arrow-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-arrow-down-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-arrow-down-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-arrow-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-arrow-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ARROW_DOWN_REGULAR: &str = "mail-arrow-down-regular";
    #[doc(alias = "mail-arrow-forward-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-arrow-forward-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-arrow-forward-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-arrow-forward-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-arrow-forward-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ARROW_FORWARD_FILLED: &str = "mail-arrow-forward-filled";
    #[doc(alias = "mail-arrow-forward-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-arrow-forward-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-arrow-forward-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-arrow-forward-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-arrow-forward-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ARROW_FORWARD_REGULAR: &str = "mail-arrow-forward-regular";
    #[doc(alias = "mail-arrow-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-arrow-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-arrow-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-arrow-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-arrow-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ARROW_UP_FILLED: &str = "mail-arrow-up-filled";
    #[doc(alias = "mail-arrow-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-arrow-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-arrow-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-arrow-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-arrow-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ARROW_UP_REGULAR: &str = "mail-arrow-up-regular";
    #[doc(alias = "mail-attach-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-attach-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-attach-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-attach-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-attach-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ATTACH_FILLED: &str = "mail-attach-filled";
    #[doc(alias = "mail-attach-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-attach-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-attach-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-attach-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-attach-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ATTACH_REGULAR: &str = "mail-attach-regular";
    #[doc(alias = "mail-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-checkmark-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-checkmark-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_CHECKMARK_FILLED: &str = "mail-checkmark-filled";
    #[doc(alias = "mail-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-checkmark-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-checkmark-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_CHECKMARK_REGULAR: &str = "mail-checkmark-regular";
    #[doc(alias = "mail-clock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-clock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-clock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-clock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-clock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_CLOCK_FILLED: &str = "mail-clock-filled";
    #[doc(alias = "mail-clock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-clock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-clock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-clock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-clock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_CLOCK_REGULAR: &str = "mail-clock-regular";
    #[doc(alias = "mail-closed-small")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-closed-small", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mail-closed-small", feature = "icon-development-kit"))]
    /// Icon name constant for the `mail-closed-small` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mail-closed-small-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_CLOSED_SMALL: &str = "mail-closed-small";
    #[doc(alias = "mail-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_DISMISS_FILLED: &str = "mail-dismiss-filled";
    #[doc(alias = "mail-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_DISMISS_REGULAR: &str = "mail-dismiss-regular";
    #[doc(alias = "mail-error-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-error-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-error-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-error-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-error-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ERROR_FILLED: &str = "mail-error-filled";
    #[doc(alias = "mail-error-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-error-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-error-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-error-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-error-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_ERROR_REGULAR: &str = "mail-error-regular";
    #[doc(alias = "mail-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_FILLED: &str = "mail-filled";
    #[doc(alias = "mail-inbox-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-inbox-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-inbox-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-inbox-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-inbox-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_INBOX_ADD_FILLED: &str = "mail-inbox-add-filled";
    #[doc(alias = "mail-inbox-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-inbox-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-inbox-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-inbox-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-inbox-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_INBOX_ADD_REGULAR: &str = "mail-inbox-add-regular";
    #[doc(alias = "mail-inbox-arrow-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-inbox-arrow-down-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-inbox-arrow-down-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-inbox-arrow-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-inbox-arrow-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_INBOX_ARROW_DOWN_FILLED: &str = "mail-inbox-arrow-down-filled";
    #[doc(alias = "mail-inbox-arrow-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-inbox-arrow-down-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-inbox-arrow-down-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-inbox-arrow-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-inbox-arrow-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_INBOX_ARROW_DOWN_REGULAR: &str = "mail-inbox-arrow-down-regular";
    #[doc(alias = "mail-inbox-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-inbox-checkmark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-inbox-checkmark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-inbox-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-inbox-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_INBOX_CHECKMARK_FILLED: &str = "mail-inbox-checkmark-filled";
    #[doc(alias = "mail-inbox-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-inbox-checkmark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-inbox-checkmark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-inbox-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-inbox-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_INBOX_CHECKMARK_REGULAR: &str = "mail-inbox-checkmark-regular";
    #[doc(alias = "mail-inbox-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-inbox-dismiss-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-inbox-dismiss-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-inbox-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-inbox-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_INBOX_DISMISS_FILLED: &str = "mail-inbox-dismiss-filled";
    #[doc(alias = "mail-inbox-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-inbox-dismiss-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-inbox-dismiss-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-inbox-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-inbox-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_INBOX_DISMISS_REGULAR: &str = "mail-inbox-dismiss-regular";
    #[doc(alias = "mail-inbox-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-inbox-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-inbox-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-inbox-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-inbox-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_INBOX_FILLED: &str = "mail-inbox-filled";
    #[doc(alias = "mail-inbox-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-inbox-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-inbox-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-inbox-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-inbox-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_INBOX_REGULAR: &str = "mail-inbox-regular";
    #[doc(alias = "mail-list-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-list-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-list-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-list-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-list-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_LIST_FILLED: &str = "mail-list-filled";
    #[doc(alias = "mail-list-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-list-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-list-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-list-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-list-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_LIST_REGULAR: &str = "mail-list-regular";
    #[doc(alias = "mail-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_MULTIPLE_FILLED: &str = "mail-multiple-filled";
    #[doc(alias = "mail-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_MULTIPLE_REGULAR: &str = "mail-multiple-regular";
    #[doc(alias = "mail-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_OFF_FILLED: &str = "mail-off-filled";
    #[doc(alias = "mail-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_OFF_REGULAR: &str = "mail-off-regular";
    #[doc(alias = "mail-open-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-open-person-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-open-person-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-open-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-open-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_OPEN_PERSON_FILLED: &str = "mail-open-person-filled";
    #[doc(alias = "mail-open-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-open-person-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-open-person-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-open-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-open-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_OPEN_PERSON_REGULAR: &str = "mail-open-person-regular";
    #[doc(alias = "mail-pause-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-pause-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-pause-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-pause-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-pause-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_PAUSE_FILLED: &str = "mail-pause-filled";
    #[doc(alias = "mail-pause-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-pause-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-pause-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-pause-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-pause-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_PAUSE_REGULAR: &str = "mail-pause-regular";
    #[doc(alias = "mail-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-prohibited-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-prohibited-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_PROHIBITED_FILLED: &str = "mail-prohibited-filled";
    #[doc(alias = "mail-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-prohibited-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-prohibited-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_PROHIBITED_REGULAR: &str = "mail-prohibited-regular";
    #[doc(alias = "mail-read")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-read", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mail-read", feature = "icon-development-kit"))]
    /// Icon name constant for the `mail-read` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mail-read-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_READ: &str = "mail-read";
    #[doc(alias = "mail-read-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-read-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-read-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-read-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-read-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_READ_FILLED: &str = "mail-read-filled";
    #[doc(alias = "mail-read-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-read-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-read-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-read-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-read-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_READ_MULTIPLE_FILLED: &str = "mail-read-multiple-filled";
    #[doc(alias = "mail-read-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mail-read-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "mail-read-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `mail-read-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-read-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_READ_MULTIPLE_REGULAR: &str = "mail-read-multiple-regular";
    #[doc(alias = "mail-read-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-read-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-read-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-read-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-read-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_READ_REGULAR: &str = "mail-read-regular";
    #[doc(alias = "mail-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_REGULAR: &str = "mail-regular";
    #[doc(alias = "mail-rewind-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-rewind-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-rewind-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-rewind-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-rewind-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_REWIND_FILLED: &str = "mail-rewind-filled";
    #[doc(alias = "mail-rewind-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-rewind-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-rewind-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-rewind-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-rewind-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_REWIND_REGULAR: &str = "mail-rewind-regular";
    #[doc(alias = "mail-secure")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-secure", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mail-secure", feature = "icon-development-kit"))]
    /// Icon name constant for the `mail-secure` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mail-secure-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_SECURE: &str = "mail-secure";
    #[doc(alias = "mail-settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-settings-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-settings-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_SETTINGS_FILLED: &str = "mail-settings-filled";
    #[doc(alias = "mail-settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-settings-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-settings-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_SETTINGS_REGULAR: &str = "mail-settings-regular";
    #[doc(alias = "mail-shield-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-shield-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-shield-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-shield-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-shield-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_SHIELD_FILLED: &str = "mail-shield-filled";
    #[doc(alias = "mail-shield-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-shield-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-shield-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-shield-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-shield-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_SHIELD_REGULAR: &str = "mail-shield-regular";
    #[doc(alias = "mail-small")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-small", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mail-small", feature = "icon-development-kit"))]
    /// Icon name constant for the `mail-small` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mail-small-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_SMALL: &str = "mail-small";
    #[doc(alias = "mail-template-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-template-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-template-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-template-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-template-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_TEMPLATE_FILLED: &str = "mail-template-filled";
    #[doc(alias = "mail-template-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-template-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-template-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-template-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-template-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_TEMPLATE_REGULAR: &str = "mail-template-regular";
    #[doc(alias = "mail-unread-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-unread-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-unread-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-unread-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-unread-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_UNREAD_FILLED: &str = "mail-unread-filled";
    #[doc(alias = "mail-unread-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-unread-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-unread-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-unread-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-unread-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_UNREAD_REGULAR: &str = "mail-unread-regular";
    #[doc(alias = "mail-warning-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-warning-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-warning-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-warning-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-warning-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_WARNING_FILLED: &str = "mail-warning-filled";
    #[doc(alias = "mail-warning-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mail-warning-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mail-warning-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mail-warning-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mail-warning-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAIL_WARNING_REGULAR: &str = "mail-warning-regular";
    #[doc(alias = "mailbox")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mailbox", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mailbox", feature = "icon-development-kit"))]
    /// Icon name constant for the `mailbox` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mailbox-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAILBOX: &str = "mailbox";
    #[doc(alias = "map")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "map", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "map", feature = "icon-development-kit"))]
    /// Icon name constant for the `map` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/map-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAP: &str = "map";
    #[doc(alias = "map-drive-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "map-drive-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "map-drive-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `map-drive-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/map-drive-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAP_DRIVE_FILLED: &str = "map-drive-filled";
    #[doc(alias = "map-drive-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "map-drive-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "map-drive-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `map-drive-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/map-drive-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAP_DRIVE_REGULAR: &str = "map-drive-regular";
    #[doc(alias = "map-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "map-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "map-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `map-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/map-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAP_FILLED: &str = "map-filled";
    #[doc(alias = "map-marker")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "map-marker", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "map-marker", feature = "icon-development-kit"))]
    /// Icon name constant for the `map-marker` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/map-marker-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAP_MARKER: &str = "map-marker";
    #[doc(alias = "map-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "map-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "map-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `map-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/map-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAP_REGULAR: &str = "map-regular";
    #[doc(alias = "mark")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mark", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mark", feature = "icon-development-kit"))]
    /// Icon name constant for the `mark` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mark-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MARK: &str = "mark";
    #[doc(alias = "markdown")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "markdown", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "markdown", feature = "icon-development-kit"))]
    /// Icon name constant for the `markdown` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/markdown-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MARKDOWN: &str = "markdown";
    #[doc(alias = "marker")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "marker", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "marker", feature = "icon-development-kit"))]
    /// Icon name constant for the `marker` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/marker-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MARKER: &str = "marker";
    #[doc(alias = "math-format-professional-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "math-format-professional-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "math-format-professional-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `math-format-professional-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/math-format-professional-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MATH_FORMAT_PROFESSIONAL_FILLED: &str = "math-format-professional-filled";
    #[doc(alias = "math-format-professional-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "math-format-professional-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "math-format-professional-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `math-format-professional-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/math-format-professional-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MATH_FORMAT_PROFESSIONAL_REGULAR: &str = "math-format-professional-regular";
    #[doc(alias = "math-formula-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "math-formula-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "math-formula-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `math-formula-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/math-formula-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MATH_FORMULA_FILLED: &str = "math-formula-filled";
    #[doc(alias = "math-formula-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "math-formula-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "math-formula-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `math-formula-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/math-formula-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MATH_FORMULA_REGULAR: &str = "math-formula-regular";
    #[doc(alias = "math-symbols-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "math-symbols-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "math-symbols-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `math-symbols-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/math-symbols-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MATH_SYMBOLS_FILLED: &str = "math-symbols-filled";
    #[doc(alias = "math-symbols-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "math-symbols-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "math-symbols-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `math-symbols-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/math-symbols-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MATH_SYMBOLS_REGULAR: &str = "math-symbols-regular";
    #[doc(alias = "maximize-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "maximize-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "maximize-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `maximize-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/maximize-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAXIMIZE_FILLED: &str = "maximize-filled";
    #[doc(alias = "maximize-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "maximize-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "maximize-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `maximize-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/maximize-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MAXIMIZE_REGULAR: &str = "maximize-regular";
    #[doc(alias = "meat")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "meat", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "meat", feature = "icon-development-kit"))]
    /// Icon name constant for the `meat` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/meat-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEAT: &str = "meat";
    #[doc(alias = "meet-now-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "meet-now-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "meet-now-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `meet-now-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/meet-now-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEET_NOW_FILLED: &str = "meet-now-filled";
    #[doc(alias = "meet-now-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "meet-now-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "meet-now-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `meet-now-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/meet-now-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEET_NOW_REGULAR: &str = "meet-now-regular";
    #[doc(alias = "meeting")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "meeting", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "meeting", feature = "icon-development-kit"))]
    /// Icon name constant for the `meeting` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/meeting-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEETING: &str = "meeting";
    #[doc(alias = "megaphone-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "megaphone-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "megaphone-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `megaphone-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/megaphone-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEGAPHONE_FILLED: &str = "megaphone-filled";
    #[doc(alias = "megaphone-loud-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "megaphone-loud-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "megaphone-loud-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `megaphone-loud-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/megaphone-loud-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEGAPHONE_LOUD_FILLED: &str = "megaphone-loud-filled";
    #[doc(alias = "megaphone-loud-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "megaphone-loud-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "megaphone-loud-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `megaphone-loud-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/megaphone-loud-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEGAPHONE_LOUD_REGULAR: &str = "megaphone-loud-regular";
    #[doc(alias = "megaphone-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "megaphone-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "megaphone-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `megaphone-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/megaphone-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEGAPHONE_OFF_FILLED: &str = "megaphone-off-filled";
    #[doc(alias = "megaphone-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "megaphone-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "megaphone-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `megaphone-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/megaphone-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEGAPHONE_OFF_REGULAR: &str = "megaphone-off-regular";
    #[doc(alias = "megaphone-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "megaphone-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "megaphone-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `megaphone-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/megaphone-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEGAPHONE_REGULAR: &str = "megaphone-regular";
    #[doc(alias = "memory")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "memory", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "memory", feature = "icon-development-kit"))]
    /// Icon name constant for the `memory` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/memory-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEMORY: &str = "memory";
    #[doc(alias = "memory-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "memory-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "memory-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `memory-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/memory-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEMORY_FILLED: &str = "memory-filled";
    #[doc(alias = "memory-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "memory-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "memory-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `memory-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/memory-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MEMORY_REGULAR: &str = "memory-regular";
    #[doc(alias = "mention-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mention-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mention-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mention-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mention-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MENTION_FILLED: &str = "mention-filled";
    #[doc(alias = "mention-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mention-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mention-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mention-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mention-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MENTION_REGULAR: &str = "mention-regular";
    #[doc(alias = "menu")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "menu", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "menu", feature = "icon-development-kit"))]
    /// Icon name constant for the `menu` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/menu-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MENU: &str = "menu";
    #[doc(alias = "menu-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "menu-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "menu-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `menu-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/menu-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MENU_LARGE: &str = "menu-large";
    #[doc(alias = "merge")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "merge", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "merge", feature = "icon-development-kit"))]
    /// Icon name constant for the `merge` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/merge-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MERGE: &str = "merge";
    #[doc(alias = "merge-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "merge-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "merge-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `merge-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/merge-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MERGE_FILLED: &str = "merge-filled";
    #[doc(alias = "merge-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "merge-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "merge-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `merge-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/merge-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MERGE_REGULAR: &str = "merge-regular";
    #[doc(alias = "merged")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "merged", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "merged", feature = "icon-development-kit"))]
    /// Icon name constant for the `merged` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/merged-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MERGED: &str = "merged";
    #[doc(alias = "mic-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_FILLED: &str = "mic-filled";
    #[doc(alias = "mic-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_OFF_FILLED: &str = "mic-off-filled";
    #[doc(alias = "mic-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_OFF_REGULAR: &str = "mic-off-regular";
    #[doc(alias = "mic-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-prohibited-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-prohibited-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_PROHIBITED_FILLED: &str = "mic-prohibited-filled";
    #[doc(alias = "mic-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-prohibited-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-prohibited-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_PROHIBITED_REGULAR: &str = "mic-prohibited-regular";
    #[doc(alias = "mic-pulse-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-pulse-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-pulse-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-pulse-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-pulse-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_PULSE_FILLED: &str = "mic-pulse-filled";
    #[doc(alias = "mic-pulse-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-pulse-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-pulse-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-pulse-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-pulse-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_PULSE_OFF_FILLED: &str = "mic-pulse-off-filled";
    #[doc(alias = "mic-pulse-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-pulse-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-pulse-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-pulse-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-pulse-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_PULSE_OFF_REGULAR: &str = "mic-pulse-off-regular";
    #[doc(alias = "mic-pulse-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-pulse-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-pulse-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-pulse-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-pulse-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_PULSE_REGULAR: &str = "mic-pulse-regular";
    #[doc(alias = "mic-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_REGULAR: &str = "mic-regular";
    #[doc(alias = "mic-sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-sparkle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-sparkle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_SPARKLE_FILLED: &str = "mic-sparkle-filled";
    #[doc(alias = "mic-sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mic-sparkle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "mic-sparkle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `mic-sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/mic-sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MIC_SPARKLE_REGULAR: &str = "mic-sparkle-regular";
    #[doc(alias = "microphone")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "microphone", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "microphone", feature = "icon-development-kit"))]
    /// Icon name constant for the `microphone` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/microphone-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MICROPHONE: &str = "microphone";
    #[doc(alias = "microphone2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "microphone2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "microphone2", feature = "icon-development-kit"))]
    /// Icon name constant for the `microphone2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/microphone2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MICROPHONE2: &str = "microphone2";
    #[doc(alias = "minus")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "minus", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "minus", feature = "icon-development-kit"))]
    /// Icon name constant for the `minus` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/minus-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MINUS: &str = "minus";
    #[doc(alias = "minus-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "minus-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "minus-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `minus-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/minus-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MINUS_LARGE: &str = "minus-large";
    #[doc(alias = "mitten")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mitten", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mitten", feature = "icon-development-kit"))]
    /// Icon name constant for the `mitten` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mitten-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MITTEN: &str = "mitten";
    #[doc(alias = "mobile-network")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mobile-network", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mobile-network", feature = "icon-development-kit"))]
    /// Icon name constant for the `mobile-network` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mobile-network-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOBILE_NETWORK: &str = "mobile-network";
    #[doc(alias = "modem")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "modem", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "modem", feature = "icon-development-kit"))]
    /// Icon name constant for the `modem` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/modem-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MODEM: &str = "modem";
    #[doc(alias = "molecule-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "molecule-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "molecule-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `molecule-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/molecule-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOLECULE_FILLED: &str = "molecule-filled";
    #[doc(alias = "molecule-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "molecule-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "molecule-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `molecule-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/molecule-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOLECULE_REGULAR: &str = "molecule-regular";
    #[doc(alias = "money")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "money", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "money", feature = "icon-development-kit"))]
    /// Icon name constant for the `money` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/money-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MONEY: &str = "money";
    #[doc(alias = "money-clip")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "money-clip", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "money-clip", feature = "icon-development-kit"))]
    /// Icon name constant for the `money-clip` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/money-clip-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MONEY_CLIP: &str = "money-clip";
    #[doc(alias = "money-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "money-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "money-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `money-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/money-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MONEY_FILLED: &str = "money-filled";
    #[doc(alias = "money-hand-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "money-hand-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "money-hand-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `money-hand-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/money-hand-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MONEY_HAND_FILLED: &str = "money-hand-filled";
    #[doc(alias = "money-hand-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "money-hand-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "money-hand-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `money-hand-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/money-hand-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MONEY_HAND_REGULAR: &str = "money-hand-regular";
    #[doc(alias = "money-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "money-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "money-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `money-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/money-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MONEY_NONE: &str = "money-none";
    #[doc(alias = "money-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "money-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "money-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `money-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/money-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MONEY_REGULAR: &str = "money-regular";
    #[doc(alias = "money-settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "money-settings-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "money-settings-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `money-settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/money-settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MONEY_SETTINGS_FILLED: &str = "money-settings-filled";
    #[doc(alias = "money-settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "money-settings-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "money-settings-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `money-settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/money-settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MONEY_SETTINGS_REGULAR: &str = "money-settings-regular";
    #[doc(alias = "monitor-pick")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "monitor-pick", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "monitor-pick", feature = "icon-development-kit"))]
    /// Icon name constant for the `monitor-pick` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/monitor-pick-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MONITOR_PICK: &str = "monitor-pick";
    #[doc(alias = "month")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "month", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "month", feature = "icon-development-kit"))]
    /// Icon name constant for the `month` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/month-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MONTH: &str = "month";
    #[doc(alias = "moon")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "moon", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "moon", feature = "icon-development-kit"))]
    /// Icon name constant for the `moon` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/moon-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOON: &str = "moon";
    #[doc(alias = "moon-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "moon-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "moon-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `moon-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/moon-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOON_ALT: &str = "moon-alt";
    #[doc(alias = "moon-alt2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "moon-alt2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "moon-alt2", feature = "icon-development-kit"))]
    /// Icon name constant for the `moon-alt2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/moon-alt2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOON_ALT2: &str = "moon-alt2";
    #[doc(alias = "moon-clouds-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "moon-clouds-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "moon-clouds-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `moon-clouds-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/moon-clouds-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOON_CLOUDS_OUTLINE: &str = "moon-clouds-outline";
    #[doc(alias = "moon-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "moon-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "moon-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `moon-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/moon-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOON_FILLED: &str = "moon-filled";
    #[doc(alias = "moon-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "moon-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "moon-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `moon-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/moon-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOON_OUTLINE: &str = "moon-outline";
    #[doc(alias = "more-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "more-circle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "more-circle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `more-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/more-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MORE_CIRCLE_FILLED: &str = "more-circle-filled";
    #[doc(alias = "more-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "more-circle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "more-circle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `more-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/more-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MORE_CIRCLE_REGULAR: &str = "more-circle-regular";
    #[doc(alias = "more-horizontal-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "more-horizontal-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "more-horizontal-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `more-horizontal-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/more-horizontal-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MORE_HORIZONTAL_FILLED: &str = "more-horizontal-filled";
    #[doc(alias = "more-horizontal-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "more-horizontal-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "more-horizontal-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `more-horizontal-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/more-horizontal-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MORE_HORIZONTAL_REGULAR: &str = "more-horizontal-regular";
    #[doc(alias = "more-vertical-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "more-vertical-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "more-vertical-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `more-vertical-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/more-vertical-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MORE_VERTICAL_FILLED: &str = "more-vertical-filled";
    #[doc(alias = "more-vertical-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "more-vertical-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "more-vertical-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `more-vertical-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/more-vertical-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MORE_VERTICAL_REGULAR: &str = "more-vertical-regular";
    #[doc(alias = "mountain")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mountain", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mountain", feature = "icon-development-kit"))]
    /// Icon name constant for the `mountain` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mountain-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOUNTAIN: &str = "mountain";
    #[doc(alias = "mouse")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mouse", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mouse", feature = "icon-development-kit"))]
    /// Icon name constant for the `mouse` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mouse-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOUSE: &str = "mouse";
    #[doc(alias = "mouse-wireless")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mouse-wireless", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mouse-wireless", feature = "icon-development-kit"))]
    /// Icon name constant for the `mouse-wireless` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mouse-wireless-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOUSE_WIRELESS: &str = "mouse-wireless";
    #[doc(alias = "mouse-wireless-disabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mouse-wireless-disabled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mouse-wireless-disabled", feature = "icon-development-kit"))]
    /// Icon name constant for the `mouse-wireless-disabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mouse-wireless-disabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOUSE_WIRELESS_DISABLED: &str = "mouse-wireless-disabled";
    #[doc(alias = "mouse-wireless-disabled-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "mouse-wireless-disabled-filled",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "mouse-wireless-disabled-filled",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `mouse-wireless-disabled-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mouse-wireless-disabled-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOUSE_WIRELESS_DISABLED_FILLED: &str = "mouse-wireless-disabled-filled";
    #[doc(alias = "mouse-wireless-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "mouse-wireless-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "mouse-wireless-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `mouse-wireless-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/mouse-wireless-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOUSE_WIRELESS_FILLED: &str = "mouse-wireless-filled";
    #[doc(alias = "move-to-window")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "move-to-window", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "move-to-window", feature = "icon-development-kit"))]
    /// Icon name constant for the `move-to-window` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/move-to-window-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOVE_TO_WINDOW: &str = "move-to-window";
    #[doc(alias = "move-tool")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "move-tool", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "move-tool", feature = "icon-development-kit"))]
    /// Icon name constant for the `move-tool` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/move-tool-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOVE_TOOL: &str = "move-tool";
    #[doc(alias = "movies-and-tv-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "movies-and-tv-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "movies-and-tv-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `movies-and-tv-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/movies-and-tv-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOVIES_AND_TV_FILLED: &str = "movies-and-tv-filled";
    #[doc(alias = "movies-and-tv-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "movies-and-tv-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "movies-and-tv-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `movies-and-tv-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/movies-and-tv-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MOVIES_AND_TV_REGULAR: &str = "movies-and-tv-regular";
    #[doc(alias = "multitasking")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "multitasking", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "multitasking", feature = "icon-development-kit"))]
    /// Icon name constant for the `multitasking` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/multitasking-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MULTITASKING: &str = "multitasking";
    #[doc(alias = "multitasking-windows")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "multitasking-windows", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "multitasking-windows", feature = "icon-development-kit"))]
    /// Icon name constant for the `multitasking-windows` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/multitasking-windows-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MULTITASKING_WINDOWS: &str = "multitasking-windows";
    #[doc(alias = "museum")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "museum", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "museum", feature = "icon-development-kit"))]
    /// Icon name constant for the `museum` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/museum-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MUSEUM: &str = "museum";
    #[doc(alias = "music-artist")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "music-artist", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "music-artist", feature = "icon-development-kit"))]
    /// Icon name constant for the `music-artist` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/music-artist-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MUSIC_ARTIST: &str = "music-artist";
    #[doc(alias = "music-artist2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "music-artist2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "music-artist2", feature = "icon-development-kit"))]
    /// Icon name constant for the `music-artist2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/music-artist2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MUSIC_ARTIST2: &str = "music-artist2";
    #[doc(alias = "music-note")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "music-note", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "music-note", feature = "icon-development-kit"))]
    /// Icon name constant for the `music-note` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/music-note-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MUSIC_NOTE: &str = "music-note";
    #[doc(alias = "music-note-2-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "music-note-2-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "music-note-2-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `music-note-2-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/music-note-2-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MUSIC_NOTE_2_FILLED: &str = "music-note-2-filled";
    #[doc(alias = "music-note-2-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "music-note-2-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "music-note-2-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `music-note-2-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/music-note-2-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MUSIC_NOTE_2_REGULAR: &str = "music-note-2-regular";
    #[doc(alias = "music-note-off-2-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "music-note-off-2-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "music-note-off-2-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `music-note-off-2-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/music-note-off-2-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MUSIC_NOTE_OFF_2_FILLED: &str = "music-note-off-2-filled";
    #[doc(alias = "music-note-off-2-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "music-note-off-2-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "music-note-off-2-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `music-note-off-2-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/music-note-off-2-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MUSIC_NOTE_OFF_2_REGULAR: &str = "music-note-off-2-regular";
    #[doc(alias = "music-note-single")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "music-note-single", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "music-note-single", feature = "icon-development-kit"))]
    /// Icon name constant for the `music-note-single` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/music-note-single-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MUSIC_NOTE_SINGLE: &str = "music-note-single";
    #[doc(alias = "music-queue")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "music-queue", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "music-queue", feature = "icon-development-kit"))]
    /// Icon name constant for the `music-queue` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/music-queue-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MUSIC_QUEUE: &str = "music-queue";
    #[doc(alias = "my-location-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "my-location-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "my-location-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `my-location-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/my-location-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MY_LOCATION_FILLED: &str = "my-location-filled";
    #[doc(alias = "my-location-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "my-location-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "my-location-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `my-location-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/my-location-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const MY_LOCATION_REGULAR: &str = "my-location-regular";
    #[doc(alias = "navigate")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "navigate", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "navigate", feature = "icon-development-kit"))]
    /// Icon name constant for the `navigate` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/navigate-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NAVIGATE: &str = "navigate";
    #[doc(alias = "navigate-east")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "navigate-east", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "navigate-east", feature = "icon-development-kit"))]
    /// Icon name constant for the `navigate-east` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/navigate-east-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NAVIGATE_EAST: &str = "navigate-east";
    #[doc(alias = "navigate-north")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "navigate-north", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "navigate-north", feature = "icon-development-kit"))]
    /// Icon name constant for the `navigate-north` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/navigate-north-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NAVIGATE_NORTH: &str = "navigate-north";
    #[doc(alias = "navigate-north-east")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "navigate-north-east", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "navigate-north-east", feature = "icon-development-kit"))]
    /// Icon name constant for the `navigate-north-east` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/navigate-north-east-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NAVIGATE_NORTH_EAST: &str = "navigate-north-east";
    #[doc(alias = "navigate-north-west")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "navigate-north-west", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "navigate-north-west", feature = "icon-development-kit"))]
    /// Icon name constant for the `navigate-north-west` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/navigate-north-west-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NAVIGATE_NORTH_WEST: &str = "navigate-north-west";
    #[doc(alias = "navigate-south")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "navigate-south", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "navigate-south", feature = "icon-development-kit"))]
    /// Icon name constant for the `navigate-south` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/navigate-south-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NAVIGATE_SOUTH: &str = "navigate-south";
    #[doc(alias = "navigate-south-east")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "navigate-south-east", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "navigate-south-east", feature = "icon-development-kit"))]
    /// Icon name constant for the `navigate-south-east` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/navigate-south-east-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NAVIGATE_SOUTH_EAST: &str = "navigate-south-east";
    #[doc(alias = "navigate-south-west")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "navigate-south-west", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "navigate-south-west", feature = "icon-development-kit"))]
    /// Icon name constant for the `navigate-south-west` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/navigate-south-west-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NAVIGATE_SOUTH_WEST: &str = "navigate-south-west";
    #[doc(alias = "navigate-west")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "navigate-west", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "navigate-west", feature = "icon-development-kit"))]
    /// Icon name constant for the `navigate-west` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/navigate-west-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NAVIGATE_WEST: &str = "navigate-west";
    #[doc(alias = "navigation-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "navigation-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "navigation-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `navigation-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/navigation-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NAVIGATION_FILLED: &str = "navigation-filled";
    #[doc(alias = "navigation-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "navigation-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "navigation-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `navigation-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/navigation-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NAVIGATION_REGULAR: &str = "navigation-regular";
    #[doc(alias = "network-adapter-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "network-adapter-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "network-adapter-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `network-adapter-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/network-adapter-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NETWORK_ADAPTER_FILLED: &str = "network-adapter-filled";
    #[doc(alias = "network-adapter-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "network-adapter-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "network-adapter-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `network-adapter-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/network-adapter-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NETWORK_ADAPTER_REGULAR: &str = "network-adapter-regular";
    #[doc(alias = "network-cellular-no-data-signal-excellent")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "network-cellular-no-data-signal-excellent",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "network-cellular-no-data-signal-excellent",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `network-cellular-no-data-signal-excellent` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/network-cellular-no-data-signal-excellent-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NETWORK_CELLULAR_NO_DATA_SIGNAL_EXCELLENT: &str =
        "network-cellular-no-data-signal-excellent";
    #[doc(alias = "network-cellular-no-data-signal-good")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "network-cellular-no-data-signal-good",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "network-cellular-no-data-signal-good",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `network-cellular-no-data-signal-good` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/network-cellular-no-data-signal-good-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NETWORK_CELLULAR_NO_DATA_SIGNAL_GOOD: &str = "network-cellular-no-data-signal-good";
    #[doc(alias = "network-cellular-no-data-signal-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "network-cellular-no-data-signal-none",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "network-cellular-no-data-signal-none",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `network-cellular-no-data-signal-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/network-cellular-no-data-signal-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NETWORK_CELLULAR_NO_DATA_SIGNAL_NONE: &str = "network-cellular-no-data-signal-none";
    #[doc(alias = "network-cellular-no-data-signal-ok")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "network-cellular-no-data-signal-ok",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "network-cellular-no-data-signal-ok",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `network-cellular-no-data-signal-ok` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/network-cellular-no-data-signal-ok-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NETWORK_CELLULAR_NO_DATA_SIGNAL_OK: &str = "network-cellular-no-data-signal-ok";
    #[doc(alias = "network-cellular-no-data-signal-weak")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "network-cellular-no-data-signal-weak",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "network-cellular-no-data-signal-weak",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `network-cellular-no-data-signal-weak` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/network-cellular-no-data-signal-weak-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NETWORK_CELLULAR_NO_DATA_SIGNAL_WEAK: &str = "network-cellular-no-data-signal-weak";
    #[doc(alias = "network-raid")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "network-raid", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "network-raid", feature = "icon-development-kit"))]
    /// Icon name constant for the `network-raid` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/network-raid-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NETWORK_RAID: &str = "network-raid";
    #[doc(alias = "network-server")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "network-server", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "network-server", feature = "icon-development-kit"))]
    /// Icon name constant for the `network-server` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/network-server-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NETWORK_SERVER: &str = "network-server";
    #[doc(alias = "network-workgroup")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "network-workgroup", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "network-workgroup", feature = "icon-development-kit"))]
    /// Icon name constant for the `network-workgroup` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/network-workgroup-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NETWORK_WORKGROUP: &str = "network-workgroup";
    #[doc(alias = "new-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "new-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "new-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `new-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/new-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NEW_FILLED: &str = "new-filled";
    #[doc(alias = "new-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "new-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "new-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `new-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/new-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NEW_REGULAR: &str = "new-regular";
    #[doc(alias = "news-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "news-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "news-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `news-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/news-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NEWS_FILLED: &str = "news-filled";
    #[doc(alias = "news-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "news-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "news-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `news-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/news-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NEWS_REGULAR: &str = "news-regular";
    #[doc(alias = "newspaper")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "newspaper", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "newspaper", feature = "icon-development-kit"))]
    /// Icon name constant for the `newspaper` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/newspaper-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NEWSPAPER: &str = "newspaper";
    #[doc(alias = "newspaper-rounded")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "newspaper-rounded", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "newspaper-rounded", feature = "icon-development-kit"))]
    /// Icon name constant for the `newspaper-rounded` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/newspaper-rounded-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NEWSPAPER_ROUNDED: &str = "newspaper-rounded";
    #[doc(alias = "next-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "next-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "next-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `next-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/next-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NEXT_FILLED: &str = "next-filled";
    #[doc(alias = "next-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "next-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "next-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `next-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/next-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NEXT_REGULAR: &str = "next-regular";
    #[doc(alias = "nintendo-controller")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "nintendo-controller", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "nintendo-controller", feature = "icon-development-kit"))]
    /// Icon name constant for the `nintendo-controller` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/nintendo-controller-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NINTENDO_CONTROLLER: &str = "nintendo-controller";
    #[doc(alias = "no-bed")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "no-bed", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "no-bed", feature = "icon-development-kit"))]
    /// Icon name constant for the `no-bed` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/no-bed-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NO_BED: &str = "no-bed";
    #[doc(alias = "no-bluetooth")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "no-bluetooth", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "no-bluetooth", feature = "icon-development-kit"))]
    /// Icon name constant for the `no-bluetooth` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/no-bluetooth-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NO_BLUETOOTH: &str = "no-bluetooth";
    #[doc(alias = "no-flying")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "no-flying", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "no-flying", feature = "icon-development-kit"))]
    /// Icon name constant for the `no-flying` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/no-flying-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NO_FLYING: &str = "no-flying";
    #[doc(alias = "no-toilets")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "no-toilets", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "no-toilets", feature = "icon-development-kit"))]
    /// Icon name constant for the `no-toilets` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/no-toilets-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NO_TOILETS: &str = "no-toilets";
    #[doc(alias = "no-toilets2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "no-toilets2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "no-toilets2", feature = "icon-development-kit"))]
    /// Icon name constant for the `no-toilets2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/no-toilets2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NO_TOILETS2: &str = "no-toilets2";
    #[doc(alias = "no-wheelchair")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "no-wheelchair", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "no-wheelchair", feature = "icon-development-kit"))]
    /// Icon name constant for the `no-wheelchair` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/no-wheelchair-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NO_WHEELCHAIR: &str = "no-wheelchair";
    #[doc(alias = "noodles")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "noodles", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "noodles", feature = "icon-development-kit"))]
    /// Icon name constant for the `noodles` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/noodles-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOODLES: &str = "noodles";
    #[doc(alias = "normalize")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "normalize", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "normalize", feature = "icon-development-kit"))]
    /// Icon name constant for the `normalize` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/normalize-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NORMALIZE: &str = "normalize";
    #[doc(alias = "not-junk")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "not-junk", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "not-junk", feature = "icon-development-kit"))]
    /// Icon name constant for the `not-junk` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/not-junk-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOT_JUNK: &str = "not-junk";
    #[doc(alias = "not-junk-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "not-junk-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "not-junk-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `not-junk-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/not-junk-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOT_JUNK_ALT: &str = "not-junk-alt";
    #[doc(alias = "note")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "note", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "note", feature = "icon-development-kit"))]
    /// Icon name constant for the `note` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/note-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTE: &str = "note";
    #[doc(alias = "note-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "note-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "note-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `note-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/note-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTE_ADD_FILLED: &str = "note-add-filled";
    #[doc(alias = "note-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "note-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "note-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `note-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/note-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTE_ADD_REGULAR: &str = "note-add-regular";
    #[doc(alias = "note-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "note-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "note-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `note-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/note-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTE_FILLED: &str = "note-filled";
    #[doc(alias = "note-pin-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "note-pin-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "note-pin-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `note-pin-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/note-pin-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTE_PIN_FILLED: &str = "note-pin-filled";
    #[doc(alias = "note-pin-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "note-pin-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "note-pin-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `note-pin-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/note-pin-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTE_PIN_REGULAR: &str = "note-pin-regular";
    #[doc(alias = "note-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "note-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "note-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `note-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/note-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTE_REGULAR: &str = "note-regular";
    #[doc(alias = "note2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "note2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "note2", feature = "icon-development-kit"))]
    /// Icon name constant for the `note2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/note2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTE2: &str = "note2";
    #[doc(alias = "notebook-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "notebook-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "notebook-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `notebook-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/notebook-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTEBOOK_FILLED: &str = "notebook-filled";
    #[doc(alias = "notebook-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "notebook-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "notebook-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `notebook-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/notebook-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTEBOOK_REGULAR: &str = "notebook-regular";
    #[doc(alias = "notepad")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "notepad", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "notepad", feature = "icon-development-kit"))]
    /// Icon name constant for the `notepad` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/notepad-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTEPAD: &str = "notepad";
    #[doc(alias = "notepad-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "notepad-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "notepad-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `notepad-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/notepad-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTEPAD_EDIT_FILLED: &str = "notepad-edit-filled";
    #[doc(alias = "notepad-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "notepad-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "notepad-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `notepad-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/notepad-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTEPAD_EDIT_REGULAR: &str = "notepad-edit-regular";
    #[doc(alias = "notepad-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "notepad-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "notepad-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `notepad-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/notepad-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTEPAD_FILLED: &str = "notepad-filled";
    #[doc(alias = "notepad-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "notepad-person-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "notepad-person-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `notepad-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/notepad-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTEPAD_PERSON_FILLED: &str = "notepad-person-filled";
    #[doc(alias = "notepad-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "notepad-person-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "notepad-person-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `notepad-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/notepad-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTEPAD_PERSON_REGULAR: &str = "notepad-person-regular";
    #[doc(alias = "notepad-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "notepad-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "notepad-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `notepad-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/notepad-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NOTEPAD_REGULAR: &str = "notepad-regular";
    #[doc(alias = "nudity")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "nudity", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "nudity", feature = "icon-development-kit"))]
    /// Icon name constant for the `nudity` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/nudity-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUDITY: &str = "nudity";
    #[doc(alias = "nudity-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "nudity-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "nudity-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `nudity-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/nudity-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUDITY_NONE: &str = "nudity-none";
    #[doc(alias = "number-circle-1-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-circle-1-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-circle-1-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-circle-1-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-circle-1-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_CIRCLE_1_FILLED: &str = "number-circle-1-filled";
    #[doc(alias = "number-circle-1-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-circle-1-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-circle-1-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-circle-1-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-circle-1-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_CIRCLE_1_REGULAR: &str = "number-circle-1-regular";
    #[doc(alias = "number-circle-2-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-circle-2-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-circle-2-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-circle-2-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-circle-2-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_CIRCLE_2_FILLED: &str = "number-circle-2-filled";
    #[doc(alias = "number-circle-2-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-circle-2-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-circle-2-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-circle-2-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-circle-2-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_CIRCLE_2_REGULAR: &str = "number-circle-2-regular";
    #[doc(alias = "number-circle-3-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-circle-3-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-circle-3-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-circle-3-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-circle-3-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_CIRCLE_3_FILLED: &str = "number-circle-3-filled";
    #[doc(alias = "number-circle-3-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-circle-3-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-circle-3-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-circle-3-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-circle-3-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_CIRCLE_3_REGULAR: &str = "number-circle-3-regular";
    #[doc(alias = "number-circle-4-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-circle-4-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-circle-4-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-circle-4-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-circle-4-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_CIRCLE_4_FILLED: &str = "number-circle-4-filled";
    #[doc(alias = "number-circle-4-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-circle-4-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-circle-4-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-circle-4-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-circle-4-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_CIRCLE_4_REGULAR: &str = "number-circle-4-regular";
    #[doc(alias = "number-circle-5-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-circle-5-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-circle-5-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-circle-5-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-circle-5-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_CIRCLE_5_FILLED: &str = "number-circle-5-filled";
    #[doc(alias = "number-circle-5-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-circle-5-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-circle-5-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-circle-5-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-circle-5-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_CIRCLE_5_REGULAR: &str = "number-circle-5-regular";
    #[doc(alias = "number-row-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-row-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-row-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-row-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-row-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_ROW_FILLED: &str = "number-row-filled";
    #[doc(alias = "number-row-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-row-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-row-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-row-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-row-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_ROW_REGULAR: &str = "number-row-regular";
    #[doc(alias = "number-symbol-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-symbol-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-symbol-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-symbol-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-symbol-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_SYMBOL_FILLED: &str = "number-symbol-filled";
    #[doc(alias = "number-symbol-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "number-symbol-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "number-symbol-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `number-symbol-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/number-symbol-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUMBER_SYMBOL_REGULAR: &str = "number-symbol-regular";
    #[doc(alias = "nut")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "nut", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "nut", feature = "icon-development-kit"))]
    /// Icon name constant for the `nut` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/nut-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const NUT: &str = "nut";
    #[doc(alias = "object-layout")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "object-layout", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "object-layout", feature = "icon-development-kit"))]
    /// Icon name constant for the `object-layout` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/object-layout-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OBJECT_LAYOUT: &str = "object-layout";
    #[doc(alias = "object-packing")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "object-packing", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "object-packing", feature = "icon-development-kit"))]
    /// Icon name constant for the `object-packing` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/object-packing-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OBJECT_PACKING: &str = "object-packing";
    #[doc(alias = "object-scale-1to1")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "object-scale-1to1", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "object-scale-1to1", feature = "icon-development-kit"))]
    /// Icon name constant for the `object-scale-1to1` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/object-scale-1to1-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OBJECT_SCALE_1TO1: &str = "object-scale-1to1";
    #[doc(alias = "object-scale-to-fit")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "object-scale-to-fit", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "object-scale-to-fit", feature = "icon-development-kit"))]
    /// Icon name constant for the `object-scale-to-fit` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/object-scale-to-fit-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OBJECT_SCALE_TO_FIT: &str = "object-scale-to-fit";
    #[doc(alias = "offline-globe")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "offline-globe", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "offline-globe", feature = "icon-development-kit"))]
    /// Icon name constant for the `offline-globe` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/offline-globe-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OFFLINE_GLOBE: &str = "offline-globe";
    #[doc(alias = "online")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "online", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "online", feature = "icon-development-kit"))]
    /// Icon name constant for the `online` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/online-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ONLINE: &str = "online";
    #[doc(alias = "opacity")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "opacity", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "opacity", feature = "icon-development-kit"))]
    /// Icon name constant for the `opacity` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/opacity-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OPACITY: &str = "opacity";
    #[doc(alias = "open-book")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "open-book", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "open-book", feature = "icon-development-kit"))]
    /// Icon name constant for the `open-book` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/open-book-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OPEN_BOOK: &str = "open-book";
    #[doc(alias = "open-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "open-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "open-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `open-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/open-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OPEN_FILLED: &str = "open-filled";
    #[doc(alias = "open-folder-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "open-folder-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "open-folder-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `open-folder-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/open-folder-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OPEN_FOLDER_FILLED: &str = "open-folder-filled";
    #[doc(alias = "open-folder-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "open-folder-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "open-folder-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `open-folder-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/open-folder-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OPEN_FOLDER_REGULAR: &str = "open-folder-regular";
    #[doc(alias = "open-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "open-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "open-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `open-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/open-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OPEN_OFF_FILLED: &str = "open-off-filled";
    #[doc(alias = "open-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "open-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "open-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `open-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/open-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OPEN_OFF_REGULAR: &str = "open-off-regular";
    #[doc(alias = "open-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "open-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "open-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `open-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/open-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OPEN_REGULAR: &str = "open-regular";
    #[doc(alias = "options-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "options-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "options-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `options-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/options-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OPTIONS_FILLED: &str = "options-filled";
    #[doc(alias = "options-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "options-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "options-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `options-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/options-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OPTIONS_REGULAR: &str = "options-regular";
    #[doc(alias = "organization-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "organization-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "organization-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `organization-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/organization-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ORGANIZATION_FILLED: &str = "organization-filled";
    #[doc(alias = "organization-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "organization-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "organization-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `organization-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/organization-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ORGANIZATION_REGULAR: &str = "organization-regular";
    #[doc(alias = "outbox")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "outbox", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "outbox", feature = "icon-development-kit"))]
    /// Icon name constant for the `outbox` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/outbox-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OUTBOX: &str = "outbox";
    #[doc(alias = "oval-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "oval-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "oval-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `oval-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/oval-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OVAL_FILLED: &str = "oval-filled";
    #[doc(alias = "oval-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "oval-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "oval-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `oval-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/oval-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OVAL_REGULAR: &str = "oval-regular";
    #[doc(alias = "overlapping-windows")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "overlapping-windows", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "overlapping-windows", feature = "icon-development-kit"))]
    /// Icon name constant for the `overlapping-windows` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/overlapping-windows-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const OVERLAPPING_WINDOWS: &str = "overlapping-windows";
    #[doc(alias = "package-x-generic")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "package-x-generic", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "package-x-generic", feature = "icon-development-kit"))]
    /// Icon name constant for the `package-x-generic` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/package-x-generic-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PACKAGE_X_GENERIC: &str = "package-x-generic";
    #[doc(alias = "padlock2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "padlock2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "padlock2", feature = "icon-development-kit"))]
    /// Icon name constant for the `padlock2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/padlock2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PADLOCK2: &str = "padlock2";
    #[doc(alias = "padlock2-open")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "padlock2-open", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "padlock2-open", feature = "icon-development-kit"))]
    /// Icon name constant for the `padlock2-open` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/padlock2-open-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PADLOCK2_OPEN: &str = "padlock2-open";
    #[doc(alias = "page-fit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "page-fit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "page-fit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `page-fit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/page-fit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAGE_FIT_FILLED: &str = "page-fit-filled";
    #[doc(alias = "page-fit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "page-fit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "page-fit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `page-fit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/page-fit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAGE_FIT_REGULAR: &str = "page-fit-regular";
    #[doc(alias = "page-orientation-landscape")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "page-orientation-landscape",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "page-orientation-landscape",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `page-orientation-landscape` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/page-orientation-landscape-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAGE_ORIENTATION_LANDSCAPE: &str = "page-orientation-landscape";
    #[doc(alias = "page-orientation-portrait")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "page-orientation-portrait",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "page-orientation-portrait",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `page-orientation-portrait` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/page-orientation-portrait-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAGE_ORIENTATION_PORTRAIT: &str = "page-orientation-portrait";
    #[doc(alias = "paint-brush-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "paint-brush-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "paint-brush-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `paint-brush-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/paint-brush-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAINT_BRUSH_FILLED: &str = "paint-brush-filled";
    #[doc(alias = "paint-brush-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "paint-brush-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "paint-brush-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `paint-brush-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/paint-brush-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAINT_BRUSH_REGULAR: &str = "paint-brush-regular";
    #[doc(alias = "paint-bucket-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "paint-bucket-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "paint-bucket-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `paint-bucket-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/paint-bucket-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAINT_BUCKET_FILLED: &str = "paint-bucket-filled";
    #[doc(alias = "paint-bucket-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "paint-bucket-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "paint-bucket-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `paint-bucket-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/paint-bucket-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAINT_BUCKET_REGULAR: &str = "paint-bucket-regular";
    #[doc(alias = "paintbrush")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "paintbrush", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "paintbrush", feature = "icon-development-kit"))]
    /// Icon name constant for the `paintbrush` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/paintbrush-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAINTBRUSH: &str = "paintbrush";
    #[doc(alias = "panel-left-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panel-left-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "panel-left-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `panel-left-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_ADD_FILLED: &str = "panel-left-add-filled";
    #[doc(alias = "panel-left-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panel-left-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "panel-left-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `panel-left-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_ADD_REGULAR: &str = "panel-left-add-regular";
    #[doc(alias = "panel-left-contract-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-contract-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-contract-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-contract-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-contract-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_CONTRACT_FILLED: &str = "panel-left-contract-filled";
    #[doc(alias = "panel-left-contract-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-contract-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-contract-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-contract-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-contract-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_CONTRACT_REGULAR: &str = "panel-left-contract-regular";
    #[doc(alias = "panel-left-expand-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-expand-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-expand-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-expand-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-expand-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_EXPAND_FILLED: &str = "panel-left-expand-filled";
    #[doc(alias = "panel-left-expand-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-expand-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-expand-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-expand-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-expand-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_EXPAND_REGULAR: &str = "panel-left-expand-regular";
    #[doc(alias = "panel-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panel-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "panel-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `panel-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_FILLED: &str = "panel-left-filled";
    #[doc(alias = "panel-left-focus-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-focus-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-focus-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-focus-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-focus-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_FOCUS_RIGHT_FILLED: &str = "panel-left-focus-right-filled";
    #[doc(alias = "panel-left-header-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-header-add-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-header-add-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-header-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-header-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_HEADER_ADD_FILLED: &str = "panel-left-header-add-filled";
    #[doc(alias = "panel-left-header-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-header-add-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-header-add-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-header-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-header-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_HEADER_ADD_REGULAR: &str = "panel-left-header-add-regular";
    #[doc(alias = "panel-left-header-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-header-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-header-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-header-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-header-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_HEADER_FILLED: &str = "panel-left-header-filled";
    #[doc(alias = "panel-left-header-key-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-header-key-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-header-key-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-header-key-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-header-key-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_HEADER_KEY_FILLED: &str = "panel-left-header-key-filled";
    #[doc(alias = "panel-left-header-key-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-header-key-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-header-key-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-header-key-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-header-key-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_HEADER_KEY_REGULAR: &str = "panel-left-header-key-regular";
    #[doc(alias = "panel-left-header-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-header-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-header-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-header-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-header-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_HEADER_REGULAR: &str = "panel-left-header-regular";
    #[doc(alias = "panel-left-key-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panel-left-key-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "panel-left-key-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `panel-left-key-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-key-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_KEY_FILLED: &str = "panel-left-key-filled";
    #[doc(alias = "panel-left-key-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panel-left-key-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "panel-left-key-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `panel-left-key-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-key-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_KEY_REGULAR: &str = "panel-left-key-regular";
    #[doc(alias = "panel-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panel-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "panel-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `panel-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_REGULAR: &str = "panel-left-regular";
    #[doc(alias = "panel-left-text-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-text-add-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-text-add-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-text-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-text-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_TEXT_ADD_FILLED: &str = "panel-left-text-add-filled";
    #[doc(alias = "panel-left-text-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-text-add-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-text-add-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-text-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-text-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_TEXT_ADD_REGULAR: &str = "panel-left-text-add-regular";
    #[doc(alias = "panel-left-text-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-text-dismiss-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-text-dismiss-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-text-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-text-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_TEXT_DISMISS_FILLED: &str = "panel-left-text-dismiss-filled";
    #[doc(alias = "panel-left-text-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-left-text-dismiss-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-left-text-dismiss-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-left-text-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-text-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_TEXT_DISMISS_REGULAR: &str = "panel-left-text-dismiss-regular";
    #[doc(alias = "panel-left-text-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panel-left-text-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "panel-left-text-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `panel-left-text-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-text-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_TEXT_FILLED: &str = "panel-left-text-filled";
    #[doc(alias = "panel-left-text-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panel-left-text-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "panel-left-text-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `panel-left-text-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-left-text-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_LEFT_TEXT_REGULAR: &str = "panel-left-text-regular";
    #[doc(alias = "panel-right-contract-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-right-contract-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-right-contract-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-right-contract-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-right-contract-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_RIGHT_CONTRACT_FILLED: &str = "panel-right-contract-filled";
    #[doc(alias = "panel-right-contract-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-right-contract-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-right-contract-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-right-contract-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-right-contract-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_RIGHT_CONTRACT_REGULAR: &str = "panel-right-contract-regular";
    #[doc(alias = "panel-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panel-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "panel-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `panel-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_RIGHT_FILLED: &str = "panel-right-filled";
    #[doc(alias = "panel-right-gallery-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-right-gallery-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-right-gallery-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-right-gallery-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-right-gallery-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_RIGHT_GALLERY_FILLED: &str = "panel-right-gallery-filled";
    #[doc(alias = "panel-right-gallery-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-right-gallery-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-right-gallery-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-right-gallery-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-right-gallery-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_RIGHT_GALLERY_REGULAR: &str = "panel-right-gallery-regular";
    #[doc(alias = "panel-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panel-right-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "panel-right-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `panel-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_RIGHT_REGULAR: &str = "panel-right-regular";
    #[doc(alias = "panel-top-gallery-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-top-gallery-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-top-gallery-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-top-gallery-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-top-gallery-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_TOP_GALLERY_FILLED: &str = "panel-top-gallery-filled";
    #[doc(alias = "panel-top-gallery-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "panel-top-gallery-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "panel-top-gallery-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `panel-top-gallery-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/panel-top-gallery-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANEL_TOP_GALLERY_REGULAR: &str = "panel-top-gallery-regular";
    #[doc(alias = "panorama-360")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panorama-360", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "panorama-360", feature = "icon-development-kit"))]
    /// Icon name constant for the `panorama-360` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/panorama-360-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANORAMA_360: &str = "panorama-360";
    #[doc(alias = "panorama-horizontal")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panorama-horizontal", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "panorama-horizontal", feature = "icon-development-kit"))]
    /// Icon name constant for the `panorama-horizontal` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/panorama-horizontal-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANORAMA_HORIZONTAL: &str = "panorama-horizontal";
    #[doc(alias = "panorama-vertical")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "panorama-vertical", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "panorama-vertical", feature = "icon-development-kit"))]
    /// Icon name constant for the `panorama-vertical` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/panorama-vertical-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PANORAMA_VERTICAL: &str = "panorama-vertical";
    #[doc(alias = "paper")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "paper", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "paper", feature = "icon-development-kit"))]
    /// Icon name constant for the `paper` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/paper-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAPER: &str = "paper";
    #[doc(alias = "paper-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "paper-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "paper-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `paper-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/paper-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAPER_FILLED: &str = "paper-filled";
    #[doc(alias = "paper-plane")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "paper-plane", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "paper-plane", feature = "icon-development-kit"))]
    /// Icon name constant for the `paper-plane` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/paper-plane-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAPER_PLANE: &str = "paper-plane";
    #[doc(alias = "papyrus")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "papyrus", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "papyrus", feature = "icon-development-kit"))]
    /// Icon name constant for the `papyrus` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/papyrus-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAPYRUS: &str = "papyrus";
    #[doc(alias = "papyrus-vertical")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "papyrus-vertical", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "papyrus-vertical", feature = "icon-development-kit"))]
    /// Icon name constant for the `papyrus-vertical` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/papyrus-vertical-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAPYRUS_VERTICAL: &str = "papyrus-vertical";
    #[doc(alias = "parent")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "parent", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "parent", feature = "icon-development-kit"))]
    /// Icon name constant for the `parent` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/parent-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PARENT: &str = "parent";
    #[doc(alias = "parking-sign")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "parking-sign", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "parking-sign", feature = "icon-development-kit"))]
    /// Icon name constant for the `parking-sign` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/parking-sign-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PARKING_SIGN: &str = "parking-sign";
    #[doc(alias = "password-entry")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "password-entry", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "password-entry", feature = "icon-development-kit"))]
    /// Icon name constant for the `password-entry` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/password-entry-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PASSWORD_ENTRY: &str = "password-entry";
    #[doc(alias = "password-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "password-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "password-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `password-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/password-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PASSWORD_FILLED: &str = "password-filled";
    #[doc(alias = "password-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "password-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "password-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `password-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/password-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PASSWORD_REGULAR: &str = "password-regular";
    #[doc(alias = "path-erase-delete")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "path-erase-delete", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "path-erase-delete", feature = "icon-development-kit"))]
    /// Icon name constant for the `path-erase-delete` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/path-erase-delete-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PATH_ERASE_DELETE: &str = "path-erase-delete";
    #[doc(alias = "path-erase-split")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "path-erase-split", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "path-erase-split", feature = "icon-development-kit"))]
    /// Icon name constant for the `path-erase-split` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/path-erase-split-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PATH_ERASE_SPLIT: &str = "path-erase-split";
    #[doc(alias = "path-erase-split2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "path-erase-split2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "path-erase-split2", feature = "icon-development-kit"))]
    /// Icon name constant for the `path-erase-split2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/path-erase-split2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PATH_ERASE_SPLIT2: &str = "path-erase-split2";
    #[doc(alias = "path-tool")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "path-tool", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "path-tool", feature = "icon-development-kit"))]
    /// Icon name constant for the `path-tool` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/path-tool-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PATH_TOOL: &str = "path-tool";
    #[doc(alias = "pause")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pause", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pause", feature = "icon-development-kit"))]
    /// Icon name constant for the `pause` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pause-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAUSE: &str = "pause";
    #[doc(alias = "pause-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pause-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pause-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pause-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pause-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAUSE_FILLED: &str = "pause-filled";
    #[doc(alias = "pause-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pause-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pause-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `pause-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pause-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAUSE_LARGE: &str = "pause-large";
    #[doc(alias = "pause-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pause-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pause-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pause-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pause-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAUSE_OFF_FILLED: &str = "pause-off-filled";
    #[doc(alias = "pause-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pause-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pause-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pause-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pause-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAUSE_OFF_REGULAR: &str = "pause-off-regular";
    #[doc(alias = "pause-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pause-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pause-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pause-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pause-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAUSE_REGULAR: &str = "pause-regular";
    #[doc(alias = "pause-settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pause-settings-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pause-settings-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pause-settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pause-settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAUSE_SETTINGS_FILLED: &str = "pause-settings-filled";
    #[doc(alias = "pause-settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pause-settings-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pause-settings-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pause-settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pause-settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAUSE_SETTINGS_REGULAR: &str = "pause-settings-regular";
    #[doc(alias = "payment-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "payment-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "payment-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `payment-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/payment-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAYMENT_FILLED: &str = "payment-filled";
    #[doc(alias = "payment-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "payment-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "payment-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `payment-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/payment-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PAYMENT_REGULAR: &str = "payment-regular";
    #[doc(alias = "pci-card")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pci-card", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pci-card", feature = "icon-development-kit"))]
    /// Icon name constant for the `pci-card` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pci-card-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PCI_CARD: &str = "pci-card";
    #[doc(alias = "pda")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pda", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pda", feature = "icon-development-kit"))]
    /// Icon name constant for the `pda` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pda-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PDA: &str = "pda";
    #[doc(alias = "pen-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pen-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pen-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pen-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pen-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEN_DISMISS_FILLED: &str = "pen-dismiss-filled";
    #[doc(alias = "pen-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pen-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pen-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pen-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pen-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEN_DISMISS_REGULAR: &str = "pen-dismiss-regular";
    #[doc(alias = "pen-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pen-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pen-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pen-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pen-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEN_FILLED: &str = "pen-filled";
    #[doc(alias = "pen-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pen-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pen-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pen-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pen-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEN_OFF_FILLED: &str = "pen-off-filled";
    #[doc(alias = "pen-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pen-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pen-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pen-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pen-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEN_OFF_REGULAR: &str = "pen-off-regular";
    #[doc(alias = "pen-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pen-prohibited-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pen-prohibited-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pen-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pen-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEN_PROHIBITED_FILLED: &str = "pen-prohibited-filled";
    #[doc(alias = "pen-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pen-prohibited-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pen-prohibited-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pen-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pen-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEN_PROHIBITED_REGULAR: &str = "pen-prohibited-regular";
    #[doc(alias = "pen-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pen-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pen-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pen-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pen-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEN_REGULAR: &str = "pen-regular";
    #[doc(alias = "pen-sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pen-sparkle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pen-sparkle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pen-sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pen-sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEN_SPARKLE_FILLED: &str = "pen-sparkle-filled";
    #[doc(alias = "pen-sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pen-sparkle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pen-sparkle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pen-sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pen-sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEN_SPARKLE_REGULAR: &str = "pen-sparkle-regular";
    #[doc(alias = "pencil")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pencil", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pencil", feature = "icon-development-kit"))]
    /// Icon name constant for the `pencil` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pencil-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PENCIL: &str = "pencil";
    #[doc(alias = "pencil-and-paper")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pencil-and-paper", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pencil-and-paper", feature = "icon-development-kit"))]
    /// Icon name constant for the `pencil-and-paper` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pencil-and-paper-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PENCIL_AND_PAPER: &str = "pencil-and-paper";
    #[doc(alias = "pencil-and-paper-small")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pencil-and-paper-small", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pencil-and-paper-small", feature = "icon-development-kit"))]
    /// Icon name constant for the `pencil-and-paper-small` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pencil-and-paper-small-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PENCIL_AND_PAPER_SMALL: &str = "pencil-and-paper-small";
    #[doc(alias = "penguin")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "penguin", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "penguin", feature = "icon-development-kit"))]
    /// Icon name constant for the `penguin` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/penguin-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PENGUIN: &str = "penguin";
    #[doc(alias = "penguin-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "penguin-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "penguin-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `penguin-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/penguin-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PENGUIN_ALT: &str = "penguin-alt";
    #[doc(alias = "people")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "people", feature = "icon-development-kit"))]
    /// Icon name constant for the `people` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/people-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE: &str = "people";
    #[doc(alias = "people-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_ADD_FILLED: &str = "people-add-filled";
    #[doc(alias = "people-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_ADD_REGULAR: &str = "people-add-regular";
    #[doc(alias = "people-call-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-call-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-call-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-call-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-call-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_CALL_FILLED: &str = "people-call-filled";
    #[doc(alias = "people-call-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-call-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-call-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-call-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-call-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_CALL_REGULAR: &str = "people-call-regular";
    #[doc(alias = "people-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-checkmark-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-checkmark-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_CHECKMARK_FILLED: &str = "people-checkmark-filled";
    #[doc(alias = "people-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "people-checkmark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "people-checkmark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `people-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_CHECKMARK_REGULAR: &str = "people-checkmark-regular";
    #[doc(alias = "people-community-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-community-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-community-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-community-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-community-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_COMMUNITY_FILLED: &str = "people-community-filled";
    #[doc(alias = "people-community-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "people-community-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "people-community-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `people-community-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-community-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_COMMUNITY_REGULAR: &str = "people-community-regular";
    #[doc(alias = "people-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_EDIT_FILLED: &str = "people-edit-filled";
    #[doc(alias = "people-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_EDIT_REGULAR: &str = "people-edit-regular";
    #[doc(alias = "people-error-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-error-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-error-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-error-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-error-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_ERROR_FILLED: &str = "people-error-filled";
    #[doc(alias = "people-error-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-error-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-error-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-error-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-error-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_ERROR_REGULAR: &str = "people-error-regular";
    #[doc(alias = "people-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_FILLED: &str = "people-filled";
    #[doc(alias = "people-list-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-list-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-list-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-list-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-list-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_LIST_FILLED: &str = "people-list-filled";
    #[doc(alias = "people-list-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-list-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-list-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-list-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-list-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_LIST_REGULAR: &str = "people-list-regular";
    #[doc(alias = "people-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "people-prohibited-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "people-prohibited-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `people-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_PROHIBITED_FILLED: &str = "people-prohibited-filled";
    #[doc(alias = "people-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "people-prohibited-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "people-prohibited-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `people-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_PROHIBITED_REGULAR: &str = "people-prohibited-regular";
    #[doc(alias = "people-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_REGULAR: &str = "people-regular";
    #[doc(alias = "people-star-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-star-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-star-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-star-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-star-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_STAR_FILLED: &str = "people-star-filled";
    #[doc(alias = "people-star-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-star-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-star-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-star-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-star-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_STAR_REGULAR: &str = "people-star-regular";
    #[doc(alias = "people-swap-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-swap-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-swap-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-swap-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-swap-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_SWAP_FILLED: &str = "people-swap-filled";
    #[doc(alias = "people-swap-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-swap-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-swap-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-swap-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-swap-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_SWAP_REGULAR: &str = "people-swap-regular";
    #[doc(alias = "people-sync-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-sync-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-sync-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-sync-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-sync-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_SYNC_FILLED: &str = "people-sync-filled";
    #[doc(alias = "people-sync-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-sync-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-sync-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-sync-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-sync-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_SYNC_REGULAR: &str = "people-sync-regular";
    #[doc(alias = "people-team-delete-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "people-team-delete-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "people-team-delete-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `people-team-delete-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-team-delete-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_TEAM_DELETE_FILLED: &str = "people-team-delete-filled";
    #[doc(alias = "people-team-delete-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "people-team-delete-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "people-team-delete-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `people-team-delete-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-team-delete-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_TEAM_DELETE_REGULAR: &str = "people-team-delete-regular";
    #[doc(alias = "people-team-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-team-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-team-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-team-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-team-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_TEAM_FILLED: &str = "people-team-filled";
    #[doc(alias = "people-team-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-team-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-team-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-team-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-team-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_TEAM_REGULAR: &str = "people-team-regular";
    #[doc(alias = "people-toolbox-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-toolbox-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-toolbox-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-toolbox-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-toolbox-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_TOOLBOX_FILLED: &str = "people-toolbox-filled";
    #[doc(alias = "people-toolbox-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "people-toolbox-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "people-toolbox-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `people-toolbox-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/people-toolbox-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEOPLE_TOOLBOX_REGULAR: &str = "people-toolbox-regular";
    #[doc(alias = "pepper")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pepper", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pepper", feature = "icon-development-kit"))]
    /// Icon name constant for the `pepper` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pepper-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PEPPER: &str = "pepper";
    #[doc(alias = "permissions-advertising")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "permissions-advertising", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "permissions-advertising", feature = "icon-development-kit"))]
    /// Icon name constant for the `permissions-advertising` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/permissions-advertising-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERMISSIONS_ADVERTISING: &str = "permissions-advertising";
    #[doc(alias = "permissions-camera")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "permissions-camera", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "permissions-camera", feature = "icon-development-kit"))]
    /// Icon name constant for the `permissions-camera` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/permissions-camera-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERMISSIONS_CAMERA: &str = "permissions-camera";
    #[doc(alias = "permissions-generic")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "permissions-generic", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "permissions-generic", feature = "icon-development-kit"))]
    /// Icon name constant for the `permissions-generic` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/permissions-generic-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERMISSIONS_GENERIC: &str = "permissions-generic";
    #[doc(alias = "permissions-location")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "permissions-location", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "permissions-location", feature = "icon-development-kit"))]
    /// Icon name constant for the `permissions-location` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/permissions-location-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERMISSIONS_LOCATION: &str = "permissions-location";
    #[doc(alias = "permissions-microphone")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "permissions-microphone", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "permissions-microphone", feature = "icon-development-kit"))]
    /// Icon name constant for the `permissions-microphone` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/permissions-microphone-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERMISSIONS_MICROPHONE: &str = "permissions-microphone";
    #[doc(alias = "permissions-notifications")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "permissions-notifications",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "permissions-notifications",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `permissions-notifications` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/permissions-notifications-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERMISSIONS_NOTIFICATIONS: &str = "permissions-notifications";
    #[doc(alias = "permissions-password")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "permissions-password", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "permissions-password", feature = "icon-development-kit"))]
    /// Icon name constant for the `permissions-password` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/permissions-password-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERMISSIONS_PASSWORD: &str = "permissions-password";
    #[doc(alias = "person")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "person", feature = "icon-development-kit"))]
    /// Icon name constant for the `person` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/person-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON: &str = "person";
    #[doc(alias = "person-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_ADD_FILLED: &str = "person-add-filled";
    #[doc(alias = "person-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_ADD_REGULAR: &str = "person-add-regular";
    #[doc(alias = "person-alert-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-alert-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-alert-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-alert-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-alert-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_ALERT_FILLED: &str = "person-alert-filled";
    #[doc(alias = "person-alert-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-alert-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-alert-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-alert-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-alert-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_ALERT_REGULAR: &str = "person-alert-regular";
    #[doc(alias = "person-arrow-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-arrow-back-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-arrow-back-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-arrow-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-arrow-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_ARROW_BACK_FILLED: &str = "person-arrow-back-filled";
    #[doc(alias = "person-arrow-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-arrow-back-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-arrow-back-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-arrow-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-arrow-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_ARROW_BACK_REGULAR: &str = "person-arrow-back-regular";
    #[doc(alias = "person-arrow-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-arrow-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-arrow-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-arrow-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-arrow-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_ARROW_LEFT_FILLED: &str = "person-arrow-left-filled";
    #[doc(alias = "person-arrow-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-arrow-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-arrow-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-arrow-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-arrow-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_ARROW_LEFT_REGULAR: &str = "person-arrow-left-regular";
    #[doc(alias = "person-arrow-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-arrow-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-arrow-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-arrow-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-arrow-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_ARROW_RIGHT_FILLED: &str = "person-arrow-right-filled";
    #[doc(alias = "person-arrow-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-arrow-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-arrow-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-arrow-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-arrow-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_ARROW_RIGHT_REGULAR: &str = "person-arrow-right-regular";
    #[doc(alias = "person-available-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-available-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-available-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-available-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-available-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_AVAILABLE_FILLED: &str = "person-available-filled";
    #[doc(alias = "person-available-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-available-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-available-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-available-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-available-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_AVAILABLE_REGULAR: &str = "person-available-regular";
    #[doc(alias = "person-board-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-board-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-board-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-board-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-board-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_BOARD_FILLED: &str = "person-board-filled";
    #[doc(alias = "person-board-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-board-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-board-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-board-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-board-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_BOARD_REGULAR: &str = "person-board-regular";
    #[doc(alias = "person-call-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-call-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-call-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-call-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-call-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_CALL_FILLED: &str = "person-call-filled";
    #[doc(alias = "person-call-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-call-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-call-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-call-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-call-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_CALL_REGULAR: &str = "person-call-regular";
    #[doc(alias = "person-chat-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-chat-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-chat-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-chat-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-chat-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_CHAT_FILLED: &str = "person-chat-filled";
    #[doc(alias = "person-chat-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-chat-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-chat-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-chat-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-chat-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_CHAT_REGULAR: &str = "person-chat-regular";
    #[doc(alias = "person-clock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-clock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-clock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-clock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-clock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_CLOCK_FILLED: &str = "person-clock-filled";
    #[doc(alias = "person-clock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-clock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-clock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-clock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-clock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_CLOCK_REGULAR: &str = "person-clock-regular";
    #[doc(alias = "person-delete-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-delete-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-delete-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-delete-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-delete-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_DELETE_FILLED: &str = "person-delete-filled";
    #[doc(alias = "person-delete-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-delete-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-delete-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-delete-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-delete-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_DELETE_REGULAR: &str = "person-delete-regular";
    #[doc(alias = "person-feedback-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-feedback-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-feedback-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-feedback-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-feedback-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_FEEDBACK_FILLED: &str = "person-feedback-filled";
    #[doc(alias = "person-feedback-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-feedback-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-feedback-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-feedback-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-feedback-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_FEEDBACK_REGULAR: &str = "person-feedback-regular";
    #[doc(alias = "person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_FILLED: &str = "person-filled";
    #[doc(alias = "person-info-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-info-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-info-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-info-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-info-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_INFO_FILLED: &str = "person-info-filled";
    #[doc(alias = "person-info-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-info-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-info-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-info-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-info-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_INFO_REGULAR: &str = "person-info-regular";
    #[doc(alias = "person-lightning-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-lightning-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-lightning-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-lightning-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-lightning-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_LIGHTNING_FILLED: &str = "person-lightning-filled";
    #[doc(alias = "person-lightning-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-lightning-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-lightning-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-lightning-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-lightning-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_LIGHTNING_REGULAR: &str = "person-lightning-regular";
    #[doc(alias = "person-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-link-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-link-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_LINK_FILLED: &str = "person-link-filled";
    #[doc(alias = "person-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-link-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-link-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_LINK_REGULAR: &str = "person-link-regular";
    #[doc(alias = "person-lock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-lock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-lock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-lock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-lock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_LOCK_FILLED: &str = "person-lock-filled";
    #[doc(alias = "person-lock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-lock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-lock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-lock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-lock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_LOCK_REGULAR: &str = "person-lock-regular";
    #[doc(alias = "person-mail-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-mail-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-mail-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-mail-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-mail-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_MAIL_FILLED: &str = "person-mail-filled";
    #[doc(alias = "person-mail-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-mail-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-mail-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-mail-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-mail-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_MAIL_REGULAR: &str = "person-mail-regular";
    #[doc(alias = "person-note-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-note-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-note-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-note-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-note-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_NOTE_FILLED: &str = "person-note-filled";
    #[doc(alias = "person-note-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-note-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-note-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-note-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-note-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_NOTE_REGULAR: &str = "person-note-regular";
    #[doc(alias = "person-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-prohibited-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-prohibited-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_PROHIBITED_FILLED: &str = "person-prohibited-filled";
    #[doc(alias = "person-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-prohibited-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-prohibited-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_PROHIBITED_REGULAR: &str = "person-prohibited-regular";
    #[doc(alias = "person-question-mark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-question-mark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-question-mark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-question-mark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-question-mark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_QUESTION_MARK_FILLED: &str = "person-question-mark-filled";
    #[doc(alias = "person-question-mark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "person-question-mark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "person-question-mark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `person-question-mark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-question-mark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_QUESTION_MARK_REGULAR: &str = "person-question-mark-regular";
    #[doc(alias = "person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_REGULAR: &str = "person-regular";
    #[doc(alias = "person-ribbon-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-ribbon-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-ribbon-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-ribbon-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-ribbon-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_RIBBON_FILLED: &str = "person-ribbon-filled";
    #[doc(alias = "person-ribbon-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-ribbon-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-ribbon-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-ribbon-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-ribbon-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_RIBBON_REGULAR: &str = "person-ribbon-regular";
    #[doc(alias = "person-search-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-search-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-search-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-search-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-search-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SEARCH_FILLED: &str = "person-search-filled";
    #[doc(alias = "person-search-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-search-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-search-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-search-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-search-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SEARCH_REGULAR: &str = "person-search-regular";
    #[doc(alias = "person-settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-settings-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-settings-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SETTINGS_FILLED: &str = "person-settings-filled";
    #[doc(alias = "person-settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-settings-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-settings-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SETTINGS_REGULAR: &str = "person-settings-regular";
    #[doc(alias = "person-standing-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-standing-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-standing-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-standing-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-standing-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_STANDING_FILLED: &str = "person-standing-filled";
    #[doc(alias = "person-standing-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-standing-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-standing-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-standing-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-standing-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_STANDING_REGULAR: &str = "person-standing-regular";
    #[doc(alias = "person-star-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-star-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-star-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-star-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-star-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_STAR_FILLED: &str = "person-star-filled";
    #[doc(alias = "person-star-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-star-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-star-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-star-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-star-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_STAR_REGULAR: &str = "person-star-regular";
    #[doc(alias = "person-subtract-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-subtract-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-subtract-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-subtract-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-subtract-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SUBTRACT_FILLED: &str = "person-subtract-filled";
    #[doc(alias = "person-subtract-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-subtract-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-subtract-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-subtract-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-subtract-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SUBTRACT_REGULAR: &str = "person-subtract-regular";
    #[doc(alias = "person-support-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-support-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-support-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-support-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-support-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SUPPORT_FILLED: &str = "person-support-filled";
    #[doc(alias = "person-support-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-support-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-support-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-support-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-support-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SUPPORT_REGULAR: &str = "person-support-regular";
    #[doc(alias = "person-swap-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-swap-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-swap-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-swap-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-swap-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SWAP_FILLED: &str = "person-swap-filled";
    #[doc(alias = "person-swap-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-swap-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-swap-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-swap-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-swap-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SWAP_REGULAR: &str = "person-swap-regular";
    #[doc(alias = "person-sync-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-sync-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-sync-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-sync-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-sync-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SYNC_FILLED: &str = "person-sync-filled";
    #[doc(alias = "person-sync-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-sync-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-sync-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-sync-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-sync-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_SYNC_REGULAR: &str = "person-sync-regular";
    #[doc(alias = "person-walking-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-walking-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-walking-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-walking-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-walking-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_WALKING_FILLED: &str = "person-walking-filled";
    #[doc(alias = "person-walking-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person-walking-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "person-walking-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `person-walking-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/person-walking-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON_WALKING_REGULAR: &str = "person-walking-regular";
    #[doc(alias = "person2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "person2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "person2", feature = "icon-development-kit"))]
    /// Icon name constant for the `person2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/person2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PERSON2: &str = "person2";
    #[doc(alias = "phone")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phone", feature = "icon-development-kit"))]
    /// Icon name constant for the `phone` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phone-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE: &str = "phone";
    #[doc(alias = "phone-chat-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-chat-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-chat-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-chat-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-chat-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_CHAT_FILLED: &str = "phone-chat-filled";
    #[doc(alias = "phone-chat-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-chat-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-chat-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-chat-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-chat-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_CHAT_REGULAR: &str = "phone-chat-regular";
    #[doc(alias = "phone-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-checkmark-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-checkmark-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_CHECKMARK_FILLED: &str = "phone-checkmark-filled";
    #[doc(alias = "phone-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-checkmark-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-checkmark-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_CHECKMARK_REGULAR: &str = "phone-checkmark-regular";
    #[doc(alias = "phone-desktop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-desktop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-desktop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-desktop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-desktop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_DESKTOP_FILLED: &str = "phone-desktop-filled";
    #[doc(alias = "phone-desktop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-desktop-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-desktop-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-desktop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-desktop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_DESKTOP_REGULAR: &str = "phone-desktop-regular";
    #[doc(alias = "phone-disabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-disabled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phone-disabled", feature = "icon-development-kit"))]
    /// Icon name constant for the `phone-disabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phone-disabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_DISABLED: &str = "phone-disabled";
    #[doc(alias = "phone-eraser-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-eraser-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-eraser-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-eraser-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-eraser-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_ERASER_FILLED: &str = "phone-eraser-filled";
    #[doc(alias = "phone-eraser-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-eraser-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-eraser-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-eraser-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-eraser-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_ERASER_REGULAR: &str = "phone-eraser-regular";
    #[doc(alias = "phone-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_FILLED: &str = "phone-filled";
    #[doc(alias = "phone-laptop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-laptop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-laptop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-laptop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-laptop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_LAPTOP_FILLED: &str = "phone-laptop-filled";
    #[doc(alias = "phone-laptop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-laptop-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-laptop-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-laptop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-laptop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_LAPTOP_REGULAR: &str = "phone-laptop-regular";
    #[doc(alias = "phone-oldschool")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-oldschool", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phone-oldschool", feature = "icon-development-kit"))]
    /// Icon name constant for the `phone-oldschool` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phone-oldschool-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_OLDSCHOOL: &str = "phone-oldschool";
    #[doc(alias = "phone-ongoing-call")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-ongoing-call", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phone-ongoing-call", feature = "icon-development-kit"))]
    /// Icon name constant for the `phone-ongoing-call` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phone-ongoing-call-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_ONGOING_CALL: &str = "phone-ongoing-call";
    #[doc(alias = "phone-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_REGULAR: &str = "phone-regular";
    #[doc(alias = "phone-right-facing")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-right-facing", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phone-right-facing", feature = "icon-development-kit"))]
    /// Icon name constant for the `phone-right-facing` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phone-right-facing-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_RIGHT_FACING: &str = "phone-right-facing";
    #[doc(alias = "phone-right-facing-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-right-facing-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phone-right-facing-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `phone-right-facing-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phone-right-facing-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_RIGHT_FACING_LARGE: &str = "phone-right-facing-large";
    #[doc(alias = "phone-span-in-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-span-in-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-span-in-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-span-in-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-span-in-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_SPAN_IN_FILLED: &str = "phone-span-in-filled";
    #[doc(alias = "phone-span-in-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-span-in-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-span-in-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-span-in-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-span-in-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_SPAN_IN_REGULAR: &str = "phone-span-in-regular";
    #[doc(alias = "phone-span-out-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-span-out-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-span-out-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-span-out-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-span-out-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_SPAN_OUT_FILLED: &str = "phone-span-out-filled";
    #[doc(alias = "phone-span-out-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-span-out-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "phone-span-out-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `phone-span-out-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/phone-span-out-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_SPAN_OUT_REGULAR: &str = "phone-span-out-regular";
    #[doc(alias = "phone-vibrate")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phone-vibrate", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phone-vibrate", feature = "icon-development-kit"))]
    /// Icon name constant for the `phone-vibrate` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phone-vibrate-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONE_VIBRATE: &str = "phone-vibrate";
    #[doc(alias = "phonelink")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phonelink", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phonelink", feature = "icon-development-kit"))]
    /// Icon name constant for the `phonelink` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phonelink-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONELINK: &str = "phonelink";
    #[doc(alias = "phonelink-delete")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phonelink-delete", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phonelink-delete", feature = "icon-development-kit"))]
    /// Icon name constant for the `phonelink-delete` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phonelink-delete-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONELINK_DELETE: &str = "phonelink-delete";
    #[doc(alias = "phonelink-lock")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phonelink-lock", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phonelink-lock", feature = "icon-development-kit"))]
    /// Icon name constant for the `phonelink-lock` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phonelink-lock-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONELINK_LOCK: &str = "phonelink-lock";
    #[doc(alias = "phonelink-off")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phonelink-off", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phonelink-off", feature = "icon-development-kit"))]
    /// Icon name constant for the `phonelink-off` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phonelink-off-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONELINK_OFF: &str = "phonelink-off";
    #[doc(alias = "phonelink-ring")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phonelink-ring", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phonelink-ring", feature = "icon-development-kit"))]
    /// Icon name constant for the `phonelink-ring` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phonelink-ring-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONELINK_RING: &str = "phonelink-ring";
    #[doc(alias = "phonelink-setup")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phonelink-setup", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phonelink-setup", feature = "icon-development-kit"))]
    /// Icon name constant for the `phonelink-setup` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phonelink-setup-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONELINK_SETUP: &str = "phonelink-setup";
    #[doc(alias = "phonelink2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phonelink2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phonelink2", feature = "icon-development-kit"))]
    /// Icon name constant for the `phonelink2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phonelink2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONELINK2: &str = "phonelink2";
    #[doc(alias = "phonelink2-off")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phonelink2-off", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phonelink2-off", feature = "icon-development-kit"))]
    /// Icon name constant for the `phonelink2-off` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phonelink2-off-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHONELINK2_OFF: &str = "phonelink2-off";
    #[doc(alias = "phosh")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "phosh", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "phosh", feature = "icon-development-kit"))]
    /// Icon name constant for the `phosh` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/phosh-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHOSH: &str = "phosh";
    #[doc(alias = "photo-camera")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "photo-camera", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "photo-camera", feature = "icon-development-kit"))]
    /// Icon name constant for the `photo-camera` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/photo-camera-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PHOTO_CAMERA: &str = "photo-camera";
    #[doc(alias = "pick-camera")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pick-camera", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pick-camera", feature = "icon-development-kit"))]
    /// Icon name constant for the `pick-camera` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pick-camera-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PICK_CAMERA: &str = "pick-camera";
    #[doc(alias = "pick-camera-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pick-camera-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pick-camera-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `pick-camera-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pick-camera-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PICK_CAMERA_ALT: &str = "pick-camera-alt";
    #[doc(alias = "pick-camera-alt2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pick-camera-alt2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pick-camera-alt2", feature = "icon-development-kit"))]
    /// Icon name constant for the `pick-camera-alt2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pick-camera-alt2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PICK_CAMERA_ALT2: &str = "pick-camera-alt2";
    #[doc(alias = "picture-in-picture-enter-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "picture-in-picture-enter-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "picture-in-picture-enter-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `picture-in-picture-enter-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/picture-in-picture-enter-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PICTURE_IN_PICTURE_ENTER_FILLED: &str = "picture-in-picture-enter-filled";
    #[doc(alias = "picture-in-picture-enter-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "picture-in-picture-enter-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "picture-in-picture-enter-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `picture-in-picture-enter-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/picture-in-picture-enter-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PICTURE_IN_PICTURE_ENTER_REGULAR: &str = "picture-in-picture-enter-regular";
    #[doc(alias = "picture-in-picture-exit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "picture-in-picture-exit-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "picture-in-picture-exit-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `picture-in-picture-exit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/picture-in-picture-exit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PICTURE_IN_PICTURE_EXIT_FILLED: &str = "picture-in-picture-exit-filled";
    #[doc(alias = "picture-in-picture-exit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "picture-in-picture-exit-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "picture-in-picture-exit-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `picture-in-picture-exit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/picture-in-picture-exit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PICTURE_IN_PICTURE_EXIT_REGULAR: &str = "picture-in-picture-exit-regular";
    #[doc(alias = "picture-in-picture-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "picture-in-picture-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "picture-in-picture-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `picture-in-picture-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/picture-in-picture-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PICTURE_IN_PICTURE_FILLED: &str = "picture-in-picture-filled";
    #[doc(alias = "picture-in-picture-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "picture-in-picture-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "picture-in-picture-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `picture-in-picture-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/picture-in-picture-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PICTURE_IN_PICTURE_REGULAR: &str = "picture-in-picture-regular";
    #[doc(alias = "pill-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pill-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pill-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pill-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pill-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PILL_FILLED: &str = "pill-filled";
    #[doc(alias = "pill-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pill-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pill-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pill-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pill-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PILL_REGULAR: &str = "pill-regular";
    #[doc(alias = "pin")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pin", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pin", feature = "icon-development-kit"))]
    /// Icon name constant for the `pin` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pin-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PIN: &str = "pin";
    #[doc(alias = "pin-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pin-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pin-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pin-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pin-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PIN_FILLED: &str = "pin-filled";
    #[doc(alias = "pin-location")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pin-location", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pin-location", feature = "icon-development-kit"))]
    /// Icon name constant for the `pin-location` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pin-location-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PIN_LOCATION: &str = "pin-location";
    #[doc(alias = "pin-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pin-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pin-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pin-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pin-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PIN_OFF_FILLED: &str = "pin-off-filled";
    #[doc(alias = "pin-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pin-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pin-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pin-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pin-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PIN_OFF_REGULAR: &str = "pin-off-regular";
    #[doc(alias = "pin-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pin-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "pin-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `pin-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/pin-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PIN_REGULAR: &str = "pin-regular";
    #[doc(alias = "pip-in")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pip-in", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pip-in", feature = "icon-development-kit"))]
    /// Icon name constant for the `pip-in` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pip-in-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PIP_IN: &str = "pip-in";
    #[doc(alias = "pip-out")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pip-out", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pip-out", feature = "icon-development-kit"))]
    /// Icon name constant for the `pip-out` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pip-out-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PIP_OUT: &str = "pip-out";
    #[doc(alias = "pipette")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pipette", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pipette", feature = "icon-development-kit"))]
    /// Icon name constant for the `pipette` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pipette-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PIPETTE: &str = "pipette";
    #[doc(alias = "play")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "play", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "play", feature = "icon-development-kit"))]
    /// Icon name constant for the `play` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/play-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAY: &str = "play";
    #[doc(alias = "play-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "play-circle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "play-circle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `play-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/play-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAY_CIRCLE_FILLED: &str = "play-circle-filled";
    #[doc(alias = "play-circle-hint-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "play-circle-hint-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "play-circle-hint-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `play-circle-hint-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/play-circle-hint-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAY_CIRCLE_HINT_FILLED: &str = "play-circle-hint-filled";
    #[doc(alias = "play-circle-hint-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "play-circle-hint-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "play-circle-hint-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `play-circle-hint-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/play-circle-hint-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAY_CIRCLE_HINT_REGULAR: &str = "play-circle-hint-regular";
    #[doc(alias = "play-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "play-circle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "play-circle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `play-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/play-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAY_CIRCLE_REGULAR: &str = "play-circle-regular";
    #[doc(alias = "play-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "play-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "play-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `play-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/play-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAY_FILLED: &str = "play-filled";
    #[doc(alias = "play-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "play-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "play-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `play-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/play-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAY_LARGE: &str = "play-large";
    #[doc(alias = "play-large-diabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "play-large-diabled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "play-large-diabled", feature = "icon-development-kit"))]
    /// Icon name constant for the `play-large-diabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/play-large-diabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAY_LARGE_DIABLED: &str = "play-large-diabled";
    #[doc(alias = "play-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "play-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "play-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `play-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/play-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAY_MULTIPLE_FILLED: &str = "play-multiple-filled";
    #[doc(alias = "play-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "play-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "play-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `play-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/play-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAY_MULTIPLE_REGULAR: &str = "play-multiple-regular";
    #[doc(alias = "play-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "play-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "play-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `play-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/play-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAY_REGULAR: &str = "play-regular";
    #[doc(alias = "playback")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "playback", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "playback", feature = "icon-development-kit"))]
    /// Icon name constant for the `playback` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/playback-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAYBACK: &str = "playback";
    #[doc(alias = "playback-error")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "playback-error", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "playback-error", feature = "icon-development-kit"))]
    /// Icon name constant for the `playback-error` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/playback-error-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAYBACK_ERROR: &str = "playback-error";
    #[doc(alias = "playback-options")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "playback-options", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "playback-options", feature = "icon-development-kit"))]
    /// Icon name constant for the `playback-options` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/playback-options-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAYBACK_OPTIONS: &str = "playback-options";
    #[doc(alias = "playback-speed")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "playback-speed", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "playback-speed", feature = "icon-development-kit"))]
    /// Icon name constant for the `playback-speed` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/playback-speed-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAYBACK_SPEED: &str = "playback-speed";
    #[doc(alias = "playlist")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "playlist", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "playlist", feature = "icon-development-kit"))]
    /// Icon name constant for the `playlist` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/playlist-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAYLIST: &str = "playlist";
    #[doc(alias = "playlist2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "playlist2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "playlist2", feature = "icon-development-kit"))]
    /// Icon name constant for the `playlist2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/playlist2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLAYLIST2: &str = "playlist2";
    #[doc(alias = "plus")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "plus", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "plus", feature = "icon-development-kit"))]
    /// Icon name constant for the `plus` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/plus-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLUS: &str = "plus";
    #[doc(alias = "plus-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "plus-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "plus-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `plus-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/plus-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PLUS_LARGE: &str = "plus-large";
    #[doc(alias = "podcast")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "podcast", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "podcast", feature = "icon-development-kit"))]
    /// Icon name constant for the `podcast` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/podcast-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PODCAST: &str = "podcast";
    #[doc(alias = "police-badge")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "police-badge", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "police-badge", feature = "icon-development-kit"))]
    /// Icon name constant for the `police-badge` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/police-badge-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const POLICE_BADGE: &str = "police-badge";
    #[doc(alias = "police-badge2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "police-badge2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "police-badge2", feature = "icon-development-kit"))]
    /// Icon name constant for the `police-badge2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/police-badge2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const POLICE_BADGE2: &str = "police-badge2";
    #[doc(alias = "poll-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "poll-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "poll-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `poll-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/poll-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const POLL_FILLED: &str = "poll-filled";
    #[doc(alias = "poll-horizontal-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "poll-horizontal-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "poll-horizontal-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `poll-horizontal-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/poll-horizontal-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const POLL_HORIZONTAL_FILLED: &str = "poll-horizontal-filled";
    #[doc(alias = "poll-horizontal-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "poll-horizontal-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "poll-horizontal-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `poll-horizontal-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/poll-horizontal-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const POLL_HORIZONTAL_REGULAR: &str = "poll-horizontal-regular";
    #[doc(alias = "poll-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "poll-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "poll-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `poll-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/poll-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const POLL_REGULAR: &str = "poll-regular";
    #[doc(alias = "portal")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "portal", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "portal", feature = "icon-development-kit"))]
    /// Icon name constant for the `portal` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/portal-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PORTAL: &str = "portal";
    #[doc(alias = "positive-feedback")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "positive-feedback", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "positive-feedback", feature = "icon-development-kit"))]
    /// Icon name constant for the `positive-feedback` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/positive-feedback-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const POSITIVE_FEEDBACK: &str = "positive-feedback";
    #[doc(alias = "post-box")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "post-box", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "post-box", feature = "icon-development-kit"))]
    /// Icon name constant for the `post-box` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/post-box-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const POST_BOX: &str = "post-box";
    #[doc(alias = "power")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "power", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "power", feature = "icon-development-kit"))]
    /// Icon name constant for the `power` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/power-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const POWER: &str = "power";
    #[doc(alias = "power-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "power-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "power-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `power-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/power-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const POWER_ALT: &str = "power-alt";
    #[doc(alias = "premium-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "premium-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "premium-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `premium-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/premium-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PREMIUM_FILLED: &str = "premium-filled";
    #[doc(alias = "premium-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "premium-person-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "premium-person-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `premium-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/premium-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PREMIUM_PERSON_FILLED: &str = "premium-person-filled";
    #[doc(alias = "premium-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "premium-person-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "premium-person-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `premium-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/premium-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PREMIUM_PERSON_REGULAR: &str = "premium-person-regular";
    #[doc(alias = "premium-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "premium-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "premium-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `premium-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/premium-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PREMIUM_REGULAR: &str = "premium-regular";
    #[doc(alias = "presence-available-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "presence-available-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "presence-available-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `presence-available-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/presence-available-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRESENCE_AVAILABLE_FILLED: &str = "presence-available-filled";
    #[doc(alias = "presence-available-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "presence-available-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "presence-available-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `presence-available-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/presence-available-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRESENCE_AVAILABLE_REGULAR: &str = "presence-available-regular";
    #[doc(alias = "presence-away-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "presence-away-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "presence-away-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `presence-away-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/presence-away-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRESENCE_AWAY_FILLED: &str = "presence-away-filled";
    #[doc(alias = "presence-away-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "presence-away-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "presence-away-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `presence-away-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/presence-away-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRESENCE_AWAY_REGULAR: &str = "presence-away-regular";
    #[doc(alias = "presence-blocked-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "presence-blocked-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "presence-blocked-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `presence-blocked-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/presence-blocked-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRESENCE_BLOCKED_REGULAR: &str = "presence-blocked-regular";
    #[doc(alias = "presence-busy-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "presence-busy-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "presence-busy-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `presence-busy-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/presence-busy-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRESENCE_BUSY_FILLED: &str = "presence-busy-filled";
    #[doc(alias = "presence-dnd-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "presence-dnd-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "presence-dnd-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `presence-dnd-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/presence-dnd-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRESENCE_DND_FILLED: &str = "presence-dnd-filled";
    #[doc(alias = "presence-dnd-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "presence-dnd-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "presence-dnd-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `presence-dnd-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/presence-dnd-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRESENCE_DND_REGULAR: &str = "presence-dnd-regular";
    #[doc(alias = "presence-offline-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "presence-offline-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "presence-offline-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `presence-offline-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/presence-offline-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRESENCE_OFFLINE_REGULAR: &str = "presence-offline-regular";
    #[doc(alias = "presence-oof-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "presence-oof-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "presence-oof-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `presence-oof-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/presence-oof-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRESENCE_OOF_REGULAR: &str = "presence-oof-regular";
    #[doc(alias = "presence-unknown-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "presence-unknown-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "presence-unknown-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `presence-unknown-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/presence-unknown-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRESENCE_UNKNOWN_REGULAR: &str = "presence-unknown-regular";
    #[doc(alias = "preview-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "preview-link-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "preview-link-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `preview-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/preview-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PREVIEW_LINK_FILLED: &str = "preview-link-filled";
    #[doc(alias = "preview-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "preview-link-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "preview-link-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `preview-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/preview-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PREVIEW_LINK_REGULAR: &str = "preview-link-regular";
    #[doc(alias = "previous-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "previous-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "previous-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `previous-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/previous-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PREVIOUS_FILLED: &str = "previous-filled";
    #[doc(alias = "previous-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "previous-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "previous-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `previous-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/previous-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PREVIOUS_REGULAR: &str = "previous-regular";
    #[doc(alias = "print-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "print-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "print-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `print-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/print-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRINT_FILLED: &str = "print-filled";
    #[doc(alias = "print-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "print-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "print-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `print-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/print-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRINT_REGULAR: &str = "print-regular";
    #[doc(alias = "printer")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "printer", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "printer", feature = "icon-development-kit"))]
    /// Icon name constant for the `printer` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/printer-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRINTER: &str = "printer";
    #[doc(alias = "printer-network")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "printer-network", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "printer-network", feature = "icon-development-kit"))]
    /// Icon name constant for the `printer-network` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/printer-network-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PRINTER_NETWORK: &str = "printer-network";
    #[doc(alias = "processor")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "processor", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "processor", feature = "icon-development-kit"))]
    /// Icon name constant for the `processor` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/processor-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROCESSOR: &str = "processor";
    #[doc(alias = "profit")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "profit", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "profit", feature = "icon-development-kit"))]
    /// Icon name constant for the `profit` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/profit-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROFIT: &str = "profit";
    #[doc(alias = "prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "prohibited-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "prohibited-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROHIBITED_FILLED: &str = "prohibited-filled";
    #[doc(alias = "prohibited-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "prohibited-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "prohibited-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `prohibited-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/prohibited-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROHIBITED_MULTIPLE_FILLED: &str = "prohibited-multiple-filled";
    #[doc(alias = "prohibited-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "prohibited-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "prohibited-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `prohibited-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/prohibited-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROHIBITED_MULTIPLE_REGULAR: &str = "prohibited-multiple-regular";
    #[doc(alias = "prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "prohibited-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "prohibited-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROHIBITED_REGULAR: &str = "prohibited-regular";
    #[doc(alias = "projection-screen-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "projection-screen-dismiss-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "projection-screen-dismiss-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `projection-screen-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/projection-screen-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROJECTION_SCREEN_DISMISS_FILLED: &str = "projection-screen-dismiss-filled";
    #[doc(alias = "projection-screen-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "projection-screen-dismiss-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "projection-screen-dismiss-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `projection-screen-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/projection-screen-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROJECTION_SCREEN_DISMISS_REGULAR: &str = "projection-screen-dismiss-regular";
    #[doc(alias = "projection-screen-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "projection-screen-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "projection-screen-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `projection-screen-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/projection-screen-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROJECTION_SCREEN_FILLED: &str = "projection-screen-filled";
    #[doc(alias = "projection-screen-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "projection-screen-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "projection-screen-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `projection-screen-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/projection-screen-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROJECTION_SCREEN_REGULAR: &str = "projection-screen-regular";
    #[doc(alias = "protocol-handler-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "protocol-handler-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "protocol-handler-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `protocol-handler-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/protocol-handler-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROTOCOL_HANDLER_FILLED: &str = "protocol-handler-filled";
    #[doc(alias = "protocol-handler-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "protocol-handler-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "protocol-handler-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `protocol-handler-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/protocol-handler-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PROTOCOL_HANDLER_REGULAR: &str = "protocol-handler-regular";
    #[doc(alias = "pub")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pub", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pub", feature = "icon-development-kit"))]
    /// Icon name constant for the `pub` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pub-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PUB: &str = "pub";
    #[doc(alias = "pull-request-denied")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pull-request-denied", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pull-request-denied", feature = "icon-development-kit"))]
    /// Icon name constant for the `pull-request-denied` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pull-request-denied-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PULL_REQUEST_DENIED: &str = "pull-request-denied";
    #[doc(alias = "pull-request-draft")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "pull-request-draft", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "pull-request-draft", feature = "icon-development-kit"))]
    /// Icon name constant for the `pull-request-draft` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/pull-request-draft-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PULL_REQUEST_DRAFT: &str = "pull-request-draft";
    #[doc(alias = "puzzle-cube-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "puzzle-cube-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "puzzle-cube-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `puzzle-cube-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/puzzle-cube-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PUZZLE_CUBE_FILLED: &str = "puzzle-cube-filled";
    #[doc(alias = "puzzle-cube-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "puzzle-cube-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "puzzle-cube-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `puzzle-cube-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/puzzle-cube-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PUZZLE_CUBE_REGULAR: &str = "puzzle-cube-regular";
    #[doc(alias = "puzzle-piece")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "puzzle-piece", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "puzzle-piece", feature = "icon-development-kit"))]
    /// Icon name constant for the `puzzle-piece` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/puzzle-piece-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PUZZLE_PIECE: &str = "puzzle-piece";
    #[doc(alias = "puzzle-piece-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "puzzle-piece-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "puzzle-piece-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `puzzle-piece-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/puzzle-piece-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PUZZLE_PIECE_FILLED: &str = "puzzle-piece-filled";
    #[doc(alias = "puzzle-piece-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "puzzle-piece-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "puzzle-piece-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `puzzle-piece-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/puzzle-piece-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const PUZZLE_PIECE_REGULAR: &str = "puzzle-piece-regular";
    #[doc(alias = "qr-code")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "qr-code", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "qr-code", feature = "icon-development-kit"))]
    /// Icon name constant for the `qr-code` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/qr-code-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const QR_CODE: &str = "qr-code";
    #[doc(alias = "qr-code-scanner")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "qr-code-scanner", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "qr-code-scanner", feature = "icon-development-kit"))]
    /// Icon name constant for the `qr-code-scanner` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/qr-code-scanner-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const QR_CODE_SCANNER: &str = "qr-code-scanner";
    #[doc(alias = "question")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "question", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "question", feature = "icon-development-kit"))]
    /// Icon name constant for the `question` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/question-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const QUESTION: &str = "question";
    #[doc(alias = "question-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "question-circle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "question-circle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `question-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/question-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const QUESTION_CIRCLE_FILLED: &str = "question-circle-filled";
    #[doc(alias = "question-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "question-circle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "question-circle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `question-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/question-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const QUESTION_CIRCLE_REGULAR: &str = "question-circle-regular";
    #[doc(alias = "question-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "question-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "question-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `question-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/question-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const QUESTION_FILLED: &str = "question-filled";
    #[doc(alias = "question-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "question-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "question-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `question-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/question-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const QUESTION_REGULAR: &str = "question-regular";
    #[doc(alias = "question-round")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "question-round", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "question-round", feature = "icon-development-kit"))]
    /// Icon name constant for the `question-round` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/question-round-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const QUESTION_ROUND: &str = "question-round";
    #[doc(alias = "quotation")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "quotation", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "quotation", feature = "icon-development-kit"))]
    /// Icon name constant for the `quotation` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/quotation-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const QUOTATION: &str = "quotation";
    #[doc(alias = "radio-button-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "radio-button-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "radio-button-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `radio-button-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/radio-button-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RADIO_BUTTON_FILLED: &str = "radio-button-filled";
    #[doc(alias = "radio-button-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "radio-button-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "radio-button-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `radio-button-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/radio-button-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RADIO_BUTTON_OFF_FILLED: &str = "radio-button-off-filled";
    #[doc(alias = "radio-button-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "radio-button-off-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "radio-button-off-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `radio-button-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/radio-button-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RADIO_BUTTON_OFF_REGULAR: &str = "radio-button-off-regular";
    #[doc(alias = "radio-button-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "radio-button-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "radio-button-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `radio-button-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/radio-button-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RADIO_BUTTON_REGULAR: &str = "radio-button-regular";
    #[doc(alias = "raid")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "raid", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "raid", feature = "icon-development-kit"))]
    /// Icon name constant for the `raid` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/raid-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RAID: &str = "raid";
    #[doc(alias = "rain")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rain", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "rain", feature = "icon-development-kit"))]
    /// Icon name constant for the `rain` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/rain-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RAIN: &str = "rain";
    #[doc(alias = "rain-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rain-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "rain-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `rain-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/rain-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RAIN_ALT: &str = "rain-alt";
    #[doc(alias = "rain-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rain-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "rain-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `rain-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/rain-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RAIN_OUTLINE: &str = "rain-outline";
    #[doc(alias = "rain-scattered-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rain-scattered-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "rain-scattered-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `rain-scattered-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/rain-scattered-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RAIN_SCATTERED_OUTLINE: &str = "rain-scattered-outline";
    #[doc(alias = "ram-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ram-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "ram-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `ram-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/ram-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RAM_FILLED: &str = "ram-filled";
    #[doc(alias = "ram-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ram-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "ram-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `ram-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/ram-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RAM_REGULAR: &str = "ram-regular";
    #[doc(alias = "rating-mature-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rating-mature-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "rating-mature-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `rating-mature-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rating-mature-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RATING_MATURE_FILLED: &str = "rating-mature-filled";
    #[doc(alias = "rating-mature-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rating-mature-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "rating-mature-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `rating-mature-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rating-mature-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RATING_MATURE_REGULAR: &str = "rating-mature-regular";
    #[doc(alias = "re-order-dots-horizontal-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "re-order-dots-horizontal-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "re-order-dots-horizontal-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `re-order-dots-horizontal-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/re-order-dots-horizontal-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RE_ORDER_DOTS_HORIZONTAL_FILLED: &str = "re-order-dots-horizontal-filled";
    #[doc(alias = "re-order-dots-horizontal-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "re-order-dots-horizontal-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "re-order-dots-horizontal-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `re-order-dots-horizontal-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/re-order-dots-horizontal-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RE_ORDER_DOTS_HORIZONTAL_REGULAR: &str = "re-order-dots-horizontal-regular";
    #[doc(alias = "re-order-dots-vertical-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "re-order-dots-vertical-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "re-order-dots-vertical-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `re-order-dots-vertical-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/re-order-dots-vertical-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RE_ORDER_DOTS_VERTICAL_FILLED: &str = "re-order-dots-vertical-filled";
    #[doc(alias = "re-order-dots-vertical-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "re-order-dots-vertical-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "re-order-dots-vertical-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `re-order-dots-vertical-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/re-order-dots-vertical-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RE_ORDER_DOTS_VERTICAL_REGULAR: &str = "re-order-dots-vertical-regular";
    #[doc(alias = "re-order-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "re-order-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "re-order-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `re-order-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/re-order-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RE_ORDER_FILLED: &str = "re-order-filled";
    #[doc(alias = "re-order-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "re-order-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "re-order-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `re-order-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/re-order-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RE_ORDER_REGULAR: &str = "re-order-regular";
    #[doc(alias = "reaction-add")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "reaction-add", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "reaction-add", feature = "icon-development-kit"))]
    /// Icon name constant for the `reaction-add` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/reaction-add-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REACTION_ADD: &str = "reaction-add";
    #[doc(alias = "reaction-add2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "reaction-add2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "reaction-add2", feature = "icon-development-kit"))]
    /// Icon name constant for the `reaction-add2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/reaction-add2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REACTION_ADD2: &str = "reaction-add2";
    #[doc(alias = "read-aloud-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "read-aloud-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "read-aloud-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `read-aloud-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/read-aloud-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const READ_ALOUD_FILLED: &str = "read-aloud-filled";
    #[doc(alias = "read-aloud-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "read-aloud-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "read-aloud-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `read-aloud-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/read-aloud-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const READ_ALOUD_REGULAR: &str = "read-aloud-regular";
    #[doc(alias = "reading-list-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "reading-list-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "reading-list-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `reading-list-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/reading-list-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const READING_LIST_ADD_FILLED: &str = "reading-list-add-filled";
    #[doc(alias = "reading-list-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "reading-list-add-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "reading-list-add-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `reading-list-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/reading-list-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const READING_LIST_ADD_REGULAR: &str = "reading-list-add-regular";
    #[doc(alias = "reading-list-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "reading-list-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "reading-list-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `reading-list-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/reading-list-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const READING_LIST_FILLED: &str = "reading-list-filled";
    #[doc(alias = "reading-list-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "reading-list-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "reading-list-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `reading-list-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/reading-list-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const READING_LIST_REGULAR: &str = "reading-list-regular";
    #[doc(alias = "receipt-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "receipt-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "receipt-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `receipt-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/receipt-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECEIPT_FILLED: &str = "receipt-filled";
    #[doc(alias = "receipt-money-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "receipt-money-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "receipt-money-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `receipt-money-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/receipt-money-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECEIPT_MONEY_FILLED: &str = "receipt-money-filled";
    #[doc(alias = "receipt-money-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "receipt-money-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "receipt-money-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `receipt-money-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/receipt-money-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECEIPT_MONEY_REGULAR: &str = "receipt-money-regular";
    #[doc(alias = "receipt-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "receipt-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "receipt-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `receipt-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/receipt-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECEIPT_REGULAR: &str = "receipt-regular";
    #[doc(alias = "receipt-sparkles-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "receipt-sparkles-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "receipt-sparkles-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `receipt-sparkles-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/receipt-sparkles-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECEIPT_SPARKLES_FILLED: &str = "receipt-sparkles-filled";
    #[doc(alias = "receipt-sparkles-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "receipt-sparkles-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "receipt-sparkles-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `receipt-sparkles-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/receipt-sparkles-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECEIPT_SPARKLES_REGULAR: &str = "receipt-sparkles-regular";
    #[doc(alias = "record-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "record-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "record-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `record-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/record-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECORD_FILLED: &str = "record-filled";
    #[doc(alias = "record-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "record-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "record-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `record-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/record-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECORD_REGULAR: &str = "record-regular";
    #[doc(alias = "record-screen")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "record-screen", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "record-screen", feature = "icon-development-kit"))]
    /// Icon name constant for the `record-screen` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/record-screen-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECORD_SCREEN: &str = "record-screen";
    #[doc(alias = "record-stop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "record-stop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "record-stop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `record-stop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/record-stop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECORD_STOP_FILLED: &str = "record-stop-filled";
    #[doc(alias = "record-stop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "record-stop-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "record-stop-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `record-stop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/record-stop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECORD_STOP_REGULAR: &str = "record-stop-regular";
    #[doc(alias = "rectangle-landscape-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "rectangle-landscape-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "rectangle-landscape-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `rectangle-landscape-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rectangle-landscape-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECTANGLE_LANDSCAPE_FILLED: &str = "rectangle-landscape-filled";
    #[doc(alias = "rectangle-landscape-hint-copy-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "rectangle-landscape-hint-copy-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "rectangle-landscape-hint-copy-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `rectangle-landscape-hint-copy-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rectangle-landscape-hint-copy-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECTANGLE_LANDSCAPE_HINT_COPY_FILLED: &str = "rectangle-landscape-hint-copy-filled";
    #[doc(alias = "rectangle-landscape-hint-copy-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "rectangle-landscape-hint-copy-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "rectangle-landscape-hint-copy-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `rectangle-landscape-hint-copy-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rectangle-landscape-hint-copy-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECTANGLE_LANDSCAPE_HINT_COPY_REGULAR: &str = "rectangle-landscape-hint-copy-regular";
    #[doc(alias = "rectangle-landscape-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "rectangle-landscape-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "rectangle-landscape-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `rectangle-landscape-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rectangle-landscape-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECTANGLE_LANDSCAPE_REGULAR: &str = "rectangle-landscape-regular";
    #[doc(alias = "rectangle-landscape-sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "rectangle-landscape-sparkle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "rectangle-landscape-sparkle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `rectangle-landscape-sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rectangle-landscape-sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECTANGLE_LANDSCAPE_SPARKLE_FILLED: &str = "rectangle-landscape-sparkle-filled";
    #[doc(alias = "rectangle-landscape-sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "rectangle-landscape-sparkle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "rectangle-landscape-sparkle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `rectangle-landscape-sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rectangle-landscape-sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RECTANGLE_LANDSCAPE_SPARKLE_REGULAR: &str = "rectangle-landscape-sparkle-regular";
    #[doc(alias = "refresh")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "refresh", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "refresh", feature = "icon-development-kit"))]
    /// Icon name constant for the `refresh` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/refresh-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REFRESH: &str = "refresh";
    #[doc(alias = "refresh-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "refresh-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "refresh-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `refresh-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/refresh-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REFRESH_LARGE: &str = "refresh-large";
    #[doc(alias = "regex")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "regex", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "regex", feature = "icon-development-kit"))]
    /// Icon name constant for the `regex` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/regex-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REGEX: &str = "regex";
    #[doc(alias = "remix-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "remix-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "remix-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `remix-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/remix-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REMIX_ADD_FILLED: &str = "remix-add-filled";
    #[doc(alias = "remix-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "remix-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "remix-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `remix-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/remix-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REMIX_ADD_REGULAR: &str = "remix-add-regular";
    #[doc(alias = "remote-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "remote-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "remote-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `remote-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/remote-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REMOTE_FILLED: &str = "remote-filled";
    #[doc(alias = "remote-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "remote-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "remote-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `remote-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/remote-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REMOTE_REGULAR: &str = "remote-regular";
    #[doc(alias = "remote-terminal")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "remote-terminal", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "remote-terminal", feature = "icon-development-kit"))]
    /// Icon name constant for the `remote-terminal` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/remote-terminal-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REMOTE_TERMINAL: &str = "remote-terminal";
    #[doc(alias = "rename-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rename-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "rename-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `rename-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rename-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RENAME_FILLED: &str = "rename-filled";
    #[doc(alias = "rename-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rename-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "rename-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `rename-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rename-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RENAME_REGULAR: &str = "rename-regular";
    #[doc(alias = "rescue")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rescue", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "rescue", feature = "icon-development-kit"))]
    /// Icon name constant for the `rescue` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/rescue-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RESCUE: &str = "rescue";
    #[doc(alias = "resize-large-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "resize-large-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "resize-large-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `resize-large-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/resize-large-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RESIZE_LARGE_FILLED: &str = "resize-large-filled";
    #[doc(alias = "resize-large-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "resize-large-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "resize-large-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `resize-large-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/resize-large-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RESIZE_LARGE_REGULAR: &str = "resize-large-regular";
    #[doc(alias = "resize-mode")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "resize-mode", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "resize-mode", feature = "icon-development-kit"))]
    /// Icon name constant for the `resize-mode` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/resize-mode-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RESIZE_MODE: &str = "resize-mode";
    #[doc(alias = "resize-small-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "resize-small-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "resize-small-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `resize-small-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/resize-small-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RESIZE_SMALL_FILLED: &str = "resize-small-filled";
    #[doc(alias = "resize-small-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "resize-small-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "resize-small-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `resize-small-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/resize-small-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RESIZE_SMALL_REGULAR: &str = "resize-small-regular";
    #[doc(alias = "resources")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "resources", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "resources", feature = "icon-development-kit"))]
    /// Icon name constant for the `resources` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/resources-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RESOURCES: &str = "resources";
    #[doc(alias = "resources-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "resources-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "resources-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `resources-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/resources-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RESOURCES_ALT: &str = "resources-alt";
    #[doc(alias = "restaurant")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "restaurant", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "restaurant", feature = "icon-development-kit"))]
    /// Icon name constant for the `restaurant` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/restaurant-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RESTAURANT: &str = "restaurant";
    #[doc(alias = "reward-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "reward-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "reward-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `reward-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/reward-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REWARD_FILLED: &str = "reward-filled";
    #[doc(alias = "reward-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "reward-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "reward-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `reward-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/reward-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REWARD_REGULAR: &str = "reward-regular";
    #[doc(alias = "rewind-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rewind-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "rewind-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `rewind-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rewind-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REWIND_FILLED: &str = "rewind-filled";
    #[doc(alias = "rewind-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rewind-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "rewind-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `rewind-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rewind-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const REWIND_REGULAR: &str = "rewind-regular";
    #[doc(alias = "rhombus-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rhombus-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "rhombus-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `rhombus-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rhombus-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RHOMBUS_FILLED: &str = "rhombus-filled";
    #[doc(alias = "rhombus-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rhombus-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "rhombus-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `rhombus-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rhombus-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RHOMBUS_REGULAR: &str = "rhombus-regular";
    #[doc(alias = "ribbon-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ribbon-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "ribbon-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `ribbon-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/ribbon-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RIBBON_FILLED: &str = "ribbon-filled";
    #[doc(alias = "ribbon-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ribbon-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "ribbon-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `ribbon-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/ribbon-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RIBBON_OFF_FILLED: &str = "ribbon-off-filled";
    #[doc(alias = "ribbon-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ribbon-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "ribbon-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `ribbon-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/ribbon-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RIBBON_OFF_REGULAR: &str = "ribbon-off-regular";
    #[doc(alias = "ribbon-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ribbon-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "ribbon-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `ribbon-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/ribbon-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RIBBON_REGULAR: &str = "ribbon-regular";
    #[doc(alias = "rich-text")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rich-text", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "rich-text", feature = "icon-development-kit"))]
    /// Icon name constant for the `rich-text` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/rich-text-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RICH_TEXT: &str = "rich-text";
    #[doc(alias = "right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "right", feature = "icon-development-kit"))]
    /// Icon name constant for the `right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RIGHT: &str = "right";
    #[doc(alias = "right-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "right-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "right-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `right-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/right-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RIGHT_LARGE: &str = "right-large";
    #[doc(alias = "road-cone-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "road-cone-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "road-cone-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `road-cone-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/road-cone-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ROAD_CONE_FILLED: &str = "road-cone-filled";
    #[doc(alias = "road-cone-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "road-cone-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "road-cone-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `road-cone-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/road-cone-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ROAD_CONE_REGULAR: &str = "road-cone-regular";
    #[doc(alias = "rocket-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rocket-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "rocket-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `rocket-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rocket-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ROCKET_FILLED: &str = "rocket-filled";
    #[doc(alias = "rocket-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rocket-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "rocket-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `rocket-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/rocket-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ROCKET_REGULAR: &str = "rocket-regular";
    #[doc(alias = "roll")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "roll", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "roll", feature = "icon-development-kit"))]
    /// Icon name constant for the `roll` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/roll-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ROLL: &str = "roll";
    #[doc(alias = "roll-vertical")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "roll-vertical", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "roll-vertical", feature = "icon-development-kit"))]
    /// Icon name constant for the `roll-vertical` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/roll-vertical-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ROLL_VERTICAL: &str = "roll-vertical";
    #[doc(alias = "rotate")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rotate", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "rotate", feature = "icon-development-kit"))]
    /// Icon name constant for the `rotate` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/rotate-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ROTATE: &str = "rotate";
    #[doc(alias = "rotation-lock")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rotation-lock", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "rotation-lock", feature = "icon-development-kit"))]
    /// Icon name constant for the `rotation-lock` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/rotation-lock-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ROTATION_LOCK: &str = "rotation-lock";
    #[doc(alias = "rotation-lock-disabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "rotation-lock-disabled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "rotation-lock-disabled", feature = "icon-development-kit"))]
    /// Icon name constant for the `rotation-lock-disabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/rotation-lock-disabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ROTATION_LOCK_DISABLED: &str = "rotation-lock-disabled";
    #[doc(alias = "routing")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "routing", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "routing", feature = "icon-development-kit"))]
    /// Icon name constant for the `routing` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/routing-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ROUTING: &str = "routing";
    #[doc(alias = "ruler-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ruler-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "ruler-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `ruler-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/ruler-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RULER_FILLED: &str = "ruler-filled";
    #[doc(alias = "ruler-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ruler-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "ruler-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `ruler-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/ruler-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RULER_REGULAR: &str = "ruler-regular";
    #[doc(alias = "run-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "run-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "run-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `run-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/run-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RUN_FILLED: &str = "run-filled";
    #[doc(alias = "run-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "run-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "run-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `run-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/run-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RUN_REGULAR: &str = "run-regular";
    #[doc(alias = "running")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "running", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "running", feature = "icon-development-kit"))]
    /// Icon name constant for the `running` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/running-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const RUNNING: &str = "running";
    #[doc(alias = "salami")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "salami", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "salami", feature = "icon-development-kit"))]
    /// Icon name constant for the `salami` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/salami-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SALAMI: &str = "salami";
    #[doc(alias = "save-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "save-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "save-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `save-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/save-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SAVE_FILLED: &str = "save-filled";
    #[doc(alias = "save-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "save-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "save-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `save-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/save-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SAVE_MULTIPLE_FILLED: &str = "save-multiple-filled";
    #[doc(alias = "save-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "save-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "save-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `save-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/save-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SAVE_MULTIPLE_REGULAR: &str = "save-multiple-regular";
    #[doc(alias = "save-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "save-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "save-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `save-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/save-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SAVE_REGULAR: &str = "save-regular";
    #[doc(alias = "savings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "savings-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "savings-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `savings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/savings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SAVINGS_FILLED: &str = "savings-filled";
    #[doc(alias = "savings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "savings-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "savings-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `savings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/savings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SAVINGS_REGULAR: &str = "savings-regular";
    #[doc(alias = "scale")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scale", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "scale", feature = "icon-development-kit"))]
    /// Icon name constant for the `scale` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/scale-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCALE: &str = "scale";
    #[doc(alias = "scale-fit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scale-fit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scale-fit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scale-fit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scale-fit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCALE_FIT_FILLED: &str = "scale-fit-filled";
    #[doc(alias = "scale-fit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scale-fit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scale-fit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scale-fit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scale-fit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCALE_FIT_REGULAR: &str = "scale-fit-regular";
    #[doc(alias = "scales")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scales", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "scales", feature = "icon-development-kit"))]
    /// Icon name constant for the `scales` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/scales-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCALES: &str = "scales";
    #[doc(alias = "scales-detail")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scales-detail", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "scales-detail", feature = "icon-development-kit"))]
    /// Icon name constant for the `scales-detail` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/scales-detail-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCALES_DETAIL: &str = "scales-detail";
    #[doc(alias = "scan-camera-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-camera-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-camera-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-camera-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-camera-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_CAMERA_FILLED: &str = "scan-camera-filled";
    #[doc(alias = "scan-camera-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-camera-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-camera-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-camera-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-camera-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_CAMERA_REGULAR: &str = "scan-camera-regular";
    #[doc(alias = "scan-dash-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-dash-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-dash-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-dash-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-dash-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_DASH_FILLED: &str = "scan-dash-filled";
    #[doc(alias = "scan-dash-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-dash-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-dash-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-dash-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-dash-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_DASH_REGULAR: &str = "scan-dash-regular";
    #[doc(alias = "scan-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_FILLED: &str = "scan-filled";
    #[doc(alias = "scan-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-person-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-person-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_PERSON_FILLED: &str = "scan-person-filled";
    #[doc(alias = "scan-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-person-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-person-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_PERSON_REGULAR: &str = "scan-person-regular";
    #[doc(alias = "scan-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_REGULAR: &str = "scan-regular";
    #[doc(alias = "scan-text-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-text-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-text-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-text-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-text-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_TEXT_FILLED: &str = "scan-text-filled";
    #[doc(alias = "scan-text-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-text-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-text-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-text-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-text-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_TEXT_REGULAR: &str = "scan-text-regular";
    #[doc(alias = "scan-thumb-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-thumb-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-thumb-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-thumb-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-thumb-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_THUMB_UP_FILLED: &str = "scan-thumb-up-filled";
    #[doc(alias = "scan-thumb-up-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "scan-thumb-up-off-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "scan-thumb-up-off-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `scan-thumb-up-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-thumb-up-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_THUMB_UP_OFF_FILLED: &str = "scan-thumb-up-off-filled";
    #[doc(alias = "scan-thumb-up-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "scan-thumb-up-off-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "scan-thumb-up-off-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `scan-thumb-up-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-thumb-up-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_THUMB_UP_OFF_REGULAR: &str = "scan-thumb-up-off-regular";
    #[doc(alias = "scan-thumb-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scan-thumb-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "scan-thumb-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `scan-thumb-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/scan-thumb-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCAN_THUMB_UP_REGULAR: &str = "scan-thumb-up-regular";
    #[doc(alias = "scanner")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scanner", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "scanner", feature = "icon-development-kit"))]
    /// Icon name constant for the `scanner` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/scanner-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCANNER: &str = "scanner";
    #[doc(alias = "scattered-clouds")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scattered-clouds", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "scattered-clouds", feature = "icon-development-kit"))]
    /// Icon name constant for the `scattered-clouds` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/scattered-clouds-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCATTERED_CLOUDS: &str = "scattered-clouds";
    #[doc(alias = "school")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "school", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "school", feature = "icon-development-kit"))]
    /// Icon name constant for the `school` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/school-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCHOOL: &str = "school";
    #[doc(alias = "scissors")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scissors", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "scissors", feature = "icon-development-kit"))]
    /// Icon name constant for the `scissors` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/scissors-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCISSORS: &str = "scissors";
    #[doc(alias = "screen-privacy")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screen-privacy", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screen-privacy", feature = "icon-development-kit"))]
    /// Icon name constant for the `screen-privacy` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screen-privacy-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREEN_PRIVACY: &str = "screen-privacy";
    #[doc(alias = "screen-privacy-disabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screen-privacy-disabled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screen-privacy-disabled", feature = "icon-development-kit"))]
    /// Icon name constant for the `screen-privacy-disabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screen-privacy-disabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREEN_PRIVACY_DISABLED: &str = "screen-privacy-disabled";
    #[doc(alias = "screen-privacy2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screen-privacy2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screen-privacy2", feature = "icon-development-kit"))]
    /// Icon name constant for the `screen-privacy2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screen-privacy2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREEN_PRIVACY2: &str = "screen-privacy2";
    #[doc(alias = "screen-privacy3")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screen-privacy3", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screen-privacy3", feature = "icon-development-kit"))]
    /// Icon name constant for the `screen-privacy3` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screen-privacy3-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREEN_PRIVACY3: &str = "screen-privacy3";
    #[doc(alias = "screen-privacy4")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screen-privacy4", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screen-privacy4", feature = "icon-development-kit"))]
    /// Icon name constant for the `screen-privacy4` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screen-privacy4-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREEN_PRIVACY4: &str = "screen-privacy4";
    #[doc(alias = "screen-privacy5")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screen-privacy5", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screen-privacy5", feature = "icon-development-kit"))]
    /// Icon name constant for the `screen-privacy5` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screen-privacy5-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREEN_PRIVACY5: &str = "screen-privacy5";
    #[doc(alias = "screen-privacy6")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screen-privacy6", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screen-privacy6", feature = "icon-development-kit"))]
    /// Icon name constant for the `screen-privacy6` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screen-privacy6-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREEN_PRIVACY6: &str = "screen-privacy6";
    #[doc(alias = "screen-privacy7")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screen-privacy7", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screen-privacy7", feature = "icon-development-kit"))]
    /// Icon name constant for the `screen-privacy7` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screen-privacy7-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREEN_PRIVACY7: &str = "screen-privacy7";
    #[doc(alias = "screen-privacy7-disabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screen-privacy7-disabled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screen-privacy7-disabled", feature = "icon-development-kit"))]
    /// Icon name constant for the `screen-privacy7-disabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screen-privacy7-disabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREEN_PRIVACY7_DISABLED: &str = "screen-privacy7-disabled";
    #[doc(alias = "screencast-recorded")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screencast-recorded", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screencast-recorded", feature = "icon-development-kit"))]
    /// Icon name constant for the `screencast-recorded` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screencast-recorded-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREENCAST_RECORDED: &str = "screencast-recorded";
    #[doc(alias = "screenshooter")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screenshooter", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screenshooter", feature = "icon-development-kit"))]
    /// Icon name constant for the `screenshooter` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screenshooter-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREENSHOOTER: &str = "screenshooter";
    #[doc(alias = "screenshot-portrait")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screenshot-portrait", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screenshot-portrait", feature = "icon-development-kit"))]
    /// Icon name constant for the `screenshot-portrait` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screenshot-portrait-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREENSHOT_PORTRAIT: &str = "screenshot-portrait";
    #[doc(alias = "screenshot-recorded")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "screenshot-recorded", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "screenshot-recorded", feature = "icon-development-kit"))]
    /// Icon name constant for the `screenshot-recorded` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/screenshot-recorded-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCREENSHOT_RECORDED: &str = "screenshot-recorded";
    #[doc(alias = "script-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "script-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "script-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `script-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/script-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCRIPT_FILLED: &str = "script-filled";
    #[doc(alias = "script-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "script-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "script-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `script-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/script-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCRIPT_REGULAR: &str = "script-regular";
    #[doc(alias = "scroll")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scroll", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "scroll", feature = "icon-development-kit"))]
    /// Icon name constant for the `scroll` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/scroll-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCROLL: &str = "scroll";
    #[doc(alias = "scroll-on-a-roll")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "scroll-on-a-roll", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "scroll-on-a-roll", feature = "icon-development-kit"))]
    /// Icon name constant for the `scroll-on-a-roll` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/scroll-on-a-roll-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SCROLL_ON_A_ROLL: &str = "scroll-on-a-roll";
    #[doc(alias = "search-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "search-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "search-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `search-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/search-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SEARCH_FILLED: &str = "search-filled";
    #[doc(alias = "search-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "search-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "search-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `search-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/search-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SEARCH_REGULAR: &str = "search-regular";
    #[doc(alias = "search-visual-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "search-visual-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "search-visual-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `search-visual-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/search-visual-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SEARCH_VISUAL_FILLED: &str = "search-visual-filled";
    #[doc(alias = "search-visual-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "search-visual-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "search-visual-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `search-visual-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/search-visual-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SEARCH_VISUAL_REGULAR: &str = "search-visual-regular";
    #[doc(alias = "select")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "select", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "select", feature = "icon-development-kit"))]
    /// Icon name constant for the `select` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/select-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SELECT: &str = "select";
    #[doc(alias = "select-mode")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "select-mode", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "select-mode", feature = "icon-development-kit"))]
    /// Icon name constant for the `select-mode` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/select-mode-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SELECT_MODE: &str = "select-mode";
    #[doc(alias = "selection")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "selection", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "selection", feature = "icon-development-kit"))]
    /// Icon name constant for the `selection` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/selection-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SELECTION: &str = "selection";
    #[doc(alias = "selection-opaque")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "selection-opaque", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "selection-opaque", feature = "icon-development-kit"))]
    /// Icon name constant for the `selection-opaque` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/selection-opaque-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SELECTION_OPAQUE: &str = "selection-opaque";
    #[doc(alias = "selection-opaque-2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "selection-opaque-2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "selection-opaque-2", feature = "icon-development-kit"))]
    /// Icon name constant for the `selection-opaque-2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/selection-opaque-2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SELECTION_OPAQUE_2: &str = "selection-opaque-2";
    #[doc(alias = "selection-opaque-3")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "selection-opaque-3", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "selection-opaque-3", feature = "icon-development-kit"))]
    /// Icon name constant for the `selection-opaque-3` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/selection-opaque-3-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SELECTION_OPAQUE_3: &str = "selection-opaque-3";
    #[doc(alias = "send")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "send", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "send", feature = "icon-development-kit"))]
    /// Icon name constant for the `send` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/send-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SEND: &str = "send";
    #[doc(alias = "send-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "send-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "send-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `send-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/send-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SEND_ALT: &str = "send-alt";
    #[doc(alias = "send-beaker-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "send-beaker-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "send-beaker-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `send-beaker-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/send-beaker-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SEND_BEAKER_FILLED: &str = "send-beaker-filled";
    #[doc(alias = "send-beaker-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "send-beaker-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "send-beaker-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `send-beaker-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/send-beaker-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SEND_BEAKER_REGULAR: &str = "send-beaker-regular";
    #[doc(alias = "send-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "send-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "send-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `send-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/send-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SEND_FILLED: &str = "send-filled";
    #[doc(alias = "send-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "send-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "send-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `send-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/send-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SEND_REGULAR: &str = "send-regular";
    #[doc(alias = "sentiment-dissatisfied")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sentiment-dissatisfied", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sentiment-dissatisfied", feature = "icon-development-kit"))]
    /// Icon name constant for the `sentiment-dissatisfied` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sentiment-dissatisfied-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SENTIMENT_DISSATISFIED: &str = "sentiment-dissatisfied";
    #[doc(alias = "sentiment-neutral")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sentiment-neutral", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sentiment-neutral", feature = "icon-development-kit"))]
    /// Icon name constant for the `sentiment-neutral` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sentiment-neutral-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SENTIMENT_NEUTRAL: &str = "sentiment-neutral";
    #[doc(alias = "sentiment-satisfied")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sentiment-satisfied", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sentiment-satisfied", feature = "icon-development-kit"))]
    /// Icon name constant for the `sentiment-satisfied` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sentiment-satisfied-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SENTIMENT_SATISFIED: &str = "sentiment-satisfied";
    #[doc(alias = "sentiment-very-dissatisfied")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "sentiment-very-dissatisfied",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "sentiment-very-dissatisfied",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `sentiment-very-dissatisfied` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sentiment-very-dissatisfied-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SENTIMENT_VERY_DISSATISFIED: &str = "sentiment-very-dissatisfied";
    #[doc(alias = "sentiment-very-satisfied")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sentiment-very-satisfied", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sentiment-very-satisfied", feature = "icon-development-kit"))]
    /// Icon name constant for the `sentiment-very-satisfied` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sentiment-very-satisfied-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SENTIMENT_VERY_SATISFIED: &str = "sentiment-very-satisfied";
    #[doc(alias = "serial-port-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "serial-port-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "serial-port-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `serial-port-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/serial-port-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SERIAL_PORT_FILLED: &str = "serial-port-filled";
    #[doc(alias = "serial-port-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "serial-port-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "serial-port-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `serial-port-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/serial-port-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SERIAL_PORT_REGULAR: &str = "serial-port-regular";
    #[doc(alias = "server-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "server-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "server-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `server-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/server-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SERVER_FILLED: &str = "server-filled";
    #[doc(alias = "server-pick")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "server-pick", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "server-pick", feature = "icon-development-kit"))]
    /// Icon name constant for the `server-pick` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/server-pick-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SERVER_PICK: &str = "server-pick";
    #[doc(alias = "server-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "server-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "server-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `server-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/server-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SERVER_REGULAR: &str = "server-regular";
    #[doc(alias = "server-surface-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "server-surface-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "server-surface-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `server-surface-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/server-surface-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SERVER_SURFACE_FILLED: &str = "server-surface-filled";
    #[doc(alias = "server-surface-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "server-surface-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "server-surface-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `server-surface-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/server-surface-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SERVER_SURFACE_MULTIPLE_FILLED: &str = "server-surface-multiple-filled";
    #[doc(alias = "server-surface-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "server-surface-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "server-surface-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `server-surface-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/server-surface-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SERVER_SURFACE_MULTIPLE_REGULAR: &str = "server-surface-multiple-regular";
    #[doc(alias = "server-surface-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "server-surface-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "server-surface-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `server-surface-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/server-surface-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SERVER_SURFACE_REGULAR: &str = "server-surface-regular";
    #[doc(alias = "service-bell-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "service-bell-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "service-bell-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `service-bell-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/service-bell-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SERVICE_BELL_FILLED: &str = "service-bell-filled";
    #[doc(alias = "service-bell-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "service-bell-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "service-bell-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `service-bell-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/service-bell-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SERVICE_BELL_REGULAR: &str = "service-bell-regular";
    #[doc(alias = "settings")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "settings", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "settings", feature = "icon-development-kit"))]
    /// Icon name constant for the `settings` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/settings-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SETTINGS: &str = "settings";
    #[doc(alias = "settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "settings-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "settings-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SETTINGS_FILLED: &str = "settings-filled";
    #[doc(alias = "settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "settings-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "settings-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SETTINGS_REGULAR: &str = "settings-regular";
    #[doc(alias = "shape-exclude-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shape-exclude-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shape-exclude-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shape-exclude-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shape-exclude-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPE_EXCLUDE_FILLED: &str = "shape-exclude-filled";
    #[doc(alias = "shape-exclude-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shape-exclude-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shape-exclude-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shape-exclude-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shape-exclude-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPE_EXCLUDE_REGULAR: &str = "shape-exclude-regular";
    #[doc(alias = "shape-intersect-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shape-intersect-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shape-intersect-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shape-intersect-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shape-intersect-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPE_INTERSECT_FILLED: &str = "shape-intersect-filled";
    #[doc(alias = "shape-intersect-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shape-intersect-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shape-intersect-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shape-intersect-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shape-intersect-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPE_INTERSECT_REGULAR: &str = "shape-intersect-regular";
    #[doc(alias = "shape-subtract-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shape-subtract-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shape-subtract-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shape-subtract-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shape-subtract-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPE_SUBTRACT_FILLED: &str = "shape-subtract-filled";
    #[doc(alias = "shape-subtract-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shape-subtract-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shape-subtract-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shape-subtract-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shape-subtract-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPE_SUBTRACT_REGULAR: &str = "shape-subtract-regular";
    #[doc(alias = "shape-union-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shape-union-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shape-union-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shape-union-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shape-union-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPE_UNION_FILLED: &str = "shape-union-filled";
    #[doc(alias = "shape-union-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shape-union-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shape-union-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shape-union-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shape-union-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPE_UNION_REGULAR: &str = "shape-union-regular";
    #[doc(alias = "shapes")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shapes", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "shapes", feature = "icon-development-kit"))]
    /// Icon name constant for the `shapes` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/shapes-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPES: &str = "shapes";
    #[doc(alias = "shapes-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shapes-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shapes-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shapes-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shapes-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPES_FILLED: &str = "shapes-filled";
    #[doc(alias = "shapes-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shapes-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "shapes-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `shapes-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/shapes-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPES_LARGE: &str = "shapes-large";
    #[doc(alias = "shapes-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shapes-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shapes-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shapes-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shapes-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHAPES_REGULAR: &str = "shapes-regular";
    #[doc(alias = "share")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "share", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "share", feature = "icon-development-kit"))]
    /// Icon name constant for the `share` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/share-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE: &str = "share";
    #[doc(alias = "share-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "share-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "share-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `share-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/share-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_ALT: &str = "share-alt";
    #[doc(alias = "share-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "share-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "share-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `share-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_FILLED: &str = "share-filled";
    #[doc(alias = "share-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "share-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "share-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `share-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_REGULAR: &str = "share-regular";
    #[doc(alias = "share-screen-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "share-screen-person-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "share-screen-person-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `share-screen-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-screen-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_SCREEN_PERSON_FILLED: &str = "share-screen-person-filled";
    #[doc(alias = "share-screen-person-overlay-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "share-screen-person-overlay-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "share-screen-person-overlay-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `share-screen-person-overlay-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-screen-person-overlay-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_SCREEN_PERSON_OVERLAY_FILLED: &str = "share-screen-person-overlay-filled";
    #[doc(alias = "share-screen-person-overlay-inside-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "share-screen-person-overlay-inside-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "share-screen-person-overlay-inside-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `share-screen-person-overlay-inside-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-screen-person-overlay-inside-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_SCREEN_PERSON_OVERLAY_INSIDE_FILLED: &str =
        "share-screen-person-overlay-inside-filled";
    #[doc(alias = "share-screen-person-overlay-inside-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "share-screen-person-overlay-inside-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "share-screen-person-overlay-inside-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `share-screen-person-overlay-inside-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-screen-person-overlay-inside-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_SCREEN_PERSON_OVERLAY_INSIDE_REGULAR: &str =
        "share-screen-person-overlay-inside-regular";
    #[doc(alias = "share-screen-person-overlay-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "share-screen-person-overlay-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "share-screen-person-overlay-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `share-screen-person-overlay-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-screen-person-overlay-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_SCREEN_PERSON_OVERLAY_REGULAR: &str = "share-screen-person-overlay-regular";
    #[doc(alias = "share-screen-person-p-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "share-screen-person-p-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "share-screen-person-p-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `share-screen-person-p-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-screen-person-p-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_SCREEN_PERSON_P_FILLED: &str = "share-screen-person-p-filled";
    #[doc(alias = "share-screen-person-p-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "share-screen-person-p-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "share-screen-person-p-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `share-screen-person-p-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-screen-person-p-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_SCREEN_PERSON_P_REGULAR: &str = "share-screen-person-p-regular";
    #[doc(alias = "share-screen-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "share-screen-person-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "share-screen-person-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `share-screen-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-screen-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_SCREEN_PERSON_REGULAR: &str = "share-screen-person-regular";
    #[doc(alias = "share-screen-stop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "share-screen-stop-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "share-screen-stop-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `share-screen-stop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-screen-stop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_SCREEN_STOP_FILLED: &str = "share-screen-stop-filled";
    #[doc(alias = "share-screen-stop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "share-screen-stop-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "share-screen-stop-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `share-screen-stop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/share-screen-stop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHARE_SCREEN_STOP_REGULAR: &str = "share-screen-stop-regular";
    #[doc(alias = "shear")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shear", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "shear", feature = "icon-development-kit"))]
    /// Icon name constant for the `shear` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/shear-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHEAR: &str = "shear";
    #[doc(alias = "shell")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shell", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "shell", feature = "icon-development-kit"))]
    /// Icon name constant for the `shell` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/shell-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHELL: &str = "shell";
    #[doc(alias = "shell-overview")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shell-overview", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "shell-overview", feature = "icon-development-kit"))]
    /// Icon name constant for the `shell-overview` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/shell-overview-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHELL_OVERVIEW: &str = "shell-overview";
    #[doc(alias = "shield-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_ADD_FILLED: &str = "shield-add-filled";
    #[doc(alias = "shield-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_ADD_REGULAR: &str = "shield-add-regular";
    #[doc(alias = "shield-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-checkmark-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-checkmark-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_CHECKMARK_FILLED: &str = "shield-checkmark-filled";
    #[doc(alias = "shield-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "shield-checkmark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "shield-checkmark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `shield-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_CHECKMARK_REGULAR: &str = "shield-checkmark-regular";
    #[doc(alias = "shield-danger")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-danger", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "shield-danger", feature = "icon-development-kit"))]
    /// Icon name constant for the `shield-danger` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/shield-danger-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_DANGER: &str = "shield-danger";
    #[doc(alias = "shield-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_DISMISS_FILLED: &str = "shield-dismiss-filled";
    #[doc(alias = "shield-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_DISMISS_REGULAR: &str = "shield-dismiss-regular";
    #[doc(alias = "shield-error-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-error-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-error-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-error-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-error-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_ERROR_FILLED: &str = "shield-error-filled";
    #[doc(alias = "shield-error-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-error-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-error-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-error-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-error-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_ERROR_REGULAR: &str = "shield-error-regular";
    #[doc(alias = "shield-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_FILLED: &str = "shield-filled";
    #[doc(alias = "shield-globe-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-globe-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-globe-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-globe-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-globe-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_GLOBE_FILLED: &str = "shield-globe-filled";
    #[doc(alias = "shield-globe-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-globe-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-globe-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-globe-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-globe-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_GLOBE_REGULAR: &str = "shield-globe-regular";
    #[doc(alias = "shield-keyhole-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-keyhole-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-keyhole-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-keyhole-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-keyhole-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_KEYHOLE_FILLED: &str = "shield-keyhole-filled";
    #[doc(alias = "shield-keyhole-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-keyhole-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-keyhole-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-keyhole-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-keyhole-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_KEYHOLE_REGULAR: &str = "shield-keyhole-regular";
    #[doc(alias = "shield-lock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-lock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-lock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-lock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-lock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_LOCK_FILLED: &str = "shield-lock-filled";
    #[doc(alias = "shield-lock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-lock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-lock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-lock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-lock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_LOCK_REGULAR: &str = "shield-lock-regular";
    #[doc(alias = "shield-question-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-question-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-question-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-question-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-question-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_QUESTION_FILLED: &str = "shield-question-filled";
    #[doc(alias = "shield-question-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-question-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-question-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-question-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-question-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_QUESTION_REGULAR: &str = "shield-question-regular";
    #[doc(alias = "shield-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_REGULAR: &str = "shield-regular";
    #[doc(alias = "shield-safe")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-safe", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "shield-safe", feature = "icon-development-kit"))]
    /// Icon name constant for the `shield-safe` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/shield-safe-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_SAFE: &str = "shield-safe";
    #[doc(alias = "shield-task-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-task-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-task-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-task-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-task-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_TASK_FILLED: &str = "shield-task-filled";
    #[doc(alias = "shield-task-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-task-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shield-task-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shield-task-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shield-task-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_TASK_REGULAR: &str = "shield-task-regular";
    #[doc(alias = "shield-warning")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shield-warning", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "shield-warning", feature = "icon-development-kit"))]
    /// Icon name constant for the `shield-warning` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/shield-warning-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIELD_WARNING: &str = "shield-warning";
    #[doc(alias = "shift")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shift", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "shift", feature = "icon-development-kit"))]
    /// Icon name constant for the `shift` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/shift-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIFT: &str = "shift";
    #[doc(alias = "shifts-activity-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shifts-activity-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shifts-activity-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shifts-activity-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shifts-activity-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIFTS_ACTIVITY_FILLED: &str = "shifts-activity-filled";
    #[doc(alias = "shifts-activity-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shifts-activity-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shifts-activity-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shifts-activity-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shifts-activity-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIFTS_ACTIVITY_REGULAR: &str = "shifts-activity-regular";
    #[doc(alias = "shifts-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shifts-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shifts-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shifts-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shifts-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIFTS_FILLED: &str = "shifts-filled";
    #[doc(alias = "shifts-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shifts-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shifts-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shifts-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shifts-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHIFTS_REGULAR: &str = "shifts-regular";
    #[doc(alias = "shoe-box")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shoe-box", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "shoe-box", feature = "icon-development-kit"))]
    /// Icon name constant for the `shoe-box` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/shoe-box-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHOE_BOX: &str = "shoe-box";
    #[doc(alias = "shopping-bag-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shopping-bag-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shopping-bag-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shopping-bag-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shopping-bag-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHOPPING_BAG_FILLED: &str = "shopping-bag-filled";
    #[doc(alias = "shopping-bag-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shopping-bag-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "shopping-bag-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `shopping-bag-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/shopping-bag-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHOPPING_BAG_REGULAR: &str = "shopping-bag-regular";
    #[doc(alias = "shopping-cart")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "shopping-cart", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "shopping-cart", feature = "icon-development-kit"))]
    /// Icon name constant for the `shopping-cart` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/shopping-cart-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHOPPING_CART: &str = "shopping-cart";
    #[doc(alias = "showers")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "showers", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "showers", feature = "icon-development-kit"))]
    /// Icon name constant for the `showers` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/showers-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SHOWERS: &str = "showers";
    #[doc(alias = "sign-language")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sign-language", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sign-language", feature = "icon-development-kit"))]
    /// Icon name constant for the `sign-language` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sign-language-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIGN_LANGUAGE: &str = "sign-language";
    #[doc(alias = "signature")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "signature", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "signature", feature = "icon-development-kit"))]
    /// Icon name constant for the `signature` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/signature-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIGNATURE: &str = "signature";
    #[doc(alias = "signature-bad")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "signature-bad", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "signature-bad", feature = "icon-development-kit"))]
    /// Icon name constant for the `signature-bad` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/signature-bad-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIGNATURE_BAD: &str = "signature-bad";
    #[doc(alias = "signature-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "signature-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "signature-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `signature-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/signature-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIGNATURE_FILLED: &str = "signature-filled";
    #[doc(alias = "signature-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "signature-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "signature-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `signature-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/signature-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIGNATURE_REGULAR: &str = "signature-regular";
    #[doc(alias = "sim")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sim", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sim", feature = "icon-development-kit"))]
    /// Icon name constant for the `sim` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sim-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIM: &str = "sim";
    #[doc(alias = "sim-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sim-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sim-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sim-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sim-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIM_FILLED: &str = "sim-filled";
    #[doc(alias = "sim-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sim-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sim-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sim-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sim-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIM_REGULAR: &str = "sim-regular";
    #[doc(alias = "single-display")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "single-display", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "single-display", feature = "icon-development-kit"))]
    /// Icon name constant for the `single-display` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/single-display-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SINGLE_DISPLAY: &str = "single-display";
    #[doc(alias = "size-horizontally")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "size-horizontally", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "size-horizontally", feature = "icon-development-kit"))]
    /// Icon name constant for the `size-horizontally` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/size-horizontally-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIZE_HORIZONTALLY: &str = "size-horizontally";
    #[doc(alias = "size-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "size-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "size-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `size-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/size-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIZE_LEFT: &str = "size-left";
    #[doc(alias = "size-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "size-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "size-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `size-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/size-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIZE_RIGHT: &str = "size-right";
    #[doc(alias = "size-vertically")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "size-vertically", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "size-vertically", feature = "icon-development-kit"))]
    /// Icon name constant for the `size-vertically` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/size-vertically-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SIZE_VERTICALLY: &str = "size-vertically";
    #[doc(alias = "skip-backwards-10")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "skip-backwards-10", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "skip-backwards-10", feature = "icon-development-kit"))]
    /// Icon name constant for the `skip-backwards-10` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/skip-backwards-10-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SKIP_BACKWARDS_10: &str = "skip-backwards-10";
    #[doc(alias = "skip-backwards-30")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "skip-backwards-30", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "skip-backwards-30", feature = "icon-development-kit"))]
    /// Icon name constant for the `skip-backwards-30` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/skip-backwards-30-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SKIP_BACKWARDS_30: &str = "skip-backwards-30";
    #[doc(alias = "skip-forward-10")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "skip-forward-10", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "skip-forward-10", feature = "icon-development-kit"))]
    /// Icon name constant for the `skip-forward-10` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/skip-forward-10-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SKIP_FORWARD_10: &str = "skip-forward-10";
    #[doc(alias = "skip-forward-30")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "skip-forward-30", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "skip-forward-30", feature = "icon-development-kit"))]
    /// Icon name constant for the `skip-forward-30` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/skip-forward-30-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SKIP_FORWARD_30: &str = "skip-forward-30";
    #[doc(alias = "skull")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "skull", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "skull", feature = "icon-development-kit"))]
    /// Icon name constant for the `skull` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/skull-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SKULL: &str = "skull";
    #[doc(alias = "skull-small")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "skull-small", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "skull-small", feature = "icon-development-kit"))]
    /// Icon name constant for the `skull-small` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/skull-small-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SKULL_SMALL: &str = "skull-small";
    #[doc(alias = "slash-forward-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "slash-forward-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "slash-forward-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `slash-forward-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slash-forward-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLASH_FORWARD_FILLED: &str = "slash-forward-filled";
    #[doc(alias = "slash-forward-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "slash-forward-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "slash-forward-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `slash-forward-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slash-forward-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLASH_FORWARD_REGULAR: &str = "slash-forward-regular";
    #[doc(alias = "slide-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "slide-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "slide-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `slide-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_ADD_FILLED: &str = "slide-add-filled";
    #[doc(alias = "slide-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "slide-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "slide-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `slide-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_ADD_REGULAR: &str = "slide-add-regular";
    #[doc(alias = "slide-eraser-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "slide-eraser-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "slide-eraser-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `slide-eraser-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-eraser-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_ERASER_FILLED: &str = "slide-eraser-filled";
    #[doc(alias = "slide-eraser-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "slide-eraser-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "slide-eraser-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `slide-eraser-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-eraser-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_ERASER_REGULAR: &str = "slide-eraser-regular";
    #[doc(alias = "slide-record-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "slide-record-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "slide-record-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `slide-record-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-record-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_RECORD_FILLED: &str = "slide-record-filled";
    #[doc(alias = "slide-record-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "slide-record-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "slide-record-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `slide-record-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-record-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_RECORD_REGULAR: &str = "slide-record-regular";
    #[doc(alias = "slide-text-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "slide-text-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "slide-text-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `slide-text-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-text-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_TEXT_FILLED: &str = "slide-text-filled";
    #[doc(alias = "slide-text-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "slide-text-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "slide-text-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `slide-text-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-text-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_TEXT_MULTIPLE_FILLED: &str = "slide-text-multiple-filled";
    #[doc(alias = "slide-text-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "slide-text-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "slide-text-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `slide-text-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-text-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_TEXT_MULTIPLE_REGULAR: &str = "slide-text-multiple-regular";
    #[doc(alias = "slide-text-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "slide-text-person-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "slide-text-person-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `slide-text-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-text-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_TEXT_PERSON_FILLED: &str = "slide-text-person-filled";
    #[doc(alias = "slide-text-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "slide-text-person-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "slide-text-person-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `slide-text-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-text-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_TEXT_PERSON_REGULAR: &str = "slide-text-person-regular";
    #[doc(alias = "slide-text-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "slide-text-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "slide-text-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `slide-text-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-text-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_TEXT_REGULAR: &str = "slide-text-regular";
    #[doc(alias = "slide-text-sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "slide-text-sparkle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "slide-text-sparkle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `slide-text-sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-text-sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_TEXT_SPARKLE_FILLED: &str = "slide-text-sparkle-filled";
    #[doc(alias = "slide-text-sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "slide-text-sparkle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "slide-text-sparkle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `slide-text-sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/slide-text-sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SLIDE_TEXT_SPARKLE_REGULAR: &str = "slide-text-sparkle-regular";
    #[doc(alias = "small-x")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "small-x", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "small-x", feature = "icon-development-kit"))]
    /// Icon name constant for the `small-x` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/small-x-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SMALL_X: &str = "small-x";
    #[doc(alias = "smartcard")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "smartcard", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "smartcard", feature = "icon-development-kit"))]
    /// Icon name constant for the `smartcard` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/smartcard-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SMARTCARD: &str = "smartcard";
    #[doc(alias = "smartphone")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "smartphone", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "smartphone", feature = "icon-development-kit"))]
    /// Icon name constant for the `smartphone` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/smartphone-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SMARTPHONE: &str = "smartphone";
    #[doc(alias = "smile")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "smile", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "smile", feature = "icon-development-kit"))]
    /// Icon name constant for the `smile` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/smile-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SMILE: &str = "smile";
    #[doc(alias = "smoothen")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "smoothen", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "smoothen", feature = "icon-development-kit"))]
    /// Icon name constant for the `smoothen` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/smoothen-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SMOOTHEN: &str = "smoothen";
    #[doc(alias = "smudge-finger")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "smudge-finger", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "smudge-finger", feature = "icon-development-kit"))]
    /// Icon name constant for the `smudge-finger` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/smudge-finger-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SMUDGE_FINGER: &str = "smudge-finger";
    #[doc(alias = "snap")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "snap", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "snap", feature = "icon-development-kit"))]
    /// Icon name constant for the `snap` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/snap-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SNAP: &str = "snap";
    #[doc(alias = "snapshots")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "snapshots", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "snapshots", feature = "icon-development-kit"))]
    /// Icon name constant for the `snapshots` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/snapshots-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SNAPSHOTS: &str = "snapshots";
    #[doc(alias = "snapshots-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "snapshots-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "snapshots-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `snapshots-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/snapshots-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SNAPSHOTS_ALT: &str = "snapshots-alt";
    #[doc(alias = "snooze-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "snooze-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "snooze-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `snooze-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/snooze-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SNOOZE_FILLED: &str = "snooze-filled";
    #[doc(alias = "snooze-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "snooze-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "snooze-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `snooze-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/snooze-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SNOOZE_REGULAR: &str = "snooze-regular";
    #[doc(alias = "snow")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "snow", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "snow", feature = "icon-development-kit"))]
    /// Icon name constant for the `snow` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/snow-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SNOW: &str = "snow";
    #[doc(alias = "snow-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "snow-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "snow-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `snow-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/snow-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SNOW_OUTLINE: &str = "snow-outline";
    #[doc(alias = "social-network")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "social-network", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "social-network", feature = "icon-development-kit"))]
    /// Icon name constant for the `social-network` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/social-network-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SOCIAL_NETWORK: &str = "social-network";
    #[doc(alias = "social-network-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "social-network-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "social-network-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `social-network-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/social-network-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SOCIAL_NETWORK_NONE: &str = "social-network-none";
    #[doc(alias = "sonar")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sonar", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sonar", feature = "icon-development-kit"))]
    /// Icon name constant for the `sonar` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sonar-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SONAR: &str = "sonar";
    #[doc(alias = "sound-wave")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sound-wave", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sound-wave", feature = "icon-development-kit"))]
    /// Icon name constant for the `sound-wave` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sound-wave-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SOUND_WAVE: &str = "sound-wave";
    #[doc(alias = "sound-wave-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sound-wave-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sound-wave-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `sound-wave-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sound-wave-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SOUND_WAVE_ALT: &str = "sound-wave-alt";
    #[doc(alias = "soundcard")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "soundcard", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "soundcard", feature = "icon-development-kit"))]
    /// Icon name constant for the `soundcard` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/soundcard-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SOUNDCARD: &str = "soundcard";
    #[doc(alias = "soup")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "soup", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "soup", feature = "icon-development-kit"))]
    /// Icon name constant for the `soup` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/soup-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SOUP: &str = "soup";
    #[doc(alias = "source-pick")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "source-pick", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "source-pick", feature = "icon-development-kit"))]
    /// Icon name constant for the `source-pick` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/source-pick-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SOURCE_PICK: &str = "source-pick";
    #[doc(alias = "space-3d-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "space-3d-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "space-3d-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `space-3d-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/space-3d-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPACE_3D_FILLED: &str = "space-3d-filled";
    #[doc(alias = "space-3d-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "space-3d-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "space-3d-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `space-3d-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/space-3d-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPACE_3D_REGULAR: &str = "space-3d-regular";
    #[doc(alias = "sparkle-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sparkle-circle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sparkle-circle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sparkle-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sparkle-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPARKLE_CIRCLE_FILLED: &str = "sparkle-circle-filled";
    #[doc(alias = "sparkle-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sparkle-circle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sparkle-circle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sparkle-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sparkle-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPARKLE_CIRCLE_REGULAR: &str = "sparkle-circle-regular";
    #[doc(alias = "sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sparkle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sparkle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPARKLE_FILLED: &str = "sparkle-filled";
    #[doc(alias = "sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sparkle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sparkle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPARKLE_REGULAR: &str = "sparkle-regular";
    #[doc(alias = "speaker-0-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-0-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-0-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-0-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-0-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_0_FILLED: &str = "speaker-0-filled";
    #[doc(alias = "speaker-0-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-0-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-0-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-0-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-0-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_0_REGULAR: &str = "speaker-0-regular";
    #[doc(alias = "speaker-1-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-1-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-1-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-1-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-1-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_1_FILLED: &str = "speaker-1-filled";
    #[doc(alias = "speaker-1-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-1-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-1-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-1-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-1-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_1_REGULAR: &str = "speaker-1-regular";
    #[doc(alias = "speaker-2-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-2-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-2-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-2-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-2-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_2_FILLED: &str = "speaker-2-filled";
    #[doc(alias = "speaker-2-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-2-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-2-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-2-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-2-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_2_REGULAR: &str = "speaker-2-regular";
    #[doc(alias = "speaker-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_EDIT_FILLED: &str = "speaker-edit-filled";
    #[doc(alias = "speaker-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_EDIT_REGULAR: &str = "speaker-edit-regular";
    #[doc(alias = "speaker-mute-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-mute-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-mute-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-mute-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-mute-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_MUTE_FILLED: &str = "speaker-mute-filled";
    #[doc(alias = "speaker-mute-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-mute-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-mute-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-mute-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-mute-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_MUTE_REGULAR: &str = "speaker-mute-regular";
    #[doc(alias = "speaker-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_OFF_FILLED: &str = "speaker-off-filled";
    #[doc(alias = "speaker-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speaker-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "speaker-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `speaker-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/speaker-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKER_OFF_REGULAR: &str = "speaker-off-regular";
    #[doc(alias = "speakers")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speakers", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "speakers", feature = "icon-development-kit"))]
    /// Icon name constant for the `speakers` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/speakers-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEAKERS: &str = "speakers";
    #[doc(alias = "speedometer")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speedometer", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "speedometer", feature = "icon-development-kit"))]
    /// Icon name constant for the `speedometer` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/speedometer-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEEDOMETER: &str = "speedometer";
    #[doc(alias = "speedometer2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speedometer2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "speedometer2", feature = "icon-development-kit"))]
    /// Icon name constant for the `speedometer2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/speedometer2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEEDOMETER2: &str = "speedometer2";
    #[doc(alias = "speedometer3")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speedometer3", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "speedometer3", feature = "icon-development-kit"))]
    /// Icon name constant for the `speedometer3` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/speedometer3-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEEDOMETER3: &str = "speedometer3";
    #[doc(alias = "speedometer4")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "speedometer4", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "speedometer4", feature = "icon-development-kit"))]
    /// Icon name constant for the `speedometer4` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/speedometer4-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPEEDOMETER4: &str = "speedometer4";
    #[doc(alias = "spinner")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "spinner", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "spinner", feature = "icon-development-kit"))]
    /// Icon name constant for the `spinner` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/spinner-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPINNER: &str = "spinner";
    #[doc(alias = "spinner-ios-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "spinner-ios-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "spinner-ios-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `spinner-ios-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/spinner-ios-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPINNER_IOS_FILLED: &str = "spinner-ios-filled";
    #[doc(alias = "spinner-ios-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "spinner-ios-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "spinner-ios-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `spinner-ios-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/spinner-ios-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPINNER_IOS_REGULAR: &str = "spinner-ios-regular";
    #[doc(alias = "split-horizontal-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "split-horizontal-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "split-horizontal-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `split-horizontal-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/split-horizontal-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPLIT_HORIZONTAL_FILLED: &str = "split-horizontal-filled";
    #[doc(alias = "split-horizontal-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "split-horizontal-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "split-horizontal-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `split-horizontal-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/split-horizontal-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPLIT_HORIZONTAL_REGULAR: &str = "split-horizontal-regular";
    #[doc(alias = "split-vertical-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "split-vertical-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "split-vertical-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `split-vertical-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/split-vertical-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPLIT_VERTICAL_FILLED: &str = "split-vertical-filled";
    #[doc(alias = "split-vertical-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "split-vertical-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "split-vertical-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `split-vertical-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/split-vertical-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPLIT_VERTICAL_REGULAR: &str = "split-vertical-regular";
    #[doc(alias = "sport-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sport-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sport-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sport-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sport-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPORT_FILLED: &str = "sport-filled";
    #[doc(alias = "sport-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sport-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sport-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sport-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sport-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPORT_REGULAR: &str = "sport-regular";
    #[doc(alias = "sport-soccer-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sport-soccer-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sport-soccer-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sport-soccer-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sport-soccer-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPORT_SOCCER_FILLED: &str = "sport-soccer-filled";
    #[doc(alias = "sport-soccer-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sport-soccer-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sport-soccer-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sport-soccer-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sport-soccer-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPORT_SOCCER_REGULAR: &str = "sport-soccer-regular";
    #[doc(alias = "spray-can-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "spray-can-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "spray-can-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `spray-can-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/spray-can-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPRAY_CAN_FILLED: &str = "spray-can-filled";
    #[doc(alias = "spray-can-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "spray-can-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "spray-can-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `spray-can-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/spray-can-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPRAY_CAN_REGULAR: &str = "spray-can-regular";
    #[doc(alias = "spring")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "spring", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "spring", feature = "icon-development-kit"))]
    /// Icon name constant for the `spring` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/spring-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SPRING: &str = "spring";
    #[doc(alias = "square-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "square-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `square-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_ADD_FILLED: &str = "square-add-filled";
    #[doc(alias = "square-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "square-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `square-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_ADD_REGULAR: &str = "square-add-regular";
    #[doc(alias = "square-arrow-forward-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "square-arrow-forward-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "square-arrow-forward-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `square-arrow-forward-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-arrow-forward-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_ARROW_FORWARD_FILLED: &str = "square-arrow-forward-filled";
    #[doc(alias = "square-arrow-forward-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "square-arrow-forward-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "square-arrow-forward-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `square-arrow-forward-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-arrow-forward-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_ARROW_FORWARD_REGULAR: &str = "square-arrow-forward-regular";
    #[doc(alias = "square-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "square-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `square-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_DISMISS_FILLED: &str = "square-dismiss-filled";
    #[doc(alias = "square-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "square-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `square-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_DISMISS_REGULAR: &str = "square-dismiss-regular";
    #[doc(alias = "square-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "square-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `square-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/square-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_FILLED: &str = "square-filled";
    #[doc(alias = "square-filled-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-filled-alt", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "square-filled-alt", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `square-filled-alt` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_FILLED_ALT: &str = "square-filled-alt";
    #[doc(alias = "square-hint-arrow-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "square-hint-arrow-back-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "square-hint-arrow-back-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `square-hint-arrow-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-hint-arrow-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_HINT_ARROW_BACK_FILLED: &str = "square-hint-arrow-back-filled";
    #[doc(alias = "square-hint-arrow-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "square-hint-arrow-back-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "square-hint-arrow-back-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `square-hint-arrow-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-hint-arrow-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_HINT_ARROW_BACK_REGULAR: &str = "square-hint-arrow-back-regular";
    #[doc(alias = "square-hint-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-hint-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "square-hint-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `square-hint-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-hint-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_HINT_FILLED: &str = "square-hint-filled";
    #[doc(alias = "square-hint-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-hint-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "square-hint-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `square-hint-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-hint-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_HINT_REGULAR: &str = "square-hint-regular";
    #[doc(alias = "square-hint-sparkles-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "square-hint-sparkles-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "square-hint-sparkles-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `square-hint-sparkles-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-hint-sparkles-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_HINT_SPARKLES_FILLED: &str = "square-hint-sparkles-filled";
    #[doc(alias = "square-hint-sparkles-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "square-hint-sparkles-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "square-hint-sparkles-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `square-hint-sparkles-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-hint-sparkles-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_HINT_SPARKLES_REGULAR: &str = "square-hint-sparkles-regular";
    #[doc(alias = "square-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "square-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `square-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_MULTIPLE_FILLED: &str = "square-multiple-filled";
    #[doc(alias = "square-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "square-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `square-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_MULTIPLE_REGULAR: &str = "square-multiple-regular";
    #[doc(alias = "square-outline-thick")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-outline-thick", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "square-outline-thick", feature = "icon-development-kit"))]
    /// Icon name constant for the `square-outline-thick` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/square-outline-thick-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_OUTLINE_THICK: &str = "square-outline-thick";
    #[doc(alias = "square-outline-thin")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-outline-thin", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "square-outline-thin", feature = "icon-development-kit"))]
    /// Icon name constant for the `square-outline-thin` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/square-outline-thin-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_OUTLINE_THIN: &str = "square-outline-thin";
    #[doc(alias = "square-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "square-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "square-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `square-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/square-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SQUARE_REGULAR: &str = "square-regular";
    #[doc(alias = "ssd")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ssd", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "ssd", feature = "icon-development-kit"))]
    /// Icon name constant for the `ssd` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/ssd-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SSD: &str = "ssd";
    #[doc(alias = "stack-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stack-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "stack-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `stack-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/stack-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STACK_FILLED: &str = "stack-filled";
    #[doc(alias = "stack-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stack-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "stack-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `stack-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/stack-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STACK_REGULAR: &str = "stack-regular";
    #[doc(alias = "stack-star-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stack-star-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "stack-star-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `stack-star-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/stack-star-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STACK_STAR_FILLED: &str = "stack-star-filled";
    #[doc(alias = "stack-star-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stack-star-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "stack-star-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `stack-star-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/stack-star-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STACK_STAR_REGULAR: &str = "stack-star-regular";
    #[doc(alias = "stacked-plates")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stacked-plates", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "stacked-plates", feature = "icon-development-kit"))]
    /// Icon name constant for the `stacked-plates` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/stacked-plates-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STACKED_PLATES: &str = "stacked-plates";
    #[doc(alias = "stamp")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stamp", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "stamp", feature = "icon-development-kit"))]
    /// Icon name constant for the `stamp` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/stamp-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAMP: &str = "stamp";
    #[doc(alias = "star-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_ADD_FILLED: &str = "star-add-filled";
    #[doc(alias = "star-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_ADD_REGULAR: &str = "star-add-regular";
    #[doc(alias = "star-arrow-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-arrow-back-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-arrow-back-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-arrow-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-arrow-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_ARROW_BACK_FILLED: &str = "star-arrow-back-filled";
    #[doc(alias = "star-arrow-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-arrow-back-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-arrow-back-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-arrow-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-arrow-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_ARROW_BACK_REGULAR: &str = "star-arrow-back-regular";
    #[doc(alias = "star-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-checkmark-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-checkmark-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_CHECKMARK_FILLED: &str = "star-checkmark-filled";
    #[doc(alias = "star-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-checkmark-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-checkmark-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_CHECKMARK_REGULAR: &str = "star-checkmark-regular";
    #[doc(alias = "star-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_DISMISS_FILLED: &str = "star-dismiss-filled";
    #[doc(alias = "star-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_DISMISS_REGULAR: &str = "star-dismiss-regular";
    #[doc(alias = "star-emphasis-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-emphasis-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-emphasis-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-emphasis-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-emphasis-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_EMPHASIS_FILLED: &str = "star-emphasis-filled";
    #[doc(alias = "star-emphasis-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-emphasis-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-emphasis-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-emphasis-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-emphasis-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_EMPHASIS_REGULAR: &str = "star-emphasis-regular";
    #[doc(alias = "star-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "star-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `star-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/star-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_FILLED: &str = "star-filled";
    #[doc(alias = "star-filled-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-filled-alt", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-filled-alt", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-filled-alt` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_FILLED_ALT: &str = "star-filled-alt";
    #[doc(alias = "star-filled-rounded")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-filled-rounded", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "star-filled-rounded", feature = "icon-development-kit"))]
    /// Icon name constant for the `star-filled-rounded` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/star-filled-rounded-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_FILLED_ROUNDED: &str = "star-filled-rounded";
    #[doc(alias = "star-half-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-half-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-half-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-half-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-half-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_HALF_FILLED: &str = "star-half-filled";
    #[doc(alias = "star-half-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-half-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-half-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-half-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-half-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_HALF_REGULAR: &str = "star-half-regular";
    #[doc(alias = "star-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "star-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `star-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/star-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_LARGE: &str = "star-large";
    #[doc(alias = "star-line-horizontal-3-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "star-line-horizontal-3-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "star-line-horizontal-3-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `star-line-horizontal-3-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-line-horizontal-3-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_LINE_HORIZONTAL_3_FILLED: &str = "star-line-horizontal-3-filled";
    #[doc(alias = "star-line-horizontal-3-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "star-line-horizontal-3-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "star-line-horizontal-3-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `star-line-horizontal-3-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-line-horizontal-3-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_LINE_HORIZONTAL_3_REGULAR: &str = "star-line-horizontal-3-regular";
    #[doc(alias = "star-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_OFF_FILLED: &str = "star-off-filled";
    #[doc(alias = "star-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_OFF_REGULAR: &str = "star-off-regular";
    #[doc(alias = "star-one-quarter-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-one-quarter-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-one-quarter-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-one-quarter-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-one-quarter-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_ONE_QUARTER_FILLED: &str = "star-one-quarter-filled";
    #[doc(alias = "star-one-quarter-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "star-one-quarter-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "star-one-quarter-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `star-one-quarter-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-one-quarter-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_ONE_QUARTER_REGULAR: &str = "star-one-quarter-regular";
    #[doc(alias = "star-outline-half-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-outline-half-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "star-outline-half-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `star-outline-half-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/star-outline-half-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_OUTLINE_HALF_LEFT: &str = "star-outline-half-left";
    #[doc(alias = "star-outline-half-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-outline-half-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "star-outline-half-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `star-outline-half-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/star-outline-half-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_OUTLINE_HALF_RIGHT: &str = "star-outline-half-right";
    #[doc(alias = "star-outline-rounded")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-outline-rounded", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "star-outline-rounded", feature = "icon-development-kit"))]
    /// Icon name constant for the `star-outline-rounded` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/star-outline-rounded-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_OUTLINE_ROUNDED: &str = "star-outline-rounded";
    #[doc(alias = "star-outline-thick")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-outline-thick", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "star-outline-thick", feature = "icon-development-kit"))]
    /// Icon name constant for the `star-outline-thick` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/star-outline-thick-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_OUTLINE_THICK: &str = "star-outline-thick";
    #[doc(alias = "star-outline-thin")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-outline-thin", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "star-outline-thin", feature = "icon-development-kit"))]
    /// Icon name constant for the `star-outline-thin` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/star-outline-thin-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_OUTLINE_THIN: &str = "star-outline-thin";
    #[doc(alias = "star-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-prohibited-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-prohibited-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_PROHIBITED_FILLED: &str = "star-prohibited-filled";
    #[doc(alias = "star-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-prohibited-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-prohibited-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_PROHIBITED_REGULAR: &str = "star-prohibited-regular";
    #[doc(alias = "star-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "star-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "star-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `star-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_REGULAR: &str = "star-regular";
    #[doc(alias = "star-three-quarter-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "star-three-quarter-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "star-three-quarter-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `star-three-quarter-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-three-quarter-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_THREE_QUARTER_FILLED: &str = "star-three-quarter-filled";
    #[doc(alias = "star-three-quarter-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "star-three-quarter-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "star-three-quarter-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `star-three-quarter-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/star-three-quarter-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STAR_THREE_QUARTER_REGULAR: &str = "star-three-quarter-regular";
    #[doc(alias = "status-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "status-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "status-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `status-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/status-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STATUS_FILLED: &str = "status-filled";
    #[doc(alias = "status-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "status-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "status-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `status-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/status-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STATUS_REGULAR: &str = "status-regular";
    #[doc(alias = "step-back")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "step-back", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "step-back", feature = "icon-development-kit"))]
    /// Icon name constant for the `step-back` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/step-back-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STEP_BACK: &str = "step-back";
    #[doc(alias = "step-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "step-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "step-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `step-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/step-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STEP_FILLED: &str = "step-filled";
    #[doc(alias = "step-in")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "step-in", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "step-in", feature = "icon-development-kit"))]
    /// Icon name constant for the `step-in` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/step-in-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STEP_IN: &str = "step-in";
    #[doc(alias = "step-out")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "step-out", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "step-out", feature = "icon-development-kit"))]
    /// Icon name constant for the `step-out` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/step-out-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STEP_OUT: &str = "step-out";
    #[doc(alias = "step-over")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "step-over", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "step-over", feature = "icon-development-kit"))]
    /// Icon name constant for the `step-over` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/step-over-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STEP_OVER: &str = "step-over";
    #[doc(alias = "step-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "step-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "step-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `step-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/step-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STEP_REGULAR: &str = "step-regular";
    #[doc(alias = "steps")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "steps", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "steps", feature = "icon-development-kit"))]
    /// Icon name constant for the `steps` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/steps-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STEPS: &str = "steps";
    #[doc(alias = "steps-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "steps-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "steps-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `steps-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/steps-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STEPS_FILLED: &str = "steps-filled";
    #[doc(alias = "steps-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "steps-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "steps-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `steps-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/steps-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STEPS_REGULAR: &str = "steps-regular";
    #[doc(alias = "stop")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stop", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "stop", feature = "icon-development-kit"))]
    /// Icon name constant for the `stop` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/stop-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STOP: &str = "stop";
    #[doc(alias = "stop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "stop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `stop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/stop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STOP_FILLED: &str = "stop-filled";
    #[doc(alias = "stop-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stop-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "stop-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `stop-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/stop-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STOP_LARGE: &str = "stop-large";
    #[doc(alias = "stop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stop-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "stop-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `stop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/stop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STOP_REGULAR: &str = "stop-regular";
    #[doc(alias = "stop-sign")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stop-sign", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "stop-sign", feature = "icon-development-kit"))]
    /// Icon name constant for the `stop-sign` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/stop-sign-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STOP_SIGN: &str = "stop-sign";
    #[doc(alias = "stop-sign-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stop-sign-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "stop-sign-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `stop-sign-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/stop-sign-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STOP_SIGN_LARGE: &str = "stop-sign-large";
    #[doc(alias = "stopwatch")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "stopwatch", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "stopwatch", feature = "icon-development-kit"))]
    /// Icon name constant for the `stopwatch` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/stopwatch-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STOPWATCH: &str = "stopwatch";
    #[doc(alias = "store-microsoft-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "store-microsoft-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "store-microsoft-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `store-microsoft-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/store-microsoft-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STORE_MICROSOFT_FILLED: &str = "store-microsoft-filled";
    #[doc(alias = "store-microsoft-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "store-microsoft-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "store-microsoft-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `store-microsoft-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/store-microsoft-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STORE_MICROSOFT_REGULAR: &str = "store-microsoft-regular";
    #[doc(alias = "storm")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "storm", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "storm", feature = "icon-development-kit"))]
    /// Icon name constant for the `storm` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/storm-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STORM: &str = "storm";
    #[doc(alias = "storm-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "storm-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "storm-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `storm-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/storm-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STORM_OUTLINE: &str = "storm-outline";
    #[doc(alias = "strong-language")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "strong-language", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "strong-language", feature = "icon-development-kit"))]
    /// Icon name constant for the `strong-language` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/strong-language-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STRONG_LANGUAGE: &str = "strong-language";
    #[doc(alias = "strong-language-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "strong-language-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "strong-language-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `strong-language-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/strong-language-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const STRONG_LANGUAGE_NONE: &str = "strong-language-none";
    #[doc(alias = "subtitles")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "subtitles", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "subtitles", feature = "icon-development-kit"))]
    /// Icon name constant for the `subtitles` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/subtitles-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTITLES: &str = "subtitles";
    #[doc(alias = "subtitles-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "subtitles-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "subtitles-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `subtitles-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtitles-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTITLES_FILLED: &str = "subtitles-filled";
    #[doc(alias = "subtitles-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "subtitles-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "subtitles-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `subtitles-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtitles-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTITLES_REGULAR: &str = "subtitles-regular";
    #[doc(alias = "subtract-circle-arrow-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "subtract-circle-arrow-back-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "subtract-circle-arrow-back-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `subtract-circle-arrow-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-circle-arrow-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_CIRCLE_ARROW_BACK_FILLED: &str = "subtract-circle-arrow-back-filled";
    #[doc(alias = "subtract-circle-arrow-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "subtract-circle-arrow-back-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "subtract-circle-arrow-back-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `subtract-circle-arrow-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-circle-arrow-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_CIRCLE_ARROW_BACK_REGULAR: &str = "subtract-circle-arrow-back-regular";
    #[doc(alias = "subtract-circle-arrow-forward-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "subtract-circle-arrow-forward-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "subtract-circle-arrow-forward-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `subtract-circle-arrow-forward-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-circle-arrow-forward-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_CIRCLE_ARROW_FORWARD_FILLED: &str = "subtract-circle-arrow-forward-filled";
    #[doc(alias = "subtract-circle-arrow-forward-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "subtract-circle-arrow-forward-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "subtract-circle-arrow-forward-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `subtract-circle-arrow-forward-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-circle-arrow-forward-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_CIRCLE_ARROW_FORWARD_REGULAR: &str = "subtract-circle-arrow-forward-regular";
    #[doc(alias = "subtract-circle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "subtract-circle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "subtract-circle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `subtract-circle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-circle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_CIRCLE_FILLED: &str = "subtract-circle-filled";
    #[doc(alias = "subtract-circle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "subtract-circle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "subtract-circle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `subtract-circle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-circle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_CIRCLE_REGULAR: &str = "subtract-circle-regular";
    #[doc(alias = "subtract-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "subtract-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "subtract-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `subtract-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_FILLED: &str = "subtract-filled";
    #[doc(alias = "subtract-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "subtract-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "subtract-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `subtract-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_REGULAR: &str = "subtract-regular";
    #[doc(alias = "subtract-square-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "subtract-square-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "subtract-square-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `subtract-square-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-square-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_SQUARE_FILLED: &str = "subtract-square-filled";
    #[doc(alias = "subtract-square-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "subtract-square-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "subtract-square-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `subtract-square-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-square-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_SQUARE_MULTIPLE_FILLED: &str = "subtract-square-multiple-filled";
    #[doc(alias = "subtract-square-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "subtract-square-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "subtract-square-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `subtract-square-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-square-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_SQUARE_MULTIPLE_REGULAR: &str = "subtract-square-multiple-regular";
    #[doc(alias = "subtract-square-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "subtract-square-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "subtract-square-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `subtract-square-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/subtract-square-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBTRACT_SQUARE_REGULAR: &str = "subtract-square-regular";
    #[doc(alias = "subway")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "subway", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "subway", feature = "icon-development-kit"))]
    /// Icon name constant for the `subway` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/subway-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUBWAY: &str = "subway";
    #[doc(alias = "success")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "success", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "success", feature = "icon-development-kit"))]
    /// Icon name constant for the `success` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/success-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUCCESS: &str = "success";
    #[doc(alias = "sun")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sun", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sun", feature = "icon-development-kit"))]
    /// Icon name constant for the `sun` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sun-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUN: &str = "sun";
    #[doc(alias = "sun-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sun-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sun-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `sun-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sun-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUN_ALT: &str = "sun-alt";
    #[doc(alias = "sun-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sun-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "sun-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `sun-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/sun-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SUN_OUTLINE: &str = "sun-outline";
    #[doc(alias = "symbols-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "symbols-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "symbols-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `symbols-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/symbols-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SYMBOLS_FILLED: &str = "symbols-filled";
    #[doc(alias = "symbols-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "symbols-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "symbols-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `symbols-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/symbols-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SYMBOLS_REGULAR: &str = "symbols-regular";
    #[doc(alias = "sync-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sync-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sync-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sync-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sync-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SYNC_OFF_FILLED: &str = "sync-off-filled";
    #[doc(alias = "sync-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "sync-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "sync-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `sync-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/sync-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const SYNC_OFF_REGULAR: &str = "sync-off-regular";
    #[doc(alias = "tab")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tab", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tab", feature = "icon-development-kit"))]
    /// Icon name constant for the `tab` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tab-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB: &str = "tab";
    #[doc(alias = "tab-desktop-arrow-clockwise-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "tab-desktop-arrow-clockwise-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "tab-desktop-arrow-clockwise-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `tab-desktop-arrow-clockwise-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-desktop-arrow-clockwise-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_DESKTOP_ARROW_CLOCKWISE_FILLED: &str = "tab-desktop-arrow-clockwise-filled";
    #[doc(alias = "tab-desktop-arrow-clockwise-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "tab-desktop-arrow-clockwise-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "tab-desktop-arrow-clockwise-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `tab-desktop-arrow-clockwise-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-desktop-arrow-clockwise-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_DESKTOP_ARROW_CLOCKWISE_REGULAR: &str = "tab-desktop-arrow-clockwise-regular";
    #[doc(alias = "tab-desktop-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tab-desktop-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tab-desktop-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tab-desktop-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-desktop-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_DESKTOP_FILLED: &str = "tab-desktop-filled";
    #[doc(alias = "tab-desktop-image-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "tab-desktop-image-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "tab-desktop-image-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `tab-desktop-image-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-desktop-image-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_DESKTOP_IMAGE_FILLED: &str = "tab-desktop-image-filled";
    #[doc(alias = "tab-desktop-image-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "tab-desktop-image-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "tab-desktop-image-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `tab-desktop-image-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-desktop-image-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_DESKTOP_IMAGE_REGULAR: &str = "tab-desktop-image-regular";
    #[doc(alias = "tab-desktop-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tab-desktop-link-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tab-desktop-link-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tab-desktop-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-desktop-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_DESKTOP_LINK_FILLED: &str = "tab-desktop-link-filled";
    #[doc(alias = "tab-desktop-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "tab-desktop-link-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "tab-desktop-link-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `tab-desktop-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-desktop-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_DESKTOP_LINK_REGULAR: &str = "tab-desktop-link-regular";
    #[doc(alias = "tab-desktop-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tab-desktop-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tab-desktop-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tab-desktop-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-desktop-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_DESKTOP_REGULAR: &str = "tab-desktop-regular";
    #[doc(alias = "tab-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tab-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tab-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tab-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_FILLED: &str = "tab-filled";
    #[doc(alias = "tab-in-private-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tab-in-private-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tab-in-private-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tab-in-private-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-in-private-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_IN_PRIVATE_FILLED: &str = "tab-in-private-filled";
    #[doc(alias = "tab-in-private-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tab-in-private-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tab-in-private-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tab-in-private-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-in-private-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_IN_PRIVATE_REGULAR: &str = "tab-in-private-regular";
    #[doc(alias = "tab-new")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tab-new", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tab-new", feature = "icon-development-kit"))]
    /// Icon name constant for the `tab-new` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tab-new-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_NEW: &str = "tab-new";
    #[doc(alias = "tab-new-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tab-new-filled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tab-new-filled", feature = "icon-development-kit"))]
    /// Icon name constant for the `tab-new-filled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tab-new-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_NEW_FILLED: &str = "tab-new-filled";
    #[doc(alias = "tab-new-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tab-new-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tab-new-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `tab-new-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tab-new-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_NEW_LARGE: &str = "tab-new-large";
    #[doc(alias = "tab-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tab-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tab-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tab-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tab-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAB_REGULAR: &str = "tab-regular";
    #[doc(alias = "table")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "table", feature = "icon-development-kit"))]
    /// Icon name constant for the `table` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/table-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE: &str = "table";
    #[doc(alias = "table-add-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-add-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-add-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-add-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-add-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_ADD_FILLED: &str = "table-add-filled";
    #[doc(alias = "table-add-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-add-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-add-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-add-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-add-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_ADD_REGULAR: &str = "table-add-regular";
    #[doc(alias = "table-bottom-row-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-bottom-row-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-bottom-row-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-bottom-row-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-bottom-row-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_BOTTOM_ROW_FILLED: &str = "table-bottom-row-filled";
    #[doc(alias = "table-bottom-row-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-bottom-row-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-bottom-row-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-bottom-row-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-bottom-row-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_BOTTOM_ROW_REGULAR: &str = "table-bottom-row-regular";
    #[doc(alias = "table-calculator-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-calculator-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-calculator-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-calculator-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-calculator-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_CALCULATOR_FILLED: &str = "table-calculator-filled";
    #[doc(alias = "table-calculator-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-calculator-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-calculator-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-calculator-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-calculator-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_CALCULATOR_REGULAR: &str = "table-calculator-regular";
    #[doc(alias = "table-cell-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-cell-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-cell-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-cell-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-cell-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_CELL_EDIT_FILLED: &str = "table-cell-edit-filled";
    #[doc(alias = "table-cell-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-cell-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-cell-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-cell-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-cell-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_CELL_EDIT_REGULAR: &str = "table-cell-edit-regular";
    #[doc(alias = "table-cells-merge-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-cells-merge-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-cells-merge-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-cells-merge-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-cells-merge-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_CELLS_MERGE_FILLED: &str = "table-cells-merge-filled";
    #[doc(alias = "table-cells-merge-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-cells-merge-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-cells-merge-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-cells-merge-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-cells-merge-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_CELLS_MERGE_REGULAR: &str = "table-cells-merge-regular";
    #[doc(alias = "table-cells-split-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-cells-split-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-cells-split-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-cells-split-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-cells-split-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_CELLS_SPLIT_FILLED: &str = "table-cells-split-filled";
    #[doc(alias = "table-cells-split-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-cells-split-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-cells-split-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-cells-split-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-cells-split-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_CELLS_SPLIT_REGULAR: &str = "table-cells-split-regular";
    #[doc(alias = "table-delete-column-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-delete-column-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-delete-column-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-delete-column-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-delete-column-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_DELETE_COLUMN_FILLED: &str = "table-delete-column-filled";
    #[doc(alias = "table-delete-column-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-delete-column-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-delete-column-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-delete-column-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-delete-column-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_DELETE_COLUMN_REGULAR: &str = "table-delete-column-regular";
    #[doc(alias = "table-delete-row-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-delete-row-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-delete-row-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-delete-row-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-delete-row-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_DELETE_ROW_FILLED: &str = "table-delete-row-filled";
    #[doc(alias = "table-delete-row-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-delete-row-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-delete-row-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-delete-row-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-delete-row-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_DELETE_ROW_REGULAR: &str = "table-delete-row-regular";
    #[doc(alias = "table-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_DISMISS_FILLED: &str = "table-dismiss-filled";
    #[doc(alias = "table-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_DISMISS_REGULAR: &str = "table-dismiss-regular";
    #[doc(alias = "table-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_EDIT_FILLED: &str = "table-edit-filled";
    #[doc(alias = "table-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_EDIT_REGULAR: &str = "table-edit-regular";
    #[doc(alias = "table-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_FILLED: &str = "table-filled";
    #[doc(alias = "table-freeze-column-and-row-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-freeze-column-and-row-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-freeze-column-and-row-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-freeze-column-and-row-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-freeze-column-and-row-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_FREEZE_COLUMN_AND_ROW_FILLED: &str = "table-freeze-column-and-row-filled";
    #[doc(alias = "table-freeze-column-and-row-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-freeze-column-and-row-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-freeze-column-and-row-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-freeze-column-and-row-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-freeze-column-and-row-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_FREEZE_COLUMN_AND_ROW_REGULAR: &str = "table-freeze-column-and-row-regular";
    #[doc(alias = "table-freeze-column-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-freeze-column-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-freeze-column-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-freeze-column-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-freeze-column-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_FREEZE_COLUMN_FILLED: &str = "table-freeze-column-filled";
    #[doc(alias = "table-freeze-column-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-freeze-column-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-freeze-column-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-freeze-column-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-freeze-column-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_FREEZE_COLUMN_REGULAR: &str = "table-freeze-column-regular";
    #[doc(alias = "table-freeze-row-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-freeze-row-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-freeze-row-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-freeze-row-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-freeze-row-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_FREEZE_ROW_FILLED: &str = "table-freeze-row-filled";
    #[doc(alias = "table-freeze-row-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-freeze-row-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-freeze-row-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-freeze-row-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-freeze-row-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_FREEZE_ROW_REGULAR: &str = "table-freeze-row-regular";
    #[doc(alias = "table-insert-column-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-insert-column-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-insert-column-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-insert-column-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-insert-column-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_INSERT_COLUMN_FILLED: &str = "table-insert-column-filled";
    #[doc(alias = "table-insert-column-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-insert-column-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-insert-column-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-insert-column-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-insert-column-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_INSERT_COLUMN_REGULAR: &str = "table-insert-column-regular";
    #[doc(alias = "table-insert-row-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-insert-row-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-insert-row-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-insert-row-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-insert-row-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_INSERT_ROW_FILLED: &str = "table-insert-row-filled";
    #[doc(alias = "table-insert-row-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-insert-row-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-insert-row-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-insert-row-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-insert-row-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_INSERT_ROW_REGULAR: &str = "table-insert-row-regular";
    #[doc(alias = "table-lightning-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-lightning-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-lightning-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-lightning-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-lightning-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_LIGHTNING_FILLED: &str = "table-lightning-filled";
    #[doc(alias = "table-lightning-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-lightning-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-lightning-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-lightning-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-lightning-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_LIGHTNING_REGULAR: &str = "table-lightning-regular";
    #[doc(alias = "table-link-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-link-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-link-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-link-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-link-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_LINK_FILLED: &str = "table-link-filled";
    #[doc(alias = "table-link-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-link-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-link-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-link-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-link-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_LINK_REGULAR: &str = "table-link-regular";
    #[doc(alias = "table-lock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-lock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-lock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-lock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-lock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_LOCK_FILLED: &str = "table-lock-filled";
    #[doc(alias = "table-lock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-lock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-lock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-lock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-lock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_LOCK_REGULAR: &str = "table-lock-regular";
    #[doc(alias = "table-move-above-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-move-above-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-move-above-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-move-above-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-move-above-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_MOVE_ABOVE_FILLED: &str = "table-move-above-filled";
    #[doc(alias = "table-move-above-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-move-above-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-move-above-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-move-above-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-move-above-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_MOVE_ABOVE_REGULAR: &str = "table-move-above-regular";
    #[doc(alias = "table-move-below-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-move-below-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-move-below-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-move-below-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-move-below-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_MOVE_BELOW_FILLED: &str = "table-move-below-filled";
    #[doc(alias = "table-move-below-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-move-below-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-move-below-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-move-below-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-move-below-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_MOVE_BELOW_REGULAR: &str = "table-move-below-regular";
    #[doc(alias = "table-move-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-move-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-move-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-move-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-move-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_MOVE_LEFT_FILLED: &str = "table-move-left-filled";
    #[doc(alias = "table-move-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-move-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-move-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-move-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-move-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_MOVE_LEFT_REGULAR: &str = "table-move-left-regular";
    #[doc(alias = "table-move-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-move-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-move-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-move-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-move-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_MOVE_RIGHT_FILLED: &str = "table-move-right-filled";
    #[doc(alias = "table-move-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-move-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-move-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-move-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-move-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_MOVE_RIGHT_REGULAR: &str = "table-move-right-regular";
    #[doc(alias = "table-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_REGULAR: &str = "table-regular";
    #[doc(alias = "table-resize-column-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-resize-column-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-resize-column-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-resize-column-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-resize-column-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_RESIZE_COLUMN_FILLED: &str = "table-resize-column-filled";
    #[doc(alias = "table-resize-column-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-resize-column-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-resize-column-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-resize-column-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-resize-column-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_RESIZE_COLUMN_REGULAR: &str = "table-resize-column-regular";
    #[doc(alias = "table-resize-row-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-resize-row-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-resize-row-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-resize-row-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-resize-row-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_RESIZE_ROW_FILLED: &str = "table-resize-row-filled";
    #[doc(alias = "table-resize-row-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-resize-row-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-resize-row-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-resize-row-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-resize-row-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_RESIZE_ROW_REGULAR: &str = "table-resize-row-regular";
    #[doc(alias = "table-settings-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-settings-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-settings-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-settings-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-settings-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SETTINGS_FILLED: &str = "table-settings-filled";
    #[doc(alias = "table-settings-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-settings-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-settings-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-settings-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-settings-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SETTINGS_REGULAR: &str = "table-settings-regular";
    #[doc(alias = "table-simple-checkmark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-simple-checkmark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-simple-checkmark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-simple-checkmark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-simple-checkmark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SIMPLE_CHECKMARK_FILLED: &str = "table-simple-checkmark-filled";
    #[doc(alias = "table-simple-checkmark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-simple-checkmark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-simple-checkmark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-simple-checkmark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-simple-checkmark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SIMPLE_CHECKMARK_REGULAR: &str = "table-simple-checkmark-regular";
    #[doc(alias = "table-simple-exclude-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-simple-exclude-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-simple-exclude-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-simple-exclude-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-simple-exclude-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SIMPLE_EXCLUDE_FILLED: &str = "table-simple-exclude-filled";
    #[doc(alias = "table-simple-exclude-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-simple-exclude-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-simple-exclude-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-simple-exclude-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-simple-exclude-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SIMPLE_EXCLUDE_REGULAR: &str = "table-simple-exclude-regular";
    #[doc(alias = "table-simple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-simple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-simple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-simple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-simple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SIMPLE_FILLED: &str = "table-simple-filled";
    #[doc(alias = "table-simple-include-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-simple-include-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-simple-include-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-simple-include-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-simple-include-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SIMPLE_INCLUDE_FILLED: &str = "table-simple-include-filled";
    #[doc(alias = "table-simple-include-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-simple-include-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-simple-include-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-simple-include-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-simple-include-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SIMPLE_INCLUDE_REGULAR: &str = "table-simple-include-regular";
    #[doc(alias = "table-simple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-simple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-simple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-simple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-simple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SIMPLE_REGULAR: &str = "table-simple-regular";
    #[doc(alias = "table-stack-above-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-stack-above-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-stack-above-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-stack-above-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-stack-above-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_STACK_ABOVE_FILLED: &str = "table-stack-above-filled";
    #[doc(alias = "table-stack-above-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-stack-above-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-stack-above-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-stack-above-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-stack-above-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_STACK_ABOVE_REGULAR: &str = "table-stack-above-regular";
    #[doc(alias = "table-stack-below-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-stack-below-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-stack-below-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-stack-below-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-stack-below-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_STACK_BELOW_FILLED: &str = "table-stack-below-filled";
    #[doc(alias = "table-stack-below-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-stack-below-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-stack-below-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-stack-below-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-stack-below-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_STACK_BELOW_REGULAR: &str = "table-stack-below-regular";
    #[doc(alias = "table-stack-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-stack-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-stack-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-stack-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-stack-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_STACK_LEFT_FILLED: &str = "table-stack-left-filled";
    #[doc(alias = "table-stack-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-stack-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-stack-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-stack-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-stack-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_STACK_LEFT_REGULAR: &str = "table-stack-left-regular";
    #[doc(alias = "table-stack-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-stack-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-stack-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-stack-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-stack-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_STACK_RIGHT_FILLED: &str = "table-stack-right-filled";
    #[doc(alias = "table-stack-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "table-stack-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "table-stack-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `table-stack-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-stack-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_STACK_RIGHT_REGULAR: &str = "table-stack-right-regular";
    #[doc(alias = "table-switch-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-switch-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-switch-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-switch-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-switch-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SWITCH_FILLED: &str = "table-switch-filled";
    #[doc(alias = "table-switch-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "table-switch-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "table-switch-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `table-switch-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/table-switch-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLE_SWITCH_REGULAR: &str = "table-switch-regular";
    #[doc(alias = "tablet")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tablet", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tablet", feature = "icon-development-kit"))]
    /// Icon name constant for the `tablet` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tablet-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLET: &str = "tablet";
    #[doc(alias = "tablet-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tablet-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tablet-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tablet-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tablet-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLET_FILLED: &str = "tablet-filled";
    #[doc(alias = "tablet-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tablet-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tablet-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tablet-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tablet-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABLET_REGULAR: &str = "tablet-regular";
    #[doc(alias = "tabs-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tabs-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tabs-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tabs-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tabs-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABS_FILLED: &str = "tabs-filled";
    #[doc(alias = "tabs-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tabs-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tabs-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tabs-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tabs-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABS_REGULAR: &str = "tabs-regular";
    #[doc(alias = "tabs-stack")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tabs-stack", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tabs-stack", feature = "icon-development-kit"))]
    /// Icon name constant for the `tabs-stack` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tabs-stack-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TABS_STACK: &str = "tabs-stack";
    #[doc(alias = "tag")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tag", feature = "icon-development-kit"))]
    /// Icon name constant for the `tag` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tag-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG: &str = "tag";
    #[doc(alias = "tag-dismiss-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-dismiss-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tag-dismiss-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tag-dismiss-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-dismiss-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_DISMISS_FILLED: &str = "tag-dismiss-filled";
    #[doc(alias = "tag-dismiss-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-dismiss-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tag-dismiss-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tag-dismiss-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-dismiss-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_DISMISS_REGULAR: &str = "tag-dismiss-regular";
    #[doc(alias = "tag-error-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-error-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tag-error-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tag-error-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-error-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_ERROR_FILLED: &str = "tag-error-filled";
    #[doc(alias = "tag-error-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-error-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tag-error-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tag-error-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-error-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_ERROR_REGULAR: &str = "tag-error-regular";
    #[doc(alias = "tag-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tag-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tag-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_FILLED: &str = "tag-filled";
    #[doc(alias = "tag-lock-accent-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-lock-accent-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tag-lock-accent-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tag-lock-accent-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-lock-accent-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_LOCK_ACCENT_FILLED: &str = "tag-lock-accent-filled";
    #[doc(alias = "tag-lock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-lock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tag-lock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tag-lock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-lock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_LOCK_FILLED: &str = "tag-lock-filled";
    #[doc(alias = "tag-lock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-lock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tag-lock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tag-lock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-lock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_LOCK_REGULAR: &str = "tag-lock-regular";
    #[doc(alias = "tag-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tag-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tag-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_MULTIPLE_FILLED: &str = "tag-multiple-filled";
    #[doc(alias = "tag-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tag-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tag-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_MULTIPLE_REGULAR: &str = "tag-multiple-regular";
    #[doc(alias = "tag-outline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-outline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tag-outline", feature = "icon-development-kit"))]
    /// Icon name constant for the `tag-outline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tag-outline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_OUTLINE: &str = "tag-outline";
    #[doc(alias = "tag-outline-add")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-outline-add", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tag-outline-add", feature = "icon-development-kit"))]
    /// Icon name constant for the `tag-outline-add` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tag-outline-add-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_OUTLINE_ADD: &str = "tag-outline-add";
    #[doc(alias = "tag-question-mark-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "tag-question-mark-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "tag-question-mark-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `tag-question-mark-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-question-mark-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_QUESTION_MARK_FILLED: &str = "tag-question-mark-filled";
    #[doc(alias = "tag-question-mark-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "tag-question-mark-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "tag-question-mark-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `tag-question-mark-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-question-mark-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_QUESTION_MARK_REGULAR: &str = "tag-question-mark-regular";
    #[doc(alias = "tag-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tag-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tag-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tag-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tag-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAG_REGULAR: &str = "tag-regular";
    #[doc(alias = "tape")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tape", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tape", feature = "icon-development-kit"))]
    /// Icon name constant for the `tape` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tape-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TAPE: &str = "tape";
    #[doc(alias = "target-arrow-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "target-arrow-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "target-arrow-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `target-arrow-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/target-arrow-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TARGET_ARROW_FILLED: &str = "target-arrow-filled";
    #[doc(alias = "target-arrow-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "target-arrow-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "target-arrow-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `target-arrow-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/target-arrow-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TARGET_ARROW_REGULAR: &str = "target-arrow-regular";
    #[doc(alias = "target-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "target-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "target-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `target-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/target-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TARGET_EDIT_FILLED: &str = "target-edit-filled";
    #[doc(alias = "target-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "target-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "target-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `target-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/target-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TARGET_EDIT_REGULAR: &str = "target-edit-regular";
    #[doc(alias = "target-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "target-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "target-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `target-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/target-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TARGET_FILLED: &str = "target-filled";
    #[doc(alias = "target-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "target-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "target-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `target-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/target-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TARGET_REGULAR: &str = "target-regular";
    #[doc(alias = "task")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "task", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "task", feature = "icon-development-kit"))]
    /// Icon name constant for the `task` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/task-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TASK: &str = "task";
    #[doc(alias = "task-assigned")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "task-assigned", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "task-assigned", feature = "icon-development-kit"))]
    /// Icon name constant for the `task-assigned` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/task-assigned-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TASK_ASSIGNED: &str = "task-assigned";
    #[doc(alias = "task-assigned-to")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "task-assigned-to", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "task-assigned-to", feature = "icon-development-kit"))]
    /// Icon name constant for the `task-assigned-to` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/task-assigned-to-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TASK_ASSIGNED_TO: &str = "task-assigned-to";
    #[doc(alias = "task-recurring")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "task-recurring", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "task-recurring", feature = "icon-development-kit"))]
    /// Icon name constant for the `task-recurring` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/task-recurring-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TASK_RECURRING: &str = "task-recurring";
    #[doc(alias = "tea")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tea", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tea", feature = "icon-development-kit"))]
    /// Icon name constant for the `tea` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tea-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEA: &str = "tea";
    #[doc(alias = "temperature-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "temperature-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "temperature-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `temperature-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/temperature-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEMPERATURE_FILLED: &str = "temperature-filled";
    #[doc(alias = "temperature-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "temperature-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "temperature-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `temperature-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/temperature-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEMPERATURE_REGULAR: &str = "temperature-regular";
    #[doc(alias = "tennis")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tennis", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tennis", feature = "icon-development-kit"))]
    /// Icon name constant for the `tennis` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tennis-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TENNIS: &str = "tennis";
    #[doc(alias = "tent-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tent-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tent-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tent-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tent-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TENT_FILLED: &str = "tent-filled";
    #[doc(alias = "tent-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tent-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tent-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tent-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tent-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TENT_REGULAR: &str = "tent-regular";
    #[doc(alias = "terminal")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "terminal", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "terminal", feature = "icon-development-kit"))]
    /// Icon name constant for the `terminal` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/terminal-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TERMINAL: &str = "terminal";
    #[doc(alias = "test")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "test", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "test", feature = "icon-development-kit"))]
    /// Icon name constant for the `test` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/test-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEST: &str = "test";
    #[doc(alias = "test-pass")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "test-pass", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "test-pass", feature = "icon-development-kit"))]
    /// Icon name constant for the `test-pass` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/test-pass-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEST_PASS: &str = "test-pass";
    #[doc(alias = "tetris-app-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tetris-app-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tetris-app-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tetris-app-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tetris-app-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TETRIS_APP_FILLED: &str = "tetris-app-filled";
    #[doc(alias = "tetris-app-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tetris-app-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tetris-app-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tetris-app-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tetris-app-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TETRIS_APP_REGULAR: &str = "tetris-app-regular";
    #[doc(alias = "text")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text", feature = "icon-development-kit"))]
    /// Icon name constant for the `text` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT: &str = "text";
    #[doc(alias = "text-align-center-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-center-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-center-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-center-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-center-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_CENTER_FILLED: &str = "text-align-center-filled";
    #[doc(alias = "text-align-center-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-center-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-center-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-center-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-center-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_CENTER_REGULAR: &str = "text-align-center-regular";
    #[doc(alias = "text-align-center-rotate-270-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-center-rotate-270-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-center-rotate-270-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-center-rotate-270-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-center-rotate-270-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_CENTER_ROTATE_270_FILLED: &str = "text-align-center-rotate-270-filled";
    #[doc(alias = "text-align-center-rotate-270-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-center-rotate-270-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-center-rotate-270-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-center-rotate-270-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-center-rotate-270-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_CENTER_ROTATE_270_REGULAR: &str = "text-align-center-rotate-270-regular";
    #[doc(alias = "text-align-center-rotate-90-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-center-rotate-90-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-center-rotate-90-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-center-rotate-90-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-center-rotate-90-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_CENTER_ROTATE_90_FILLED: &str = "text-align-center-rotate-90-filled";
    #[doc(alias = "text-align-center-rotate-90-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-center-rotate-90-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-center-rotate-90-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-center-rotate-90-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-center-rotate-90-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_CENTER_ROTATE_90_REGULAR: &str = "text-align-center-rotate-90-regular";
    #[doc(alias = "text-align-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-align-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-align-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-align-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_LEFT_FILLED: &str = "text-align-left-filled";
    #[doc(alias = "text-align-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-align-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-align-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-align-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_LEFT_REGULAR: &str = "text-align-left-regular";
    #[doc(alias = "text-align-left-rotate-270-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-left-rotate-270-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-left-rotate-270-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-left-rotate-270-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-left-rotate-270-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_LEFT_ROTATE_270_FILLED: &str = "text-align-left-rotate-270-filled";
    #[doc(alias = "text-align-left-rotate-270-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-left-rotate-270-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-left-rotate-270-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-left-rotate-270-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-left-rotate-270-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_LEFT_ROTATE_270_REGULAR: &str = "text-align-left-rotate-270-regular";
    #[doc(alias = "text-align-left-rotate-90-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-left-rotate-90-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-left-rotate-90-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-left-rotate-90-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-left-rotate-90-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_LEFT_ROTATE_90_FILLED: &str = "text-align-left-rotate-90-filled";
    #[doc(alias = "text-align-left-rotate-90-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-left-rotate-90-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-left-rotate-90-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-left-rotate-90-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-left-rotate-90-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_LEFT_ROTATE_90_REGULAR: &str = "text-align-left-rotate-90-regular";
    #[doc(alias = "text-align-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-align-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-align-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-align-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_RIGHT_FILLED: &str = "text-align-right-filled";
    #[doc(alias = "text-align-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_RIGHT_REGULAR: &str = "text-align-right-regular";
    #[doc(alias = "text-align-right-rotate-270-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-right-rotate-270-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-right-rotate-270-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-right-rotate-270-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-right-rotate-270-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_RIGHT_ROTATE_270_FILLED: &str = "text-align-right-rotate-270-filled";
    #[doc(alias = "text-align-right-rotate-270-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-right-rotate-270-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-right-rotate-270-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-right-rotate-270-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-right-rotate-270-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_RIGHT_ROTATE_270_REGULAR: &str = "text-align-right-rotate-270-regular";
    #[doc(alias = "text-align-right-rotate-90-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-right-rotate-90-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-right-rotate-90-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-right-rotate-90-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-right-rotate-90-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_RIGHT_ROTATE_90_FILLED: &str = "text-align-right-rotate-90-filled";
    #[doc(alias = "text-align-right-rotate-90-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-align-right-rotate-90-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-align-right-rotate-90-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-align-right-rotate-90-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-align-right-rotate-90-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALIGN_RIGHT_ROTATE_90_REGULAR: &str = "text-align-right-rotate-90-regular";
    #[doc(alias = "text-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ALT: &str = "text-alt";
    #[doc(alias = "text-bold")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-bold", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-bold", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-bold` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-bold-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BOLD: &str = "text-bold";
    #[doc(alias = "text-bold-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-bold-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-bold-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-bold-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bold-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BOLD_FILLED: &str = "text-bold-filled";
    #[doc(alias = "text-bold-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-bold-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-bold-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-bold-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bold-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BOLD_REGULAR: &str = "text-bold-regular";
    #[doc(alias = "text-bullet-list-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-bullet-list-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-bullet-list-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-bullet-list-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bullet-list-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BULLET_LIST_FILLED: &str = "text-bullet-list-filled";
    #[doc(alias = "text-bullet-list-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-bullet-list-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-bullet-list-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-bullet-list-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bullet-list-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BULLET_LIST_REGULAR: &str = "text-bullet-list-regular";
    #[doc(alias = "text-bullet-list-square-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-bullet-list-square-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-bullet-list-square-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-bullet-list-square-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bullet-list-square-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BULLET_LIST_SQUARE_FILLED: &str = "text-bullet-list-square-filled";
    #[doc(alias = "text-bullet-list-square-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-bullet-list-square-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-bullet-list-square-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-bullet-list-square-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bullet-list-square-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BULLET_LIST_SQUARE_REGULAR: &str = "text-bullet-list-square-regular";
    #[doc(alias = "text-bullet-list-square-sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-bullet-list-square-sparkle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-bullet-list-square-sparkle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-bullet-list-square-sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bullet-list-square-sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BULLET_LIST_SQUARE_SPARKLE_FILLED: &str =
        "text-bullet-list-square-sparkle-filled";
    #[doc(alias = "text-bullet-list-square-sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-bullet-list-square-sparkle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-bullet-list-square-sparkle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-bullet-list-square-sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bullet-list-square-sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BULLET_LIST_SQUARE_SPARKLE_REGULAR: &str =
        "text-bullet-list-square-sparkle-regular";
    #[doc(alias = "text-bullet-list-square-warning-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-bullet-list-square-warning-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-bullet-list-square-warning-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-bullet-list-square-warning-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bullet-list-square-warning-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BULLET_LIST_SQUARE_WARNING_FILLED: &str =
        "text-bullet-list-square-warning-filled";
    #[doc(alias = "text-bullet-list-square-warning-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-bullet-list-square-warning-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-bullet-list-square-warning-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-bullet-list-square-warning-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bullet-list-square-warning-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BULLET_LIST_SQUARE_WARNING_REGULAR: &str =
        "text-bullet-list-square-warning-regular";
    #[doc(alias = "text-bullet-list-tree-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-bullet-list-tree-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-bullet-list-tree-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-bullet-list-tree-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bullet-list-tree-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BULLET_LIST_TREE_FILLED: &str = "text-bullet-list-tree-filled";
    #[doc(alias = "text-bullet-list-tree-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-bullet-list-tree-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-bullet-list-tree-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-bullet-list-tree-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-bullet-list-tree-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_BULLET_LIST_TREE_REGULAR: &str = "text-bullet-list-tree-regular";
    #[doc(alias = "text-case-lowercase-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-case-lowercase-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-case-lowercase-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-case-lowercase-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-case-lowercase-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_CASE_LOWERCASE_FILLED: &str = "text-case-lowercase-filled";
    #[doc(alias = "text-case-lowercase-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-case-lowercase-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-case-lowercase-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-case-lowercase-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-case-lowercase-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_CASE_LOWERCASE_REGULAR: &str = "text-case-lowercase-regular";
    #[doc(alias = "text-case-title-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-case-title-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-case-title-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-case-title-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-case-title-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_CASE_TITLE_FILLED: &str = "text-case-title-filled";
    #[doc(alias = "text-case-title-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-case-title-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-case-title-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-case-title-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-case-title-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_CASE_TITLE_REGULAR: &str = "text-case-title-regular";
    #[doc(alias = "text-case-uppercase-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-case-uppercase-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-case-uppercase-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-case-uppercase-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-case-uppercase-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_CASE_UPPERCASE_FILLED: &str = "text-case-uppercase-filled";
    #[doc(alias = "text-case-uppercase-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-case-uppercase-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-case-uppercase-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-case-uppercase-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-case-uppercase-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_CASE_UPPERCASE_REGULAR: &str = "text-case-uppercase-regular";
    #[doc(alias = "text-change-case-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-change-case-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-change-case-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-change-case-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-change-case-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_CHANGE_CASE_FILLED: &str = "text-change-case-filled";
    #[doc(alias = "text-change-case-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-change-case-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-change-case-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-change-case-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-change-case-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_CHANGE_CASE_REGULAR: &str = "text-change-case-regular";
    #[doc(alias = "text-clear-formatting-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-clear-formatting-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-clear-formatting-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-clear-formatting-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-clear-formatting-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_CLEAR_FORMATTING_FILLED: &str = "text-clear-formatting-filled";
    #[doc(alias = "text-clear-formatting-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-clear-formatting-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-clear-formatting-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-clear-formatting-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-clear-formatting-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_CLEAR_FORMATTING_REGULAR: &str = "text-clear-formatting-regular";
    #[doc(alias = "text-color-accent-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-color-accent-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-color-accent-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-color-accent-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-color-accent-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_COLOR_ACCENT_FILLED: &str = "text-color-accent-filled";
    #[doc(alias = "text-color-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-color-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-color-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-color-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-color-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_COLOR_FILLED: &str = "text-color-filled";
    #[doc(alias = "text-color-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-color-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-color-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-color-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-color-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_COLOR_REGULAR: &str = "text-color-regular";
    #[doc(alias = "text-density-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-density-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-density-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-density-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-density-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_DENSITY_FILLED: &str = "text-density-filled";
    #[doc(alias = "text-density-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-density-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-density-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-density-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-density-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_DENSITY_REGULAR: &str = "text-density-regular";
    #[doc(alias = "text-direction-ltr")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-direction-ltr", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-direction-ltr", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-direction-ltr` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-direction-ltr-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_DIRECTION_LTR: &str = "text-direction-ltr";
    #[doc(alias = "text-direction-rtl")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-direction-rtl", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-direction-rtl", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-direction-rtl` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-direction-rtl-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_DIRECTION_RTL: &str = "text-direction-rtl";
    #[doc(alias = "text-expand-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-expand-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-expand-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-expand-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-expand-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_EXPAND_FILLED: &str = "text-expand-filled";
    #[doc(alias = "text-expand-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-expand-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-expand-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-expand-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-expand-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_EXPAND_REGULAR: &str = "text-expand-regular";
    #[doc(alias = "text-field-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-field-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-field-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-field-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-field-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_FIELD_FILLED: &str = "text-field-filled";
    #[doc(alias = "text-field-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-field-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-field-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-field-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-field-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_FIELD_REGULAR: &str = "text-field-regular";
    #[doc(alias = "text-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_FILLED: &str = "text-filled";
    #[doc(alias = "text-font-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-font-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-font-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-font-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-font-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_FONT_FILLED: &str = "text-font-filled";
    #[doc(alias = "text-font-info-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-font-info-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-font-info-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-font-info-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-font-info-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_FONT_INFO_FILLED: &str = "text-font-info-filled";
    #[doc(alias = "text-font-info-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-font-info-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-font-info-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-font-info-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-font-info-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_FONT_INFO_REGULAR: &str = "text-font-info-regular";
    #[doc(alias = "text-font-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-font-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-font-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-font-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-font-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_FONT_REGULAR: &str = "text-font-regular";
    #[doc(alias = "text-font-size-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-font-size-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-font-size-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-font-size-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-font-size-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_FONT_SIZE_FILLED: &str = "text-font-size-filled";
    #[doc(alias = "text-font-size-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-font-size-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-font-size-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-font-size-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-font-size-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_FONT_SIZE_REGULAR: &str = "text-font-size-regular";
    #[doc(alias = "text-grammar-wand-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-grammar-wand-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-grammar-wand-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-grammar-wand-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-grammar-wand-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_GRAMMAR_WAND_FILLED: &str = "text-grammar-wand-filled";
    #[doc(alias = "text-grammar-wand-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-grammar-wand-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-grammar-wand-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-grammar-wand-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-grammar-wand-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_GRAMMAR_WAND_REGULAR: &str = "text-grammar-wand-regular";
    #[doc(alias = "text-indent-decrease-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-indent-decrease-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-indent-decrease-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-indent-decrease-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-indent-decrease-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_INDENT_DECREASE_FILLED: &str = "text-indent-decrease-filled";
    #[doc(alias = "text-indent-decrease-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-indent-decrease-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-indent-decrease-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-indent-decrease-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-indent-decrease-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_INDENT_DECREASE_REGULAR: &str = "text-indent-decrease-regular";
    #[doc(alias = "text-indent-increase-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-indent-increase-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-indent-increase-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-indent-increase-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-indent-increase-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_INDENT_INCREASE_FILLED: &str = "text-indent-increase-filled";
    #[doc(alias = "text-indent-increase-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-indent-increase-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-indent-increase-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-indent-increase-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-indent-increase-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_INDENT_INCREASE_REGULAR: &str = "text-indent-increase-regular";
    #[doc(alias = "text-indent-less")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-indent-less", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-indent-less", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-indent-less` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-indent-less-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_INDENT_LESS: &str = "text-indent-less";
    #[doc(alias = "text-indent-more")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-indent-more", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-indent-more", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-indent-more` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-indent-more-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_INDENT_MORE: &str = "text-indent-more";
    #[doc(alias = "text-italic")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-italic", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-italic", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-italic` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-italic-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ITALIC: &str = "text-italic";
    #[doc(alias = "text-italic-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-italic-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-italic-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-italic-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-italic-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ITALIC_FILLED: &str = "text-italic-filled";
    #[doc(alias = "text-italic-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-italic-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-italic-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-italic-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-italic-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_ITALIC_REGULAR: &str = "text-italic-regular";
    #[doc(alias = "text-justify-center")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-justify-center", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-justify-center", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-justify-center` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-justify-center-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_JUSTIFY_CENTER: &str = "text-justify-center";
    #[doc(alias = "text-justify-fill")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-justify-fill", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-justify-fill", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-justify-fill` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-justify-fill-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_JUSTIFY_FILL: &str = "text-justify-fill";
    #[doc(alias = "text-justify-left")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-justify-left", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-justify-left", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-justify-left` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-justify-left-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_JUSTIFY_LEFT: &str = "text-justify-left";
    #[doc(alias = "text-justify-right")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-justify-right", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-justify-right", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-justify-right` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-justify-right-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_JUSTIFY_RIGHT: &str = "text-justify-right";
    #[doc(alias = "text-paragraph-direction-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-paragraph-direction-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-paragraph-direction-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-paragraph-direction-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-paragraph-direction-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_PARAGRAPH_DIRECTION_LEFT_FILLED: &str = "text-paragraph-direction-left-filled";
    #[doc(alias = "text-paragraph-direction-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-paragraph-direction-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-paragraph-direction-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-paragraph-direction-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-paragraph-direction-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_PARAGRAPH_DIRECTION_LEFT_REGULAR: &str = "text-paragraph-direction-left-regular";
    #[doc(alias = "text-paragraph-direction-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-paragraph-direction-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-paragraph-direction-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-paragraph-direction-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-paragraph-direction-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_PARAGRAPH_DIRECTION_RIGHT_FILLED: &str = "text-paragraph-direction-right-filled";
    #[doc(alias = "text-paragraph-direction-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-paragraph-direction-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-paragraph-direction-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-paragraph-direction-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-paragraph-direction-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_PARAGRAPH_DIRECTION_RIGHT_REGULAR: &str =
        "text-paragraph-direction-right-regular";
    #[doc(alias = "text-paragraph-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-paragraph-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-paragraph-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-paragraph-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-paragraph-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_PARAGRAPH_FILLED: &str = "text-paragraph-filled";
    #[doc(alias = "text-paragraph-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-paragraph-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-paragraph-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-paragraph-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-paragraph-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_PARAGRAPH_REGULAR: &str = "text-paragraph-regular";
    #[doc(alias = "text-position-square-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-position-square-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-position-square-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-position-square-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-position-square-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_POSITION_SQUARE_LEFT_FILLED: &str = "text-position-square-left-filled";
    #[doc(alias = "text-position-square-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-position-square-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-position-square-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-position-square-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-position-square-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_POSITION_SQUARE_LEFT_REGULAR: &str = "text-position-square-left-regular";
    #[doc(alias = "text-position-square-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-position-square-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-position-square-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-position-square-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-position-square-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_POSITION_SQUARE_RIGHT_FILLED: &str = "text-position-square-right-filled";
    #[doc(alias = "text-position-square-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-position-square-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-position-square-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-position-square-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-position-square-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_POSITION_SQUARE_RIGHT_REGULAR: &str = "text-position-square-right-regular";
    #[doc(alias = "text-quote-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-quote-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-quote-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-quote-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-quote-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_QUOTE_FILLED: &str = "text-quote-filled";
    #[doc(alias = "text-quote-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-quote-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-quote-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-quote-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-quote-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_QUOTE_REGULAR: &str = "text-quote-regular";
    #[doc(alias = "text-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_REGULAR: &str = "text-regular";
    #[doc(alias = "text-sort-ascending-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-sort-ascending-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-sort-ascending-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-sort-ascending-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-sort-ascending-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_SORT_ASCENDING_FILLED: &str = "text-sort-ascending-filled";
    #[doc(alias = "text-sort-ascending-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-sort-ascending-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-sort-ascending-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-sort-ascending-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-sort-ascending-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_SORT_ASCENDING_REGULAR: &str = "text-sort-ascending-regular";
    #[doc(alias = "text-sort-descending-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-sort-descending-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-sort-descending-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-sort-descending-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-sort-descending-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_SORT_DESCENDING_FILLED: &str = "text-sort-descending-filled";
    #[doc(alias = "text-sort-descending-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-sort-descending-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-sort-descending-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-sort-descending-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-sort-descending-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_SORT_DESCENDING_REGULAR: &str = "text-sort-descending-regular";
    #[doc(alias = "text-squiggly")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-squiggly", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-squiggly", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-squiggly` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-squiggly-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_SQUIGGLY: &str = "text-squiggly";
    #[doc(alias = "text-strikethrough")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-strikethrough", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-strikethrough", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-strikethrough` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-strikethrough-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_STRIKETHROUGH: &str = "text-strikethrough";
    #[doc(alias = "text-strikethrough-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-strikethrough-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-strikethrough-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-strikethrough-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-strikethrough-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_STRIKETHROUGH_FILLED: &str = "text-strikethrough-filled";
    #[doc(alias = "text-strikethrough-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-strikethrough-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-strikethrough-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-strikethrough-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-strikethrough-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_STRIKETHROUGH_REGULAR: &str = "text-strikethrough-regular";
    #[doc(alias = "text-subscript-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-subscript-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-subscript-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-subscript-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-subscript-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_SUBSCRIPT_FILLED: &str = "text-subscript-filled";
    #[doc(alias = "text-subscript-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-subscript-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-subscript-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-subscript-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-subscript-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_SUBSCRIPT_REGULAR: &str = "text-subscript-regular";
    #[doc(alias = "text-superscript-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-superscript-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-superscript-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-superscript-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-superscript-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_SUPERSCRIPT_FILLED: &str = "text-superscript-filled";
    #[doc(alias = "text-superscript-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-superscript-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-superscript-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-superscript-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-superscript-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_SUPERSCRIPT_REGULAR: &str = "text-superscript-regular";
    #[doc(alias = "text-t-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-t-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-t-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-t-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-t-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_T_FILLED: &str = "text-t-filled";
    #[doc(alias = "text-t-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-t-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-t-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-t-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-t-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_T_REGULAR: &str = "text-t-regular";
    #[doc(alias = "text-t-tag-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-t-tag-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-t-tag-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-t-tag-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-t-tag-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_T_TAG_FILLED: &str = "text-t-tag-filled";
    #[doc(alias = "text-t-tag-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-t-tag-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-t-tag-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-t-tag-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-t-tag-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_T_TAG_REGULAR: &str = "text-t-tag-regular";
    #[doc(alias = "text-underline")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-underline", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text-underline", feature = "icon-development-kit"))]
    /// Icon name constant for the `text-underline` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text-underline-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_UNDERLINE: &str = "text-underline";
    #[doc(alias = "text-underline-character-u-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-underline-character-u-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-underline-character-u-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-underline-character-u-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-underline-character-u-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_UNDERLINE_CHARACTER_U_FILLED: &str = "text-underline-character-u-filled";
    #[doc(alias = "text-underline-character-u-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "text-underline-character-u-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "text-underline-character-u-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `text-underline-character-u-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-underline-character-u-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_UNDERLINE_CHARACTER_U_REGULAR: &str = "text-underline-character-u-regular";
    #[doc(alias = "text-underline-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-underline-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-underline-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-underline-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-underline-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_UNDERLINE_FILLED: &str = "text-underline-filled";
    #[doc(alias = "text-underline-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-underline-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-underline-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-underline-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-underline-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_UNDERLINE_REGULAR: &str = "text-underline-regular";
    #[doc(alias = "text-wrap-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-wrap-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-wrap-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-wrap-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-wrap-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_WRAP_FILLED: &str = "text-wrap-filled";
    #[doc(alias = "text-wrap-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-wrap-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-wrap-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-wrap-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-wrap-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_WRAP_OFF_FILLED: &str = "text-wrap-off-filled";
    #[doc(alias = "text-wrap-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-wrap-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-wrap-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-wrap-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-wrap-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_WRAP_OFF_REGULAR: &str = "text-wrap-off-regular";
    #[doc(alias = "text-wrap-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text-wrap-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "text-wrap-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `text-wrap-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/text-wrap-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT_WRAP_REGULAR: &str = "text-wrap-regular";
    #[doc(alias = "text2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text2", feature = "icon-development-kit"))]
    /// Icon name constant for the `text2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT2: &str = "text2";
    #[doc(alias = "text3")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "text3", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "text3", feature = "icon-development-kit"))]
    /// Icon name constant for the `text3` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/text3-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXT3: &str = "text3";
    #[doc(alias = "textbox-align-bottom-center-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-bottom-center-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-bottom-center-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-bottom-center-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-bottom-center-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_BOTTOM_CENTER_FILLED: &str = "textbox-align-bottom-center-filled";
    #[doc(alias = "textbox-align-bottom-center-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-bottom-center-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-bottom-center-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-bottom-center-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-bottom-center-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_BOTTOM_CENTER_REGULAR: &str = "textbox-align-bottom-center-regular";
    #[doc(alias = "textbox-align-bottom-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-bottom-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-bottom-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-bottom-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-bottom-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_BOTTOM_LEFT_FILLED: &str = "textbox-align-bottom-left-filled";
    #[doc(alias = "textbox-align-bottom-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-bottom-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-bottom-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-bottom-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-bottom-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_BOTTOM_LEFT_REGULAR: &str = "textbox-align-bottom-left-regular";
    #[doc(alias = "textbox-align-bottom-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-bottom-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-bottom-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-bottom-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-bottom-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_BOTTOM_RIGHT_FILLED: &str = "textbox-align-bottom-right-filled";
    #[doc(alias = "textbox-align-bottom-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-bottom-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-bottom-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-bottom-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-bottom-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_BOTTOM_RIGHT_REGULAR: &str = "textbox-align-bottom-right-regular";
    #[doc(alias = "textbox-align-center-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-center-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-center-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-center-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-center-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_CENTER_FILLED: &str = "textbox-align-center-filled";
    #[doc(alias = "textbox-align-center-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-center-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-center-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-center-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-center-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_CENTER_REGULAR: &str = "textbox-align-center-regular";
    #[doc(alias = "textbox-align-middle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-middle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-middle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-middle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-middle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_MIDDLE_FILLED: &str = "textbox-align-middle-filled";
    #[doc(alias = "textbox-align-middle-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-middle-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-middle-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-middle-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-middle-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_MIDDLE_LEFT_FILLED: &str = "textbox-align-middle-left-filled";
    #[doc(alias = "textbox-align-middle-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-middle-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-middle-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-middle-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-middle-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_MIDDLE_LEFT_REGULAR: &str = "textbox-align-middle-left-regular";
    #[doc(alias = "textbox-align-middle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-middle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-middle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-middle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-middle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_MIDDLE_REGULAR: &str = "textbox-align-middle-regular";
    #[doc(alias = "textbox-align-middle-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-middle-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-middle-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-middle-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-middle-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_MIDDLE_RIGHT_FILLED: &str = "textbox-align-middle-right-filled";
    #[doc(alias = "textbox-align-middle-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-middle-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-middle-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-middle-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-middle-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_MIDDLE_RIGHT_REGULAR: &str = "textbox-align-middle-right-regular";
    #[doc(alias = "textbox-align-top-center-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-top-center-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-top-center-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-top-center-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-top-center-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_TOP_CENTER_FILLED: &str = "textbox-align-top-center-filled";
    #[doc(alias = "textbox-align-top-center-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-top-center-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-top-center-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-top-center-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-top-center-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_TOP_CENTER_REGULAR: &str = "textbox-align-top-center-regular";
    #[doc(alias = "textbox-align-top-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-top-left-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-top-left-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-top-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-top-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_TOP_LEFT_FILLED: &str = "textbox-align-top-left-filled";
    #[doc(alias = "textbox-align-top-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-top-left-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-top-left-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-top-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-top-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_TOP_LEFT_REGULAR: &str = "textbox-align-top-left-regular";
    #[doc(alias = "textbox-align-top-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-top-right-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-top-right-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-top-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-top-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_TOP_RIGHT_FILLED: &str = "textbox-align-top-right-filled";
    #[doc(alias = "textbox-align-top-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "textbox-align-top-right-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "textbox-align-top-right-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `textbox-align-top-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-align-top-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_ALIGN_TOP_RIGHT_REGULAR: &str = "textbox-align-top-right-regular";
    #[doc(alias = "textbox-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "textbox-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "textbox-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `textbox-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_FILLED: &str = "textbox-filled";
    #[doc(alias = "textbox-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "textbox-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "textbox-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `textbox-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/textbox-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TEXTBOX_REGULAR: &str = "textbox-regular";
    #[doc(alias = "theater")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "theater", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "theater", feature = "icon-development-kit"))]
    /// Icon name constant for the `theater` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/theater-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const THEATER: &str = "theater";
    #[doc(alias = "thermometer")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "thermometer", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "thermometer", feature = "icon-development-kit"))]
    /// Icon name constant for the `thermometer` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/thermometer-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const THERMOMETER: &str = "thermometer";
    #[doc(alias = "thumb-dislike-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "thumb-dislike-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "thumb-dislike-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `thumb-dislike-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/thumb-dislike-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const THUMB_DISLIKE_FILLED: &str = "thumb-dislike-filled";
    #[doc(alias = "thumb-dislike-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "thumb-dislike-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "thumb-dislike-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `thumb-dislike-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/thumb-dislike-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const THUMB_DISLIKE_REGULAR: &str = "thumb-dislike-regular";
    #[doc(alias = "thumb-like-dislike-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "thumb-like-dislike-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "thumb-like-dislike-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `thumb-like-dislike-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/thumb-like-dislike-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const THUMB_LIKE_DISLIKE_FILLED: &str = "thumb-like-dislike-filled";
    #[doc(alias = "thumb-like-dislike-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "thumb-like-dislike-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "thumb-like-dislike-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `thumb-like-dislike-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/thumb-like-dislike-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const THUMB_LIKE_DISLIKE_REGULAR: &str = "thumb-like-dislike-regular";
    #[doc(alias = "thumb-like-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "thumb-like-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "thumb-like-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `thumb-like-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/thumb-like-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const THUMB_LIKE_FILLED: &str = "thumb-like-filled";
    #[doc(alias = "thumb-like-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "thumb-like-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "thumb-like-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `thumb-like-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/thumb-like-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const THUMB_LIKE_REGULAR: &str = "thumb-like-regular";
    #[doc(alias = "thumbs-down")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "thumbs-down", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "thumbs-down", feature = "icon-development-kit"))]
    /// Icon name constant for the `thumbs-down` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/thumbs-down-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const THUMBS_DOWN: &str = "thumbs-down";
    #[doc(alias = "thumbs-up")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "thumbs-up", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "thumbs-up", feature = "icon-development-kit"))]
    /// Icon name constant for the `thumbs-up` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/thumbs-up-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const THUMBS_UP: &str = "thumbs-up";
    #[doc(alias = "thunderbolt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "thunderbolt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "thunderbolt", feature = "icon-development-kit"))]
    /// Icon name constant for the `thunderbolt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/thunderbolt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const THUNDERBOLT: &str = "thunderbolt";
    #[doc(alias = "ticket")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ticket", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "ticket", feature = "icon-development-kit"))]
    /// Icon name constant for the `ticket` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/ticket-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TICKET: &str = "ticket";
    #[doc(alias = "ticket-diagonal-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ticket-diagonal-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "ticket-diagonal-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `ticket-diagonal-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/ticket-diagonal-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TICKET_DIAGONAL_FILLED: &str = "ticket-diagonal-filled";
    #[doc(alias = "ticket-diagonal-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ticket-diagonal-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "ticket-diagonal-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `ticket-diagonal-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/ticket-diagonal-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TICKET_DIAGONAL_REGULAR: &str = "ticket-diagonal-regular";
    #[doc(alias = "ticket-special")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ticket-special", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "ticket-special", feature = "icon-development-kit"))]
    /// Icon name constant for the `ticket-special` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/ticket-special-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TICKET_SPECIAL: &str = "ticket-special";
    #[doc(alias = "timer")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "timer", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "timer", feature = "icon-development-kit"))]
    /// Icon name constant for the `timer` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/timer-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TIMER: &str = "timer";
    #[doc(alias = "timer-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "timer-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "timer-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `timer-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/timer-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TIMER_FILLED: &str = "timer-filled";
    #[doc(alias = "timer-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "timer-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "timer-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `timer-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/timer-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TIMER_REGULAR: &str = "timer-regular";
    #[doc(alias = "timer-sand")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "timer-sand", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "timer-sand", feature = "icon-development-kit"))]
    /// Icon name constant for the `timer-sand` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/timer-sand-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TIMER_SAND: &str = "timer-sand";
    #[doc(alias = "today")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "today", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "today", feature = "icon-development-kit"))]
    /// Icon name constant for the `today` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/today-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TODAY: &str = "today";
    #[doc(alias = "today-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "today-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "today-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `today-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/today-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TODAY_ALT: &str = "today-alt";
    #[doc(alias = "toggle-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "toggle-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "toggle-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `toggle-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/toggle-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOGGLE_LEFT_FILLED: &str = "toggle-left-filled";
    #[doc(alias = "toggle-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "toggle-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "toggle-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `toggle-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/toggle-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOGGLE_LEFT_REGULAR: &str = "toggle-left-regular";
    #[doc(alias = "toggle-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "toggle-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "toggle-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `toggle-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/toggle-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOGGLE_MULTIPLE_FILLED: &str = "toggle-multiple-filled";
    #[doc(alias = "toggle-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "toggle-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "toggle-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `toggle-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/toggle-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOGGLE_MULTIPLE_REGULAR: &str = "toggle-multiple-regular";
    #[doc(alias = "toggle-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "toggle-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "toggle-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `toggle-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/toggle-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOGGLE_RIGHT_FILLED: &str = "toggle-right-filled";
    #[doc(alias = "toggle-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "toggle-right-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "toggle-right-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `toggle-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/toggle-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOGGLE_RIGHT_REGULAR: &str = "toggle-right-regular";
    #[doc(alias = "toilets")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "toilets", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "toilets", feature = "icon-development-kit"))]
    /// Icon name constant for the `toilets` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/toilets-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOILETS: &str = "toilets";
    #[doc(alias = "toilets2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "toilets2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "toilets2", feature = "icon-development-kit"))]
    /// Icon name constant for the `toilets2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/toilets2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOILETS2: &str = "toilets2";
    #[doc(alias = "toolbars")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "toolbars", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "toolbars", feature = "icon-development-kit"))]
    /// Icon name constant for the `toolbars` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/toolbars-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOOLBARS: &str = "toolbars";
    #[doc(alias = "toolbox-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "toolbox-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "toolbox-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `toolbox-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/toolbox-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOOLBOX_FILLED: &str = "toolbox-filled";
    #[doc(alias = "toolbox-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "toolbox-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "toolbox-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `toolbox-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/toolbox-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOOLBOX_REGULAR: &str = "toolbox-regular";
    #[doc(alias = "top")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "top", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "top", feature = "icon-development-kit"))]
    /// Icon name constant for the `top` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/top-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOP: &str = "top";
    #[doc(alias = "top-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "top-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "top-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `top-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/top-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOP_LARGE: &str = "top-large";
    #[doc(alias = "tornado")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tornado", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tornado", feature = "icon-development-kit"))]
    /// Icon name constant for the `tornado` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tornado-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TORNADO: &str = "tornado";
    #[doc(alias = "touchpad")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "touchpad", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "touchpad", feature = "icon-development-kit"))]
    /// Icon name constant for the `touchpad` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/touchpad-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOUCHPAD: &str = "touchpad";
    #[doc(alias = "touchpad-disabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "touchpad-disabled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "touchpad-disabled", feature = "icon-development-kit"))]
    /// Icon name constant for the `touchpad-disabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/touchpad-disabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOUCHPAD_DISABLED: &str = "touchpad-disabled";
    #[doc(alias = "town")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "town", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "town", feature = "icon-development-kit"))]
    /// Icon name constant for the `town` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/town-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TOWN: &str = "town";
    #[doc(alias = "train")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "train", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "train", feature = "icon-development-kit"))]
    /// Icon name constant for the `train` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/train-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRAIN: &str = "train";
    #[doc(alias = "tram")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tram", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tram", feature = "icon-development-kit"))]
    /// Icon name constant for the `tram` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tram-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRAM: &str = "tram";
    #[doc(alias = "transform")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "transform", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "transform", feature = "icon-development-kit"))]
    /// Icon name constant for the `transform` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/transform-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRANSFORM: &str = "transform";
    #[doc(alias = "translate-auto-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "translate-auto-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "translate-auto-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `translate-auto-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/translate-auto-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRANSLATE_AUTO_FILLED: &str = "translate-auto-filled";
    #[doc(alias = "translate-auto-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "translate-auto-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "translate-auto-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `translate-auto-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/translate-auto-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRANSLATE_AUTO_REGULAR: &str = "translate-auto-regular";
    #[doc(alias = "translate-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "translate-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "translate-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `translate-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/translate-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRANSLATE_FILLED: &str = "translate-filled";
    #[doc(alias = "translate-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "translate-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "translate-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `translate-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/translate-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRANSLATE_OFF_FILLED: &str = "translate-off-filled";
    #[doc(alias = "translate-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "translate-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "translate-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `translate-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/translate-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRANSLATE_OFF_REGULAR: &str = "translate-off-regular";
    #[doc(alias = "translate-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "translate-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "translate-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `translate-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/translate-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRANSLATE_REGULAR: &str = "translate-regular";
    #[doc(alias = "transparent-background")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "transparent-background", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "transparent-background", feature = "icon-development-kit"))]
    /// Icon name constant for the `transparent-background` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/transparent-background-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRANSPARENT_BACKGROUND: &str = "transparent-background";
    #[doc(alias = "tree")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tree", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tree", feature = "icon-development-kit"))]
    /// Icon name constant for the `tree` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tree-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TREE: &str = "tree";
    #[doc(alias = "tree2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tree2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tree2", feature = "icon-development-kit"))]
    /// Icon name constant for the `tree2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tree2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TREE2: &str = "tree2";
    #[doc(alias = "triangle-down-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "triangle-down-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "triangle-down-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `triangle-down-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/triangle-down-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRIANGLE_DOWN_FILLED: &str = "triangle-down-filled";
    #[doc(alias = "triangle-down-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "triangle-down-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "triangle-down-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `triangle-down-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/triangle-down-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRIANGLE_DOWN_REGULAR: &str = "triangle-down-regular";
    #[doc(alias = "triangle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "triangle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "triangle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `triangle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/triangle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRIANGLE_FILLED: &str = "triangle-filled";
    #[doc(alias = "triangle-left-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "triangle-left-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "triangle-left-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `triangle-left-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/triangle-left-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRIANGLE_LEFT_FILLED: &str = "triangle-left-filled";
    #[doc(alias = "triangle-left-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "triangle-left-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "triangle-left-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `triangle-left-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/triangle-left-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRIANGLE_LEFT_REGULAR: &str = "triangle-left-regular";
    #[doc(alias = "triangle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "triangle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "triangle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `triangle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/triangle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRIANGLE_REGULAR: &str = "triangle-regular";
    #[doc(alias = "triangle-right-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "triangle-right-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "triangle-right-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `triangle-right-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/triangle-right-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRIANGLE_RIGHT_FILLED: &str = "triangle-right-filled";
    #[doc(alias = "triangle-right-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "triangle-right-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "triangle-right-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `triangle-right-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/triangle-right-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TRIANGLE_RIGHT_REGULAR: &str = "triangle-right-regular";
    #[doc(alias = "trophy")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "trophy", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "trophy", feature = "icon-development-kit"))]
    /// Icon name constant for the `trophy` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/trophy-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TROPHY: &str = "trophy";
    #[doc(alias = "trophy-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "trophy-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "trophy-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `trophy-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/trophy-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TROPHY_FILLED: &str = "trophy-filled";
    #[doc(alias = "trophy-lock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "trophy-lock-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "trophy-lock-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `trophy-lock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/trophy-lock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TROPHY_LOCK_FILLED: &str = "trophy-lock-filled";
    #[doc(alias = "trophy-lock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "trophy-lock-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "trophy-lock-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `trophy-lock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/trophy-lock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TROPHY_LOCK_REGULAR: &str = "trophy-lock-regular";
    #[doc(alias = "trophy-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "trophy-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "trophy-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `trophy-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/trophy-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TROPHY_OFF_FILLED: &str = "trophy-off-filled";
    #[doc(alias = "trophy-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "trophy-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "trophy-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `trophy-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/trophy-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TROPHY_OFF_REGULAR: &str = "trophy-off-regular";
    #[doc(alias = "trophy-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "trophy-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "trophy-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `trophy-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/trophy-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TROPHY_REGULAR: &str = "trophy-regular";
    #[doc(alias = "tty")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tty", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tty", feature = "icon-development-kit"))]
    /// Icon name constant for the `tty` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tty-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TTY: &str = "tty";
    #[doc(alias = "tv")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tv", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "tv", feature = "icon-development-kit"))]
    /// Icon name constant for the `tv` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/tv-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TV: &str = "tv";
    #[doc(alias = "tv-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tv-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tv-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tv-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tv-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TV_FILLED: &str = "tv-filled";
    #[doc(alias = "tv-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tv-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tv-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tv-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tv-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TV_REGULAR: &str = "tv-regular";
    #[doc(alias = "tv-usb-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tv-usb-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tv-usb-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tv-usb-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tv-usb-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TV_USB_FILLED: &str = "tv-usb-filled";
    #[doc(alias = "tv-usb-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "tv-usb-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "tv-usb-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `tv-usb-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/tv-usb-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const TV_USB_REGULAR: &str = "tv-usb-regular";
    #[doc(alias = "ungroup")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ungroup", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "ungroup", feature = "icon-development-kit"))]
    /// Icon name constant for the `ungroup` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/ungroup-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const UNGROUP: &str = "ungroup";
    #[doc(alias = "up")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "up", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "up", feature = "icon-development-kit"))]
    /// Icon name constant for the `up` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/up-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const UP: &str = "up";
    #[doc(alias = "up-large")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "up-large", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "up-large", feature = "icon-development-kit"))]
    /// Icon name constant for the `up-large` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/up-large-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const UP_LARGE: &str = "up-large";
    #[doc(alias = "update")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "update", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "update", feature = "icon-development-kit"))]
    /// Icon name constant for the `update` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/update-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const UPDATE: &str = "update";
    #[doc(alias = "uppercase")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "uppercase", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "uppercase", feature = "icon-development-kit"))]
    /// Icon name constant for the `uppercase` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/uppercase-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const UPPERCASE: &str = "uppercase";
    #[doc(alias = "ups")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "ups", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "ups", feature = "icon-development-kit"))]
    /// Icon name constant for the `ups` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/ups-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const UPS: &str = "ups";
    #[doc(alias = "usb-stick")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "usb-stick", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "usb-stick", feature = "icon-development-kit"))]
    /// Icon name constant for the `usb-stick` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/usb-stick-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const USB_STICK: &str = "usb-stick";
    #[doc(alias = "user-trash")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "user-trash", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "user-trash", feature = "icon-development-kit"))]
    /// Icon name constant for the `user-trash` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/user-trash-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const USER_TRASH: &str = "user-trash";
    #[doc(alias = "user-trash-full")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "user-trash-full", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "user-trash-full", feature = "icon-development-kit"))]
    /// Icon name constant for the `user-trash-full` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/user-trash-full-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const USER_TRASH_FULL: &str = "user-trash-full";
    #[doc(alias = "vault-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vault-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vault-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vault-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vault-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VAULT_FILLED: &str = "vault-filled";
    #[doc(alias = "vault-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vault-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vault-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vault-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vault-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VAULT_REGULAR: &str = "vault-regular";
    #[doc(alias = "vehicle-bicycle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-bicycle-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-bicycle-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-bicycle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-bicycle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_BICYCLE_FILLED: &str = "vehicle-bicycle-filled";
    #[doc(alias = "vehicle-bicycle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-bicycle-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-bicycle-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-bicycle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-bicycle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_BICYCLE_REGULAR: &str = "vehicle-bicycle-regular";
    #[doc(alias = "vehicle-bus-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-bus-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-bus-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-bus-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-bus-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_BUS_FILLED: &str = "vehicle-bus-filled";
    #[doc(alias = "vehicle-bus-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-bus-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-bus-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-bus-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-bus-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_BUS_REGULAR: &str = "vehicle-bus-regular";
    #[doc(alias = "vehicle-cab-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-cab-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-cab-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-cab-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-cab-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_CAB_FILLED: &str = "vehicle-cab-filled";
    #[doc(alias = "vehicle-cab-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-cab-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-cab-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-cab-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-cab-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_CAB_REGULAR: &str = "vehicle-cab-regular";
    #[doc(alias = "vehicle-car-collision-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "vehicle-car-collision-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "vehicle-car-collision-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `vehicle-car-collision-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-car-collision-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_CAR_COLLISION_FILLED: &str = "vehicle-car-collision-filled";
    #[doc(alias = "vehicle-car-collision-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "vehicle-car-collision-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "vehicle-car-collision-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `vehicle-car-collision-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-car-collision-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_CAR_COLLISION_REGULAR: &str = "vehicle-car-collision-regular";
    #[doc(alias = "vehicle-car-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-car-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-car-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-car-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-car-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_CAR_FILLED: &str = "vehicle-car-filled";
    #[doc(alias = "vehicle-car-parking-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "vehicle-car-parking-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "vehicle-car-parking-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `vehicle-car-parking-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-car-parking-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_CAR_PARKING_FILLED: &str = "vehicle-car-parking-filled";
    #[doc(alias = "vehicle-car-parking-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "vehicle-car-parking-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "vehicle-car-parking-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `vehicle-car-parking-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-car-parking-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_CAR_PARKING_REGULAR: &str = "vehicle-car-parking-regular";
    #[doc(alias = "vehicle-car-profile-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "vehicle-car-profile-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "vehicle-car-profile-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `vehicle-car-profile-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-car-profile-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_CAR_PROFILE_FILLED: &str = "vehicle-car-profile-filled";
    #[doc(alias = "vehicle-car-profile-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "vehicle-car-profile-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "vehicle-car-profile-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `vehicle-car-profile-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-car-profile-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_CAR_PROFILE_REGULAR: &str = "vehicle-car-profile-regular";
    #[doc(alias = "vehicle-car-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-car-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-car-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-car-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-car-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_CAR_REGULAR: &str = "vehicle-car-regular";
    #[doc(alias = "vehicle-ship-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-ship-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-ship-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-ship-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-ship-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_SHIP_FILLED: &str = "vehicle-ship-filled";
    #[doc(alias = "vehicle-ship-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-ship-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-ship-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-ship-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-ship-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_SHIP_REGULAR: &str = "vehicle-ship-regular";
    #[doc(alias = "vehicle-subway-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-subway-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-subway-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-subway-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-subway-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_SUBWAY_FILLED: &str = "vehicle-subway-filled";
    #[doc(alias = "vehicle-subway-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-subway-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-subway-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-subway-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-subway-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_SUBWAY_REGULAR: &str = "vehicle-subway-regular";
    #[doc(alias = "vehicle-truck-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-truck-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-truck-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-truck-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-truck-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_TRUCK_FILLED: &str = "vehicle-truck-filled";
    #[doc(alias = "vehicle-truck-profile-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "vehicle-truck-profile-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "vehicle-truck-profile-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `vehicle-truck-profile-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-truck-profile-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_TRUCK_PROFILE_FILLED: &str = "vehicle-truck-profile-filled";
    #[doc(alias = "vehicle-truck-profile-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "vehicle-truck-profile-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "vehicle-truck-profile-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `vehicle-truck-profile-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-truck-profile-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_TRUCK_PROFILE_REGULAR: &str = "vehicle-truck-profile-regular";
    #[doc(alias = "vehicle-truck-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vehicle-truck-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "vehicle-truck-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `vehicle-truck-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/vehicle-truck-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VEHICLE_TRUCK_REGULAR: &str = "vehicle-truck-regular";
    #[doc(alias = "video-background-effect-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-background-effect-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-background-effect-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-background-effect-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-background-effect-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_BACKGROUND_EFFECT_FILLED: &str = "video-background-effect-filled";
    #[doc(alias = "video-background-effect-horizontal-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-background-effect-horizontal-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-background-effect-horizontal-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-background-effect-horizontal-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-background-effect-horizontal-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_BACKGROUND_EFFECT_HORIZONTAL_FILLED: &str =
        "video-background-effect-horizontal-filled";
    #[doc(alias = "video-background-effect-horizontal-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-background-effect-horizontal-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-background-effect-horizontal-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-background-effect-horizontal-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-background-effect-horizontal-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_BACKGROUND_EFFECT_HORIZONTAL_REGULAR: &str =
        "video-background-effect-horizontal-regular";
    #[doc(alias = "video-background-effect-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-background-effect-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-background-effect-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-background-effect-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-background-effect-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_BACKGROUND_EFFECT_REGULAR: &str = "video-background-effect-regular";
    #[doc(alias = "video-camera")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-camera", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "video-camera", feature = "icon-development-kit"))]
    /// Icon name constant for the `video-camera` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/video-camera-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_CAMERA: &str = "video-camera";
    #[doc(alias = "video-chat-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-chat-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "video-chat-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `video-chat-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-chat-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_CHAT_FILLED: &str = "video-chat-filled";
    #[doc(alias = "video-chat-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-chat-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "video-chat-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `video-chat-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-chat-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_CHAT_REGULAR: &str = "video-chat-regular";
    #[doc(alias = "video-clip-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-clip-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "video-clip-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `video-clip-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-clip-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_CLIP_FILLED: &str = "video-clip-filled";
    #[doc(alias = "video-clip-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-clip-multiple-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-clip-multiple-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-clip-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-clip-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_CLIP_MULTIPLE_FILLED: &str = "video-clip-multiple-filled";
    #[doc(alias = "video-clip-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-clip-multiple-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-clip-multiple-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-clip-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-clip-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_CLIP_MULTIPLE_REGULAR: &str = "video-clip-multiple-regular";
    #[doc(alias = "video-clip-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-clip-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "video-clip-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `video-clip-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-clip-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_CLIP_OFF_FILLED: &str = "video-clip-off-filled";
    #[doc(alias = "video-clip-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-clip-off-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "video-clip-off-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `video-clip-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-clip-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_CLIP_OFF_REGULAR: &str = "video-clip-off-regular";
    #[doc(alias = "video-clip-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-clip-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "video-clip-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `video-clip-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-clip-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_CLIP_REGULAR: &str = "video-clip-regular";
    #[doc(alias = "video-decode")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-decode", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "video-decode", feature = "icon-development-kit"))]
    /// Icon name constant for the `video-decode` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/video-decode-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_DECODE: &str = "video-decode";
    #[doc(alias = "video-encoder")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-encoder", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "video-encoder", feature = "icon-development-kit"))]
    /// Icon name constant for the `video-encoder` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/video-encoder-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_ENCODER: &str = "video-encoder";
    #[doc(alias = "video-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "video-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `video-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_FILLED: &str = "video-filled";
    #[doc(alias = "video-person-call-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-person-call-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-person-call-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-person-call-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-person-call-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_PERSON_CALL_FILLED: &str = "video-person-call-filled";
    #[doc(alias = "video-person-call-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-person-call-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-person-call-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-person-call-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-person-call-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_PERSON_CALL_REGULAR: &str = "video-person-call-regular";
    #[doc(alias = "video-person-clock-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-person-clock-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-person-clock-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-person-clock-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-person-clock-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_PERSON_CLOCK_FILLED: &str = "video-person-clock-filled";
    #[doc(alias = "video-person-clock-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-person-clock-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-person-clock-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-person-clock-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-person-clock-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_PERSON_CLOCK_REGULAR: &str = "video-person-clock-regular";
    #[doc(alias = "video-person-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-person-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "video-person-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `video-person-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-person-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_PERSON_FILLED: &str = "video-person-filled";
    #[doc(alias = "video-person-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-person-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "video-person-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `video-person-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-person-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_PERSON_REGULAR: &str = "video-person-regular";
    #[doc(alias = "video-person-sparkle-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-person-sparkle-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-person-sparkle-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-person-sparkle-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-person-sparkle-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_PERSON_SPARKLE_FILLED: &str = "video-person-sparkle-filled";
    #[doc(alias = "video-person-sparkle-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-person-sparkle-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-person-sparkle-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-person-sparkle-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-person-sparkle-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_PERSON_SPARKLE_REGULAR: &str = "video-person-sparkle-regular";
    #[doc(alias = "video-prohibited-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-prohibited-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "video-prohibited-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `video-prohibited-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-prohibited-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_PROHIBITED_FILLED: &str = "video-prohibited-filled";
    #[doc(alias = "video-prohibited-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "video-prohibited-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "video-prohibited-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `video-prohibited-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-prohibited-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_PROHIBITED_REGULAR: &str = "video-prohibited-regular";
    #[doc(alias = "video-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "video-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "video-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `video-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/video-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIDEO_REGULAR: &str = "video-regular";
    #[doc(alias = "view-columns")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "view-columns", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "view-columns", feature = "icon-development-kit"))]
    /// Icon name constant for the `view-columns` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/view-columns-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIEW_COLUMNS: &str = "view-columns";
    #[doc(alias = "view-switcher")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "view-switcher", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "view-switcher", feature = "icon-development-kit"))]
    /// Icon name constant for the `view-switcher` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/view-switcher-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIEW_SWITCHER: &str = "view-switcher";
    #[doc(alias = "violence")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "violence", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "violence", feature = "icon-development-kit"))]
    /// Icon name constant for the `violence` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/violence-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIOLENCE: &str = "violence";
    #[doc(alias = "violence-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "violence-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "violence-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `violence-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/violence-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIOLENCE_NONE: &str = "violence-none";
    #[doc(alias = "violence2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "violence2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "violence2", feature = "icon-development-kit"))]
    /// Icon name constant for the `violence2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/violence2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIOLENCE2: &str = "violence2";
    #[doc(alias = "violence2-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "violence2-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "violence2-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `violence2-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/violence2-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIOLENCE2_NONE: &str = "violence2-none";
    #[doc(alias = "violence3")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "violence3", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "violence3", feature = "icon-development-kit"))]
    /// Icon name constant for the `violence3` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/violence3-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIOLENCE3: &str = "violence3";
    #[doc(alias = "violence3-none")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "violence3-none", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "violence3-none", feature = "icon-development-kit"))]
    /// Icon name constant for the `violence3-none` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/violence3-none-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VIOLENCE3_NONE: &str = "violence3-none";
    #[doc(alias = "voicemail-arrow-back-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "voicemail-arrow-back-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "voicemail-arrow-back-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `voicemail-arrow-back-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/voicemail-arrow-back-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VOICEMAIL_ARROW_BACK_FILLED: &str = "voicemail-arrow-back-filled";
    #[doc(alias = "voicemail-arrow-back-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "voicemail-arrow-back-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "voicemail-arrow-back-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `voicemail-arrow-back-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/voicemail-arrow-back-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VOICEMAIL_ARROW_BACK_REGULAR: &str = "voicemail-arrow-back-regular";
    #[doc(alias = "voicemail-arrow-forward-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "voicemail-arrow-forward-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "voicemail-arrow-forward-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `voicemail-arrow-forward-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/voicemail-arrow-forward-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VOICEMAIL_ARROW_FORWARD_FILLED: &str = "voicemail-arrow-forward-filled";
    #[doc(alias = "voicemail-arrow-forward-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "voicemail-arrow-forward-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "voicemail-arrow-forward-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `voicemail-arrow-forward-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/voicemail-arrow-forward-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VOICEMAIL_ARROW_FORWARD_REGULAR: &str = "voicemail-arrow-forward-regular";
    #[doc(alias = "voicemail-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "voicemail-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "voicemail-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `voicemail-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/voicemail-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VOICEMAIL_FILLED: &str = "voicemail-filled";
    #[doc(alias = "voicemail-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "voicemail-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "voicemail-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `voicemail-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/voicemail-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VOICEMAIL_REGULAR: &str = "voicemail-regular";
    #[doc(alias = "voicemail-shield-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "voicemail-shield-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "voicemail-shield-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `voicemail-shield-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/voicemail-shield-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VOICEMAIL_SHIELD_FILLED: &str = "voicemail-shield-filled";
    #[doc(alias = "voicemail-shield-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "voicemail-shield-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "voicemail-shield-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `voicemail-shield-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/voicemail-shield-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VOICEMAIL_SHIELD_REGULAR: &str = "voicemail-shield-regular";
    #[doc(alias = "voicemail-subtract-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "voicemail-subtract-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "voicemail-subtract-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `voicemail-subtract-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/voicemail-subtract-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VOICEMAIL_SUBTRACT_FILLED: &str = "voicemail-subtract-filled";
    #[doc(alias = "voicemail-subtract-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "voicemail-subtract-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "voicemail-subtract-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `voicemail-subtract-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/voicemail-subtract-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VOICEMAIL_SUBTRACT_REGULAR: &str = "voicemail-subtract-regular";
    #[doc(alias = "vpn-caps")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vpn-caps", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "vpn-caps", feature = "icon-development-kit"))]
    /// Icon name constant for the `vpn-caps` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/vpn-caps-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VPN_CAPS: &str = "vpn-caps";
    #[doc(alias = "vpn-caps-disabled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "vpn-caps-disabled", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "vpn-caps-disabled", feature = "icon-development-kit"))]
    /// Icon name constant for the `vpn-caps-disabled` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/vpn-caps-disabled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const VPN_CAPS_DISABLED: &str = "vpn-caps-disabled";
    #[doc(alias = "wacom")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wacom", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wacom", feature = "icon-development-kit"))]
    /// Icon name constant for the `wacom` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wacom-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WACOM: &str = "wacom";
    #[doc(alias = "walking")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "walking", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "walking", feature = "icon-development-kit"))]
    /// Icon name constant for the `walking` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/walking-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WALKING: &str = "walking";
    #[doc(alias = "walking2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "walking2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "walking2", feature = "icon-development-kit"))]
    /// Icon name constant for the `walking2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/walking2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WALKING2: &str = "walking2";
    #[doc(alias = "wallet")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wallet", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wallet", feature = "icon-development-kit"))]
    /// Icon name constant for the `wallet` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wallet-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WALLET: &str = "wallet";
    #[doc(alias = "wallet-credit-card-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "wallet-credit-card-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "wallet-credit-card-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `wallet-credit-card-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/wallet-credit-card-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WALLET_CREDIT_CARD_FILLED: &str = "wallet-credit-card-filled";
    #[doc(alias = "wallet-credit-card-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "wallet-credit-card-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "wallet-credit-card-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `wallet-credit-card-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/wallet-credit-card-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WALLET_CREDIT_CARD_REGULAR: &str = "wallet-credit-card-regular";
    #[doc(alias = "wallet-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wallet-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "wallet-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `wallet-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/wallet-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WALLET_FILLED: &str = "wallet-filled";
    #[doc(alias = "wallet-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wallet-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "wallet-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `wallet-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/wallet-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WALLET_REGULAR: &str = "wallet-regular";
    #[doc(alias = "wallet2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wallet2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wallet2", feature = "icon-development-kit"))]
    /// Icon name constant for the `wallet2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wallet2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WALLET2: &str = "wallet2";
    #[doc(alias = "wallet3")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wallet3", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wallet3", feature = "icon-development-kit"))]
    /// Icon name constant for the `wallet3` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wallet3-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WALLET3: &str = "wallet3";
    #[doc(alias = "wand-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wand-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "wand-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `wand-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/wand-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WAND_FILLED: &str = "wand-filled";
    #[doc(alias = "wand-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wand-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "wand-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `wand-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/wand-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WAND_REGULAR: &str = "wand-regular";
    #[doc(alias = "warning")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "warning", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "warning", feature = "icon-development-kit"))]
    /// Icon name constant for the `warning` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/warning-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WARNING: &str = "warning";
    #[doc(alias = "warning-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "warning-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "warning-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `warning-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/warning-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WARNING_FILLED: &str = "warning-filled";
    #[doc(alias = "warning-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "warning-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "warning-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `warning-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/warning-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WARNING_REGULAR: &str = "warning-regular";
    #[doc(alias = "water-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "water-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "water-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `water-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/water-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WATER_FILLED: &str = "water-filled";
    #[doc(alias = "water-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "water-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "water-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `water-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/water-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WATER_REGULAR: &str = "water-regular";
    #[doc(alias = "weather-alert")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "weather-alert", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "weather-alert", feature = "icon-development-kit"))]
    /// Icon name constant for the `weather-alert` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/weather-alert-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEATHER_ALERT: &str = "weather-alert";
    #[doc(alias = "weather-moon-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "weather-moon-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "weather-moon-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `weather-moon-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/weather-moon-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEATHER_MOON_FILLED: &str = "weather-moon-filled";
    #[doc(alias = "weather-moon-off-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "weather-moon-off-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "weather-moon-off-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `weather-moon-off-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/weather-moon-off-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEATHER_MOON_OFF_FILLED: &str = "weather-moon-off-filled";
    #[doc(alias = "weather-moon-off-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "weather-moon-off-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "weather-moon-off-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `weather-moon-off-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/weather-moon-off-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEATHER_MOON_OFF_REGULAR: &str = "weather-moon-off-regular";
    #[doc(alias = "weather-moon-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "weather-moon-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "weather-moon-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `weather-moon-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/weather-moon-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEATHER_MOON_REGULAR: &str = "weather-moon-regular";
    #[doc(alias = "weather-partly-cloudy-day-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "weather-partly-cloudy-day-filled",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "weather-partly-cloudy-day-filled",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `weather-partly-cloudy-day-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/weather-partly-cloudy-day-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEATHER_PARTLY_CLOUDY_DAY_FILLED: &str = "weather-partly-cloudy-day-filled";
    #[doc(alias = "weather-partly-cloudy-day-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "weather-partly-cloudy-day-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "weather-partly-cloudy-day-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `weather-partly-cloudy-day-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/weather-partly-cloudy-day-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEATHER_PARTLY_CLOUDY_DAY_REGULAR: &str = "weather-partly-cloudy-day-regular";
    #[doc(alias = "weather-showers-scattered")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "weather-showers-scattered",
            feature = "icon-development-kit"
        )))
    )]
    #[cfg(any(
        feature = "weather-showers-scattered",
        feature = "icon-development-kit"
    ))]
    /// Icon name constant for the `weather-showers-scattered` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/weather-showers-scattered-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEATHER_SHOWERS_SCATTERED: &str = "weather-showers-scattered";
    #[doc(alias = "weather-sunny-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "weather-sunny-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "weather-sunny-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `weather-sunny-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/weather-sunny-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEATHER_SUNNY_FILLED: &str = "weather-sunny-filled";
    #[doc(alias = "weather-sunny-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "weather-sunny-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "weather-sunny-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `weather-sunny-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/weather-sunny-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEATHER_SUNNY_REGULAR: &str = "weather-sunny-regular";
    #[doc(alias = "web-asset-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "web-asset-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "web-asset-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `web-asset-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/web-asset-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEB_ASSET_FILLED: &str = "web-asset-filled";
    #[doc(alias = "web-asset-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "web-asset-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "web-asset-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `web-asset-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/web-asset-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEB_ASSET_REGULAR: &str = "web-asset-regular";
    #[doc(alias = "week")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "week", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "week", feature = "icon-development-kit"))]
    /// Icon name constant for the `week` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/week-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEEK: &str = "week";
    #[doc(alias = "weight")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "weight", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "weight", feature = "icon-development-kit"))]
    /// Icon name constant for the `weight` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/weight-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEIGHT: &str = "weight";
    #[doc(alias = "weight2")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "weight2", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "weight2", feature = "icon-development-kit"))]
    /// Icon name constant for the `weight2` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/weight2-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WEIGHT2: &str = "weight2";
    #[doc(alias = "wheat")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wheat", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wheat", feature = "icon-development-kit"))]
    /// Icon name constant for the `wheat` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wheat-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WHEAT: &str = "wheat";
    #[doc(alias = "wheelchair")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wheelchair", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wheelchair", feature = "icon-development-kit"))]
    /// Icon name constant for the `wheelchair` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wheelchair-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WHEELCHAIR: &str = "wheelchair";
    #[doc(alias = "wheelchair-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wheelchair-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wheelchair-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `wheelchair-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wheelchair-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WHEELCHAIR_ALT: &str = "wheelchair-alt";
    #[doc(alias = "wheelchair-limited")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wheelchair-limited", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wheelchair-limited", feature = "icon-development-kit"))]
    /// Icon name constant for the `wheelchair-limited` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wheelchair-limited-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WHEELCHAIR_LIMITED: &str = "wheelchair-limited";
    #[doc(alias = "wheelchair-modified-isa")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wheelchair-modified-isa", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wheelchair-modified-isa", feature = "icon-development-kit"))]
    /// Icon name constant for the `wheelchair-modified-isa` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wheelchair-modified-isa-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WHEELCHAIR_MODIFIED_ISA: &str = "wheelchair-modified-isa";
    #[doc(alias = "window")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "window", feature = "icon-development-kit"))]
    /// Icon name constant for the `window` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/window-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW: &str = "window";
    #[doc(alias = "window-apps-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-apps-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-apps-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-apps-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-apps-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_APPS_FILLED: &str = "window-apps-filled";
    #[doc(alias = "window-apps-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-apps-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-apps-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-apps-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-apps-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_APPS_REGULAR: &str = "window-apps-regular";
    #[doc(alias = "window-arrow-up-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-arrow-up-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-arrow-up-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-arrow-up-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-arrow-up-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_ARROW_UP_FILLED: &str = "window-arrow-up-filled";
    #[doc(alias = "window-arrow-up-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-arrow-up-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-arrow-up-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-arrow-up-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-arrow-up-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_ARROW_UP_REGULAR: &str = "window-arrow-up-regular";
    #[doc(alias = "window-dev-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-dev-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-dev-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-dev-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-dev-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_DEV_EDIT_FILLED: &str = "window-dev-edit-filled";
    #[doc(alias = "window-dev-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-dev-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-dev-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-dev-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-dev-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_DEV_EDIT_REGULAR: &str = "window-dev-edit-regular";
    #[doc(alias = "window-dev-tools-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-dev-tools-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-dev-tools-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-dev-tools-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-dev-tools-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_DEV_TOOLS_FILLED: &str = "window-dev-tools-filled";
    #[doc(alias = "window-dev-tools-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(
            feature = "window-dev-tools-regular",
            feature = "fluentui-system-icons"
        )))
    )]
    #[cfg(any(
        feature = "window-dev-tools-regular",
        feature = "fluentui-system-icons"
    ))]
    /// Icon name constant for the `window-dev-tools-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-dev-tools-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_DEV_TOOLS_REGULAR: &str = "window-dev-tools-regular";
    #[doc(alias = "window-edit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-edit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-edit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-edit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-edit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_EDIT_FILLED: &str = "window-edit-filled";
    #[doc(alias = "window-edit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-edit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-edit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-edit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-edit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_EDIT_REGULAR: &str = "window-edit-regular";
    #[doc(alias = "window-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_FILLED: &str = "window-filled";
    #[doc(alias = "window-flat")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-flat", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "window-flat", feature = "icon-development-kit"))]
    /// Icon name constant for the `window-flat` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/window-flat-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_FLAT: &str = "window-flat";
    #[doc(alias = "window-grow")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-grow", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "window-grow", feature = "icon-development-kit"))]
    /// Icon name constant for the `window-grow` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/window-grow-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_GROW: &str = "window-grow";
    #[doc(alias = "window-multiple-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-multiple-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-multiple-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-multiple-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-multiple-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_MULTIPLE_FILLED: &str = "window-multiple-filled";
    #[doc(alias = "window-multiple-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-multiple-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-multiple-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-multiple-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-multiple-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_MULTIPLE_REGULAR: &str = "window-multiple-regular";
    #[doc(alias = "window-new-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-new-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-new-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-new-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-new-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_NEW_FILLED: &str = "window-new-filled";
    #[doc(alias = "window-new-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-new-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-new-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-new-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-new-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_NEW_REGULAR: &str = "window-new-regular";
    #[doc(alias = "window-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_REGULAR: &str = "window-regular";
    #[doc(alias = "window-scrolling")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-scrolling", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "window-scrolling", feature = "icon-development-kit"))]
    /// Icon name constant for the `window-scrolling` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/window-scrolling-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_SCROLLING: &str = "window-scrolling";
    #[doc(alias = "window-shield-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-shield-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-shield-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-shield-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-shield-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_SHIELD_FILLED: &str = "window-shield-filled";
    #[doc(alias = "window-shield-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-shield-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-shield-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-shield-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-shield-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_SHIELD_REGULAR: &str = "window-shield-regular";
    #[doc(alias = "window-shrink")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-shrink", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "window-shrink", feature = "icon-development-kit"))]
    /// Icon name constant for the `window-shrink` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/window-shrink-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_SHRINK: &str = "window-shrink";
    #[doc(alias = "window-sound-source")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-sound-source", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "window-sound-source", feature = "icon-development-kit"))]
    /// Icon name constant for the `window-sound-source` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/window-sound-source-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_SOUND_SOURCE: &str = "window-sound-source";
    #[doc(alias = "window-wrench-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-wrench-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-wrench-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-wrench-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-wrench-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_WRENCH_FILLED: &str = "window-wrench-filled";
    #[doc(alias = "window-wrench-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "window-wrench-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "window-wrench-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `window-wrench-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/window-wrench-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDOW_WRENCH_REGULAR: &str = "window-wrench-regular";
    #[doc(alias = "windy")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "windy", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "windy", feature = "icon-development-kit"))]
    /// Icon name constant for the `windy` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/windy-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINDY: &str = "windy";
    #[doc(alias = "wine-glass")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wine-glass", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wine-glass", feature = "icon-development-kit"))]
    /// Icon name constant for the `wine-glass` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wine-glass-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINE_GLASS: &str = "wine-glass";
    #[doc(alias = "wine-glasses")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wine-glasses", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wine-glasses", feature = "icon-development-kit"))]
    /// Icon name constant for the `wine-glasses` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wine-glasses-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WINE_GLASSES: &str = "wine-glasses";
    #[doc(alias = "work-week")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "work-week", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "work-week", feature = "icon-development-kit"))]
    /// Icon name constant for the `work-week` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/work-week-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WORK_WEEK: &str = "work-week";
    #[doc(alias = "wrench-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wrench-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "wrench-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `wrench-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/wrench-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WRENCH_FILLED: &str = "wrench-filled";
    #[doc(alias = "wrench-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wrench-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "wrench-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `wrench-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/wrench-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WRENCH_REGULAR: &str = "wrench-regular";
    #[doc(alias = "wrench-wide")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "wrench-wide", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "wrench-wide", feature = "icon-development-kit"))]
    /// Icon name constant for the `wrench-wide` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/wrench-wide-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const WRENCH_WIDE: &str = "wrench-wide";
    #[doc(alias = "x-circular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "x-circular", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "x-circular", feature = "icon-development-kit"))]
    /// Icon name constant for the `x-circular` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/x-circular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const X_CIRCULAR: &str = "x-circular";
    #[doc(alias = "xbox-controller")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "xbox-controller", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "xbox-controller", feature = "icon-development-kit"))]
    /// Icon name constant for the `xbox-controller` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/xbox-controller-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const XBOX_CONTROLLER: &str = "xbox-controller";
    #[doc(alias = "xbox-controller-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "xbox-controller-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "xbox-controller-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `xbox-controller-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/xbox-controller-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const XBOX_CONTROLLER_FILLED: &str = "xbox-controller-filled";
    #[doc(alias = "xbox-controller-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "xbox-controller-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "xbox-controller-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `xbox-controller-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/xbox-controller-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const XBOX_CONTROLLER_REGULAR: &str = "xbox-controller-regular";
    #[doc(alias = "year")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "year", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "year", feature = "icon-development-kit"))]
    /// Icon name constant for the `year` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/year-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const YEAR: &str = "year";
    #[doc(alias = "year-alt")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "year-alt", feature = "icon-development-kit")))
    )]
    #[cfg(any(feature = "year-alt", feature = "icon-development-kit"))]
    /// Icon name constant for the `year-alt` icon.
    ///
    /// Source: `icon-development-kit`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/icon-development-kit/year-alt-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const YEAR_ALT: &str = "year-alt";
    #[doc(alias = "zoom-fit-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "zoom-fit-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "zoom-fit-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `zoom-fit-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/zoom-fit-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ZOOM_FIT_FILLED: &str = "zoom-fit-filled";
    #[doc(alias = "zoom-fit-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "zoom-fit-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "zoom-fit-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `zoom-fit-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/zoom-fit-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ZOOM_FIT_REGULAR: &str = "zoom-fit-regular";
    #[doc(alias = "zoom-in-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "zoom-in-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "zoom-in-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `zoom-in-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/zoom-in-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ZOOM_IN_FILLED: &str = "zoom-in-filled";
    #[doc(alias = "zoom-in-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "zoom-in-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "zoom-in-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `zoom-in-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/zoom-in-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ZOOM_IN_REGULAR: &str = "zoom-in-regular";
    #[doc(alias = "zoom-out-filled")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "zoom-out-filled", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "zoom-out-filled", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `zoom-out-filled` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/zoom-out-filled-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ZOOM_OUT_FILLED: &str = "zoom-out-filled";
    #[doc(alias = "zoom-out-regular")]
    #[cfg_attr(
        docsrs,
        doc(cfg(any(feature = "zoom-out-regular", feature = "fluentui-system-icons")))
    )]
    #[cfg(any(feature = "zoom-out-regular", feature = "fluentui-system-icons"))]
    /// Icon name constant for the `zoom-out-regular` icon.
    ///
    /// Source: `fluentui-system-icons`
    ///
    /// <img alt-name="Icon preview" src="https://raw.githubusercontent.com/Relm4/icons/main/icons/fluentui-system-icons/zoom-out-regular-symbolic.svg" width="64" style="color: #fff;background: #fff;border-radius: 5px;padding: 5px;"/>
    pub const ZOOM_OUT_REGULAR: &str = "zoom-out-regular";
    // END AUTOGENERATED
}
